﻿// =====================================================================================================
//================================= INIT DATABASE ROUTINES =============================================
// =====================================================================================================


var dbVersion = '1.0';
var schemaVersion = '1.0';
var dbSize = 10000000;


var db = window.openDatabase("Garden", dbVersion, "Organic Gardening", dbSize);


checkDatabase();


function checkDatabase() {
   // db 
    // It is our job to make sure the database is up and running and working correctly
    var value = window.localStorage.getItem("dbVersion");

    if (value != schemaVersion) {
            initGardenDB()
    }
}

function initGardenDB()
{
//    var db = window.openDatabase("Garden", dbVersion, "Organic Gardening", 200000);
    db.transaction(populateDB, errorCB, successCB);
}

function errorCB(err) {
    console.log("Error Loading Local Database: " + err.code);
    alert("Database Error: " + err.message + " code " + err.code + ' - Try Rebooting Your Device');
    //alert("Error Loading Local Database: " + err.code);
}

function successCB() {
    window.localStorage.setItem("dbVersion", schemaVersion);
   // alert("DB WAS UPDATED");
}

function populateDB(tx) {
    resetDB(tx)
    createTables(tx);
    populateTable_Plants(tx);
    populateTable_citystate(tx);
}

function resetDB(tx) {
    tx.executeSql('DROP TABLE IF EXISTS CityState');
    tx.executeSql('DROP TABLE IF EXISTS GardenPlants');
    tx.executeSql('DROP TABLE IF EXISTS Gardens');
    tx.executeSql('DROP TABLE IF EXISTS Plants');
}


function createTables(tx) {
    tx.executeSql('DROP TABLE IF EXISTS WeatherData');
    tx.executeSql('CREATE TABLE  WeatherData (RecID int,loccode text,state text, station text, coop text, division text, temp integer, season integer, Prob10 integer, Prob20 integer, Prob30 integer, Prob40 integer, Prob50 integer, Prob60 integer, Prob70 integer, Prob80 integer, Prob90 integer, FreezeYears integer, JulianDay integer, Deviation integer)');

    tx.executeSql('DROP TABLE IF EXISTS Plants');
    tx.executeSql('CREATE TABLE  Plants (PlantID int NOT NULL,PlantType,PlantName text,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes)');

    tx.executeSql('DROP TABLE IF EXISTS CityState');
    tx.executeSql('CREATE TABLE  CityState (COOP text,ST text,COUNTY text, CITY text,lat_dec real,long_dec real, avg_last_spring text, avg_first_fall text, spring10_36 text, spring10_32 text, spring10_28 text, fall90_36 text, fall90_32 text, fall90_28 text, free90_36 text, free90_32 text, free90_28 text)');

    tx.executeSql('CREATE TABLE IF NOT EXISTS Gardens (GardenName text, GardenLocation text)');
    tx.executeSql('CREATE TABLE IF NOT EXISTS GardenPlants (GardenID int, PlantID int, PlantDay int, PlantMonth int, PlantYear int)');
}





function populateTable_Plants(tx) {
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (1,'v','Amaranth','amaranth.png','120-150 seeds','',NULL,'0.125','12-18','','','6','2 to 4','50','50','50','','LSF+2-4 wks','1','2','4','n/a','','','','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (2,'h','Angelica','angelica.png','5 to 10','',NULL,'0','12-24','','','12-24','','','','','','LSF-2 wks','0','2','2','FFF-1-2 wks','0','1','2','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (3,'v','Artichoke','artichocke.png','3 or 4','yes',NULL,'','24-36','','','24-36','8 to 12','85-100','85','100','','LSF-6 wks*','0','6','6','','','','','','Perennial GAA','*plant in coldframe; plant out after LSF')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (4,'v','Arugula','arugula.png','500 seeds','',NULL,'0.25','12','','','6-10','','40-50','40','50','','LSF-4-6 wks','0','4','6','FFF-1-2 wks','0','1','2','yes','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (5,'v','Asparagus','asparagus.png','8 to 15','yes',NULL,'','36-60','yes','','8-14','12 to 14','365','365','365','','','','','','','','','','','Perennial','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (6,'h','Basil','basil.png','100 seeds/8 to20 plants','',NULL,'0.125','12','','','12-18','2 to 6','42-60','42','60','','LSF+2-4 wks','1','2','4','n/a','','','','yes','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (7,'v','Bean, bush','beans.png','20-40 seeds','',NULL,'1-1 1/2','24-30','yes','','3-6','','48-60','48','60','','LSF+1-2 wks','1','1','2','n/a','','','','yes','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (8,'v','Bean, dry','beans.png','20-40 seeds','',NULL,'1-1 1/2','24-30','yes','','3-6','','75-100','75','100','','LSF+1-2 wks','1','1','2','n/a','','','','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (9,'v','Bean, fava','bean-fava.png','20-30 seeds','',NULL,'1','18-36','','','4-6','','75','75','75','','LSF-4-6 wks','0','4','6','FFF-12-13 wks','0','12','13','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (10,'v','Bean, lima','beans-lima.png','30-40 seeds','',NULL,'1','18-36','yes','','3-4','','65-85','62','85','','LSF+2-4 wks','1','2','4','n/a','','','','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (11,'v','Bean, pole','beans.png','12-15 seeds','',NULL,'1-1 1/2','36-48','','yes','10','','62-68','62','68','','LSF+1-2 wks','1','1','2','n/a','','','','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (12,'v','Beet','beet.png','100 seeds','',NULL,'1/2','18','yes','','3','','50-70','50','70','','LSF-2-4 wks','0','2','4','FFF-4-7 wks','0','4','7','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (13,'v','Broccoli','broccoli.png','5','yes',NULL,'0.25','30','','','24','7 to 9','55-75','55','75','','LSF-2 wks','0','2','2','FFF-8-10 wks','0','8','10','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (14,'v','Brussels sprouts','brussels-sprouts.png','5','yes',NULL,'0.25','30','','','18-24','0','90-100','90','100','','','','','','FFF-16 wks','0','16','16','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (15,'v','Cabbage','cabbage.png','4 or 5','yes',NULL,'0.25','30','','','24','8 to 10','65-100','65','100','','LSF-4 wks','0','4','4','FFF-16 wks','0','16','16','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (16,'v','Carrot','carrot.png','300 seeds','',NULL,'0.25','18-24','yes','','2','','50-95','50','95','','LSF-3 wks','0','3','3','n/a','','','','yes','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (17,'v','Cauliflower','cauliflower.png','5','yes',NULL,'0.25','24-36','','','18-24','4 to 6','50-80','50','80','','LSF-2 wks','0','2','2','FFF-16-18 wks','0','16','18','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (18,'v','Celeriac','celeriac.png','12 to 15','yes',NULL,'0.125','24-36','','','8-12','10 to 12','95-100','95','100','','LSF-1-2 wks','0','1','2','n/a','','','','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (19,'v','Celery','celery.png','15','yes',NULL,'0.125','24-36','','','6-12','10 to 12','80-100','80','100','','LSF-1-2 wks','0','1','2','FFF-16-20 wks','0','16','20','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (20,'h','Chamomile (Matricaria recutita)','chamomile.png','12-15','yes',NULL,'1/8','12-18','','','8','8 to 12','60-65','60','65','','LSF-2-3 wks','0','2','3','','','','','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (21,'v','Chard','chard.png','60 seeds','',NULL,'0.5','18-24','yes','','4-6','','50-65','50','65','','LSF-1-2 wks','0','1','2','','','','','yes','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (22,'v','Chinese cabbbage','chinese-cabbage.png','150 seeds','',NULL,'0.25','18-24','','','6-8','','50-70','50','70','','LSF+2-8 wks*','1','2','8','','','','','','','*for fall harvest')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (23,'h','Chervil','chervil.png','100 seeds','',NULL,'0','12-18','','','9-12','','55-60','55','60','','LSF-2-6 wks','0','2','6','FFF-6-8 wks','0','6','8','yes','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (24,'h','Chives','chives.png','100 seeds','yes',NULL,'0.25','12-18','','','4-8','8 to 10','75-85','75','85','','LSF-4-6 wks','0','4','6','','','','','','perennial','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (25,'h','Cilantro','cilantro.png','60 seeds','',NULL,'0.5','','','','4','','50-55','50','55','','LSF+1-2 wks','1','','','','','','','yes','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (26,'v','Collard','collard.png','50 seeds','',NULL,'1/4-1/2','18-30','','','12','','50-60','50','60','','LSF-4 wks','0','4','4','FFF-10-12 wks','0','10','12','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (27,'h','Coriander','coriander.png','60 seeds','',NULL,'0.5','','','','4','','90-105','90','105','','LSF+1-2 wks','1','1','2','','','','','yes','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (28,'v','Corn','corn.png','25 seeds','',NULL,'1-2','30-42','','','12-15','','65-90','65','90','','LSF+2-4 wks','1','2','4','','','','','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (29,'v','Cowpea','cowpea.png','30-60 seeds','',NULL,'1','36-60','yes','','4-6','','60-80','60','80','','LSF+2-4 wks','1','2','4','','','','','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (30,'v','Cucumber','cucumber.png','60 seeds/6-10 plants','',NULL,'1/2-1','60','','yes','8','1 to 2','50-65','50','65','','LSF+1-2 wks','1','1','2','FFF-12-14 wks','0','12','14','yes','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (31,'v','Daikon','daikon.png','60 seeds','',NULL,'1/4-1/2','18','yes','','4-6','','50-60','50','60','','LSF-2-5 wks','0','2','5','FFF-8-12 wks','0','8','12','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (32,'h','Dill','dill.png','100 seeds','',NULL,'0','12-18','','','4-6','','56-70','56','70','','LSF-3-4 wks','0','3','4','','','','','yes','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (33,'v','Edamame','edamame.png','60-100 seeds','',NULL,'1','18-30','yes','','6-8','','75-90','75','90','','LSF+1-2 wks','1','1','2','','','','','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (34,'v','Eggplant','eggplant.png','5 or 6','yes',NULL,'1/4','30-36','','','18','6 to 9','60-70','60','70','','LSF+2-4 wks','1','2','4','','','','','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (35,'v','Endive','endive.png','10','yes',NULL,'1/16','18','','','12','8','40-60','40','60','','LSF-2-4 wks','0','2','4','FFF-12-14 wks','0','12','14','yes','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (36,'v','Fennel','fennel.png','100 seeds','',NULL,'1/16','18','','','6','','65-90','65','90','','LSF-2-4 wks','0','2','4','','','','','yes','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (37,'v','Garlic','garlic.png','20-30 cloves','',NULL,'1 1/2-2','18-24','','','4-6','','300','300','300','','','','','','FFF+0-4 wks*','1','0','4','','perennial','*plant in fall for harvest the following summer')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (38,'v','Horseradish','horseradish.png','5-10 roots','yes',NULL,'5-6','18-30','','','12-18','','150','150','150','','LSF+/-2 wks','2','2','2','','','','','','perennial','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (39,'v','Kale','kale.png','50 seeds','',NULL,'1/4-1/2','18-30','','','12','','50-65','50','65','','LSF-4 wks','0','4','4','FFF-10-12 wks','0','10','12','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (40,'v','Kohlrabi','kohlrabi.png','100-120 seeds','',NULL,'1/4','12-18','','','3-6','','40-75','40','75','','LSF-4-6 wks','0','4','6','FFF-2-4 wks','0','2','4','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (41,'v','Leek','leek.png','60-100','',NULL,'1/4-1/2','24','','','6','10-12','70-100','70','100','','LSF+/-2-4 wks','2','2','4','','','','','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (42,'v','Lettuce','lettuce.png','200-500 seeds','',NULL,'1/8','12-18','yes','','6','6','40-70','40','70','','LSF-3-4 wks','0','3','4','FFF-9-12 wks','0','9','12','yes','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (43,'h','Marjoram','marjoram.png','10-15','yes',NULL,'0','12-18','','','6-8','6-8','80-95','80','95','','LSF+2 wks','1','2','2','','','','','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (44,'v','Melons','mellons.png','3-6','',NULL,'1','48-72','','yes','8','1-2','75-90','75','90','','LSF+3 wks','1','3','3','','','','','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (45,'h','Mustard','mustard.png','100-150 seeds','',NULL,'1/4-1/2','24','','','6-10','','35-70','35','70','','LSF-4 wks','0','4','4','FFF-4 wks','0','4','4','yes','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (46,'v','Okra','okra.png','60 seeds','',NULL,'1/2-1','36','yes','','12-18','0-1','50-65','50','65','','LSF+5 wks','1','5','5','','','','','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (47,'v','Onion sets','onion-set.png','100','no',NULL,'1','18','yes','','3','','63-70','63','70','','LSF-6 wks','0','6','6','','','','','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (48,'v','Onion','onion.png','30-40','yes',NULL,'1/4','12-18','yes','','4-6','6-8','90-105','90','105','','LSF-4 wks','0','4','4','','','','','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (49,'h','Oregano','oregano.png','5-10','yes',NULL,'0','12-18','','','10-12','8-10','80-90','80','90','','LSF+0 wks','1','0','0','','','','','','perennial','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (50,'h','Parsley','parsley.png','250 seeds','',NULL,'1/4','12-18','','','6-12','8','56-70','56','70','','LSF-4 wks','0','4','4','','','','','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (51,'v','Parsnip','parsnip.png','250 seeds','',NULL,'1/2-1','18-24','yes','','3','','80-120','80','120','','LSF+0-2 wks','1','0','2','','','','','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (52,'v','Pea','pea.png','350 seeds','',NULL,'1-2','30','yes','','3','','56-75','56','75','','LSF-4-6 wks','0','4','6','FFF-12-14 wks','0','12','14','yes','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (53,'v','Pepper','pepper.png','6','yes',NULL,'1/4','30','','','20','4','55-65','55','65','','LSF+4 wks','1','4','4','','','','','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (54,'v','Potato tubers','potato.png','5-10 tubers','no',NULL,'3','36','yes','','12','','70-90','70','90','','LSF-4 wks','0','4','4','','','','','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (55,'v','Pumpkin','pumpkin.png','10-15 seeds','',NULL,'1','72','','yes','12','LSF+2','85-110','85','110','','LSF+5 wks','1','5','5','FFF-14 wks','0','14','14','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (56,'v','Radish','radish.png','100-300 seeds','',NULL,'1/2','18','yes','','2-3','','21-50','21','50','','LSF-5 wks','0','5','5','FFF-10-12 wks','0','10','12','yes','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (57,'v','Rhubarb','rhubarb.png','3 or 4 crowns','',NULL,'','72','','','36-48','','365-700','365','700','','LSF+/-2 wks','2','2','2','','','','','','perennial','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (58,'h','Rosemary','rosemary.png','8-10','yes',NULL,'','','yes','','12-18','12-14','80-180','80','180','','LSF+0-2 wks','1','0','2','','','','','','perennial','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (59,'v','Rutabaga','rutabaga.png','60 seeds','',NULL,'3/8','18-24','','','6','','95-100','95','100','','','','','','FFF-15-20 wks','0','15','20','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (60,'h','Sage','sage.png','8-10','yes',NULL,'','12-18','','','12','6-8','80-90','80','90','','LSF+2 wks','1','2','2','','','','','','perennial','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (61,'h','Scallion','scallions.png','250 seeds','',NULL,'1/2','12-18','','','8','5-6','50-70','50','70','','LSF-2 wks','0','2','2','FFF-12-16 wks','0','12','16','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (62,'v','Shallot','shallot.png','250-500 seeds','',NULL,'1/2','12-18','','','1-3','','100-110','100','110','','LSF-2 wks','0','2','2','','','','','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (63,'h','Sorrel','sorrel.png','100-150 seeds','',NULL,'1/8-1/4','12-18','','','8','2-4','55-60','55','60','','LSF+/-0-2 wks','2','0','2','','','','','','perennial','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (64,'v','Spinach','spinach.png','90-100 seeds','',NULL,'1/2','18','yes','','3','','37-45','37','45','','LSF-4-6 wks','0','4','6','FFF-8-10 wks','0','8','10','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (65,'v','Squash, summer','squash-summer-zucchini.png','20-30 seeds','',NULL,'1/2-1','48','','yes','8','1','45-50','45','50','','LSF+3-4 wks','1','3','4','','','','','yes','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (66,'v','Squash, winter','squash-winter-butternut.png','20-30 seeds','',NULL,'3/4','72','','yes','12','1','85-110','85','110','','LSF+5 wks','1','5','5','FFF-14 wks','0','14','14','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (67,'v','Strawberry','strawberries.png','10','yes',NULL,'','12','','','12','','120-365','120','365','','LSF-4-6 wks','0','4','6','','','','','','perennial','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (68,'v','Sweet corn','sweetcorn.png','25 seeds','',NULL,'1-2','30-42','','','12-15','','65-90','65','90','','LSF+2-4 wks','1','2','4','','','','','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (69,'v','Sweet potatoes','sweet-potato.png','10 slips','',NULL,'','36','yes','','12','','70-100','70','100','','LSF+3-4 wks','1','3','4','','','','','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (70,'h','Thyme','thyme.png','10-15','yes',NULL,'0','12-18','','','6-8','6-8','90-95','90','95','','LSF-2-3 wks','0','2','3','','','','','','perennial','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (71,'v','Tomatillo','tomatillo.png','4','yes',NULL,'','24-36','','','24-36','6-8','60-70','60','70','','LSF+4-5 wks','1','4','5','','','','','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (72,'v','Tomato','tomato.png','4','yes',NULL,'0','40','','','30','4-6','56-80','56','80','','LSF+3-4 wks','1','3','4','','','','','','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (73,'v','Turnip','turnip.png','100-300 seeds','',NULL,'1/4-1/2','12-18','yes','','2-3','','38-50','38','50','','LSF-5 wks','0','5','5','FFF-10-12 wks','0','10','12','yes','','')");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (78,'f','Ageratum (Ageratum houstonianum)','ageratum.png',NULL,NULL,'SI','0','9-12',NULL,NULL,NULL,'6-8','80-100',NULL,NULL,NULL,' LSF+0-1','1','0','1','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (79,'f','Alyssum (Lobularia maritima)','alyssum.png',NULL,NULL,'direct-sow','0','6',NULL,NULL,NULL,'','50-85',NULL,NULL,NULL,'LSF-2-3','0','2','3','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (80,'f','Agastaches (Agastache spp.)','agastaches.png',NULL,NULL,'SI','0','12-24',NULL,NULL,NULL,'8-12','90-120',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (81,'f','China aster (Callistephus chinensis)','china-aster.png',NULL,NULL,'either','  1/16','6-12',NULL,NULL,NULL,'6-8','70-110',NULL,NULL,NULL,'LSF+2','1','2','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (82,'f','Baby-blue-eyes (Nemophila menziesii)','baby-blue-eyes.png',NULL,NULL,'either','  1/8','6',NULL,NULL,NULL,'8-10','55-80',NULL,NULL,NULL,'LSF+0-1','1','0','1','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (83,'f','Garden balsam (Impatiens balsaminea)','garden_balsam.png',NULL,NULL,'either','  1/16','10',NULL,NULL,NULL,'6-8','50-65',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (84,'f','Bee balm (Monarda didyma)','bee-balm.png',NULL,NULL,'SI','  1/4','10-12',NULL,NULL,NULL,'6-8','300-365',NULL,NULL,NULL,'LSF+0-1','1','0','1','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (85,'f','Wax begonia (Begonia semperflorens-cultorum)','wax_begonia.png',NULL,NULL,'SI','0','6-10',NULL,NULL,NULL,'8','65-70',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (86,'f','Bells of Ireland (Moluccella laevis)','bells-of-ireland.png',NULL,NULL,'direct-sow','  1/16','10-12',NULL,NULL,NULL,'','90-110',NULL,NULL,NULL,'LSF-2-4','0','2','4','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (87,'f','Black-eyed Susan (Rudbeckia hirta)','black-eyed-susan.png',NULL,NULL,'either','0','12-18',NULL,NULL,NULL,'8-10','100-120',NULL,NULL,NULL,'LSF+/-2','2','2','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (88,'f','Blanket flower (Gaillardia x grandiflora)','blanket_flower.png',NULL,NULL,'direct-sow','  1/4','12',NULL,NULL,NULL,'','100-120',NULL,NULL,NULL,'LSF-4-6','0','4','6','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (89,'f','Butterfly bush (Buddleia davidii)','butterfly-bush.png',NULL,NULL,'SI','0','36-72',NULL,NULL,NULL,'10-12','85-90',NULL,NULL,NULL,'LSF+2','1','2','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (90,'f','Butterfly weed (Asclepias tuberosa)','butterfly-weed.png',NULL,NULL,'SI','','12-24',NULL,NULL,NULL,'10-12','90',NULL,NULL,NULL,'LSF+0-1','1','0','1','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (91,'f','California poppy (Eschscholzia californica)','california-poppy.png',NULL,NULL,'direct-sow','  1/4','6',NULL,NULL,NULL,'','55-60',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (92,'f','Calliopsis (Coreopsis tinctoria)','calliopsis.png',NULL,NULL,'either','  1/4','8',NULL,NULL,NULL,'6-8','60-80',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (93,'f','Canterbury bells (Campanula medium)','canterbury-bells.png',NULL,NULL,'SI','0','10',NULL,NULL,NULL,'6-10','150-300',NULL,NULL,NULL,'LSF+0-1','1','0','1','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (94,'f','Cardinal climber (Ipomoea x multifida)','cardinal_climber.png',NULL,NULL,'direct-sow','  1/2','12',NULL,NULL,NULL,'','75',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (95,'f','Castor bean (Ricinus communis)','castor_bean.png',NULL,NULL,'either','1','36-48',NULL,NULL,NULL,'6-8','80-90',NULL,NULL,NULL,'LSF+1','1','1','1','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (96,'f','Wheat celosia (Celosia spicata)','wheat_celosia.png',NULL,NULL,'SI','0','6-12',NULL,NULL,NULL,'6-8','60-80',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (97,'f','Cockscomb (Celosia cristata)','cockscomb.png',NULL,NULL,'SI','0','12-18',NULL,NULL,NULL,'6-8','90-120',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (98,'f','Coleus (Solenostemon scuttellarioides, formerly Coleus x hybridus)','coleus.png',NULL,NULL,'SI','0','9-12',NULL,NULL,NULL,'8','45',NULL,NULL,NULL,'LSF+2','1','2','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (99,'f','Columbines (Aquilegia spp.)','columbines.png',NULL,NULL,'direct-sow','0','6-12',NULL,NULL,NULL,'','365',NULL,NULL,NULL,'','','','','FFF-4-8','0','4','8',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (100,'f','Orange coneflower (Rudbeckia fulgida)','orange-coneflower.png',NULL,NULL,'SI','  1/2','12-24',NULL,NULL,NULL,'12-16','300-365',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (101,'f','Purple coneflower (Echinacea purpurea)','coneflower-purple.png',NULL,NULL,'SI','  1/2','12-24',NULL,NULL,NULL,'8-10','110',NULL,NULL,NULL,'LSF+0-1','1','0','1','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (102,'f','Corn cockle (Agrostemma githago)','corn-cockle.png',NULL,NULL,'direct-sow','  1/8','6-9',NULL,NULL,NULL,'','90-100',NULL,NULL,NULL,'LSF-1-2','0','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (103,'f','Cornflower (Centaurea cyanus)','cornflower.png',NULL,NULL,'direct-sow','  1/8','6-9',NULL,NULL,NULL,'','85-95',NULL,NULL,NULL,'LSF-4-6','0','4','6','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (104,'f','Cosmos (Cosmos bipinnatus)','cosmos.png',NULL,NULL,'direct-sow','1/4-1/2','9-12',NULL,NULL,NULL,'','75-120',NULL,NULL,NULL,'LSF+0-1','1','0','1','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (105,'f','Yellow cosmos (Cosmos sulphureus)','yellow_cosmos.png',NULL,NULL,'direct-sow','1/4-1/2','9-12',NULL,NULL,NULL,'','85',NULL,NULL,NULL,'LSF+0-1','1','0','1','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (106,'f','Cypress vine (Ipomoea quamoclit)','cypress.png',NULL,NULL,'direct-sow','  1/2','12',NULL,NULL,NULL,'','75',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (107,'f','Dahlias (Dahlia spp.)','dahlia.png',NULL,NULL,'SI','  1/4','12-18',NULL,NULL,NULL,'8-10','150-160',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (108,'f','Swan River daisy (Brachycome iberidifolia)','swan_river_daisy.png',NULL,NULL,'SI','0','9-12',NULL,NULL,NULL,'8-10','70-80',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (109,'f','Delphinium (Delphinium x belladonna)','delphinium.png',NULL,NULL,'SI','  1/8','12-18',NULL,NULL,NULL,'10-16','100-125',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (110,'f','Evening primroses (Oenothera spp.)','evening-primrose.png',NULL,NULL,'either','0','12-24',NULL,NULL,NULL,'8','150-300',NULL,NULL,NULL,'LSF-4','','','','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (111,'f','Flowering tobacco (Nicotiana alata)','flowering_tobacco.png',NULL,NULL,'SI','0','9-12',NULL,NULL,NULL,'6-8','75',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (112,'f','Garden forget-me-not (Myosotis sylvatica)','garden-forget-me-not.png',NULL,NULL,'either','0','6',NULL,NULL,NULL,'8-9','365',NULL,NULL,NULL,'LSF+/-2','2','2','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (113,'f','Summer forget-me-not (Anchusa capensis)','summer_forget_me_not.png',NULL,NULL,'either','  1/16','12',NULL,NULL,NULL,'10-12','365',NULL,NULL,NULL,'LSF+2','1','2','2','FFF-2-4*','0','2','4',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (114,'f','Four-o’clock (Mirabilis jalapa)','four-oclock.png',NULL,NULL,'either','  1/4','14',NULL,NULL,NULL,'6-8','56-80',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (115,'f','Common foxglove (Digitalis purpurea)','common-foxglove.png',NULL,NULL,'SI','0','12',NULL,NULL,NULL,'10-12','120-140',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (116,'f','Gazania (Gazania rigens)','gazania.png',NULL,NULL,'either','  1/8','6-8',NULL,NULL,NULL,'6-8','60-80',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (117,'f','Zonal geranium (Pelargonium x hortorum)','zonal-geranium.png',NULL,NULL,'SI','  1/4','10-12',NULL,NULL,NULL,'12-16','120-150',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (118,'f','Globe amaranth (Gomphrena globosa)','globe-amaranth.png',NULL,NULL,'SI','  1/16','6-8',NULL,NULL,NULL,'6-8','85-100',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (119,'f','Gloriosa daisy (Rudbeckia hirta ‘Gloriosa Daisy’)','gloriosa-daisy.png',NULL,NULL,'SI','0','12',NULL,NULL,NULL,'8-10','100-120',NULL,NULL,NULL,'LSF+/-2','2','2','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (120,'f','Hollyhock (Alcea rosea)','hollyhock.png',NULL,NULL,'either','0','12-24',NULL,NULL,NULL,'8-10','365',NULL,NULL,NULL,'LSF+1-2','1','1','2','FFF-4-8*','0','4','8',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (121,'f','Hyacinth bean (Dolichos lablab)','hyacinth-bean.png',NULL,NULL,'either','1','12',NULL,NULL,NULL,'4-6','100-120',NULL,NULL,NULL,'LSF+2','1','2','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (122,'f','Impatiens (Impatiens wallerana)','impatiens.png',NULL,NULL,'SI','0','8-12',NULL,NULL,NULL,'8-10','56-80',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (123,'f','Johnny-jump-up (Viola tricolor)','johnny-jump-up.png',NULL,NULL,'SI','  1/16','6-9',NULL,NULL,NULL,'8-12','60-70',NULL,NULL,NULL,'LSF-1-2','0','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (124,'f','Joseph’s-coat (Amaranthus tricolor)','josephs_coat.png',NULL,NULL,'either','  1/8','6-12',NULL,NULL,NULL,'4-6','80-100',NULL,NULL,NULL,'LSF+0-1','1','0','1','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (125,'f','Kiss-me-over-the-garden-gate (Polygonum orientale)','kiss_me_over.png',NULL,NULL,'SI','  1/16','18-24',NULL,NULL,NULL,'8-10','100-110',NULL,NULL,NULL,'LSF-1-2','0','1','2','FFF+0-2*','1','0','2',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (126,'f','Candle larkspur (Delphinium elatum)','candle-larkspur.png',NULL,NULL,'SI','  1/8','12-18',NULL,NULL,NULL,'10-16','100-125',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (127,'f','Rocket larkspur (Consolida ambigua)','rocket_larkspur.png',NULL,NULL,'direct-sow','  1/4','4-6',NULL,NULL,NULL,'','100-120',NULL,NULL,NULL,'LSF-4-6','0','4','6','FFF-2*','0','2','2',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (128,'f','Lavender (Lavandula spp. )','lavender.png',NULL,NULL,'SI','  1/8','12-18',NULL,NULL,NULL,'12-16','100-365',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (129,'f','Lobelia (Lobelia erinus)','lobelia.png',NULL,NULL,'SI','0','6',NULL,NULL,NULL,'10-12','60-75',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (130,'f','Love-in-a-mist (Nigella damascena)','love-in-a-mist.png',NULL,NULL,'direct-sow','  1/8','6-9',NULL,NULL,NULL,'','63-85',NULL,NULL,NULL,'LSF-1-2','0','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (131,'f','Love-lies-bleeding (Amaranthus caudatus)','love-lies-bleeding.png',NULL,NULL,'either','  1/8','12-15',NULL,NULL,NULL,'4-6','80-100',NULL,NULL,NULL,'LSF+0-1','1','0','1','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (132,'f','Lupines (Lupinus spp.)','lupine_bluebonnet.png',NULL,NULL,'SI','  1/2','18-24',NULL,NULL,NULL,'6-8','365',NULL,NULL,NULL,'LSF-4','0','4','4','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (133,'f','Marigolds (Tagetes spp.)','marigold.png',NULL,NULL,'either','  1/16','8-18',NULL,NULL,NULL,'6-8','50-90',NULL,NULL,NULL,'LSF+0-1','1','0','1','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (134,'f','Moonflower (Ipomoea spp.)','moonflower.png',NULL,NULL,'direct-sow','  1/2','12',NULL,NULL,NULL,'','80-100',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (135,'f','Morning glories (Ipomoea spp.)','morning-glory.png',NULL,NULL,'direct-sow','  1/2','12',NULL,NULL,NULL,'','45-110',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (136,'f','Nasturtium (Tropaeolum majus)','nasturtium.png',NULL,NULL,'direct-sow','  1/2','12-36',NULL,NULL,NULL,'','55-65',NULL,NULL,NULL,'LSF-1-2','0','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (137,'f','Pansy (Viola x wittrockiana)','pansy.png',NULL,NULL,'SI','  1/8','6-9',NULL,NULL,NULL,'10-14','90-110',NULL,NULL,NULL,'LSF-1-2','0','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (138,'f','Common garden petunia (Petunia x hybrida)','common-garden-petunia.png',NULL,NULL,'SI','0','12',NULL,NULL,NULL,'8-10','55-70',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (139,'f','Annual phlox (Phlox drummondii)','annual_phlox.png',NULL,NULL,'direct-sow','  1/8','8-12',NULL,NULL,NULL,'','50-65',NULL,NULL,NULL,'LSF-4-6','0','4','6','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (140,'f','Pincushion flower (Scabiosa atropurpurea)','pincushion_flower.png',NULL,NULL,'SI','0','9-15',NULL,NULL,NULL,'4-6','75-80',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (141,'f','Corn poppy (Papaver rhoeas)','corn-poppy.png',NULL,NULL,'direct-sow','  1/4','6-8',NULL,NULL,NULL,'','55-65',NULL,NULL,NULL,'LSF-4-6','0','4','6','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (142,'f','Iceland poppy (Papaver nudicaule)','iceland-poppy.png',NULL,NULL,'either','0','10-12',NULL,NULL,NULL,'6-8','100',NULL,NULL,NULL,'LSF+/-2','2','2','2','FFF+0-2*','1','0','2',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (143,'f','Pot marigold (Calendula officinalis)','pot-marigold.png',NULL,NULL,'direct-sow','  1/4','6-12',NULL,NULL,NULL,'','50-60',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (144,'f','Rose moss (Portulaca grandiflora)','rose-moss.png',NULL,NULL,'direct-sow','  1/4','12',NULL,NULL,NULL,'','65-70',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (145,'f','Scarlet runner bean (Phaseolus coccineus)','scarlett-runner-bean.png',NULL,NULL,'either','1','4-8',NULL,NULL,NULL,'2-3','45-55',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (146,'f','Mealycup sage (Salvia farinacea)','mealycup-sage.png',NULL,NULL,'SI','  1/4','12',NULL,NULL,NULL,'6-8','90-120',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (147,'f','Scarlet sage (Salvia splendens)','scarlet-sage.png',NULL,NULL,'SI','0','12',NULL,NULL,NULL,'8-10','75-90',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (148,'f','Texas sage (Salvia coccinea)','texas_sage.png',NULL,NULL,'SI','  1/4','12-18',NULL,NULL,NULL,'8-10','60-70',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (149,'f','Violet sage (Salvia x superba)','violet-sage.png',NULL,NULL,'SI','  1/4','12-18',NULL,NULL,NULL,'12-16','120-150',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (150,'f','Salpiglossis (Salpiglossis sinuata','salpiglossis.png',NULL,NULL,'SI','  1/8','8-12',NULL,NULL,NULL,'4-6','65-75',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (151,'f','Snapdragons (Antirrhinum spp.)','snapdragons.png',NULL,NULL,'SI','0','9-12',NULL,NULL,NULL,'8-10','100-120',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (152,'f','Snow-on-the-mountain (Euphorbia marginata)','snow_on_the_mountain.png',NULL,NULL,'either','  1/4','6-9',NULL,NULL,NULL,'4-6','100-120',NULL,NULL,NULL,'LSF+0-1','1','0','1','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (153,'f','Spiderflower (Cleome hassleriana)','spiderflower.png',NULL,NULL,'direct-sow','0','12-36',NULL,NULL,NULL,'','75',NULL,NULL,NULL,'LSF+0-1','1','0','1','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (154,'f','Statice (Limonium sinuatum)','statice.png',NULL,NULL,'SI','0','12',NULL,NULL,NULL,'8','110-120',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (155,'f','Stock (Matthiola incana)','stock.png',NULL,NULL,'either','0','10-15',NULL,NULL,NULL,'6-8','100-115',NULL,NULL,NULL,'LSF-1-2','0','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (156,'f','Sunflowers (Helianthus spp.)','sunflower.png',NULL,NULL,'direct-sow','1/2-1','24-48',NULL,NULL,NULL,'','60-100',NULL,NULL,NULL,'LSF+0-1','1','0','1','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (157,'f','Sweet pea (Lathyrus odorata)','sweet-pea.png',NULL,NULL,'direct-sow','1  1/2','6-12',NULL,NULL,NULL,'','65-90',NULL,NULL,NULL,'LSF-4-6','0','4','6','FFF+0-2*','1','0','2',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (158,'f','Sweet William (Dianthus barbatus)','sweet-william.png',NULL,NULL,'SI','  1/4','6-12',NULL,NULL,NULL,'10-12','90-120',NULL,NULL,NULL,'LSF-1-2','0','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (159,'f','Mexican sunflower (Tithonia rotundifolia)','mexican-sunflower.png',NULL,NULL,'direct-sow','0','24',NULL,NULL,NULL,'','100-120',NULL,NULL,NULL,'LSF+2','1','2','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (160,'f','Red valerian (Centranthus ruber)','red-valerian.png',NULL,NULL,'either','  1/16','24-30',NULL,NULL,NULL,'8-10','150-300',NULL,NULL,NULL,'LSF-4','0','4','4','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (161,'f','Garden verbena (Verbena x hybrida)','garden-verbena.png',NULL,NULL,'either','1/8','10-12',NULL,NULL,NULL,'6-8','55-80',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (162,'f','Sweet violet (Viola odorata)','sweet-violet.png',NULL,NULL,'SI','1/16','6-9',NULL,NULL,NULL,'12-16','120-150',NULL,NULL,NULL,'LSF-1-2','0','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (163,'f','Yarrows (Achillea spp.)','yarrow.png',NULL,NULL,'SI','0','12-18',NULL,NULL,NULL,'8-12','120',NULL,NULL,NULL,'LSF+0-1','1','0','1','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (164,'f','Creeping zinnia (Sanvitalia procumbens)','creeping-zinnia.png',NULL,NULL,'direct-sow','  1/4','12',NULL,NULL,NULL,'','63-77',NULL,NULL,NULL,'LSF-1-2','0','1','2','','','','',NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO Plants (PlantID,PlantType,PlantName,ImageName,SeedAmt,Recommended,IndoorsorSow,PlantingDepth,DistanceRows,RaisedRows,RaisedHills,ThinningDistance,LSFIndoors,FirstHarvest,FirstHarvestMin,FirstHarvestMax,LastHarvest,SpringSow,SpringSowType,SpringSowMin,SpringSowMax,FallSow,FallSowType,FallSowMin,FallSowMax,MultipleSow,Perennial,Notes) VALUES (165,'f','Zinnias (Zinnia spp.)','zinnia.png',NULL,NULL,'either','1/8','9-12',NULL,NULL,NULL,'4','50-90',NULL,NULL,NULL,'LSF+1-2','1','1','2','','','','',NULL,NULL,NULL)");
}

function populateTable_citystate(tx) {

    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900001','BC',NULL,'Port Alberni',4.925000000000000e+001,1.248000000000000e+002,'5/8','10/15',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900002','BC',NULL,'Prince George',5.391666700000000e+001,1.227666670000000e+002,'6/4','9/3',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900003','BC',NULL,'Prince Rupert',5.430000000000000e+001,1.303000000000000e+002,'5/9','10/13',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900004','BC',NULL,'Vancouver',4.925000000000000e+001,1.231000000000000e+002,'5/28','11/5',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900005','BC',NULL,'Victoria',4.841666700000000e+001,1.233500000000000e+002,'4/19','11/5',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900006','MB',NULL,'Brandon',4.983333300000000e+001,9.995000000000000e+001,'5/27','9/10',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900007','MB',NULL,'Lynn Lake',5.683333300000000e+001,1.010833330000000e+002,'6/8','9/6',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900008','MB',NULL,'The Pas',5.381666700000000e+001,1.012333330000000e+002,'5/27','9/17',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900009','MB',NULL,'Thompson',5.573333300000000e+001,9.784999999999999e+001,'6/15','8/16',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900010','MB',NULL,'Winnipeg',4.988333300000000e+001,9.713333299999999e+001,'5/25','9/22',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900011','NB',NULL,'Bathurst',4.761666700000000e+001,6.563333299999999e+001,'5/13','9/26',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900012','NB',NULL,'Edmundston',4.736666700000000e+001,6.831666700000000e+001,'5/28','9/18',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900013','NB',NULL,'Fredericton',4.595000000000000e+001,6.663333299999999e+001,'5/20','9/22',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900014','NB',NULL,'Moncton',4.608333300000000e+001,6.476666700000000e+001,'5/24','9/27',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900015','NB',NULL,'Saint John',4.526666700000000e+001,6.605000000000000e+001,'5/18','10/4',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900016','NL',NULL,'Corner Brook',4.895000000000000e+001,5.793333300000000e+001,'5/22','10/12',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900017','NL',NULL,'Gander',4.895000000000000e+001,5.460000000000000e+001,'6/3','10/5',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900018','NL',NULL,'Grand Falls',4.893333300000000e+001,5.563333300000000e+001,'6/2','9/26',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900019','NL',NULL,'St. John''s',4.755000000000000e+001,5.270000000000000e+001,'6/2','10/12',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900020','NS',NULL,'Halifax',4.463333300000000e+001,6.356666700000000e+001,'5/6','10/20',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900021','NS',NULL,'Kentville',4.506666700000000e+001,6.448333300000000e+001,'5/16','10/5',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900022','NS',NULL,'Sydney',4.613333300000000e+001,6.018333300000000e+001,'5/24','10/13',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900023','NS',NULL,'Truro',4.535000000000000e+001,6.328333300000000e+001,'5/30','9/21',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900024','NS',NULL,'Yarmouth',4.383333300000000e+001,6.609999999999999e+001,'5/1','10/18',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900025','NT',NULL,'Aklavik',6.821666700000000e+001,1.350000000000000e+002,'6/13','8/30',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900026','NT',NULL,'Fort Simpson',6.181666700000000e+001,1.213000000000000e+002,'6/3','8/24',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900027','NT',NULL,'Yellowknife',6.245000000000000e+001,1.143666670000000e+002,'5/27','9/15',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900028','ON',NULL,'Barrie',4.436666700000000e+001,7.970000000000000e+001,'5/26','9/16',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900029','ON',NULL,'Hamilton',4.323333300000000e+001,7.988333299999999e+001,'4/29','10/15',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900030','ON',NULL,'Kapuskasing',4.940000000000000e+001,8.241666700000000e+001,'6/12','9/8',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900031','ON',NULL,'Kingston',4.421666700000000e+001,7.648333300000000e+001,'5/2','10/10',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900032','ON',NULL,'Kitchener',4.343333300000000e+001,8.046666700000000e+001,'5/11','9/29',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900033','ON',NULL,'London',4.296666700000000e+001,8.123333300000000e+001,'5/9','10/8',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900034','ON',NULL,'Ottawa',4.541666700000000e+001,7.568333300000001e+001,'5/9','10/5',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900035','ON',NULL,'Owen Sound',4.456666700000000e+001,8.093333300000001e+001,'5/12','10/15',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900036','ON',NULL,'Peterborough',4.430000000000000e+001,7.831666700000000e+001,'5/18','9/20',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900037','ON',NULL,'Sudbury',4.648333300000000e+001,8.100000000000000e+001,'5/17','9/25',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900038','ON',NULL,'Thunder Bay',4.840000000000000e+001,8.926666700000000e+001,'6/1','9/15',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900039','ON',NULL,'Timmins',4.846666700000000e+001,8.131666700000000e+001,'6/8','9/6',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900040','ON',NULL,'Toronto',4.365000000000000e+001,7.936666700000001e+001,'5/9','10/6',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900041','ON',NULL,'Windsor',4.228333300000000e+001,8.298333300000000e+001,'4/25','10/22',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900042','PE',NULL,'Charlottetown',4.623333300000000e+001,6.311666700000000e+001,'5/17','1/14',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900043','PE',NULL,'Summerside',4.638333300000000e+001,6.378333300000000e+001,'5/9','10/19',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900044','PE',NULL,'Tignish',4.695000000000000e+001,6.401666700000000e+001,'5/23','10/9',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900045','QC',NULL,'Baie Comeau',4.921666700000000e+001,6.820000000000000e+001,'5/28','9/15',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900046','QC',NULL,'Chicoutimi',4.841666700000000e+001,7.105000000000000e+001,'5/17','9/30',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900047','QC',NULL,'Montreal',4.550000000000000e+001,7.355000000000000e+001,'5/3','10/7',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900048','QC',NULL,'Quebec',4.680000000000000e+001,7.123333300000000e+001,'5/13','9/29',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900049','QC',NULL,'Rimouski',4.841666700000000e+001,6.851666700000000e+001,'5/13','9/30',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900050','QC',NULL,'Sherbrooke',4.540000000000000e+001,7.188333299999999e+001,'6/1','9/10',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900051','QC',NULL,'Tadoussac',4.813333300000000e+001,6.970000000000000e+001,'5/13','10/2',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900052','QC',NULL,'Thetford Mines',4.608333300000000e+001,7.130000000000000e+001,'5/28','9/14',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900053','QC',NULL,'Trois-Rivières',4.633333300000000e+001,7.253333300000000e+001,'5/19','9/23',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900054','SK',NULL,'Moose Jaw',5.038333300000000e+001,1.055500000000000e+002,'5/20','9/18',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900055','SK',NULL,'North Battleford',5.276666700000000e+001,1.082833330000000e+002,'5/19','9/17',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900056','SK',NULL,'Prince Albert',5.320000000000000e+001,1.057500000000000e+002,'6/2','9/4',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900057','SK',NULL,'Regina',5.045000000000000e+001,1.046000000000000e+002,'5/21','9/10',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900058','SK',NULL,'Saskatoon',5.213333300000000e+001,1.066333330000000e+002,'5/21','9/15',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900059','SK',NULL,'Weyburn',4.965000000000000e+001,1.038500000000000e+002,'5/22','9/12',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900060','SK',NULL,'Yorkton',5.120000000000000e+001,1.024500000000000e+002,'5/23','9/11',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900061','YT',NULL,'Dawson',6.405000000000000e+001,1.394166670000000e+002,'6/13','8/17',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900062','YT',NULL,'Watson Lake',6.005000000000000e+001,1.287000000000000e+002,'6/2','9/4',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('147271','KS','SCOTT','SCOTT CITY',3.848194444000000e+001,-1.009188890000000e+002,'05/15','10/23','05/25','05/15','05/04','10/16','10/23','11/04','0126','0142','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('147305','KS','CHAUTAUQUA','SEDAN',3.713166666000000e+001,-9.618611100000000e+001,'04/23','11/10','05/10','04/23','04/16','10/27','11/10','11/24','0149','0170','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('147397','KS','WALLACE','SHARON SPRINGS',3.889611111000000e+001,-1.017513890000000e+002,'05/16','10/23','05/23','05/16','05/04','10/12','10/23','11/03','0123','0138','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('147542','KS','SMITH','SMITH CTR',3.977722222000000e+001,-9.877833300000000e+001,'05/06','10/26','05/13','05/06','04/21','10/13','10/26','11/04','0133','0149','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('147796','KS','RICE','STERLING',3.821444444000000e+001,-9.820777800000001e+001,'04/26','11/05','05/08','04/26','04/14','10/24','11/05','11/20','0146','0167','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('147922','KS','HASKELL','SUBLETTE 7WSW',3.744138888000000e+001,-1.009791670000000e+002,'05/07','10/30','05/14','05/07','04/25','10/20','10/30','11/09','0137','0152','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('148038','KS','HAMILTON','SYRACUSE 1NE',3.799277777000000e+001,-1.017416670000000e+002,'05/14','10/18','05/23','05/14','05/04','10/09','10/18','10/27','0121','0135','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('148167','KS','SHAWNEE','TOPEKA ASOS',3.907250000000000e+001,-9.562611100000000e+001,'05/03','10/27','05/14','05/03','04/16','10/18','10/27','11/15','0134','0154','0188')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('148235','KS','GREELEY','TRIBUNE 1W',3.846611111000000e+001,-1.017758330000000e+002,'05/21','10/19','05/25','05/21','05/12','10/07','10/19','10/27','0119','0130','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('148250','KS','DONIPHAN','TROY 3N',3.982833333000000e+001,-9.508805600000000e+001,'04/27','10/29','05/08','04/27','04/18','10/14','10/29','11/09','0142','0157','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('148259','KS','RILEY','TUTTLE CREEK LAKE',3.924750000000000e+001,-9.659944400000001e+001,'05/09','10/27','05/18','05/09','04/25','10/12','10/27','11/06','0128','0146','0173')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('148287','KS','GRANT','ULYSSES 3NE',3.759833333000000e+001,-1.012908330000000e+002,'05/09','10/24','05/16','05/09','04/25','10/16','10/24','11/07','0132','0145','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('148495','KS','TREGO','WAKEENEY',3.902972222000000e+001,-9.988305600000000e+001,'05/06','10/28','05/15','05/06','04/25','10/17','10/28','11/09','0131','0151','0176')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('148563','KS','POTTAWATOMIE','WAMEGO 4 W',3.921416666000000e+001,-9.637027800000000e+001,'05/01','11/01','05/15','05/01','04/20','10/20','11/01','11/14','0131','0156','0177')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('148578','KS','WASHINGTON','WASHINGTON',3.980888888000000e+001,-9.705500000000001e+001,'05/08','10/26','05/17','05/08','04/24','10/11','10/26','11/07','0130','0151','0177')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('148648','KS','ROOKS','WEBSTER DAM',3.940305555000000e+001,-9.941916700000000e+001,'05/10','10/25','05/17','05/10','04/27','10/10','10/25','11/04','0125','0139','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('148670','KS','SUMNER','WELLINGTON',3.727777777000000e+001,-9.740972200000000e+001,'04/24','11/08','05/08','04/24','04/13','10/24','11/08','11/20','0143','0169','0195')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('148830','KS','SEDGWICK','WICHITA MID-CONTINENT',3.764750000000000e+001,-9.743000000000001e+001,'04/26','11/14','05/08','04/26','04/11','10/28','11/14','11/24','0153','0170','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('148946','KS','RUSSELL','WILSON LAKE',3.896666666000000e+001,-9.848888900000000e+001,'05/05','11/01','05/13','05/05','04/24','10/20','11/01','11/12','0139','0155','0172')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('148964','KS','COWLEY','WINFIELD 3NE',3.728888888000000e+001,-9.694083300000000e+001,'04/26','11/07','05/12','04/26','04/14','10/22','11/07','11/23','0143','0167','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('148988','KS','LOGAN','WINONA',3.905888888000000e+001,-1.012438890000000e+002,'05/16','10/26','05/19','05/16','05/01','10/12','10/26','11/05','0127','0139','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('149080','KS','WOODSON','YATES CTR',3.787277777000000e+001,-9.572472200000000e+001,'04/21','11/11','05/04','04/21','04/12','10/28','11/11','11/22','0153','0183','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('150254','KY','BOYD','ASHLAND',3.845361111000000e+001,-8.261305600000000e+001,'05/21','10/27','06/05','05/21','05/10','10/18','10/27','11/09','0111','0137','0158')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('150381','KY','KNOX','BARBOURVILLE',3.688250000000000e+001,-8.388194400000000e+001,'05/08','11/04','05/17','05/08','04/19','10/24','11/04','11/19','0139','0163','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('150397','KY','NELSON','BARDSTOWN 5E',3.781944444000000e+001,-8.538472200000000e+001,'05/06','10/29','05/19','05/06','04/20','10/18','10/29','11/12','0138','0157','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('150402','KY','CARLISLE','BARDWELL 2 E',3.688305555000000e+001,-8.899611100000000e+001,'04/21','11/04','05/05','04/21','04/14','10/21','11/04','11/25','0156','0174','0199')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('150422','KY','ALLEN','BARREN RIVER LAKE',3.689777777000000e+001,-8.612472200000001e+001,'04/29','11/05','05/17','04/29','04/18','10/24','11/05','11/23','0144','0169','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('150450','KY','HARLAN','BAXTER',3.685833333000000e+001,-8.333027800000001e+001,'05/06','11/05','05/19','05/06','04/23','10/29','11/05','11/20','0144','0164','0190')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('150619','KY','MADISON','BEREA COLLEGE',3.757333333000000e+001,-8.429083300000001e+001,'04/29','11/12','05/12','04/29','04/16','10/28','11/12','11/20','0146','0168','0190')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('150630','KY','BULLITT','BERNHEIM FOREST',3.791611111000000e+001,-8.565722200000000e+001,'05/12','10/31','05/20','05/12','04/23','10/18','10/31','11/11','0135','0150','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('150909','KY','WARREN','BOWLING GREEN RGNL AP',3.696472222000000e+001,-8.642388900000000e+001,'04/26','11/07','05/08','04/26','04/14','10/24','11/07','11/21','0155','0175','0197')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('151855','KY','BOONE','COVINGTON WSO',3.904305555000000e+001,-8.467166700000000e+001,'05/06','10/30','05/15','05/06','04/18','10/20','10/30','11/15','0141','0161','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('151998','KY','HARRISON','CYNTHIANA',3.837694444000000e+001,-8.430305600000000e+001,'05/08','10/31','05/18','05/08','04/23','10/17','10/31','11/15','0136','0157','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('152040','KY','BOYLE','DANVILLE',3.765277777000000e+001,-8.477083300000000e+001,'04/26','11/10','05/10','04/26','04/16','10/30','11/10','11/21','0152','0179','0197')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('152214','KY','MERCER','DIX DAM',3.778583333000000e+001,-8.470777800000001e+001,'04/25','11/14','05/13','04/25','04/16','10/25','11/14','11/22','0147','0177','0200')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('152791','KY','ROWAN','CAVE RUN  LAKE',3.812277777000000e+001,-8.353277799999999e+001,'05/10','10/31','05/20','05/10','04/28','10/19','10/31','11/17','0129','0148','0173')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('153223','KY','LIVINGSTON','GILBERTSVILLE KY DAM',3.701472222000000e+001,-8.826777800000001e+001,'04/17','11/16','04/27','04/17','04/08','11/04','11/16','11/30','0165','0192','0212')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('153430','KY','GREEN','GREENSBURG',3.725916666000000e+001,-8.550222200000000e+001,'05/02','11/03','05/18','05/02','04/17','10/21','11/03','11/19','0143','0164','0190')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('153762','KY','HENDERSON','HENDERSON 8 SSW',3.775583333000000e+001,-8.764555600000000e+001,'04/20','11/10','05/06','04/20','04/15','10/23','11/10','11/19','0154','0180','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('153929','KY','LARUE','HODGENVILLE LINCOLN P',3.753166666000000e+001,-8.573500000000000e+001,'05/02','11/03','05/20','05/02','04/18','10/21','11/03','11/14','0137','0165','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('153994','KY','CHRISTIAN','HOPKINSVILLE',3.684916666000000e+001,-8.752055600000000e+001,'04/22','11/06','05/05','04/22','04/14','10/26','11/06','11/24','0157','0174','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('154093','KY','LESLIE','HYDEN',3.715000000000000e+001,-8.336666700000001e+001,'05/12','10/30','05/19','05/12','04/26','10/21','10/30','11/16','0136','0152','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('154208','KY','RUSSELL','JAMESTOWN WWTP',3.700555555000000e+001,-8.506166700000000e+001,'04/28','11/08','05/18','04/28','04/20','10/21','11/08','11/20','0143','0172','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('154703','KY','GRAYSON','LEITCHFIELD 2 N',3.751083333000000e+001,-8.628916700000001e+001,'05/06','10/30','05/14','05/06','04/18','10/20','10/30','11/11','0140','0156','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('154746','KY','FAYETTE','LEXINGTON BLUEGRASS AP',3.804083333000000e+001,-8.460583300000000e+001,'04/28','11/09','05/10','04/28','04/18','10/24','11/09','11/20','0152','0173','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('154898','KY','LAUREL','LONDON FAA AP',3.708722222000000e+001,-8.407694400000000e+001,'05/07','10/30','05/17','05/07','04/19','10/19','10/30','11/13','0138','0159','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('154954','KY','JEFFERSON','LOUISVILLE INTL AP',3.818111111000000e+001,-8.573916700000000e+001,'04/21','11/15','05/02','04/21','04/12','10/31','11/15','11/29','0164','0182','0208')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('155067','KY','HOPKINS','MADISONVILLE',3.734750000000000e+001,-8.752388900000000e+001,'04/24','11/04','05/08','04/24','04/14','10/23','11/04','11/20','0152','0172','0194')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('155097','KY','EDMONSON','MAMMOTH CAVE',3.713166666000000e+001,-8.614805600000000e+001,'05/10','10/28','05/22','05/10','04/22','10/15','10/28','11/13','0131','0154','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('155243','KY','MASON','MAYSVILLE SEWAGE PLT',3.868694444000000e+001,-8.378722200000000e+001,'05/07','11/03','05/15','05/07','04/22','10/23','11/03','11/17','0142','0158','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('155524','KY','WAYNE','MONTICELLO 3 NE',3.686666666000000e+001,-8.482750000000000e+001,'05/06','11/06','05/17','05/06','04/20','10/20','11/06','11/16','0142','0159','0181')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('155648','KY','ROCKCASTLE','MT VERNON',3.735416666000000e+001,-8.433694400000000e+001,'05/10','10/25','05/19','05/10','04/21','10/18','10/25','11/14','0136','0155','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('155694','KY','CALLOWAY','MURRAY',3.661222222000000e+001,-8.830833300000001e+001,'04/17','11/15','04/24','04/17','04/14','10/27','11/15','11/25','0168','0184','0208')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('155834','KY','EDMONSON','NOLIN RIVER LAKE',3.727916666000000e+001,-8.624916700000000e+001,'05/13','10/31','05/26','05/13','04/24','10/17','10/31','11/15','0127','0148','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('156110','KY','MCCRACKEN','PADUCAH BARKLEY AP',3.705638888000000e+001,-8.877444400000000e+001,'04/21','11/09','05/03','04/21','04/14','10/22','11/09','11/22','0161','0177','0199')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('156580','KY','CALDWELL','PRINCETON 1 SE',3.712444444000000e+001,-8.786722200000000e+001,'04/25','11/05','05/10','04/25','04/17','10/22','11/05','11/18','0152','0173','0191')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('156882','KY','OHIO','ROCHESTER FERRY',3.721638888000000e+001,-8.689388900000000e+001,'04/24','11/07','05/09','04/24','04/14','10/25','11/07','11/24','0150','0174','0197')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('156988','KY','BRECKINRIDGE','ROUGH RIVER LAKE',3.761777777000000e+001,-8.650444400000001e+001,'05/11','10/25','05/23','05/11','04/21','10/14','10/25','11/06','0125','0148','0177')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('157049','KY','LOGAN','RUSSELLVILLE',3.685500000000000e+001,-8.688833300000000e+001,'04/26','11/05','05/16','04/26','04/17','10/22','11/05','11/18','0144','0172','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('157215','KY','ALLEN','SCOTTSVILLE',3.674583333000000e+001,-8.622583299999999e+001,'04/19','11/13','04/29','04/19','04/14','10/28','11/13','11/24','0167','0184','0206')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('157510','KY','PULASKI','SOMERSET 2 N',3.711666666000000e+001,-8.461666700000001e+001,'05/07','10/28','05/18','05/07','04/25','10/17','10/28','11/12','0136','0155','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('157677','KY','MCCREARY','STEARNS 2S',3.667361111000000e+001,-8.447916700000000e+001,'05/12','10/27','05/31','05/12','04/27','10/15','10/27','11/11','0124','0146','0172')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('158446','KY','GALLATIN','WARSAW MARKLAND DAM',3.877444444000000e+001,-8.496722200000001e+001,'05/09','10/30','05/18','05/09','04/26','10/21','10/30','11/13','0140','0155','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('158551','KY','MORGAN','WEST LIBERTY 3NW',3.693833333000000e+001,-8.330111100000001e+001,'05/22','10/19','06/02','05/22','05/10','10/15','10/19','11/06','0109','0132','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('160098','LA','RAPIDES','ALEXANDRIA',3.132055555000000e+001,-9.246111100000000e+001,'03/23','12/15','04/08','03/23','03/09','11/30','12/15','01/03','0211','0236','0279')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('160205','LA','TANGIPAHOA','AMITE',3.070944444000000e+001,-9.052500000000001e+001,'04/01','12/04','04/13','04/01','03/13','11/27','12/04','12/25','0193','0221','0262')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('160537','LA','MOREHOUSE','BASTROP',3.276916666000000e+001,-9.200555600000000e+001,'04/04','12/03','04/14','04/04','03/18','11/17','12/03','12/17','0195','0218','0248')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('160549','LA','EAST BATON ROUGE','BATON ROUGE METRO AP',3.053722222000000e+001,-9.114694400000001e+001,'03/19','12/19','04/01','03/19','03/08','12/02','12/19','01/04','0220','0248','0271')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('160945','LA','WASHINGTON','BOGALUSA',3.078083333000000e+001,-8.985666700000000e+001,'03/24','12/09','04/09','03/24','03/12','11/25','12/09','01/02','0207','0232','0262')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('161287','LA','AVOYELLES','BUNKIE',3.095944444000000e+001,-9.217861100000000e+001,'03/20','12/17','04/06','03/20','03/08','12/02','12/17','01/21','0213','0237','0281')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('161411','LA','OUACHITA','CALHOUN RSCH STN',3.251333333000000e+001,-9.234861100000001e+001,'04/12','11/25','04/18','04/12','03/27','11/13','11/25','12/07','0185','0204','0233')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('161565','LA','IBERVILLE','CARVILLE 2 SW',3.019805555000000e+001,-9.112555600000000e+001,'03/12','12/23','03/26','03/12','03/01','12/12','12/23','00/00','0234','0259','0290')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('162151','LA','ST. TAMMANY','COVINGTON 4 NNW',3.052722222000000e+001,-9.011138900000000e+001,'04/05','12/04','04/15','04/05','03/19','11/21','12/04','12/25','0192','0217','0253')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('162212','LA','ACADIA','CROWLEY 2 NE',3.024083333000000e+001,-9.234777800000001e+001,'03/21','12/20','03/28','03/21','03/05','12/02','12/20','01/01','0226','0246','0283')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('162367','LA','BEAUREGARD','DE RIDDER',3.084277777000000e+001,-9.328694400000001e+001,'03/27','12/12','04/11','03/27','03/15','11/26','12/12','12/30','0208','0234','0256')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('162534','LA','ASSUMPTION','DONALDSONVILLE 4 SW',3.007194444000000e+001,-9.102777800000000e+001,'03/18','12/26','03/24','03/18','03/01','12/09','12/26','01/25','0238','0260','0295')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('163313','LA','ST. MARY','FRANKLIN 3 NW',2.982333333000000e+001,-9.154416700000000e+001,'03/16','12/27','03/30','03/16','03/07','12/08','12/27','00/00','0228','0258','0289')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('163433','LA','LAFOURCHE','GALLIANO',2.946305555000000e+001,-9.030722200000000e+001,'03/09','01/05','03/24','03/09','02/24','12/19','01/05','00/00','0244','0275','0296')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('163800','LA','ST. LANDRY','GRAND COTEAU',3.041916666000000e+001,-9.204388899999999e+001,'03/20','12/16','04/07','03/20','03/15','11/30','12/16','12/29','0211','0242','0263')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('163979','LA','CAMERON','HACKBERRY 8 SSW',2.988944444000000e+001,-9.340194400000000e+001,'03/06','01/25','03/21','03/06','02/20','12/23','01/25','00/00','0253','0272','0305')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('164355','LA','CLAIBORNE','HOMER 1N',3.281000000000000e+001,-9.306250000000000e+001,'04/12','11/28','04/16','04/12','03/29','11/19','11/28','12/11','0194','0204','0225')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('164674','LA','IBERIA','JEANERETTE 5 NW',2.995916666000000e+001,-9.171083299999999e+001,'03/14','12/28','03/27','03/14','03/02','12/07','12/28','00/00','0231','0261','0289')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('164700','LA','JEFFERSON DAVIS','JENNINGS',3.020027777000000e+001,-9.266416700000001e+001,'03/22','12/26','03/29','03/22','03/06','12/05','12/26','00/00','0226','0253','0285')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('165026','LA','LAFAYETTE','LAFAYETTE FCWOS',3.020500000000000e+001,-9.198750000000000e+001,'03/17','12/22','03/27','03/17','03/02','12/02','12/22','00/00','0230','0256','0290')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('165065','LA','CAMERON','LAKE ARTHUR 10 SW',3.000305555000000e+001,-9.278083300000000e+001,'03/11','01/06','03/24','03/11','02/28','12/07','01/06','00/00','0234','0260','0294')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('165078','LA','CALCASIEU','LAKE CHARLES AP',3.012472222000000e+001,-9.322833300000001e+001,'03/16','12/26','03/29','03/16','03/02','12/07','12/26','00/00','0228','0253','0290')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('165090','LA','EAST CARROLL','LAKE PROVIDENCE',3.280666666000000e+001,-9.117305600000000e+001,'03/27','12/09','04/06','03/27','03/09','11/23','12/09','01/01','0211','0230','0261')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('165266','LA','VERNON','LEESVILLE',3.114166666000000e+001,-9.323972200000000e+001,'04/08','11/29','04/16','04/08','03/19','11/21','11/29','12/18','0189','0212','0244')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('165620','LA','EAST BATON ROUGE','LSU BEN-HUR FARM',3.036444444000000e+001,-9.116722200000000e+001,'03/23','12/10','04/05','03/23','03/13','11/29','12/10','12/29','0212','0233','0268')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('165874','LA','DE SOTO','MANSFIELD',3.203888888000000e+001,-9.370527800000001e+001,'04/08','12/05','04/15','04/08','03/25','11/21','12/05','12/31','0195','0214','0239')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('166244','LA','WEBSTER','MINDEN',3.260527777000000e+001,-9.329472199999999e+001,'04/09','11/29','04/15','04/09','03/25','11/17','11/29','12/20','0191','0207','0239')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('166394','LA','ST. MARY','MORGAN CITY',2.968333333000000e+001,-9.117611100000001e+001,'03/03','00/00','03/24','03/03','02/22','12/25','00/00','00/00','0252','0283','0304')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('166657','LA','IBERIA','NEW IBERIA ACADIANA AP',3.003750000000000e+001,-9.188388900000000e+001,'03/21','12/28','03/29','03/21','03/04','12/03','12/28','00/00','0227','0252','0285')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('166660','LA','JEFFERSON','NEW ORLEANS AP',2.999333333000000e+001,-9.025111100000000e+001,'03/13','01/01','03/27','03/13','02/24','12/20','01/01','00/00','0235','0264','0293')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('166664','LA','ORLEANS','NEW ORLEANS AUDUBON',2.991666666000000e+001,-9.013027800000000e+001,'02/28','00/00','03/15','02/28','02/06','01/01','00/00','00/00','0264','0294','0325')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('166686','LA','POINTE COUPEE','NEW ROADS 5 NE',3.072666666000000e+001,-9.136722200000000e+001,'03/20','12/15','04/05','03/20','03/10','12/04','12/15','12/29','0219','0237','0270')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('166938','LA','ALLEN','OBERLIN FIRE TWR',3.060361111000000e+001,-9.277388900000000e+001,'03/24','12/20','04/07','03/24','03/08','11/29','12/20','01/07','0214','0241','0273')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('167767','LA','ST. JOHN THE BAPTIST','RESERVE',3.005638888000000e+001,-9.058027800000001e+001,'03/18','12/27','03/27','03/18','03/04','12/13','12/27','02/01','0234','0265','0285')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('167932','LA','CAMERON','ROCKEFELLER WL REFUGE',2.972861111000000e+001,-9.281805600000000e+001,'03/11','01/02','03/25','03/11','03/01','12/13','01/02','00/00','0238','0273','0296')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('168067','LA','LINCOLN','RUSTON LA TECH',3.253444444000000e+001,-9.268888900000000e+001,'04/08','11/30','04/17','04/08','03/30','11/19','11/30','12/15','0189','0209','0238')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('168163','LA','TENSAS','ST JOSEPH 3 N',3.194972222000000e+001,-9.123361100000000e+001,'03/27','12/05','04/10','03/27','03/07','11/25','12/05','12/24','0197','0226','0263')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('168440','LA','CADDO','SHREVEPORT AP',3.244722222000000e+001,-9.382444400000000e+001,'03/31','12/07','04/17','03/31','03/18','11/21','12/07','12/21','0197','0223','0254')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('168539','LA','ST. TAMMANY','SLIDELL',3.026500000000000e+001,-8.976972200000000e+001,'03/22','12/19','04/05','03/22','03/12','11/29','12/19','01/18','0216','0244','0275')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('168923','LA','MADISON','TALLULAH',3.239944444000000e+001,-9.118416700000000e+001,'04/02','12/01','04/13','04/02','03/20','11/22','12/01','12/16','0198','0215','0242')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('169803','LA','WINN','WINNFIELD 3 N',3.196222222000000e+001,-9.265611100000000e+001,'04/09','11/28','04/17','04/09','03/24','11/10','11/28','12/10','0181','0202','0229')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('169806','LA','FRANKLIN','WINNSBORO 5 SSE',3.209972222000000e+001,-9.170222200000001e+001,'04/03','12/02','04/12','04/03','03/15','11/20','12/02','12/12','0192','0213','0242')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('170275','ME','KENNEBEC','AUGUSTA FAA AP',4.432055555000000e+001,-6.979722200000001e+001,'05/08','10/19','05/18','05/08','04/24','10/13','10/19','11/12','0133','0147','0173')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('170355','ME','PENOBSCOT','BANGOR AP',4.479777777000000e+001,-6.881861100000000e+001,'05/23','10/19','06/04','05/23','05/10','10/09','10/19','11/04','0109','0131','0153')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('170480','ME','WALDO','BELFAST',4.443944444000000e+001,-6.898916700000000e+001,'05/22','10/14','06/04','05/22','05/04','10/08','10/14','10/29','0106','0133','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('170814','ME','SOMERSET','BRASSUA DAM',4.566027777000000e+001,-6.981194400000000e+001,'06/06','10/07','06/23','06/06','05/26','09/21','10/07','10/15','0072','0104','0124')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('170833','ME','AROOSTOOK','BRIDGEWATER',4.642833333000000e+001,-6.784416700000000e+001,'06/17','09/24','07/03','06/17','05/31','09/13','09/24','10/11','0044','0074','0116')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('170844','ME','CUMBERLAND','BRIDGTON 3 NW',4.406972222000000e+001,-7.074666700000000e+001,'05/28','10/11','06/16','05/28','05/13','09/27','10/11','10/20','0082','0110','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('171175','ME','AROOSTOOK','CARIBOU WFO',4.687055555000000e+001,-6.801722200000000e+001,'05/27','10/03','06/12','05/27','05/13','09/22','10/03','10/16','0085','0118','0143')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('171472','ME','AROOSTOOK','CLAYTON LAKE',4.661055555000000e+001,-6.952194400000001e+001,'06/14','09/18','06/30','06/14','05/30','09/09','09/18','10/07','0051','0080','0113')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('171628','ME','PENOBSCOT','CORINNA',4.491972222000000e+001,-6.924166700000001e+001,'05/30','10/06','06/13','05/30','05/13','09/25','10/06','10/15','0087','0111','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('172765','ME','FRANKLIN','FARMINGTON',4.468888888000000e+001,-7.015666700000000e+001,'06/12','09/30','06/22','06/12','05/28','09/18','09/30','10/11','0064','0092','0121')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('172878','ME','AROOSTOOK','FT KENT',4.723861111000000e+001,-6.861361100000001e+001,'06/09','09/29','06/24','06/09','05/24','09/22','09/29','10/14','0068','0092','0121')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('173046','ME','KENNEBEC','GARDINER',4.422027777000000e+001,-6.978888900000000e+001,'05/18','10/14','05/31','05/18','05/02','10/05','10/14','10/29','0111','0135','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('173261','ME','WASHINGTON','GRAND LAKE STREAM',4.517750000000000e+001,-6.777416700000001e+001,'05/29','10/08','06/09','05/29','05/19','09/27','10/08','10/19','0100','0121','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('173892','ME','AROOSTOOK','HOULTON AP',4.612361111000000e+001,-6.779277800000000e+001,'06/15','09/28','07/06','06/15','05/27','09/15','09/28','10/10','0050','0085','0120')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('174086','ME','SOMERSET','JACKMAN',4.562333333000000e+001,-7.025500000000000e+001,'06/17','09/30','07/02','06/17','05/30','09/17','09/30','10/12','0053','0085','0116')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('174566','ME','ANDROSCOGGIN','LEWISTON',4.410000000000000e+001,-7.021666700000000e+001,'05/07','10/27','05/20','05/07','04/24','10/13','10/27','11/14','0133','0153','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('174781','ME','SOMERSET','LONG FALLS DAM',4.522194444000000e+001,-7.019833300000001e+001,'06/05','10/04','06/25','06/05','05/19','09/21','10/04','10/15','0073','0103','0132')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('174927','ME','SOMERSET','MADISON',4.479833333000000e+001,-6.988777800000000e+001,'05/25','10/11','06/15','05/25','05/07','10/01','10/11','10/26','0082','0121','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('175261','ME','OXFORD','MIDDLE DAM',4.479305555000000e+001,-7.091666700000000e+001,'06/09','10/01','06/26','06/09','05/26','09/25','10/01','10/15','0062','0101','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('175675','ME','LINCOLN','NEWCASTLE',4.404611111000000e+001,-6.953666699999999e+001,'05/11','10/21','05/26','05/11','04/29','10/11','10/21','11/08','0125','0145','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('176905','ME','CUMBERLAND','PORTLAND JETPORT',4.364972222000000e+001,-7.030027800000001e+001,'05/15','10/15','05/25','05/15','05/01','10/06','10/15','10/30','0124','0141','0165')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('176937','ME','AROOSTOOK','PRESQUE ISLE',4.665388888000000e+001,-6.800888900000000e+001,'06/03','10/03','06/22','06/03','05/20','09/20','10/03','10/15','0071','0105','0131')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('177037','ME','FRANKLIN','RANGELEY',4.498916666000000e+001,-7.067194400000000e+001,'06/12','10/02','06/29','06/12','05/30','09/22','10/02','10/13','0063','0088','0122')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('177479','ME','YORK','SANFORD 2 NNW',4.345694444000000e+001,-7.078027800000000e+001,'05/22','10/09','06/08','05/22','05/09','09/30','10/09','10/24','0098','0126','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('178965','ME','AROOSTOOK','VAN BUREN 2',4.716638888000000e+001,-6.793972200000000e+001,'06/13','09/29','06/23','06/13','05/29','09/22','09/29','10/14','0064','0087','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('179151','ME','KENNEBEC','WATERVILLE TRTMT PLT',4.452722222000000e+001,-6.965444400000000e+001,'05/21','10/12','06/07','05/21','05/09','10/03','10/12','10/25','0101','0126','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('179891','ME','WASHINGTON','WOODLAND',4.515694444000000e+001,-6.740444400000000e+001,'05/31','10/11','06/08','05/31','05/14','09/26','10/11','10/19','0090','0113','0142')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('180015','MD','HARFORD','ABERDEEN PHILLIPS FLD',3.947166666000000e+001,-7.616972199999999e+001,'04/23','11/13','05/07','04/23','04/13','10/27','11/13','11/25','0152','0179','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('180335','MD','WORCESTER','ASSATEAGUE',3.807222222000000e+001,-7.521277800000000e+001,'04/20','11/26','05/01','04/20','04/12','11/13','11/26','12/15','0171','0187','0216')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('180465','MD','ANNE ARUNDEL','BALTIMORE WASH INTL AP',3.916666666000000e+001,-7.668333300000001e+001,'04/22','11/11','05/08','04/22','04/12','10/30','11/11','11/26','0153','0181','0203')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('180700','MD','PRINCE GEORGE''S','BELTSVILLE',3.903027777000000e+001,-7.693138900000000e+001,'05/01','11/04','05/16','05/01','04/19','10/25','11/04','11/14','0144','0164','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('181530','MD','FREDERICK','CATOCTIN MTN PARK',3.964527777000000e+001,-7.748305600000001e+001,'05/05','11/06','05/19','05/05','04/20','10/26','11/06','11/18','0141','0162','0190')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('182060','MD','HARFORD','CONOWINGO DAM',3.965583333000000e+001,-7.617555600000000e+001,'05/03','11/10','05/10','05/03','04/17','10/31','11/10','11/24','0148','0165','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('182325','MD','PRINCE GEORGE''S','DALECARLIA RSVR',3.893444444000000e+001,-7.710222200000000e+001,'05/04','11/08','05/19','05/04','04/20','10/27','11/08','11/22','0136','0160','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('182906','MD','FREDERICK','EMMITSBURG 2 SE',3.968111111000000e+001,-7.729138900000000e+001,'05/15','10/26','05/29','05/15','04/28','10/15','10/26','11/11','0117','0145','0167')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('185111','MD','PRINCE GEORGE''S','LAUREL 3 W',3.908472222000000e+001,-7.690027800000000e+001,'04/20','11/18','05/04','04/20','04/10','11/04','11/18','12/03','0159','0177','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('186350','MD','DISTRICT OF COLUMBIA','NATL ARBORETUM DC',3.891333333000000e+001,-7.697000000000000e+001,'04/20','11/09','05/07','04/20','04/11','10/29','11/09','11/25','0154','0179','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('186620','MD','GARRETT','OAKLAND 1 SE',3.941333333000000e+001,-7.940000000000001e+001,'06/03','10/08','06/20','06/03','05/15','10/02','10/08','10/24','0080','0114','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('187330','MD','SOMERSET','PRINCESS ANNE',3.821222222000000e+001,-7.568222200000000e+001,'05/09','11/03','05/19','05/09','04/19','10/20','11/03','11/18','0132','0152','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('187806','MD','TALBOT','ROYAL OAK 2 SSW',3.871444444000000e+001,-7.618972200000000e+001,'04/15','11/22','04/27','04/15','04/03','11/06','11/22','12/05','0169','0194','0221')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('188005','MD','WICOMICO','SALISBURY FAA AP',3.834055555000000e+001,-7.551027800000000e+001,'04/24','11/10','05/10','04/24','04/14','10/26','11/10','11/25','0151','0177','0202')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('188065','MD','GARRETT','SAVAGE RIVER DAM',3.951027777000000e+001,-7.914000000000000e+001,'05/15','10/24','06/03','05/15','05/02','10/09','10/24','11/08','0113','0141','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('188380','MD','WORCESTER','SNOW HILL 4 N',3.823638888000000e+001,-7.537888900000000e+001,'04/30','11/02','05/15','04/30','04/15','10/20','11/02','11/16','0139','0167','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('189070','MD','PRINCE GEORGE''S','UPPER MARLBORO 3 NNW',3.885194444000000e+001,-7.676833300000000e+001,'04/29','11/03','05/17','04/29','04/17','10/22','11/03','11/12','0136','0162','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('190120','MA','HAMPSHIRE','AMHERST',4.238611111000000e+001,-7.253749999999999e+001,'05/24','10/09','06/08','05/24','05/09','10/01','10/09','10/29','0091','0125','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('190408','MA','WORCESTER','BARRE FALLS DAM',4.242833333000000e+001,-7.202750000000000e+001,'06/08','10/02','06/28','06/08','05/22','09/18','10/02','10/14','0064','0095','0125')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('190666','MA','WORCESTER','BIRCH HILL DAM',4.263250000000000e+001,-7.212333300000000e+001,'06/13','09/30','06/25','06/13','05/19','09/19','09/30','10/10','0066','0085','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('190736','MA','NORFOLK','BLUE HILL',4.221222222000000e+001,-7.111361100000001e+001,'05/01','11/05','05/11','05/01','04/23','10/17','11/05','11/17','0143','0159','0183')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('190770','MA','SUFFOLK','BOSTON',4.236055555000000e+001,-7.101055599999999e+001,'04/21','11/21','05/01','04/21','04/08','11/09','11/21','12/04','0170','0193','0217')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('190860','MA','PLYMOUTH','BROCKTON',4.204777777000000e+001,-7.100500000000000e+001,'05/16','10/20','06/05','05/16','05/04','10/07','10/20','11/05','0112','0139','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('190998','MA','WORCESTER','BUFFUMVILLE LAKE',4.211638888000000e+001,-7.190750000000000e+001,'05/18','10/14','06/04','05/18','05/05','10/03','10/14','10/29','0107','0133','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('192107','MA','WORCESTER','EAST BRIMFIELD LAKE',4.211027777000000e+001,-7.212694400000000e+001,'05/18','10/20','05/31','05/18','05/02','10/05','10/20','10/30','0114','0138','0159')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('192451','MA','PLYMOUTH','EAST WAREHAM',4.176527777000000e+001,-7.066972199999999e+001,'05/05','11/04','05/20','05/05','04/23','10/20','11/04','11/16','0136','0162','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('192501','MA','DUKES','EDGARTOWN',4.138527777000000e+001,-7.051805600000000e+001,'05/12','11/09','05/21','05/12','04/26','10/27','11/09','11/20','0138','0158','0188')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('193505','MA','ESSEX','HAVERHILL',4.275944444000000e+001,-7.106027800000000e+001,'05/17','10/23','05/30','05/17','05/04','10/13','10/23','11/05','0110','0132','0159')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('193624','MA','PLYMOUTH','HINGHAM',4.222694444000000e+001,-7.091249999999999e+001,'05/15','10/28','05/25','05/15','04/27','10/11','10/28','11/10','0127','0146','0176')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('193821','MA','BARNSTABLE','HYANNIS',4.166500000000000e+001,-7.030388900000000e+001,'05/07','11/06','05/25','05/07','04/23','10/21','11/06','11/20','0136','0162','0191')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('194105','MA','ESSEX','LAWRENCE',4.269916666000000e+001,-7.116583300000001e+001,'05/03','10/30','05/18','05/03','04/24','10/14','10/30','11/17','0138','0158','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('194313','MA','MIDDLESEX','LOWELL',4.264083333000000e+001,-7.136361100000001e+001,'05/10','10/24','05/23','05/10','05/01','10/07','10/24','11/09','0124','0142','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('194744','MA','ESSEX','MIDDLETON',4.259472222000000e+001,-7.102083300000000e+001,'05/16','10/23','05/23','05/16','04/28','10/06','10/23','11/07','0123','0142','0166')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('196486','MA','PLYMOUTH','PLYMOUTH-KINGSTON',4.198194444000000e+001,-7.069611100000000e+001,'05/23','11/01','05/27','05/23','05/08','10/16','11/01','11/17','0126','0137','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('196783','MA','MIDDLESEX','READING',4.252416666000000e+001,-7.112638900000000e+001,'05/17','10/22','05/28','05/17','05/03','10/06','10/22','11/04','0118','0138','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('196938','MA','PLYMOUTH','ROCHESTER',4.178500000000000e+001,-7.091750000000000e+001,'05/07','10/30','05/24','05/07','04/24','10/17','10/30','11/17','0130','0153','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('197627','MA','WORCESTER','SOUTHBRIDGE 3 SW',4.205833333000000e+001,-7.207222200000000e+001,'05/17','10/23','05/27','05/17','05/01','10/04','10/23','11/05','0118','0138','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('198573','MA','WORCESTER','TULLY LAKE',4.264000000000000e+001,-7.222444400000001e+001,'05/20','10/07','06/08','05/20','05/07','10/03','10/07','10/25','0098','0128','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('199923','MA','WORCESTER','WORCESTER',4.227055555000000e+001,-7.187305600000001e+001,'05/07','10/29','05/22','05/07','04/23','10/11','10/29','11/11','0129','0149','0172')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('200032','MI','LENAWEE','ADRIAN 2 NNE',4.191638888000000e+001,-8.401583300000000e+001,'05/18','10/20','06/03','05/18','05/02','10/07','10/20','11/04','0111','0131','0156')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('200146','MI','GRATIOT','ALMA',4.338638888000000e+001,-8.464916700000001e+001,'05/18','10/19','06/04','05/18','05/08','10/06','10/19','11/06','0109','0135','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('200164','MI','ALPENA','ALPENA CO RGNL AP',4.507166666000000e+001,-8.356444400000000e+001,'06/07','10/07','06/24','06/07','05/20','09/28','10/07','10/23','0080','0104','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('200169','MI','ALPENA','ALPENA WWTP',4.506055555000000e+001,-8.342805600000000e+001,'05/23','10/28','06/03','05/23','05/03','10/12','10/28','11/12','0108','0132','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('200230','MI','WASHTENAW','ANN ARBOR U OF MICH',4.229472222000000e+001,-8.371083299999999e+001,'05/09','10/30','05/26','05/09','04/27','10/19','10/30','11/12','0127','0149','0173')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('200417','MI','HURON','BAD AXE',4.380805555000000e+001,-8.299388900000000e+001,'05/20','10/26','06/06','05/20','05/06','10/09','10/26','11/14','0114','0137','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('200446','MI','LAKE','BALDWIN',4.390055555000000e+001,-8.585055600000000e+001,'06/14','10/04','07/03','06/14','05/30','09/25','10/04','10/20','0050','0096','0125')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('200552','MI','CALHOUN','BATTLE CREEK 5NW',4.236666666000000e+001,-8.526666700000000e+001,'05/30','10/19','06/11','05/30','05/13','10/03','10/19','11/08','0100','0122','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('200710','MI','BERRIEN','BENTON HARBOR AP',4.212444444000000e+001,-8.642666700000000e+001,'05/31','10/27','06/10','05/31','05/12','10/15','10/27','11/14','0103','0119','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('200718','MI','ONTONAGON','BERGLAND DAM',4.658694444000000e+001,-8.954750000000000e+001,'06/20','10/04','07/07','06/20','06/03','09/20','10/04','10/12','0045','0086','0109')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('200779','MI','MECOSTA','BIG RAPIDS WTR WKS',4.370722222000000e+001,-8.548222199999999e+001,'06/06','10/07','06/14','06/06','05/14','09/26','10/07','10/26','0086','0110','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('200864','MI','VAN BUREN','BLOOMINGDALE',4.238416666000000e+001,-8.596250000000001e+001,'05/30','10/14','06/16','05/30','05/14','09/30','10/14','11/04','0094','0124','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('200925','MI','CHARLEVOIX','BOYNE FALLS',4.516722222000000e+001,-8.491388900000000e+001,'06/16','10/02','07/15','06/16','05/30','09/23','10/02','10/24','0041','0085','0118')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('201176','MI','WEXFORD','CADILLAC',4.426555555000000e+001,-8.539666699999999e+001,'06/19','09/30','07/18','06/19','06/02','09/25','09/30','10/16','0034','0074','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('201299','MI','TUSCOLA','CARO WWTP',4.348388888000000e+001,-8.339194400000000e+001,'06/06','10/10','06/20','06/06','05/17','09/29','10/10','10/27','0083','0104','0142')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('201476','MI','EATON','CHARLOTTE',4.455027777000000e+001,-8.482583300000000e+001,'05/30','10/15','06/13','05/30','05/12','10/06','10/15','11/02','0094','0124','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('201492','MI','CHEBOYGAN','CHEBOYGAN',4.565277777000000e+001,-8.447250000000000e+001,'06/01','10/27','06/12','06/01','05/18','10/08','10/27','11/05','0096','0121','0143')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('201675','MI','BRANCH','COLDWATER ST SCHOOL',4.196222222000000e+001,-8.499250000000001e+001,'05/17','10/17','05/30','05/17','05/05','10/11','10/17','11/07','0112','0136','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('201896','MI','EMMET','CROSS VILLAGE 1E',4.564138888000000e+001,-8.501416700000000e+001,'06/07','10/26','06/23','06/07','05/22','10/10','10/26','11/10','0091','0113','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('202015','MI','WAYNE','DEARBORN',4.231944444000000e+001,-8.323777800000001e+001,'05/17','10/29','05/29','05/17','04/28','10/12','10/29','11/07','0119','0140','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('202094','MI','CHIPPEWA','DETOUR VILLAGE',4.599833333000000e+001,-8.390138900000000e+001,'05/25','10/30','06/07','05/25','05/13','10/12','10/30','11/14','0105','0130','0156')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('202103','MI','WAYNE','DETROIT METRO AIRPORT',4.223138888000000e+001,-8.333083300000000e+001,'05/10','10/30','05/28','05/10','04/28','10/15','10/30','11/14','0125','0150','0171')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('202250','MI','CASS','DOWAGIAC 1 W',4.198555555000000e+001,-8.613194400000000e+001,'05/31','10/19','06/08','05/31','05/11','10/06','10/19','11/07','0102','0128','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('202381','MI','CHARLEVOIX','EAST JORDAN',4.515194444000000e+001,-8.513222200000000e+001,'06/13','10/09','06/29','06/13','05/22','09/27','10/09','10/26','0059','0099','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('202423','MI','IOSCO','EAST TAWAS',4.428388888000000e+001,-8.350361100000001e+001,'06/02','10/13','06/20','06/02','05/15','10/03','10/13','10/30','0084','0117','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('202445','MI','BERRIEN','EAU CLAIRE 4 NE',4.201472222000000e+001,-8.624083300000000e+001,'05/14','11/05','05/27','05/14','04/28','10/24','11/05','11/18','0133','0153','0183')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('202626','MI','DELTA','ESCANABA',4.571805555000000e+001,-8.709388900000000e+001,'05/30','10/28','06/06','05/30','05/08','10/11','10/28','11/12','0109','0128','0159')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('202846','MI','GENESEE','FLINT FCWOS',4.296666666000000e+001,-8.374944400000000e+001,'05/19','10/27','06/07','05/19','05/02','10/08','10/27','11/07','0109','0137','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('202984','MI','BENZIE','FRANKFORT 2NE',4.464805555000000e+001,-8.620999999999999e+001,'05/26','10/29','06/09','05/26','05/06','10/18','10/29','11/18','0112','0134','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('203096','MI','OTSEGO','GAYLORD',4.503027777000000e+001,-8.467805600000000e+001,'06/12','10/07','07/04','06/12','05/27','09/26','10/07','10/23','0055','0087','0117')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('203170','MI','GLADWIN','GLADWIN',4.397583333000000e+001,-8.449083300000000e+001,'05/30','10/08','06/28','05/30','05/17','10/01','10/08','10/25','0073','0112','0143')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('203333','MI','KENT','GERALD R FORD INTL AP',4.288250000000000e+001,-8.552388900000000e+001,'05/19','10/21','06/02','05/19','05/12','10/10','10/21','11/09','0113','0139','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('203391','MI','CRAWFORD','GRAYLING',4.465416666000000e+001,-8.469944400000000e+001,'06/20','09/29','07/16','06/20','06/02','09/17','09/29','10/12','0036','0072','0107')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('203429','MI','MONTCALM','GREENVILLE 2 NNE',4.320250000000000e+001,-8.524222200000000e+001,'06/04','10/11','06/14','06/04','05/13','10/01','10/11','10/28','0095','0113','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('203477','MI','WAYNE','GROSSE POINTE FARMS',4.240777777000000e+001,-8.288916700000000e+001,'05/05','11/05','05/19','05/05','04/27','10/27','11/05','11/19','0139','0162','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('203504','MI','KALAMAZOO','GULL LK BIOLOGICAL STN',4.238333333000000e+001,-8.538277800000000e+001,'05/18','10/25','06/01','05/18','05/04','10/09','10/25','11/12','0118','0139','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('203529','MI','IOSCO','HALE LOUD DAM',4.446333333000000e+001,-8.372166700000000e+001,'06/02','10/12','06/10','06/02','05/16','10/01','10/12','10/25','0096','0117','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('203585','MI','HURON','HARBOR BEACH 1 SSE',4.383222222000000e+001,-8.264277800000001e+001,'05/15','11/02','05/30','05/15','05/01','10/13','11/02','11/13','0120','0149','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('203628','MI','ALCONA','HARRISVILLE 2NNE',4.468194444000000e+001,-8.328083300000000e+001,'05/30','10/19','06/15','05/30','05/13','10/08','10/19','11/02','0100','0125','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('203632','MI','OCEANA','HART 3 WSW',4.367472222000000e+001,-8.642388900000000e+001,'05/28','10/22','06/13','05/28','05/11','10/07','10/22','11/10','0102','0125','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('203661','MI','BARRY','HASTINGS',4.264222222000000e+001,-8.528749999999999e+001,'05/28','10/17','06/13','05/28','05/08','10/03','10/17','11/02','0101','0125','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('203744','MI','BARAGA','HERMAN',4.666500000000000e+001,-8.837500000000000e+001,'07/11','10/03','07/28','07/11','06/19','09/16','10/03','10/10','0014','0039','0081')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('203769','MI','OCEANA','HESPERIA 4 WNW',4.359083333000000e+001,-8.610555600000001e+001,'06/11','10/10','07/02','06/11','05/18','09/28','10/10','10/23','0062','0103','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('203823','MI','HILLSDALE','HILLSDALE',4.193527777000000e+001,-8.464111100000000e+001,'05/27','10/15','06/18','05/27','05/14','10/06','10/15','10/30','0091','0124','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('203858','MI','OTTAWA','HOLLAND WTP',4.279888888000000e+001,-8.620500000000000e+001,'05/25','10/24','06/11','05/25','05/09','10/12','10/24','11/12','0105','0130','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('203932','MI','MISSAUKEE','HOUGHTON LAKE 6 WSW',4.431194444000000e+001,-8.489222200000000e+001,'07/08','09/26','07/25','07/08','06/08','09/13','09/26','10/06','0021','0047','0102')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('203936','MI','ROSCOMMON','HOUGHTON ROSCOMMON AP',4.435916666000000e+001,-8.467388900000000e+001,'06/05','10/10','07/02','06/05','05/15','09/24','10/10','10/24','0060','0103','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('204078','MI','IONIA','IONIA 2SSW',4.295305555000000e+001,-8.507777800000000e+001,'05/27','10/19','06/12','05/27','05/10','10/02','10/19','10/31','0099','0125','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('204090','MI','DICKINSON','IRON MT KINGSFORD WWTP',4.578583333000000e+001,-8.808416699999999e+001,'06/10','10/02','06/24','06/10','05/18','09/24','10/02','10/17','0073','0099','0130')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('204104','MI','GOGEBIC','IRONWOOD',4.646555555000000e+001,-9.018916700000000e+001,'06/16','10/05','06/30','06/16','06/02','09/27','10/05','10/12','0059','0083','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('204150','MI','JACKSON','JACKSON COUNTY AP',4.226666666000000e+001,-8.446666700000000e+001,'05/19','10/20','06/11','05/19','05/04','10/07','10/20','11/05','0108','0136','0156')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('204257','MI','KALKASKA','KALKASKA',4.472805555000000e+001,-8.517277799999999e+001,'06/15','10/03','07/08','06/15','05/26','09/23','10/03','10/25','0042','0081','0122')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('204328','MI','HOUGHTON','KENTON',4.648638888000000e+001,-8.889166700000000e+001,'07/01','09/25','07/26','07/01','06/18','09/05','09/25','10/08','0017','0057','0084')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('204502','MI','MISSAUKEE','LAKE CITY EXP FARM',4.430888888000000e+001,-8.520500000000000e+001,'06/14','10/03','07/18','06/14','05/25','09/25','10/03','10/17','0040','0087','0120')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('204641','MI','CLINTON','LANSING CAPITAL CY AP',4.278027777000000e+001,-8.457888900000000e+001,'05/25','10/14','06/12','05/25','05/12','10/03','10/14','11/01','0096','0126','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('204655','MI','LAPEER','LAPEER WWTP',4.306083333000000e+001,-8.330750000000001e+001,'05/28','10/23','06/16','05/28','05/12','10/07','10/23','11/05','0083','0109','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('204954','MI','MASON','LUDINGTON 4 SE',4.390666666000000e+001,-8.639416700000000e+001,'06/08','10/21','06/14','06/08','05/24','10/05','10/21','11/06','0092','0114','0143')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('204967','MI','OGEMAW','LUPTON 1S',4.442000000000000e+001,-8.402333299999999e+001,'06/16','09/29','07/19','06/16','06/04','09/19','09/29','10/12','0036','0087','0104')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('205065','MI','MANISTEE','MANISTEE 3SE',4.421138888000000e+001,-8.629388899999999e+001,'05/29','10/30','06/20','05/29','05/22','10/14','10/30','11/11','0080','0115','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('205073','MI','SCHOOLCRAFT','MANISTIQUE WWTP',4.595111111000000e+001,-8.625138900000000e+001,'06/04','10/20','06/17','06/04','05/23','10/08','10/20','11/03','0080','0100','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('205097','MI','LEELANAU','MAPLE CITY 1E',4.485500000000000e+001,-8.583527800000000e+001,'06/14','10/16','06/25','06/14','05/25','10/09','10/16','11/06','0071','0106','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('205178','MI','MARQUETTE','MARQUETTE',4.654583333000000e+001,-8.737944400000001e+001,'05/26','10/28','06/12','05/26','05/15','10/15','10/28','11/13','0103','0132','0156')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('205184','MI','MARQUETTE','MARQUETTE WFO',4.653138888000000e+001,-8.754916700000000e+001,'06/15','10/05','07/01','06/15','05/26','09/22','10/05','10/20','0058','0091','0125')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('205434','MI','MIDLAND','MIDLAND',4.360888888000000e+001,-8.420111100000000e+001,'05/26','10/17','06/05','05/26','05/07','10/09','10/17','11/10','0107','0130','0156')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('205452','MI','LIVINGSTON','MILFORD GM PROVING GRD',4.257944444000000e+001,-8.368444400000000e+001,'05/17','10/25','06/02','05/17','05/06','10/10','10/25','11/06','0113','0136','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('205567','MI','MUSKEGON','MONTAGUE 4 NW',4.346138888000000e+001,-8.641750000000000e+001,'06/10','10/16','06/21','06/10','05/28','10/01','10/16','10/26','0074','0101','0128')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('205650','MI','MACOMB','MT CLEMENS ANG BASE',4.260833333000000e+001,-8.281833300000000e+001,'05/15','11/05','05/25','05/15','04/28','10/18','11/05','11/14','0131','0149','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('205662','MI','ISABELLA','MT PLEASANT UNIV',4.358583333000000e+001,-8.476972200000000e+001,'05/16','10/26','06/03','05/16','05/06','10/07','10/26','11/13','0113','0138','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('205690','MI','ALGER','MUNISING',4.641222222000000e+001,-8.666249999999999e+001,'06/18','10/19','07/05','06/18','05/30','10/10','10/19','11/07','0051','0090','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('205712','MI','MUSKEGON','MUSKEGON CO AP',4.317111111000000e+001,-8.623666700000000e+001,'05/26','10/22','06/06','05/26','05/08','10/09','10/22','11/09','0104','0130','0156')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('206184','MI','PRESQUE ISLE','ONAWAY 4N',4.541083333000000e+001,-8.422333300000000e+001,'05/30','10/17','06/14','05/30','05/14','10/03','10/17','11/03','0087','0116','0145')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('206300','MI','SHIAWASSEE','OWOSSO WWTP',4.301611111000000e+001,-8.418000000000001e+001,'05/19','10/20','06/09','05/19','05/11','10/08','10/20','11/07','0104','0139','0153')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('206438','MI','EMMET','PELLSTON RGNL AP',4.556444444000000e+001,-8.479277800000000e+001,'06/13','09/30','07/07','06/13','05/25','09/19','09/30','10/18','0045','0086','0125')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('206507','MI','EMMET','PETOSKEY',4.537250000000000e+001,-8.497666700000001e+001,'05/21','10/29','06/09','05/21','05/05','10/15','10/29','11/14','0106','0139','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('206680','MI','ST. CLAIR','PORT HURON',4.297500000000000e+001,-8.241944400000000e+001,'05/10','11/08','05/26','05/10','04/28','10/17','11/08','11/16','0123','0151','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('207277','MI','CHARLEVOIX','ST JAMES 4SSW BEAVER',4.569111111000000e+001,-8.554638900000001e+001,'05/28','10/25','06/26','05/28','05/15','10/17','10/25','11/09','0086','0131','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('207280','MI','CLINTON','SAINT JOHNS',4.301138888000000e+001,-8.455416700000001e+001,'05/20','10/21','06/03','05/20','05/05','10/09','10/21','11/06','0110','0135','0158')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('207350','MI','SANILAC','SANDUSKY',4.341944444000000e+001,-8.281916699999999e+001,'05/17','10/27','06/04','05/17','05/05','10/09','10/27','11/14','0112','0131','0153')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('207366','MI','CHIPPEWA','SAULT STE MARIE SNDRSN',4.647944444000000e+001,-8.435722199999999e+001,'06/15','10/11','07/01','06/15','05/25','09/25','10/11','10/25','0064','0096','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('207690','MI','VAN BUREN','SOUTH HAVEN',4.240138888000000e+001,-8.628333300000000e+001,'05/11','11/10','05/28','05/11','04/26','10/25','11/10','11/25','0123','0154','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('207812','MI','IRON','STAMBAUGH 2SSE',4.605555555000000e+001,-8.862750000000000e+001,'07/04','09/19','07/25','07/04','06/10','09/07','09/19','09/30','0020','0054','0096')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('207820','MI','ARENAC','STANDISH 5SW',4.394722222000000e+001,-8.403777800000000e+001,'05/31','10/14','06/13','05/31','05/11','09/29','10/14','10/27','0089','0111','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('208043','MI','CHIPPEWA','TAHQUAMENON FALLS SP',4.660138888000000e+001,-8.522388900000000e+001,'07/11','09/23','07/31','07/11','06/21','09/13','09/23','10/10','0007','0048','0080')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('208184','MI','ST. JOSEPH','THREE RIVERS',4.192972222000000e+001,-8.563833300000000e+001,'05/17','10/19','06/05','05/17','05/08','10/08','10/19','11/05','0112','0137','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('208417','MI','OTSEGO','VANDERBILT 11ENE',4.517027777000000e+001,-8.443972200000000e+001,'07/05','09/20','07/30','07/05','06/15','09/04','09/20','10/09','0009','0047','0089')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('208800','MI','OGEMAW','WEST BRANCH 3SE',4.425416666000000e+001,-8.420111100000000e+001,'06/04','10/06','06/16','06/04','05/21','09/27','10/06','10/24','0081','0106','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('208920','MI','CHIPPEWA','WHITEFISH POINT',4.675305555000000e+001,-8.497888900000000e+001,'06/14','10/19','06/30','06/14','05/18','10/05','10/19','11/02','0068','0107','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('209218','MI','WASHTENAW','YPSILANTI E MICH U',4.224750000000000e+001,-8.362527799999999e+001,'05/08','11/02','05/18','05/08','04/26','10/17','11/02','11/16','0135','0156','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('210018','MN','NORMAN','ADA',4.729916666000000e+001,-9.651611100000000e+001,'05/22','10/06','05/29','05/22','05/13','09/27','10/06','10/18','0104','0120','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('210050','MN','MARSHALL','AGASSIZ REFUGE',4.830055555000000e+001,-9.598166700000000e+001,'05/27','10/05','06/01','05/27','05/13','09/23','10/05','10/13','0094','0105','0132')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('210059','MN','AITKIN','AITKIN 2E',4.652583333000000e+001,-9.366750000000000e+001,'06/01','10/03','06/16','06/01','05/17','09/25','10/03','10/11','0079','0110','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('210075','MN','FREEBORN','ALBERT LEA 3 SE',4.360638888000000e+001,-9.330194400000001e+001,'05/16','10/14','05/22','05/16','05/03','10/05','10/14','10/30','0120','0136','0159')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('210112','MN','DOUGLAS','ALEXANDRIA CHANDLER FLD',4.586777777000000e+001,-9.539416700000000e+001,'05/16','10/17','05/21','05/16','05/01','10/07','10/17','10/28','0121','0136','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('210252','MN','MARSHALL','ARGYLE',4.833111111000000e+001,-9.682527800000000e+001,'05/26','10/05','06/13','05/26','05/20','09/25','10/05','10/14','0076','0107','0130')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('210287','MN','BIG STONE','ARTICHOKE LAKE',4.537833333000000e+001,-9.615416700000000e+001,'05/19','10/14','05/22','05/19','05/04','10/02','10/14','10/24','0118','0128','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('210355','MN','MOWER','AUSTIN WWT FAC',4.365416666000000e+001,-9.297388900000000e+001,'05/16','10/12','05/29','05/16','05/07','10/02','10/12','10/22','0108','0127','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('210643','MN','BELTRAMI','BEMIDJI',4.753694444000000e+001,-9.482972200000000e+001,'05/29','10/05','06/13','05/29','05/20','09/27','10/05','10/12','0081','0112','0128')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('210667','MN','SWIFT','BENSON',4.531666666000000e+001,-9.561666700000001e+001,'05/17','10/13','05/24','05/17','05/04','10/05','10/13','10/26','0116','0128','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('210746','MN','KOOCHICHING','BIG FALLS',4.819694444000000e+001,-9.379944399999999e+001,'06/14','09/25','06/30','06/14','05/26','09/16','09/25','10/07','0056','0086','0119')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('210939','MN','CROW WING','BRAINERD',4.634333333000000e+001,-9.420861100000001e+001,'05/27','10/05','06/18','05/27','05/15','09/25','10/05','10/11','0081','0106','0130')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('211107','MN','WRIGHT','BUFFALO 2NE',4.519694444000000e+001,-9.384000000000000e+001,'05/16','10/16','05/24','05/16','05/06','10/05','10/16','10/25','0119','0134','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('211198','MN','HOUSTON','CALEDONIA',4.363083333000000e+001,-9.150277800000001e+001,'05/18','10/12','05/24','05/18','05/04','10/06','10/12','10/31','0118','0131','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('211227','MN','ISANTI','CAMBRIDGE 5ESE',4.555055555000000e+001,-9.312638900000000e+001,'05/22','10/06','06/10','05/22','05/13','09/27','10/06','10/19','0096','0122','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('211263','MN','YELLOW MEDICINE','CANBY',4.471833333000000e+001,-9.626972200000000e+001,'05/17','10/15','05/26','05/17','05/09','10/06','10/15','10/24','0112','0132','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('211374','MN','CASS','CASS LAKE',4.738472222000000e+001,-9.461472200000000e+001,'06/10','09/28','06/28','06/10','05/26','09/14','09/28','10/07','0055','0087','0116')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('211630','MN','CARLTON','CLOQUET',4.670472222000000e+001,-9.252527800000000e+001,'06/13','09/29','06/23','06/13','05/28','09/20','09/29','10/10','0067','0091','0117')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('211691','MN','STEARNS','COLLEGEVILLE ST JOHN',4.558722222000000e+001,-9.440472200000001e+001,'05/14','10/18','05/22','05/14','05/04','10/07','10/18','10/31','0122','0135','0156')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('211891','MN','POLK','CROOKSTON NW EXP STN',4.780138888000000e+001,-9.660277800000000e+001,'05/23','10/03','06/02','05/23','05/16','09/24','10/03','10/16','0096','0116','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('212142','MN','BECKER','DETROIT LAKES 1 NNE',4.683722222000000e+001,-9.583722200000000e+001,'06/02','09/27','06/26','06/02','05/21','09/22','09/27','10/13','0055','0101','0118')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('212248','MN','ST. LOUIS','DULUTH INTL AP',4.683694444000000e+001,-9.218333300000001e+001,'06/08','10/04','06/24','06/08','05/24','09/28','10/04','10/21','0074','0102','0131')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('212698','MN','MARTIN','FAIRMONT',4.364472222000000e+001,-9.446555600000001e+001,'05/11','10/21','05/17','05/11','04/22','10/13','10/21','11/02','0130','0144','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('212721','MN','RICE','FARIBAULT',4.430750000000000e+001,-9.326500000000000e+001,'05/22','10/10','06/08','05/22','05/08','10/05','10/10','10/24','0101','0124','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('212881','MN','CHISAGO','FOREST LAKE 5NE',4.533972222000000e+001,-9.291249999999999e+001,'05/13','10/18','05/24','05/13','05/01','10/07','10/18','11/02','0120','0139','0158')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('212916','MN','POLK','FOSSTON 1 E',4.756361111000000e+001,-9.572444400000001e+001,'05/31','10/02','06/25','05/31','05/20','09/25','10/02','10/12','0065','0101','0122')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('213076','MN','SIBLEY','GAYLORD',4.455638888000000e+001,-9.422055600000000e+001,'05/12','10/15','05/22','05/12','04/29','10/07','10/15','10/30','0120','0137','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('213104','MN','CLAY','GEORGETOWN 1 E',4.707916666000000e+001,-9.677583300000001e+001,'05/25','10/08','05/31','05/25','05/14','09/26','10/08','10/19','0099','0112','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('213174','MN','POPE','GLENWOOD 2 WNW',4.565833333000000e+001,-9.543916700000000e+001,'05/23','10/09','06/04','05/23','05/09','09/29','10/09','10/22','0099','0124','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('213282','MN','COOK','GRAND MARAIS',4.775166666000000e+001,-9.035777800000000e+001,'05/26','10/10','06/11','05/26','05/13','10/05','10/10','11/05','0096','0123','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('213290','MN','MOWER','GRAND MEADOW',4.370472222000000e+001,-9.256444400000000e+001,'05/15','10/16','05/25','05/15','05/05','10/07','10/16','10/26','0118','0136','0152')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('213296','MN','COOK','GRAND PORTAGE',4.797111111000000e+001,-8.969083300000000e+001,'07/08','09/25','07/08','07/08','07/10','09/18','09/25','10/19','0021','0023','0032')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('213303','MN','ITASCA','GRAND RPDS FOREST LAB',4.724361111000000e+001,-9.349750000000000e+001,'05/31','10/01','06/16','05/31','05/17','09/24','10/01','10/10','0074','0104','0130')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('213411','MN','CASS','GULL LAKE DAM',4.641194444000000e+001,-9.436083300000000e+001,'05/19','10/08','05/30','05/19','05/11','10/01','10/08','10/23','0111','0129','0142')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('213417','MN','COOK','GUNFLINT LAKE 10 NW',4.816027777000000e+001,-9.088416700000001e+001,'06/12','10/06','06/30','06/12','05/25','09/29','10/06','10/21','0064','0096','0121')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('213567','MN','DAKOTA','HASTINGS DAM 2',4.475972222000000e+001,-9.286888900000000e+001,'05/22','10/22','05/29','05/22','05/05','10/10','10/22','11/05','0115','0131','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('214026','MN','KOOCHICHING','INTERNATIONAL FALLS AP',4.856138888000000e+001,-9.339805600000000e+001,'06/08','09/29','06/29','06/08','05/24','09/20','09/29','10/05','0065','0095','0120')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('214103','MN','AITKIN','ISLE 12N',4.631972222000000e+001,-9.350138900000000e+001,'06/01','10/06','06/25','06/01','05/22','09/29','10/06','10/21','0075','0106','0124')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('214106','MN','CLEARWATER','ITASCA UNIV OF MINN',4.722555555000000e+001,-9.519194400000001e+001,'06/05','10/01','06/17','06/05','05/24','09/26','10/01','10/12','0071','0099','0125')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('214176','MN','SCOTT','JORDAN 1SSW',4.465000000000000e+001,-9.363555599999999e+001,'05/23','10/07','06/06','05/23','05/13','10/01','10/07','10/20','0094','0115','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('214233','MN','BELTRAMI','KELLIHER',4.794222222000000e+001,-9.445527800000001e+001,'06/10','10/01','06/20','06/10','05/23','09/22','10/01','10/12','0071','0099','0123')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('214546','MN','REDWOOD','LAMBERTON SW EXP STN',4.423944444000000e+001,-9.531527800000001e+001,'05/17','10/12','05/28','05/17','05/10','09/29','10/12','10/24','0108','0128','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('214652','MN','CASS','LEECH LAKE',4.724666666000000e+001,-9.422277800000001e+001,'05/24','10/08','06/07','05/24','05/15','09/27','10/08','10/18','0092','0113','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('214778','MN','MEEKER','LITCHFIELD',4.512777777000000e+001,-9.453472200000000e+001,'05/20','10/14','05/31','05/20','05/05','10/03','10/14','10/27','0109','0127','0143')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('214793','MN','MORRISON','LITTLE FALLS 1 N',4.599333333000000e+001,-9.435083299999999e+001,'05/22','10/08','06/05','05/22','05/15','10/03','10/08','10/19','0097','0122','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('214861','MN','TODD','LONG PRAIRIE',4.596472222000000e+001,-9.488916700000000e+001,'05/30','10/05','06/05','05/30','05/11','10/02','10/05','10/18','0093','0112','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('214937','MN','ROCK','LUVERNE',4.366583333000000e+001,-9.620222200000001e+001,'05/19','10/07','05/29','05/19','05/10','09/30','10/07','10/21','0105','0125','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('214994','MN','LAC QUI PARLE','MADISON SEWAGE PLT',4.500250000000000e+001,-9.616611100000000e+001,'05/17','10/11','05/22','05/17','05/08','09/28','10/11','10/19','0113','0125','0145')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('215204','MN','LYON','MARSHALL',4.447055555000000e+001,-9.579083300000001e+001,'05/19','10/14','05/25','05/19','05/05','10/06','10/14','10/24','0114','0133','0156')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('215325','MN','STEARNS','MELROSE',4.567750000000000e+001,-9.480222200000000e+001,'05/23','10/07','06/07','05/23','05/09','09/28','10/07','10/18','0100','0119','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('215392','MN','MILLE LACS','MILACA',4.575333333000000e+001,-9.366166699999999e+001,'05/24','10/07','06/08','05/24','05/11','09/28','10/07','10/17','0099','0119','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('215400','MN','CHIPPEWA','MILAN 1 NW',4.512194444000000e+001,-9.592694400000001e+001,'05/23','10/04','06/03','05/23','05/13','09/26','10/04','10/17','0098','0116','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('215435','MN','HENNEPIN','MINNEAPOLIS/ST PAUL AP',4.488305555000000e+001,-9.322888900000000e+001,'05/12','10/20','05/24','05/12','04/28','10/07','10/20','11/02','0120','0140','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('215563','MN','LAC QUI PARLE','MONTEVIDEO 1 SW',4.493638888000000e+001,-9.575361100000001e+001,'05/18','10/10','06/05','05/18','05/08','10/03','10/10','10/24','0093','0126','0142')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('215598','MN','CARLTON','MOOSE LAKE 1 SSE',4.643777777000000e+001,-9.275777800000000e+001,'06/12','10/03','06/25','06/12','05/30','09/28','10/03','10/13','0058','0087','0115')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('215615','MN','KANABEC','MORA',4.587750000000000e+001,-9.331472200000000e+001,'06/06','10/01','06/30','06/06','05/28','09/25','10/01','10/09','0061','0091','0113')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('215638','MN','STEVENS','MORRIS WC EXP STN',4.559027777000000e+001,-9.587472200000001e+001,'05/19','10/10','05/28','05/19','05/09','09/28','10/10','10/24','0105','0123','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('216276','MN','OTTER TAIL','OTTERTAIL',4.643138888000000e+001,-9.554638900000001e+001,'05/18','10/12','05/27','05/18','05/09','10/03','10/12','10/24','0109','0129','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('216287','MN','STEELE','OWATONNA',4.409805555000000e+001,-9.323083300000000e+001,'05/16','10/13','05/31','05/16','05/09','10/07','10/13','10/23','0110','0133','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('216547','MN','CROW WING','PINE RIVER DAM',4.666944444000000e+001,-9.410888900000001e+001,'05/27','10/07','06/12','05/27','05/16','09/28','10/07','10/16','0087','0114','0131')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('216565','MN','PIPESTONE','PIPESTONE',4.401388888000000e+001,-9.632583300000000e+001,'06/07','10/04','06/23','06/07','05/19','09/25','10/04','10/11','0072','0099','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('216612','MN','ITASCA','POKEGAMA DAM',4.725083333000000e+001,-9.358611100000000e+001,'05/26','10/06','06/13','05/26','05/15','09/26','10/06','10/17','0090','0116','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('216654','MN','FILLMORE','PRESTON',4.367250000000000e+001,-9.207472199999999e+001,'06/01','10/06','06/16','06/01','05/19','09/29','10/06','10/15','0080','0104','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('216787','MN','RED LAKE','RED LAKE FALLS',4.788805555000000e+001,-9.626583300000000e+001,'05/25','10/05','06/07','05/25','05/15','09/23','10/05','10/15','0091','0109','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('216795','MN','BELTRAMI','RED LAKE INDIAN AGCY',4.787694444000000e+001,-9.501611100000000e+001,'06/01','10/04','06/17','06/01','05/22','09/28','10/04','10/16','0083','0109','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('216822','MN','GOODHUE','RED WING DAM 3',4.461027777000000e+001,-9.261000000000000e+001,'05/22','10/17','05/29','05/22','05/04','10/08','10/17','10/30','0113','0128','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('217004','MN','OLMSTED','ROCHESTER INTL AP',4.390416666000000e+001,-9.249166700000001e+001,'05/16','10/15','06/02','05/16','05/04','10/02','10/15','10/26','0109','0137','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('217107','MN','DAKOTA','ROSEMOUNT AGR EXP STN',4.471777777000000e+001,-9.309750000000000e+001,'05/17','10/11','05/29','05/17','05/08','10/06','10/11','10/27','0112','0129','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('217149','MN','WILKIN','ROTHSAY',4.648083333000000e+001,-9.628694400000001e+001,'05/21','10/10','05/31','05/21','05/13','09/29','10/10','10/20','0104','0120','0142')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('217294','MN','SHERBURNE','ST CLOUD MUNI AP',4.554333333000000e+001,-9.405138900000000e+001,'05/28','10/03','06/11','05/28','05/13','09/26','10/03','10/15','0093','0112','0132')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('217326','MN','WATONWAN','ST JAMES FILT PLT',4.399027777000000e+001,-9.461222200000000e+001,'05/11','10/18','05/26','05/11','05/08','10/04','10/18','10/26','0116','0136','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('217405','MN','NICOLLET','ST PETER',4.432222222000000e+001,-9.396555600000001e+001,'05/12','10/18','05/26','05/12','05/06','10/05','10/18','10/29','0115','0135','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('217460','MN','AITKIN','SANDY LAKE DAM LIBBY',4.679527777000000e+001,-9.332111100000000e+001,'05/26','10/08','06/13','05/26','05/15','09/28','10/08','10/14','0084','0113','0132')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('217502','MN','SHERBURNE','SANTIAGO 3 E',4.554611111000000e+001,-9.375722200000000e+001,'06/05','09/29','06/16','06/05','05/19','09/23','09/29','10/11','0082','0102','0128')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('217907','MN','BROWN','SPRINGFIELD 1 NW',4.424694444000000e+001,-9.498638900000000e+001,'05/17','10/09','05/27','05/17','05/07','09/29','10/09','10/26','0110','0125','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('218227','MN','WABASHA','THEILMAN 1SSW',4.428138888000000e+001,-9.219416699999999e+001,'06/01','10/13','06/13','06/01','05/13','10/05','10/13','10/27','0094','0111','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('218254','MN','BELTRAMI','THORHULT',4.823250000000000e+001,-9.524805600000001e+001,'06/15','09/25','07/06','06/15','05/27','09/16','09/25','10/04','0045','0081','0107')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('218311','MN','ST. LOUIS','TOWER 2S',4.778166666000000e+001,-9.227833300000000e+001,'07/21','09/09','08/05','07/21','07/05','08/21','09/09','09/20','0000','0024','0050')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('218323','MN','LYON','TRACY',4.423944444000000e+001,-9.563083300000000e+001,'05/14','10/19','05/24','05/14','05/08','10/05','10/19','10/25','0117','0136','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('218419','MN','LAKE','TWO HARBORS',4.702583333000000e+001,-9.166527800000000e+001,'05/30','10/11','06/16','05/30','05/09','10/06','10/11','11/05','0100','0120','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('218579','MN','WADENA','WADENA 3 S',4.639388888000000e+001,-9.539388900000000e+001,'05/22','10/05','06/04','05/22','05/13','09/28','10/05','10/20','0097','0122','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('218679','MN','ROSEAU','WARROAD',4.889472222000000e+001,-9.533000000000000e+001,'05/31','10/03','06/15','05/31','05/18','09/26','10/03','10/14','0077','0107','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('218692','MN','WASECA','WASECA EXP STN',4.407083333000000e+001,-9.352638900000000e+001,'05/17','10/10','05/25','05/17','05/06','10/03','10/10','10/24','0114','0128','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('218700','MN','BELTRAMI','WASKISH 4NE',4.820638888000000e+001,-9.439388900000000e+001,'06/04','10/02','07/05','06/04','05/23','09/22','10/02','10/10','0055','0105','0121')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('218808','MN','FARIBAULT','WELLS',4.374611111000000e+001,-9.373638900000000e+001,'05/15','10/15','05/22','05/15','05/04','10/04','10/15','10/26','0118','0137','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('218907','MN','TRAVERSE','WHEATON',4.580805555000000e+001,-9.650416700000000e+001,'05/18','10/11','05/22','05/18','05/09','10/04','10/11','10/28','0117','0127','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('219033','MN','COTTONWOOD','WINDOM',4.385750000000000e+001,-9.511666700000001e+001,'05/17','10/13','05/27','05/17','05/05','10/01','10/13','10/23','0110','0127','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('219046','MN','FARIBAULT','WINNEBAGO',4.376388888000000e+001,-9.416611100000000e+001,'05/14','10/17','05/21','05/14','05/06','10/07','10/17','10/28','0123','0140','0153')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('219072','MN','WINONA','WINONA DAM 5 A',4.408750000000000e+001,-9.167027800000000e+001,'05/14','10/20','05/26','05/14','05/02','10/09','10/20','11/05','0115','0133','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('219170','MN','NOBLES','WORTHINGTON 2 NNE',4.364500000000000e+001,-9.558027800000001e+001,'05/15','10/12','05/27','05/15','05/09','10/01','10/12','10/22','0110','0130','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('219173','MN','CARLTON','WRIGHT 3 E',4.668027777000000e+001,-9.295416700000000e+001,'06/16','09/25','07/03','06/16','05/29','09/18','09/25','10/06','0048','0079','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('220021','MS','MONROE','ABERDEEN',3.383000000000000e+001,-8.852138900000000e+001,'04/13','11/21','04/25','04/13','03/24','11/12','11/21','12/03','0178','0201','0234')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('220488','MS','PANOLA','BATESVILLE 2 SW',3.430611111000000e+001,-8.998055600000001e+001,'04/16','11/13','04/25','04/16','04/08','10/29','11/13','11/25','0169','0188','0209')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('220660','MS','HUMPHREYS','BELZONI',3.317722222000000e+001,-9.049194400000000e+001,'04/04','12/02','04/12','04/04','03/14','11/19','12/02','12/19','0192','0221','0248')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('220792','MS','HARRISON','BILOXI',3.039305555000000e+001,-8.900083300000000e+001,'03/19','01/07','03/30','03/19','03/04','12/16','01/07','02/16','0234','0256','0284')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('220955','MS','PRENTISS','BOONEVILLE',3.463444444000000e+001,-8.856222200000001e+001,'04/14','11/20','04/24','04/14','03/31','11/09','11/20','12/08','0173','0194','0227')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('221094','MS','LINCOLN','BROOKHAVEN CITY',3.154472222000000e+001,-9.045805600000000e+001,'04/10','11/25','04/18','04/10','03/25','11/10','11/25','12/13','0186','0204','0237')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('221314','MS','CALHOUN','CALHOUN CITY',3.385861111000000e+001,-8.931583300000000e+001,'04/15','11/14','04/27','04/15','04/06','10/27','11/14','11/25','0168','0185','0211')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('221389','MS','MADISON','CANTON 4N',3.267138888000000e+001,-9.003611100000001e+001,'04/11','11/23','04/19','04/11','03/26','11/12','11/23','12/08','0180','0199','0231')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('221489','MS','LEAKE','CARTHAGE',3.275055555000000e+001,-8.953888900000000e+001,'04/13','11/20','04/21','04/13','03/26','11/05','11/20','12/05','0175','0195','0222')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('221606','MS','TALLAHATCHIE','CHARLESTON',3.400388888000000e+001,-9.006805600000000e+001,'04/13','11/17','04/21','04/13','04/01','11/05','11/17','12/04','0175','0194','0225')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('221707','MS','COAHOMA','CLARKSDALE',3.418638888000000e+001,-9.055722200000000e+001,'04/04','11/29','04/13','04/04','03/21','11/16','11/29','12/18','0195','0215','0246')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('221852','MS','COVINGTON','COLLINS',3.164194444000000e+001,-8.955722200000000e+001,'04/07','11/27','04/15','04/07','03/20','11/16','11/27','12/16','0191','0210','0241')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('221865','MS','MARION','COLUMBIA',3.125027777000000e+001,-8.983611100000000e+001,'03/31','12/03','04/14','03/31','03/17','11/20','12/03','12/31','0192','0224','0249')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('221962','MS','ALCORN','CORINTH 7 SW',3.487916666000000e+001,-8.861777800000000e+001,'04/19','11/14','04/27','04/19','04/03','10/27','11/14','11/21','0166','0181','0211')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('222094','MS','COPIAH','CRYSTAL SPGS EXP STN',3.194611111000000e+001,-9.037750000000000e+001,'04/07','12/12','04/15','04/07','03/18','11/22','12/12','12/28','0193','0219','0247')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('222385','MS','SIMPSON','D''LO 2 SW',3.195444444000000e+001,-8.993277800000000e+001,'04/13','11/17','04/22','04/13','03/24','11/02','11/17','12/01','0177','0192','0223')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('222896','MS','WEBSTER','EUPORA 2 E',3.356277777000000e+001,-8.923583300000000e+001,'04/18','11/11','04/23','04/18','04/08','10/28','11/11','11/28','0170','0181','0207')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('223107','MS','SCOTT','FOREST',3.236000000000000e+001,-8.942083300000000e+001,'04/15','11/15','04/24','04/15','03/31','10/30','11/15','12/02','0172','0195','0226')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('223208','MS','ITAWAMBA','FULTON 3 W',3.426138888000000e+001,-8.845694399999999e+001,'04/24','11/12','05/03','04/24','04/08','10/26','11/12','11/29','0160','0173','0205')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('223605','MS','WASHINGTON','GREENVILLE',3.335916666000000e+001,-9.106000000000000e+001,'03/27','12/05','04/13','03/27','03/15','11/18','12/05','12/18','0196','0226','0249')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('223627','MS','CARROLL','GREENWOOD LEFLORE AP',3.349638888000000e+001,-9.008666700000001e+001,'04/12','12/09','04/19','04/12','03/24','11/21','12/09','12/26','0184','0196','0232')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('223645','MS','GRENADA','GRENADA',3.376083333000000e+001,-8.981361100000000e+001,'04/17','11/18','04/21','04/17','03/31','11/01','11/18','12/08','0175','0189','0217')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('223887','MS','FORREST','HATTIESBURG 5SW',3.125472222000000e+001,-8.933916700000000e+001,'03/31','12/03','04/11','03/31','03/11','11/21','12/03','01/06','0194','0228','0256')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('223975','MS','DESOTO','HERNANDO',3.481611111000000e+001,-8.998527799999999e+001,'04/12','11/17','04/19','04/12','03/28','11/11','11/17','12/07','0182','0200','0227')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('224001','MS','BENTON','HICKORY FLAT',3.461888888000000e+001,-8.919111100000001e+001,'04/25','11/08','04/29','04/25','04/11','10/24','11/08','11/19','0162','0176','0202')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('224173','MS','MARSHALL','HOLLY SPRINGS 4 N',3.482194444000000e+001,-8.943472199999999e+001,'04/21','11/05','04/29','04/21','04/11','10/23','11/05','11/17','0160','0176','0197')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('224265','MS','CHICKASAW','HOUSTON',3.392777777000000e+001,-8.900833299999999e+001,'04/20','11/12','04/29','04/20','04/08','10/23','11/12','11/22','0163','0182','0203')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('224377','MS','TATE','INDEPENDENCE 1W',3.469888888000000e+001,-8.982138900000000e+001,'04/16','11/14','04/25','04/16','04/06','10/27','11/14','11/27','0171','0188','0206')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('224472','MS','RANKIN','JACKSON INTL AP',3.232055555000000e+001,-9.007777800000000e+001,'04/08','11/26','04/18','04/08','03/21','11/16','11/26','12/10','0187','0207','0241')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('224776','MS','ATTALA','KOSCIUSKO',3.305833333000000e+001,-8.957972200000000e+001,'04/15','11/18','04/23','04/15','04/02','11/01','11/18','12/04','0171','0196','0223')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('224939','MS','JONES','LAUREL',3.167555555000000e+001,-8.912361100000000e+001,'03/27','12/03','04/13','03/27','03/13','11/18','12/03','12/19','0198','0225','0252')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('225247','MS','WINSTON','LOUISVILLE',3.313555555000000e+001,-8.907111100000000e+001,'04/14','11/25','04/18','04/14','03/27','11/13','11/25','12/07','0182','0203','0230')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('225614','MS','PIKE','MCCOMB AP',3.118277777000000e+001,-9.047083300000000e+001,'04/04','12/04','04/16','04/04','03/21','11/18','12/04','12/29','0192','0220','0241')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('225704','MS','FRANKLIN','MEADVILLE',3.146638888000000e+001,-9.088527800000000e+001,'04/10','12/02','04/19','04/10','03/21','11/16','12/02','12/20','0183','0212','0242')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('225776','MS','LAUDERDALE','MERIDIAN AP',3.233472222000000e+001,-8.874416700000000e+001,'04/11','11/23','04/20','04/11','03/22','11/10','11/23','12/16','0183','0203','0242')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('225987','MS','LAWRENCE','MONTICELLO',3.155194444000000e+001,-9.010583300000000e+001,'04/11','11/28','04/16','04/11','03/19','11/13','11/28','12/11','0180','0196','0230')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('226009','MS','SUNFLOWER','MOORHEAD',3.345166666000000e+001,-9.050972200000000e+001,'04/04','12/07','04/15','04/04','03/21','11/19','12/07','12/16','0195','0217','0244')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('226177','MS','ADAMS','NATCHEZ',3.158888888000000e+001,-9.134083300000000e+001,'03/25','12/05','04/16','03/25','03/14','11/25','12/05','12/22','0192','0229','0261')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('226308','MS','NEWTON','NEWTON EXP STN',3.233777777000000e+001,-8.908166700000000e+001,'04/12','11/16','04/22','04/12','03/28','11/03','11/16','12/06','0173','0195','0225')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('226476','MS','HINDS','OAKLEY EXP STN',3.220611111000000e+001,-9.051333300000000e+001,'04/10','11/23','04/19','04/10','03/25','11/07','11/23','12/06','0184','0200','0231')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('226718','MS','JACKSON','PASCAGOULA 3 NE',3.039611111000000e+001,-8.847805600000000e+001,'03/19','12/29','04/01','03/19','03/07','12/18','12/29','01/23','0218','0250','0279')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('226894','MS','NESHOBA','PHILADELPHIA 1 WSW',3.276916666000000e+001,-8.913027800000000e+001,'04/10','11/23','04/20','04/10','03/25','11/07','11/23','12/06','0183','0200','0232')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('226921','MS','PEARL RIVER','PICAYUNE',3.052166666000000e+001,-8.970833300000000e+001,'03/28','12/13','04/11','03/28','03/11','11/22','12/13','01/06','0197','0228','0259')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('227111','MS','PONTOTOC','PONTOTOC EXP STN',3.413805555000000e+001,-8.899833300000000e+001,'04/19','11/22','04/23','04/19','04/02','11/05','11/22','12/03','0173','0191','0216')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('227128','MS','PEARL RIVER','POPLARVILLE EXP STN',3.084083333000000e+001,-8.954527800000000e+001,'03/24','12/13','04/11','03/24','03/16','11/27','12/13','01/03','0205','0230','0255')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('227132','MS','CLAIBORNE','PORT GIBSON 1 NE',3.198500000000000e+001,-9.097194399999999e+001,'04/09','11/23','04/18','04/09','03/20','11/13','11/23','12/05','0180','0200','0236')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('227467','MS','TIPPAH','RIPLEY',3.473972222000000e+001,-8.895138900000001e+001,'04/19','11/15','04/29','04/19','04/08','10/29','11/15','11/20','0165','0184','0205')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('227560','MS','SHARKEY','ROLLING FORK',3.289777777000000e+001,-9.088527800000000e+001,'04/05','11/27','04/12','04/05','03/21','11/20','11/27','12/14','0192','0214','0238')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('227840','MS','HARRISON','SAUCIER EXP FOREST',3.062638888000000e+001,-8.905500000000001e+001,'03/24','12/17','04/06','03/24','03/14','11/29','12/17','01/13','0212','0238','0271')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('228374','MS','OKTIBBEHA','STATE UNIV',3.346916666000000e+001,-8.878222200000000e+001,'04/12','11/23','04/20','04/12','03/28','11/09','11/23','12/08','0180','0201','0230')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('228445','MS','WASHINGTON','STONEVILLE EXP STA',3.343111111000000e+001,-9.091083300000000e+001,'03/31','11/30','04/13','03/31','03/15','11/17','11/30','12/19','0193','0214','0251')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('228998','MS','TUNICA','TUNICA 2 N',3.472805555000000e+001,-9.036833300000001e+001,'04/07','11/25','04/17','04/07','03/27','11/07','11/25','12/10','0185','0204','0229')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('229003','MS','LEE','TUPELO RGNL AP',3.426222222000000e+001,-8.877138900000000e+001,'04/22','11/16','05/02','04/22','04/08','11/06','11/16','12/07','0158','0175','0203')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('229048','MS','WALTHALL','TYLERTOWN 5ESE',3.108000000000000e+001,-9.006027800000000e+001,'04/08','12/03','04/16','04/08','03/20','11/21','12/03','12/23','0194','0215','0250')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('229079','MS','LAFAYETTE','UNIVERSITY',3.437250000000000e+001,-8.953083300000000e+001,'04/25','11/05','05/10','04/25','04/12','10/22','11/05','11/21','0144','0169','0199')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('229400','MS','YALOBUSHA','WATER VALLEY',3.415833333000000e+001,-8.963111100000000e+001,'04/18','11/16','04/25','04/18','04/08','11/01','11/16','11/28','0175','0188','0210')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('229439','MS','WAYNE','WAYNESBORO 2 W',3.167722222000000e+001,-8.867083300000000e+001,'04/11','11/15','04/24','04/11','03/27','11/03','11/15','12/07','0171','0194','0222')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('229639','MS','STONE','WIGGINS',3.086666666000000e+001,-8.913333299999999e+001,'04/03','12/07','04/08','04/03','03/19','11/23','12/07','01/02','0208','0226','0252')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('229743','MS','MONTGOMERY','WINONA 5 E',3.348472222000000e+001,-8.962444400000000e+001,'04/20','11/11','04/28','04/20','04/10','10/25','11/11','11/22','0165','0179','0204')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('229793','MS','WILKINSON','WOODVILLE 4 ESE',3.109305555000000e+001,-9.123250000000000e+001,'03/25','12/09','04/12','03/25','03/12','11/27','12/09','12/26','0208','0232','0266')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('229860','MS','YAZOO','YAZOO CITY 5 NNE',3.290277777000000e+001,-9.038166699999999e+001,'04/07','11/30','04/15','04/07','03/21','11/20','11/30','12/24','0192','0213','0241')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('230022','MO','STODDARD','ADVANCE 1 S',3.709555555000000e+001,-8.991611100000000e+001,'04/23','10/31','05/04','04/23','04/16','10/24','10/31','11/19','0152','0170','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('230127','MO','OREGON','ALTON 6 SE',3.663000000000000e+001,-9.130416700000001e+001,'05/04','10/24','05/23','05/04','04/21','10/14','10/24','11/07','0130','0155','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('230143','MO','DEKALB','AMITY 4 NE',3.989138888000000e+001,-9.436000000000000e+001,'05/01','10/25','05/12','05/01','04/24','10/18','10/25','11/06','0135','0152','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('230204','MO','ST. CLAIR','APPLETON CITY',3.818694444000000e+001,-9.402805600000001e+001,'04/23','11/06','05/08','04/23','04/18','10/23','11/06','11/16','0146','0169','0188')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('230608','MO','HARRISON','BETHANY',4.025750000000000e+001,-9.402694400000000e+001,'04/29','10/28','05/17','04/29','04/20','10/14','10/28','11/09','0126','0156','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('230657','MO','CHRISTIAN','BILLINGS 1SW',3.705361111000000e+001,-9.357500000000000e+001,'04/29','11/05','05/12','04/29','04/15','10/17','11/05','11/19','0142','0162','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('230789','MO','POLK','BOLIVAR 1 NE',3.761666666000000e+001,-9.339111100000000e+001,'05/09','10/28','05/20','05/09','04/20','10/18','10/28','11/13','0125','0142','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('230856','MO','PIKE','BOWLING GREEN 1 E',3.934472222000000e+001,-9.117111100000000e+001,'05/13','10/19','05/25','05/13','04/25','10/12','10/19','11/04','0121','0142','0166')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('230980','MO','LINN','BROOKFIELD',3.976500000000000e+001,-9.305944400000000e+001,'04/29','10/31','05/12','04/29','04/16','10/20','10/31','11/10','0142','0161','0188')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('231037','MO','CHARITON','BRUNSWICK',3.942472222000000e+001,-9.313305600000000e+001,'05/01','10/29','05/12','05/01','04/17','10/22','10/29','11/10','0143','0155','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('231101','MO','REYNOLDS','BUNKER 4N',3.751388888000000e+001,-9.119388900000000e+001,'05/02','10/30','05/15','05/02','04/14','10/18','10/30','11/16','0134','0152','0191')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('231145','MO','BATES','BUTLER 4W',3.826111111000000e+001,-9.440500000000000e+001,'05/03','10/31','05/16','05/03','04/20','10/17','10/31','11/17','0134','0153','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('231189','MO','MONITEAU','CALIFORNIA',3.862777777000000e+001,-9.255444400000000e+001,'04/20','11/09','05/07','04/20','04/13','10/26','11/09','11/19','0150','0179','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('231275','MO','LEWIS','CANTON L&D 20',4.014333333000000e+001,-9.151583300000000e+001,'04/21','11/07','05/10','04/21','04/14','10/20','11/07','11/15','0145','0175','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('231289','MO','SCOTT','CAPE GIRARDEAU FAA AP',3.722527777000000e+001,-8.957055600000000e+001,'04/18','11/09','04/30','04/18','04/10','10/28','11/09','11/25','0160','0180','0202')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('231340','MO','CARROLL','CARROLLTON',3.935944444000000e+001,-9.348861100000001e+001,'04/30','10/29','05/10','04/30','04/17','10/21','10/29','11/11','0139','0157','0188')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('231356','MO','JASPER','CARTHAGE',3.717722222000000e+001,-9.430472200000000e+001,'04/24','11/12','05/08','04/24','04/14','10/21','11/12','11/22','0145','0169','0202')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('231364','MO','PEMISCOT','CARUTHERSVILLE',3.612611111000000e+001,-8.970000000000000e+001,'04/13','11/19','04/24','04/13','04/01','10/31','11/19','12/05','0171','0194','0215')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('231383','MO','BARRY','CASSVILLE RANGER STN',3.667277777000000e+001,-9.385777800000000e+001,'05/08','10/24','05/18','05/08','04/23','10/13','10/24','11/08','0132','0150','0177')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('231674','MO','WAYNE','CLEARWATER DAM',3.713194444000000e+001,-9.077555600000000e+001,'04/28','11/01','05/14','04/28','04/15','10/20','11/01','11/14','0145','0171','0194')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('231711','MO','HENRY','CLINTON',3.839500000000000e+001,-9.377111100000001e+001,'05/02','11/03','05/12','05/02','04/20','10/17','11/03','11/13','0140','0160','0183')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('231791','MO','BOONE','COLUMBIA RGNL AP',3.881694444000000e+001,-9.221833300000000e+001,'04/21','11/06','05/06','04/21','04/14','10/21','11/06','11/20','0147','0174','0191')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('231822','MO','NODAWAY','CONCEPTION',4.023944444000000e+001,-9.468333300000001e+001,'04/29','10/27','05/12','04/29','04/20','10/19','10/27','11/14','0138','0155','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('232289','MO','RIPLEY','DONIPHAN',3.662055555000000e+001,-9.081250000000000e+001,'05/03','10/25','05/18','05/03','04/18','10/16','10/25','11/08','0137','0157','0181')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('232302','MO','OZARK','DORA 1N',3.679000000000000e+001,-9.221916700000000e+001,'05/05','10/29','05/20','05/05','04/24','10/15','10/29','11/17','0134','0153','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('232503','MO','MILLER','ELDON',3.834861111000000e+001,-9.258083300000000e+001,'04/22','11/07','04/30','04/22','04/14','10/27','11/07','11/27','0153','0178','0195')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('232591','MO','LINCOLN','ELSBERRY 1 S',3.915055555000000e+001,-9.078472200000000e+001,'05/06','10/24','05/16','05/06','04/19','10/17','10/24','11/06','0135','0150','0181')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('232809','MO','ST. FRANCOIS','FARMINGTON',3.779222222000000e+001,-9.041027800000001e+001,'05/05','10/22','05/20','05/05','04/23','10/18','10/22','11/02','0129','0151','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('232850','MO','JEFFERSON','FESTUS',3.823055555000000e+001,-9.039805600000000e+001,'05/02','10/24','05/17','05/02','04/25','10/18','10/24','11/10','0132','0155','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('233038','MO','MADISON','FREDERICKTOWN',3.757388888000000e+001,-9.030861100000000e+001,'05/13','10/18','05/24','05/13','05/02','10/10','10/18','10/31','0118','0143','0159')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('233043','MO','OSAGE','FREEDOM',3.845833333000000e+001,-9.170277800000000e+001,'04/30','10/24','05/18','04/30','04/22','10/18','10/24','11/10','0133','0156','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('233079','MO','CALLAWAY','FULTON',3.884722222000000e+001,-9.194138900000000e+001,'04/22','11/01','05/09','04/22','04/17','10/19','11/01','11/14','0146','0171','0190')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('233094','MO','STONE','GALENA',3.680611111000000e+001,-9.346611100000000e+001,'05/05','10/25','05/18','05/05','04/23','10/14','10/25','11/17','0131','0151','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('233102','MO','DAVIESS','GALLATIN 1W',3.991333333000000e+001,-9.398027800000000e+001,'05/01','11/12','05/10','05/01','04/19','11/11','11/12','11/15','0147','0169','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('233568','MO','CALDWELL','HAMILTON 2W',3.974250000000000e+001,-9.403472200000000e+001,'05/14','10/19','05/29','05/14','05/03','10/04','10/19','10/28','0113','0138','0159')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('233601','MO','MARION','HANNIBAL WTR WKS',3.972333333000000e+001,-9.137194400000000e+001,'04/27','11/06','05/06','04/27','04/16','10/25','11/06','11/19','0149','0171','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('234019','MO','TEXAS','HOUSTON',3.731861111000000e+001,-9.196250000000001e+001,'05/08','10/18','05/22','05/08','04/25','10/10','10/18','11/07','0127','0148','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('234226','MO','CAPE GIRARDEAU','JACKSON',3.737805555000000e+001,-8.966777800000000e+001,'04/26','10/31','05/09','04/26','04/14','10/18','10/31','11/18','0145','0165','0197')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('234271','MO','COLE','JEFFERSON CITY WTP',3.858527777000000e+001,-9.218250000000001e+001,'04/28','11/05','05/10','04/28','04/19','10/22','11/05','11/25','0145','0162','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('234315','MO','JASPER','JOPLIN REGIONAL  AIRPORT',3.714666666000000e+001,-9.450222200000000e+001,'04/21','11/13','05/06','04/21','04/14','10/26','11/13','11/25','0148','0175','0195')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('234359','MO','CLAY','KANSAS CY DOWNTOWN AP',3.912083333000000e+001,-9.459694399999999e+001,'04/21','11/11','05/01','04/21','04/11','10/30','11/11','11/24','0158','0182','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('234417','MO','DUNKLIN','KENNETT RADIO KBOA',3.622527777000000e+001,-9.007500000000000e+001,'04/15','11/10','04/24','04/15','04/04','10/27','11/10','11/27','0167','0186','0211')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('234544','MO','ADAIR','KIRKSVILLE',4.020583333000000e+001,-9.257472199999999e+001,'05/04','10/27','05/15','05/04','04/20','10/16','10/27','11/10','0135','0153','0176')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('234694','MO','MILLER','LAKESIDE',3.820444444000000e+001,-9.262083300000001e+001,'04/25','11/09','05/11','04/25','04/12','10/26','11/09','11/26','0143','0181','0202')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('234705','MO','BARTON','LAMAR 2W',3.749333333000000e+001,-9.431472200000000e+001,'04/22','11/10','05/02','04/22','04/13','10/29','11/10','11/25','0153','0174','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('234825','MO','LACLEDE','LEBANON 2W',3.768500000000000e+001,-9.269361100000000e+001,'05/04','11/01','05/18','05/04','04/18','10/16','11/01','11/19','0132','0157','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('234919','MO','TEXAS','LICKING 4N',3.755444444000000e+001,-9.188305600000000e+001,'05/15','10/18','05/24','05/15','05/03','10/12','10/18','11/08','0124','0142','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('235027','MO','DADE','LOCKWOOD',3.739083333000000e+001,-9.394888899999999e+001,'04/21','11/06','05/08','04/21','04/13','10/24','11/06','11/22','0148','0176','0197')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('235207','MO','DUNKLIN','MALDEN MUNI AP',3.659944444000000e+001,-8.998944400000001e+001,'04/13','11/14','04/20','04/13','04/03','10/30','11/14','12/02','0171','0192','0215')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('235227','MO','WRIGHT','MANSFIELD',3.710888888000000e+001,-9.257888900000000e+001,'05/06','11/02','05/21','05/06','04/25','10/20','11/02','11/19','0119','0144','0165')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('235253','MO','BOLLINGER','MARBLE HILL',3.730361111000000e+001,-8.996638900000001e+001,'05/09','10/20','05/21','05/09','04/27','10/13','10/20','11/04','0126','0149','0167')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('235298','MO','SALINE','MARSHALL',3.913416666000000e+001,-9.322250000000000e+001,'04/22','11/04','05/05','04/22','04/17','10/21','11/04','11/14','0146','0169','0191')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('235307','MO','WEBSTER','MARSHFIELD',3.733388888000000e+001,-9.290972200000000e+001,'04/27','11/05','05/08','04/27','04/14','10/24','11/05','11/22','0149','0164','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('235340','MO','NODAWAY','MARYVILLE 2E',4.034583333000000e+001,-9.483416699999999e+001,'05/05','10/23','05/14','05/05','04/23','10/08','10/23','11/04','0126','0147','0167')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('235492','MO','SCOTLAND','MEMPHIS',4.045750000000000e+001,-9.218222200000000e+001,'05/06','10/28','05/17','05/06','04/25','10/13','10/28','11/09','0131','0146','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('235541','MO','AUDRAIN','MEXICO',3.917555555000000e+001,-9.188611100000000e+001,'04/26','11/01','05/08','04/26','04/20','10/22','11/01','11/16','0144','0163','0181')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('235671','MO','RANDOLPH','MOBERLY',3.941944444000000e+001,-9.243694400000000e+001,'04/22','11/06','05/04','04/22','04/15','10/23','11/06','11/19','0152','0176','0190')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('235834','MO','WRIGHT','MTN GROVE 2 N',3.715416666000000e+001,-9.226166700000000e+001,'04/26','11/06','05/16','04/26','04/15','10/19','11/06','11/21','0138','0159','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('235862','MO','LAWRENCE','MT VERNON M U SW CTR',3.707333333000000e+001,-9.387888900000000e+001,'05/06','10/28','05/17','05/06','04/20','10/14','10/28','11/14','0134','0149','0182')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('235976','MO','NEWTON','NEOSHO',3.686388888000000e+001,-9.436000000000000e+001,'05/04','10/30','05/18','05/04','04/17','10/14','10/30','11/14','0135','0147','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('235987','MO','VERNON','NEVADA WTP',3.783944444000000e+001,-9.437361100000000e+001,'05/02','10/31','05/13','05/02','04/23','10/21','10/31','11/19','0133','0152','0172')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('236012','MO','HOWARD','NEW FRANKLIN 1W',3.901722222000000e+001,-9.275583300000000e+001,'04/23','10/31','05/09','04/23','04/17','10/18','10/31','11/13','0143','0166','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('236045','MO','NEW MADRID','NEW MADRID',3.658694444000000e+001,-8.953250000000000e+001,'04/15','11/14','04/24','04/15','04/06','11/01','11/14','11/30','0167','0189','0208')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('236357','MO','HOLT','OREGON',3.998083333000000e+001,-9.514638900000000e+001,'04/30','10/29','05/08','04/30','04/20','10/20','10/29','11/16','0143','0158','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('236402','MO','ST. CLAIR','OSCEOLA',3.804916666000000e+001,-9.370361100000000e+001,'05/04','11/05','05/16','05/04','04/18','10/20','11/05','11/17','0137','0156','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('236460','MO','TANEY','OZARK BEACH',3.665972222000000e+001,-9.312611100000000e+001,'04/28','11/06','05/13','04/28','04/18','10/19','11/06','11/20','0141','0163','0191')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('236641','MO','PERRY','PERRYVILLE WTP',3.773416666000000e+001,-8.992000000000000e+001,'05/08','10/22','05/16','05/08','04/22','10/15','10/22','11/09','0132','0152','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('236777','MO','HICKORY','POMME DE TERRE DAM',3.790500000000000e+001,-9.331694400000001e+001,'05/02','11/04','05/13','05/02','04/15','10/21','11/04','11/22','0143','0159','0191')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('236791','MO','BUTLER','POPLAR BLUFF',3.675777777000000e+001,-9.040555600000000e+001,'04/17','11/12','04/27','04/17','04/08','10/30','11/12','11/26','0168','0185','0210')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('236804','MO','PEMISCOT','PORTAGEVILLE',3.641361111000000e+001,-8.969972199999999e+001,'04/13','11/16','04/19','04/13','03/31','10/31','11/16','12/05','0175','0192','0216')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('236866','MO','MERCER','PRINCETON',4.039861111000000e+001,-9.358388900000000e+001,'05/02','10/26','05/12','05/02','04/20','10/16','10/26','11/05','0131','0153','0172')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('237263','MO','PHELPS','ROLLA UNI OF MISSOURI',3.795722222000000e+001,-9.177583300000001e+001,'04/19','11/08','04/30','04/19','04/09','10/27','11/08','11/25','0158','0185','0204')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('237397','MO','ST. CHARLES','ST CHARLES ELM POINT',3.881472222000000e+001,-9.051694400000000e+001,'04/27','11/02','05/10','04/27','04/15','10/19','11/02','11/18','0143','0162','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('237452','MO','ST. LOUIS','ST LOUIS SCI CTR',3.862916666000000e+001,-9.027055600000000e+001,'04/26','11/14','05/07','04/26','04/09','11/03','11/14','11/29','0150','0179','0210')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('237455','MO','ST. LOUIS','ST LOUIS LAMBERT AP',3.875250000000000e+001,-9.037361100000000e+001,'04/19','11/12','04/27','04/19','04/10','10/30','11/12','11/26','0163','0184','0203')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('237506','MO','DENT','SALEM',3.763305555000000e+001,-9.153638900000000e+001,'05/05','10/25','05/18','05/05','04/16','10/15','10/25','11/15','0135','0154','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('237514','MO','CHARITON','SALISBURY',3.942472222000000e+001,-9.281055600000001e+001,'04/27','10/27','05/11','04/27','04/19','10/20','10/27','11/09','0135','0156','0172')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('237578','MO','RALLS','SAVERTON L&D 22',3.963611111000000e+001,-9.124944400000000e+001,'04/16','11/12','04/28','04/16','04/13','10/29','11/12','11/24','0164','0184','0206')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('237632','MO','PETTIS','SEDALIA WTP',3.867527777000000e+001,-9.322277800000001e+001,'05/05','10/26','05/17','05/05','04/24','10/16','10/26','11/10','0130','0148','0177')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('237720','MO','SHELBY','SHELBINA',3.968277777000000e+001,-9.204666700000000e+001,'05/09','10/26','05/20','05/09','04/22','10/18','10/26','11/08','0126','0144','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('237772','MO','SCOTT','SIKESTON PWR STN',3.687750000000000e+001,-8.962305600000001e+001,'04/19','11/14','04/25','04/19','04/05','10/26','11/14','12/01','0169','0184','0212')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('237963','MO','GRUNDY','SPICKARD 7 W',4.024722222000000e+001,-9.371583300000000e+001,'05/08','10/18','05/19','05/08','04/21','10/12','10/18','11/05','0125','0144','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('237976','MO','GREENE','SPRINGFIELD WSO AP',3.723972222000000e+001,-9.338972200000001e+001,'04/29','11/07','05/12','04/29','04/15','10/22','11/07','11/23','0143','0165','0195')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('238051','MO','LEWIS','STEFFENVILLE',3.997138888000000e+001,-9.188722199999999e+001,'05/04','10/28','05/16','05/04','04/18','10/17','10/28','11/10','0137','0151','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('238082','MO','CEDAR','STOCKTON DAM',3.769666666000000e+001,-9.377222200000000e+001,'04/23','11/10','05/07','04/23','04/10','10/27','11/10','11/24','0149','0170','0199')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('238184','MO','TEXAS','SUMMERSVILLE',3.717777777000000e+001,-9.165333300000000e+001,'04/29','10/29','05/16','04/29','04/15','10/18','10/29','11/11','0139','0162','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('238223','MO','SALINE','SWEET SPRINGS',3.896638888000000e+001,-9.341944400000000e+001,'05/01','10/28','05/12','05/01','04/18','10/17','10/28','11/12','0140','0158','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('238444','MO','GRUNDY','TRENTON',4.008250000000000e+001,-9.360861100000000e+001,'05/04','11/03','05/12','05/04','04/17','10/28','11/03','11/10','0137','0151','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('238577','MO','AUDRAIN','VANDALIA',3.931666666000000e+001,-9.148333300000000e+001,'04/27','11/01','05/09','04/27','04/16','10/20','11/01','11/17','0145','0163','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('238603','MO','MORGAN','VERSAILLES 2W',3.844000000000000e+001,-9.285194400000000e+001,'05/01','10/31','05/13','05/01','04/19','10/18','10/31','11/11','0139','0161','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('238614','MO','MARIES','VICHY ROLLA NATIONAL AP',3.813111111000000e+001,-9.176833300000000e+001,'04/24','11/07','05/05','04/24','04/12','10/24','11/07','11/23','0149','0174','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('238620','MO','MARIES','VIENNA 2 WNW',3.820166666000000e+001,-9.198111100000000e+001,'05/10','10/21','05/22','05/10','04/23','10/13','10/21','11/03','0120','0147','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('238700','MO','WAYNE','WAPPAPELLO DAM',3.692305555000000e+001,-9.028361099999999e+001,'04/16','11/16','04/26','04/16','04/05','11/04','11/16','11/26','0169','0192','0214')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('238712','MO','JOHNSON','WARRENSBURG 4NW',3.878416666000000e+001,-9.380083300000000e+001,'05/04','11/02','05/13','05/04','04/19','10/23','11/02','11/10','0131','0151','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('238725','MO','WARREN','WARRENTON 1 N',3.883500000000000e+001,-9.113861100000000e+001,'04/24','10/31','05/06','04/24','04/14','10/22','10/31','11/18','0147','0164','0190')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('238754','MO','DOUGLAS','WASOLA 5N',3.685805555000000e+001,-9.258750000000001e+001,'04/23','11/14','05/08','04/23','04/12','10/26','11/14','11/24','0142','0166','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('238805','MO','ST. CHARLES','WELDON SPRING NWS',3.869888888000000e+001,-9.068277800000000e+001,'05/03','10/31','05/15','05/03','04/23','10/24','10/31','11/16','0133','0153','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('238880','MO','HOWELL','WEST PLAINS',3.674250000000000e+001,-9.183472200000000e+001,'04/28','10/30','05/10','04/28','04/18','10/18','10/30','11/12','0144','0167','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('240088','MT','CARTER','ALBION 1 N',4.520888888000000e+001,-1.042647220000000e+002,'06/11','09/28','07/01','06/11','05/22','09/18','09/28','10/04','0058','0091','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('240364','MT','LEWIS AND CLARK','AUGUSTA',4.749305555000000e+001,-1.123963890000000e+002,'06/09','09/22','07/06','06/09','05/21','09/16','09/22','10/01','0048','0093','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('240375','MT','LEWIS AND CLARK','AUSTIN 1 W',4.664555555000000e+001,-1.122655560000000e+002,'06/21','09/23','07/17','06/21','06/04','09/15','09/23','10/07','0041','0080','0102')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('240392','MT','GLACIER','BABB 6 NE',4.893888888000000e+001,-1.133719440000000e+002,'07/04','09/15','07/24','07/04','06/05','09/03','09/15','10/02','0018','0058','0094')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('240622','MT','GALLATIN','BOZEMAN GALLATIN FLD',4.578805555000000e+001,-1.111608330000000e+002,'06/23','09/23','07/07','06/23','05/26','09/16','09/23','10/06','0049','0074','0112')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('240743','MT','POWDER RIVER','BIDDLE 8 SW',4.504027777000000e+001,-1.054855560000000e+002,'06/02','10/01','06/23','06/02','05/19','09/24','10/01','10/13','0079','0101','0123')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('240755','MT','LAKE','BIGFORK 13 S',4.787500000000000e+001,-1.140330560000000e+002,'06/03','10/22','06/20','06/03','05/06','10/11','10/22','11/11','0082','0113','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('240770','MT','CHOUTEAU','BIG SANDY',4.813500000000000e+001,-1.100608330000000e+002,'06/09','09/30','06/21','06/09','05/24','09/21','09/30','10/08','0068','0088','0115')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('240780','MT','SWEET GRASS','BIG TIMBER',4.583277777000000e+001,-1.099502780000000e+002,'05/31','10/02','06/24','05/31','05/19','09/22','10/02','10/12','0070','0103','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('240802','MT','YELLOWSTONE','BILLINGS WTP',4.577166666000000e+001,-1.084811110000000e+002,'05/24','10/10','06/04','05/24','05/12','09/27','10/10','10/23','0097','0119','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('240807','MT','YELLOWSTONE','BILLINGS INTL AP',4.580694444000000e+001,-1.085422220000000e+002,'05/17','10/14','05/28','05/17','05/03','10/05','10/14','10/26','0108','0130','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('240923','MT','DAWSON','BLOOMFIELD 5 NNE',4.746944444000000e+001,-1.048950000000000e+002,'06/10','09/24','06/29','06/10','05/21','09/17','09/24','10/06','0059','0090','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('241008','MT','JEFFERSON','BOULDER',4.623138888000000e+001,-1.121136110000000e+002,'06/30','09/20','07/20','06/30','06/10','09/11','09/20','09/27','0031','0061','0092')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('241044','MT','GALLATIN','BOZEMAN MONTANA ST U',4.566222222000000e+001,-1.110452780000000e+002,'06/11','10/02','07/01','06/11','05/21','09/22','10/02','10/19','0068','0095','0123')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('241047','MT','GALLATIN','BOZEMAN 6 W EXP FARM',4.567500000000000e+001,-1.111550000000000e+002,'06/22','09/24','07/09','06/22','05/24','09/15','09/24','10/06','0048','0081','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('241084','MT','ROSEBUD','BRANDENBERG',4.581611111000000e+001,-1.062313890000000e+002,'05/31','09/28','06/26','05/31','05/19','09/19','09/28','10/12','0076','0101','0122')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('241088','MT','ROOSEVELT','BREDETTE',4.854750000000000e+001,-1.052705560000000e+002,'05/28','10/04','06/11','05/28','05/18','09/24','10/04','10/11','0092','0113','0126')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('241102','MT','CARBON','BRIDGER 2 N',4.532611111000000e+001,-1.089091670000000e+002,'06/03','10/01','06/22','06/03','05/18','09/23','10/01','10/17','0081','0106','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('241127','MT','POWDER RIVER','BROADUS',4.544416666000000e+001,-1.054072220000000e+002,'06/02','09/29','06/19','06/02','05/21','09/24','09/29','10/12','0078','0101','0119')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('241169','MT','MCCONE','BROCKWAY 3 WSW',4.728750000000000e+001,-1.058300000000000e+002,'06/08','09/27','06/28','06/08','05/20','09/20','09/27','10/06','0056','0091','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('241297','MT','BIG HORN','BUSBY',4.553972222000000e+001,-1.069597220000000e+002,'06/08','09/27','07/09','06/08','05/26','09/18','09/27','10/03','0045','0091','0111')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('241318','MT','SILVER BOW','BUTTE BERT MOONEY AP',4.596472222000000e+001,-1.125005560000000e+002,'07/07','09/16','07/25','07/07','06/17','09/07','09/16','09/25','0022','0052','0086')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('241518','MT','WIBAUX','CARLYLE 13 NW',4.674472222000000e+001,-1.043088890000000e+002,'06/03','10/04','06/23','06/03','05/19','09/26','10/04','10/15','0077','0102','0126')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('241552','MT','CASCADE','CASCADE 5 S',4.721944444000000e+001,-1.117100000000000e+002,'06/08','09/26','07/09','06/08','05/24','09/14','09/26','10/05','0047','0094','0116')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('241557','MT','CASCADE','CASCADE 20 SSE',4.699555555000000e+001,-1.115772220000000e+002,'07/27','09/11','08/01','07/27','06/26','08/23','09/11','09/22','0003','0023','0078')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('241692','MT','LIBERTY','CHESTER',4.851527777000000e+001,-1.109711110000000e+002,'06/17','09/24','07/11','06/17','05/24','09/11','09/24','10/03','0043','0080','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('241722','MT','BLAINE','CHINOOK',4.858833333000000e+001,-1.092255560000000e+002,'06/04','09/22','06/22','06/04','05/22','09/20','09/22','10/05','0063','0094','0120')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('241737','MT','TETON','CHOTEAU',4.782055555000000e+001,-1.121919440000000e+002,'06/09','10/02','06/24','06/09','05/26','09/26','10/02','10/18','0073','0095','0118')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('241758','MT','MCCONE','CIRCLE',4.741222222000000e+001,-1.055950000000000e+002,'05/31','09/28','06/15','05/31','05/15','09/21','09/28','10/11','0085','0103','0121')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('241875','MT','GARFIELD','COHAGEN',4.705666666000000e+001,-1.066166670000000e+002,'06/10','09/26','06/24','06/10','05/21','09/21','09/26','10/03','0064','0092','0112')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('241905','MT','ROSEBUD','COLSTRIP',4.589444444000000e+001,-1.066336110000000e+002,'05/26','10/09','06/12','05/26','05/16','09/25','10/09','10/21','0087','0113','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('241938','MT','STILLWATER','COLUMBUS',4.564444444000000e+001,-1.092675000000000e+002,'06/01','10/01','06/23','06/01','05/19','09/21','10/01','10/12','0078','0111','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('241974','MT','PONDERA','CONRAD',4.817944444000000e+001,-1.119613890000000e+002,'06/21','09/22','07/15','06/21','05/26','09/15','09/22','10/01','0038','0077','0110')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('241984','MT','PHILLIPS','CONTENT 3 SSE',4.797638888000000e+001,-1.075486110000000e+002,'06/06','09/28','06/27','06/06','05/24','09/19','09/28','10/09','0066','0096','0116')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('241995','MT','PARK','COOKE CITY 2 W',4.501888888000000e+001,-1.099550000000000e+002,'07/31','09/01','08/05','07/31','07/12','08/12','09/01','09/19','0000','0005','0036')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('242104','MT','FLATHEAD','CRESTON',4.818888888000000e+001,-1.141341670000000e+002,'06/10','09/30','07/06','06/10','05/18','09/17','09/30','10/12','0053','0092','0123')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('242122','MT','ROOSEVELT','CULBERTSON',4.815027777000000e+001,-1.045088890000000e+002,'06/07','09/24','06/26','06/07','05/27','09/17','09/24','10/06','0062','0092','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('242173','MT','GLACIER','CUT BANK AP',4.860333333000000e+001,-1.123752780000000e+002,'06/14','09/25','07/08','06/14','05/21','09/18','09/25','10/04','0054','0086','0117')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('242221','MT','RAVALLI','DARBY',4.602638888000000e+001,-1.141763890000000e+002,'06/24','09/28','07/13','06/24','05/24','09/17','09/28','10/12','0048','0079','0117')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('242275','MT','POWELL','DEER LODGE 3 W',4.639111111000000e+001,-1.127975000000000e+002,'07/19','09/11','07/31','07/19','07/05','08/28','09/11','09/20','0005','0030','0060')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('242301','MT','GLACIER','DEL BONITA',4.899833333000000e+001,-1.127886110000000e+002,'06/23','09/25','07/19','06/23','05/28','09/14','09/25','10/07','0039','0075','0103')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('242347','MT','FERGUS','DENTON',4.731805555000000e+001,-1.099372220000000e+002,'07/07','09/15','07/30','07/07','06/12','09/04','09/15','09/28','0013','0050','0087')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('242409','MT','BEAVERHEAD','DILLION U OF MONTANA WESTERN',4.521277777000000e+001,-1.126447220000000e+002,'06/27','09/23','07/14','06/27','05/29','09/17','09/23','10/05','0036','0075','0105')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('242421','MT','SILVER BOW','DIVIDE',4.575111111000000e+001,-1.127547220000000e+002,'07/06','09/25','07/21','07/06','06/13','09/11','09/25','10/05','0027','0054','0091')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('242500','MT','GRANITE','DRUMMOND AVIATION',4.663833333000000e+001,-1.131761110000000e+002,'07/12','09/17','07/27','07/12','06/18','09/05','09/17','09/29','0018','0042','0079')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('242629','MT','GLACIER','EAST GLACIER',4.844694444000000e+001,-1.132238890000000e+002,'07/12','09/16','07/27','07/12','06/05','09/02','09/16','09/27','0012','0048','0094')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('242689','MT','CARTER','EKALAKA',4.589027777000000e+001,-1.045461110000000e+002,'06/06','09/30','06/27','06/06','05/19','09/25','09/30','10/12','0066','0095','0124')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('242793','MT','MADISON','ENNIS',4.533944444000000e+001,-1.117111110000000e+002,'06/26','09/23','07/16','06/26','06/05','09/17','09/23','10/04','0040','0068','0102')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('242827','MT','LINCOLN','EUREKA RS',4.889777777000000e+001,-1.150644440000000e+002,'06/09','10/01','07/04','06/09','05/21','09/20','10/01','10/14','0058','0091','0123')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('242857','MT','TETON','FAIRFIELD',4.761527777000000e+001,-1.119855560000000e+002,'05/30','10/04','06/23','05/30','05/14','09/23','10/04','10/18','0075','0103','0132')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('243013','MT','PETROLEUM','FLATWILLOW 4 ENE',4.685111111000000e+001,-1.083133330000000e+002,'06/05','10/04','06/26','06/05','05/22','09/22','10/04','10/13','0071','0099','0123')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('243110','MT','HILL','FT ASSINNIBOINE',4.849833333000000e+001,-1.097972220000000e+002,'05/28','10/03','06/12','05/28','05/17','09/22','10/03','10/10','0079','0104','0122')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('243113','MT','CHOUTEAU','FT BENTON',4.783055555000000e+001,-1.106608330000000e+002,'05/31','09/30','06/20','05/31','05/19','09/24','09/30','10/11','0075','0099','0119')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('243176','MT','MCCONE','FT PECK PWR PLT',4.801194444000000e+001,-1.064116670000000e+002,'05/21','10/08','06/02','05/21','05/07','09/26','10/08','10/23','0101','0119','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('243378','MT','PARK','GARDINER',4.503166666000000e+001,-1.107036110000000e+002,'06/15','10/05','07/05','06/15','05/25','09/24','10/05','10/15','0065','0093','0120')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('243445','MT','CHOUTEAU','GERALDINE',4.760138888000000e+001,-1.102669440000000e+002,'06/12','10/01','06/29','06/12','05/18','09/24','10/01','10/09','0058','0091','0118')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('243489','MT','LEWIS AND CLARK','GIBSON DAM',4.760166666000000e+001,-1.127536110000000e+002,'06/22','09/23','07/15','06/22','05/30','09/11','09/23','10/12','0038','0072','0106')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('243530','MT','HILL','GILDFORD',4.856527777000000e+001,-1.103022220000000e+002,'06/08','09/28','06/21','06/08','05/21','09/20','09/28','10/04','0063','0097','0120')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('243558','MT','VALLEY','GLASGOW INTL AP',4.821388888000000e+001,-1.066213890000000e+002,'05/19','10/07','06/01','05/19','05/07','09/24','10/07','10/18','0103','0122','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('243570','MT','MADISON','GLEN 4 N',4.552611111000000e+001,-1.127005560000000e+002,'07/06','09/22','07/21','07/06','06/17','09/12','09/22','09/28','0026','0053','0085')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('243581','MT','DAWSON','GLENDIVE',4.710638888000000e+001,-1.047183330000000e+002,'05/14','10/11','05/25','05/14','05/06','09/30','10/11','10/24','0107','0131','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('243617','MT','TOOLE','GOLDBUTTE 7 N',4.897611111000000e+001,-1.113994440000000e+002,'06/23','09/21','07/25','06/23','05/29','09/11','09/21','10/04','0025','0062','0104')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('243727','MT','FERGUS','GRASS RANGE',4.702583333000000e+001,-1.088030560000000e+002,'06/11','09/29','07/02','06/11','05/22','09/23','09/29','10/10','0066','0093','0121')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('243751','MT','CASCADE','GREAT FALLS AP',4.747333333000000e+001,-1.113822220000000e+002,'06/01','10/05','06/19','06/01','05/13','09/29','10/05','10/18','0076','0105','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('243885','MT','RAVALLI','HAMILTON',4.625527777000000e+001,-1.141641670000000e+002,'06/08','10/02','06/26','06/08','05/22','09/25','10/02','10/12','0062','0092','0121')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('243915','MT','BIG HORN','HARDIN',4.573166666000000e+001,-1.076091670000000e+002,'05/27','10/05','06/15','05/27','05/07','09/24','10/05','10/18','0090','0112','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('243939','MT','WHEATLAND','HARLOWTON',4.643277777000000e+001,-1.098311110000000e+002,'06/10','09/24','07/07','06/10','05/26','09/14','09/24','10/07','0050','0092','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('243984','MT','MINERAL','HAUGAN 1 W',4.738888888000000e+001,-1.154225000000000e+002,'07/20','09/27','08/05','07/20','06/21','09/19','09/27','10/12','0000','0029','0075')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('243996','MT','HILL','HAVRE AP ASOS',4.854277777000000e+001,-1.097633330000000e+002,'05/30','09/29','06/18','05/30','05/16','09/22','09/29','10/08','0077','0108','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('244038','MT','GALLATIN','HEBGEN DAM',4.486666666000000e+001,-1.113391670000000e+002,'07/06','09/20','07/19','07/06','06/15','09/09','09/20','09/28','0027','0049','0089')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('244055','MT','LEWIS AND CLARK','HELENA AP ASOS',4.660555555000000e+001,-1.119636110000000e+002,'06/04','09/29','06/22','06/04','05/15','09/21','09/29','10/15','0071','0102','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('244084','MT','SANDERS','HERON 2 NW',4.808000000000000e+001,-1.160013890000000e+002,'06/24','09/29','07/18','06/24','05/23','09/11','09/29','10/15','0033','0073','0121')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('244180','MT','VALLEY','HINSDALE 4 SW',4.834777777000000e+001,-1.071533330000000e+002,'05/22','10/05','06/02','05/22','05/10','09/30','10/05','10/20','0104','0122','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('244241','MT','LEWIS AND CLARK','HOLTER DAM',4.699138888000000e+001,-1.120122220000000e+002,'05/27','10/12','06/21','05/27','05/08','09/30','10/12','10/29','0083','0114','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('244328','MT','FLATHEAD','HUNGRY HORSE DAM',4.834250000000000e+001,-1.140216670000000e+002,'05/31','10/09','06/21','05/31','05/09','09/24','10/09','10/24','0076','0107','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('244345','MT','YELLOWSTONE','HUNTLEY EXP STN',4.592277777000000e+001,-1.082444440000000e+002,'05/30','09/30','06/23','05/30','05/17','09/20','09/30','10/11','0075','0105','0126')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('244358','MT','TREASURE','HYSHAM',4.629416666000000e+001,-1.072277780000000e+002,'05/25','10/05','06/08','05/25','05/14','09/24','10/05','10/17','0094','0112','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('244364','MT','TREASURE','HYSHAM 25 SSE',4.593527777000000e+001,-1.071375000000000e+002,'06/13','09/25','07/06','06/13','05/24','09/20','09/25','10/05','0055','0089','0111')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('244386','MT','ROSEBUD','INGOMAR 14 NE',4.673916666000000e+001,-1.072077780000000e+002,'05/30','09/26','06/30','05/30','05/25','09/21','09/26','10/07','0070','0102','0113')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('244447','MT','BEAVERHEAD','JACKSON',4.536805555000000e+001,-1.134088890000000e+002,'07/27','09/10','08/03','07/27','07/16','08/23','09/10','09/19','0000','0015','0034')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('244506','MT','CARBON','JOLIET',4.547305555000000e+001,-1.090097220000000e+002,'06/06','10/03','06/25','06/06','05/22','09/21','10/03','10/15','0075','0099','0123')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('244512','MT','LIBERTY','JOPLIN',4.856166666000000e+001,-1.107669440000000e+002,'06/10','09/28','06/29','06/10','05/22','09/19','09/28','10/04','0061','0093','0116')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('244522','MT','GARFIELD','JORDAN',4.731444444000000e+001,-1.069102780000000e+002,'05/29','09/27','06/21','05/29','05/19','09/21','09/27','10/05','0073','0102','0120')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('244545','MT','WHEATLAND','JUDITH GAP 13 E',4.665000000000000e+001,-1.094800000000000e+002,'07/08','09/20','07/25','07/08','06/14','09/12','09/20','10/01','0025','0054','0092')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('244558','MT','FLATHEAD','KALISPELL GLACIER AP',4.830416666000000e+001,-1.142636110000000e+002,'06/30','09/25','07/12','06/30','05/27','09/13','09/25','10/08','0041','0067','0113')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('244820','MT','BEAVERHEAD','LAKEVIEW',4.459944444000000e+001,-1.118125000000000e+002,'07/23','09/07','08/01','07/23','07/06','08/24','09/07','09/17','0002','0021','0048')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('244954','MT','MEAGHER','LENNEP 5 SW',4.636194444000000e+001,-1.106002780000000e+002,'07/14','09/18','07/29','07/14','06/21','09/06','09/18','09/25','0010','0044','0081')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('244985','MT','FERGUS','LEWISTOWN AP',4.704916666000000e+001,-1.094577780000000e+002,'06/10','09/28','07/06','06/10','05/21','09/22','09/28','10/10','0054','0091','0123')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('245015','MT','LINCOLN','LIBBY 1 NE RS',4.840361111000000e+001,-1.155391670000000e+002,'06/26','09/29','07/12','06/26','05/28','09/19','09/29','10/21','0041','0070','0111')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('245020','MT','LINCOLN','LIBBY 32 SSE',4.797333333000000e+001,-1.152238890000000e+002,'08/02','09/07','08/05','08/02','07/09','08/24','09/07','09/19','0000','0000','0046')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('245030','MT','BEAVERHEAD','LIMA',4.463305555000000e+001,-1.125927780000000e+002,'07/16','09/15','07/24','07/16','07/05','09/04','09/15','09/25','0016','0035','0061')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('245040','MT','LEWIS AND CLARK','LINCOLN RS',4.695583333000000e+001,-1.126547220000000e+002,'07/29','09/03','08/08','07/29','07/04','08/21','09/03','09/18','0000','0013','0049')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('245043','MT','MISSOULA','LINDBERGH LAKE',4.740833333000000e+001,-1.137125000000000e+002,'06/25','09/27','07/11','06/25','05/31','09/16','09/27','10/08','0042','0070','0105')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('245086','MT','PARK','LIVINGSTON AP',4.569833333000000e+001,-1.104408330000000e+002,'06/09','09/27','06/29','06/09','05/23','09/21','09/27','10/09','0062','0093','0116')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('245153','MT','CHOUTEAU','LOMA 1 WNW',4.794416666000000e+001,-1.105308330000000e+002,'05/31','09/27','06/12','05/31','05/18','09/22','09/27','10/09','0081','0098','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('245340','MT','PHILLIPS','MALTA 35 S',4.784166666000000e+001,-1.079555560000000e+002,'06/03','09/25','06/22','06/03','05/22','09/21','09/25','10/04','0076','0100','0119')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('245387','MT','MEAGHER','MARTINSDALE 3 NNW',4.650000000000000e+001,-1.103377780000000e+002,'07/12','09/19','07/31','07/12','06/16','09/08','09/19','09/23','0012','0041','0086')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('245572','MT','SHERIDAN','MEDICINE LAKE 3 SE',4.848277777000000e+001,-1.044513890000000e+002,'05/30','10/02','06/13','05/30','05/16','09/21','10/02','10/10','0087','0108','0126')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('245596','MT','MUSSELSHELL','MELSTONE',4.660083333000000e+001,-1.078688890000000e+002,'05/26','10/08','06/05','05/26','05/13','09/25','10/08','10/17','0099','0116','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('245603','MT','SWEET GRASS','MELVILLE 4 W',4.610472222000000e+001,-1.100500000000000e+002,'06/29','09/23','07/22','06/29','06/04','09/12','09/23','10/01','0032','0064','0101')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('245690','MT','CUSTER','MILES CITY AP',4.642666666000000e+001,-1.058825000000000e+002,'05/19','10/13','05/26','05/19','05/06','10/02','10/13','10/27','0112','0124','0143')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('245735','MT','MISSOULA','MISSOULA 2 NE',4.689833333000000e+001,-1.139677780000000e+002,'06/09','10/05','07/01','06/09','05/19','09/25','10/05','10/19','0070','0096','0124')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('245745','MT','MISSOULA','MISSOULA INTL AP',4.692083333000000e+001,-1.140925000000000e+002,'06/15','10/02','07/08','06/15','05/19','09/23','10/02','10/11','0056','0090','0122')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('245754','MT','CUSTER','MIZPAH 4 NNW',4.628583333000000e+001,-1.052919440000000e+002,'05/29','09/26','06/13','05/29','05/21','09/20','09/26','10/06','0084','0101','0117')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('245761','MT','JUDITH BASIN','MOCCASIN EXP STN',4.705750000000000e+001,-1.099513890000000e+002,'06/16','10/02','07/03','06/16','05/21','09/22','10/02','10/11','0059','0090','0122')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('245870','MT','POWDER RIVER','MOORHEAD 9 NE',4.517583333000000e+001,-1.057516670000000e+002,'06/04','10/01','06/23','06/04','05/17','09/20','10/01','10/11','0078','0099','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('245872','MT','GARFIELD','MOSBY 4 ENE',4.702194444000000e+001,-1.078225000000000e+002,'05/27','10/04','06/15','05/27','05/14','09/26','10/04','10/18','0091','0116','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('245961','MT','STILLWATER','MYSTIC LAKE',4.524361111000000e+001,-1.097311110000000e+002,'06/22','09/27','07/15','06/22','05/30','09/20','09/27','10/09','0047','0083','0110')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('246008','MT','CASCADE','NEIHART 8 NNW',4.704138888000000e+001,-1.107761110000000e+002,'07/08','09/23','07/26','07/08','06/12','09/07','09/23','09/29','0015','0047','0089')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('246157','MT','MADISON','NORRIS MADISON PH',4.548555555000000e+001,-1.116325000000000e+002,'05/21','10/12','06/12','05/21','05/07','09/29','10/12','10/24','0093','0121','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('246218','MT','FLATHEAD','OLNEY',4.854972222000000e+001,-1.145738890000000e+002,'07/17','09/09','08/02','07/17','06/25','08/24','09/09','09/25','0008','0037','0071')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('246236','MT','VALLEY','OPHEIM 10 N',4.899888888000000e+001,-1.063800000000000e+002,'06/27','09/17','07/24','06/27','06/01','09/09','09/17','09/28','0018','0054','0096')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('246238','MT','VALLEY','OPHEIM 12 SSE',4.869555555000000e+001,-1.063152780000000e+002,'06/09','09/22','07/05','06/09','05/29','09/15','09/22','10/03','0046','0093','0105')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('246472','MT','GRANITE','PHILIPSBURG RS',4.631583333000000e+001,-1.133000000000000e+002,'07/21','09/11','07/29','07/21','06/29','08/29','09/11','09/20','0008','0031','0068')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('246601','MT','FALLON','PLEVNA',4.641777777000000e+001,-1.045163890000000e+002,'06/06','09/29','06/25','06/06','05/21','09/22','09/29','10/07','0064','0094','0118')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('246615','MT','FLATHEAD','POLEBRIDGE',4.876472222000000e+001,-1.142841670000000e+002,'07/31','08/30','08/04','07/31','07/07','08/14','08/30','09/14','0000','0010','0051')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('246635','MT','LAKE','POLSON',4.767500000000000e+001,-1.141905560000000e+002,'05/21','10/17','06/10','05/21','05/06','10/03','10/17','10/30','0094','0123','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('246640','MT','LAKE','POLSON KERR DAM',4.767750000000000e+001,-1.142419440000000e+002,'05/24','10/13','06/17','05/24','05/07','09/30','10/13','10/25','0085','0119','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('246691','MT','CUSTER','POWDERVILLE 8 NNE',4.585250000000000e+001,-1.050350000000000e+002,'06/03','09/30','06/14','06/03','05/18','09/25','09/30','10/13','0082','0096','0124')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('246862','MT','STILLWATER','RAPELJE',4.596361111000000e+001,-1.092530560000000e+002,'06/07','09/27','07/06','06/07','05/22','09/22','09/27','10/12','0060','0095','0120')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('246893','MT','SHERIDAN','RAYMOND BORDER STN',4.899750000000000e+001,-1.045750000000000e+002,'05/30','10/03','06/09','05/30','05/19','09/23','10/03','10/13','0079','0103','0120')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('246902','MT','JUDITH BASIN','RAYNESFORD 2 NNW',4.729722222000000e+001,-1.107455560000000e+002,'06/13','10/01','07/08','06/13','05/24','09/24','10/01','10/12','0050','0088','0119')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('246918','MT','CARBON','RED LODGE',4.518972222000000e+001,-1.092861110000000e+002,'06/25','09/27','07/12','06/25','06/01','09/20','09/27','10/06','0046','0077','0110')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('247034','MT','CARTER','RIDGEWAY 1 S',4.550222222000000e+001,-1.044477780000000e+002,'06/07','09/29','06/29','06/07','05/21','09/23','09/29','10/09','0063','0091','0115')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('247136','MT','ROSEBUD','ROCK SPRINGS',4.682027777000000e+001,-1.062452780000000e+002,'05/28','10/02','06/18','05/28','05/16','09/25','10/02','10/14','0076','0106','0121')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('247159','MT','LEWIS AND CLARK','ROGERS PASS 9 NNE',4.719000000000000e+001,-1.122905560000000e+002,'06/16','09/29','07/04','06/16','05/30','09/19','09/29','10/14','0050','0088','0108')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('247214','MT','MUSSELSHELL','ROUNDUP',4.644138888000000e+001,-1.085397220000000e+002,'05/27','10/04','06/09','05/27','05/16','09/23','10/04','10/15','0091','0108','0130')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('247263','MT','GOLDEN VALLEY','RYEGATE 18 NNW',4.653333333000000e+001,-1.093441670000000e+002,'06/21','09/25','07/12','06/21','06/03','09/15','09/25','10/07','0041','0079','0108')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('247265','MT','PHILLIPS','SACO 1 NNW',4.846611111000000e+001,-1.073527780000000e+002,'05/31','09/28','06/20','05/31','05/20','09/23','09/28','10/08','0077','0103','0122')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('247286','MT','LAKE','SAINT IGNATIUS',4.731500000000000e+001,-1.140983330000000e+002,'06/04','10/02','07/02','06/04','05/17','09/23','10/02','10/14','0065','0097','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('247318','MT','MINERAL','SAINT REGIS 1 NE',4.730361111000000e+001,-1.150908330000000e+002,'07/07','09/25','07/31','07/07','06/15','09/10','09/25','10/06','0012','0054','0089')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('247382','MT','RICHLAND','SAVAGE',4.745361111000000e+001,-1.043377780000000e+002,'05/25','10/07','06/04','05/25','05/14','09/24','10/07','10/14','0098','0115','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('247448','MT','MISSOULA','SEELEY LAKE RS',4.721416666000000e+001,-1.135202780000000e+002,'07/17','09/19','08/02','07/17','06/15','08/30','09/19','10/04','0003','0034','0088')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('247540','MT','CHOUTEAU','SHONKIN 7 S',4.753194444000000e+001,-1.105769440000000e+002,'06/17','10/01','07/10','06/17','05/22','09/21','10/01','10/16','0048','0088','0118')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('247560','MT','RICHLAND','SIDNEY',4.772833333000000e+001,-1.041466670000000e+002,'05/27','10/02','06/10','05/27','05/17','09/23','10/02','10/14','0090','0111','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('247620','MT','HILL','SIMPSON 6 N WILDHORSE',4.899916666000000e+001,-1.102147220000000e+002,'06/14','09/22','07/02','06/14','05/27','09/13','09/22','10/03','0051','0084','0110')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('247740','MT','POWDER RIVER','SONNETTE 2 WNW',4.541833333000000e+001,-1.058683330000000e+002,'06/16','09/24','07/12','06/16','05/30','09/19','09/24','10/02','0045','0086','0108')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('247864','MT','JUDITH BASIN','STANFORD',4.715472222000000e+001,-1.102238890000000e+002,'06/20','09/27','07/08','06/20','05/27','09/20','09/27','10/06','0050','0084','0113')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('247894','MT','RAVALLI','STEVENSVILLE',4.651361111000000e+001,-1.140911110000000e+002,'06/20','09/23','07/15','06/20','05/30','09/12','09/23','10/02','0042','0077','0106')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('247964','MT','RAVALLI','SULA 3 ENE',4.584777777000000e+001,-1.139269440000000e+002,'07/31','08/31','08/03','07/31','07/10','08/15','08/31','09/18','0000','0010','0046')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('248021','MT','CASCADE','SUN RIVER 4 S',4.747777777000000e+001,-1.117405560000000e+002,'06/14','09/24','07/07','06/14','05/22','09/17','09/24','10/07','0052','0088','0115')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('248043','MT','MINERAL','SUPERIOR',4.719277777000000e+001,-1.148902780000000e+002,'06/01','10/01','07/02','06/01','05/19','09/23','10/01','10/20','0067','0105','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('248087','MT','LAKE','SWAN LAKE',4.792027777000000e+001,-1.138394440000000e+002,'07/08','09/19','08/01','07/08','06/14','09/04','09/19','10/05','0002','0046','0087')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('248165','MT','PRAIRIE','TERRY',4.679388888000000e+001,-1.053022220000000e+002,'05/29','09/29','06/17','05/29','05/16','09/26','09/29','10/10','0075','0102','0120')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('248169','MT','PRAIRIE','TERRY 21 NNW',4.707000000000000e+001,-1.054952780000000e+002,'06/11','09/26','06/25','06/11','05/24','09/21','09/26','10/06','0067','0091','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('248211','MT','SANDERS','THOMPSON FALLS PH',4.759333333000000e+001,-1.153594440000000e+002,'05/29','10/04','06/22','05/29','05/14','09/26','10/04','10/28','0080','0107','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('248233','MT','LIBERTY','TIBER DAM',4.831000000000000e+001,-1.110877780000000e+002,'05/31','09/29','06/20','05/31','05/16','09/20','09/29','10/12','0068','0110','0128')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('248324','MT','BROADWATER','TOWNSEND',4.633083333000000e+001,-1.115377780000000e+002,'06/09','09/27','07/06','06/09','05/27','09/19','09/27','10/08','0060','0096','0112')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('248363','MT','GALLATIN','TRIDENT',4.594694444000000e+001,-1.114747220000000e+002,'06/13','09/27','06/27','06/13','05/16','09/19','09/27','10/11','0072','0094','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('248380','MT','SANDERS','TROUT CREEK RS',4.786694444000000e+001,-1.156277780000000e+002,'07/04','09/30','07/31','07/04','06/03','09/12','09/30','10/13','0013','0057','0097')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('248390','MT','LINCOLN','TROY',4.848055555000000e+001,-1.159061110000000e+002,'06/15','10/07','07/11','06/15','05/29','09/22','10/07','10/26','0044','0086','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('248430','MT','MADISON','TWIN BRIDGES',4.554722222000000e+001,-1.123261110000000e+002,'07/05','09/14','07/26','07/05','06/16','09/04','09/14','09/24','0017','0048','0085')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('248501','MT','PONDERA','VALIER',4.830888888000000e+001,-1.122511110000000e+002,'06/08','10/01','06/27','06/08','05/15','09/21','10/01','10/14','0069','0094','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('248569','MT','MCCONE','VIDA 6 NE',4.788000000000000e+001,-1.053686110000000e+002,'05/27','09/28','06/07','05/27','05/14','09/22','09/28','10/12','0092','0106','0132')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('248597','MT','MADISON','VIRGINIA CITY',4.529250000000000e+001,-1.119480560000000e+002,'07/06','09/27','07/19','07/06','06/20','09/17','09/27','10/02','0032','0052','0084')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('248777','MT','SHERIDAN','WESTBY',4.887083333000000e+001,-1.040500000000000e+002,'05/28','09/30','06/12','05/28','05/17','09/23','09/30','10/12','0078','0107','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('248783','MT','RAVALLI','WESTERN AG RSCH CTR',4.632861111000000e+001,-1.140836110000000e+002,'06/15','09/30','07/08','06/15','05/25','09/19','09/30','10/10','0054','0089','0112')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('248809','MT','FLATHEAD','WEST GLACIER',4.850027777000000e+001,-1.139847220000000e+002,'06/24','09/26','07/08','06/24','05/24','09/13','09/26','10/14','0043','0080','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('248902','MT','FLATHEAD','WHITEFISH',4.840805555000000e+001,-1.143594440000000e+002,'06/07','09/28','07/05','06/07','05/17','09/20','09/28','10/12','0057','0095','0123')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('248957','MT','WIBAUX','WIBAUX 2 E',4.698777777000000e+001,-1.041566670000000e+002,'06/13','09/26','07/08','06/13','05/31','09/18','09/26','10/10','0050','0081','0104')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('249023','MT','PARK','WILSALL 8 ENE',4.603055555000000e+001,-1.105055560000000e+002,'06/29','09/22','07/20','06/29','06/06','09/14','09/22','10/01','0030','0071','0099')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('249033','MT','FERGUS','WINIFRED',4.755888888000000e+001,-1.093758330000000e+002,'06/02','09/24','06/29','06/02','05/19','09/18','09/24','10/03','0057','0098','0120')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('249067','MT','BEAVERHEAD','WISDOM',4.561777777000000e+001,-1.134513890000000e+002,'08/02','08/13','08/05','08/02','07/28','08/06','08/13','09/01','0000','0000','0017')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('249240','MT','BIG HORN','YELLOWTAIL DAM',4.531277777000000e+001,-1.079383330000000e+002,'05/18','10/18','06/02','05/18','05/03','10/05','10/18','11/04','0108','0132','0158')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('249900','MT','PHILLIPS','ZORTMAN',4.791777777000000e+001,-1.085272220000000e+002,'06/21','10/04','07/05','06/21','06/07','09/22','10/04','10/06','0053','0076','0099')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('250030','NE','SIOUX','AGATE 3 E',4.242444444000000e+001,-1.037347220000000e+002,'07/02','09/27','07/13','07/02','06/06','09/18','09/27','09/29','0039','0062','0101')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('250050','NE','BROWN','AINSWORTH',4.255222222000000e+001,-9.985555600000001e+001,'05/13','10/24','05/22','05/13','05/07','10/07','10/24','10/30','0122','0139','0152')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('250130','NE','BOX BUTTE','ALLIANCE 1WNW',4.211027777000000e+001,-1.028966670000000e+002,'05/25','10/07','06/10','05/25','05/15','09/27','10/07','10/18','0097','0120','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('250245','NE','CUSTER','ANSELMO 2 SE',4.159750000000000e+001,-9.982583300000000e+001,'05/23','10/06','06/18','05/23','05/12','10/02','10/06','10/18','0085','0118','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('250355','NE','CUSTER','ARNOLD',4.142250000000000e+001,-1.001838890000000e+002,'06/02','10/09','06/11','06/02','05/12','09/29','10/09','10/19','0097','0115','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('250365','NE','ARTHUR','ARTHUR',4.156972222000000e+001,-1.016913890000000e+002,'05/22','10/06','06/07','05/22','05/14','10/01','10/06','10/20','0099','0121','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('250375','NE','SAUNDERS','ASHLAND NO 2',4.104083333000000e+001,-9.637750000000000e+001,'05/10','10/22','05/17','05/10','04/26','10/11','10/22','11/06','0129','0145','0171')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('250420','NE','HOLT','ATKINSON 3SW',4.251361111000000e+001,-9.903027800000000e+001,'05/13','10/15','05/20','05/13','05/09','10/02','10/15','10/26','0120','0128','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('250435','NE','NEMAHA','AUBURN 5 ESE',4.037055555000000e+001,-9.574694400000000e+001,'05/11','10/20','05/17','05/11','04/23','10/08','10/20','11/06','0128','0138','0166')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('250640','NE','FURNAS','BEAVER CITY',4.013055555000000e+001,-9.982777800000000e+001,'05/20','10/11','05/29','05/20','05/08','10/03','10/11','10/25','0115','0126','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('250760','NE','DUNDY','BENKELMAN',4.005250000000000e+001,-1.015386110000000e+002,'05/18','10/19','05/26','05/18','05/11','10/08','10/19','10/27','0118','0130','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('250865','NE','DEUEL','BIG SPRINGS',4.104694444000000e+001,-1.021466670000000e+002,'05/18','10/14','05/30','05/18','05/08','10/05','10/14','10/26','0110','0128','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('251145','NE','MORRILL','BRIDGEPORT',4.166805555000000e+001,-1.031038890000000e+002,'05/19','10/06','06/09','05/19','05/10','09/30','10/06','10/17','0099','0124','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('251200','NE','CUSTER','BROKEN BOW 2 W',4.140833333000000e+001,-9.967500000000000e+001,'05/25','10/08','06/07','05/25','05/16','10/01','10/08','10/17','0098','0116','0132')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('251345','NE','GARFIELD','BURWELL',4.177694444000000e+001,-9.914333300000000e+001,'05/17','10/10','05/24','05/17','05/11','10/02','10/10','10/24','0118','0126','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('251365','NE','BOYD','BUTTE',4.291305555000000e+001,-9.885111100000000e+001,'05/16','10/17','05/19','05/16','05/06','10/08','10/17','10/29','0124','0133','0153')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('251415','NE','FURNAS','CAMBRIDGE',4.028472222000000e+001,-1.001433330000000e+002,'05/15','10/15','05/25','05/15','05/07','10/07','10/15','10/24','0120','0133','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('251450','NE','GOSPER','CANADAY STEAM PLT',4.069444444000000e+001,-9.970083300000000e+001,'05/15','10/23','05/19','05/15','05/03','10/09','10/23','10/30','0126','0138','0159')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('251560','NE','MERRICK','CENTRAL CITY',4.111555555000000e+001,-9.800638900000000e+001,'05/07','10/25','05/13','05/07','04/24','10/11','10/25','11/03','0130','0149','0172')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('251575','NE','DAWES','CHADRON 3SW',4.280833333000000e+001,-1.030533330000000e+002,'05/25','10/10','06/03','05/25','05/09','10/02','10/10','10/23','0102','0115','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('251590','NE','HOLT','CHAMBERS',4.220305555000000e+001,-9.874666700000000e+001,'05/13','10/15','05/20','05/13','05/05','10/05','10/15','10/27','0119','0131','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('251684','NE','CLAY','CLAY CTR',4.052083333000000e+001,-9.805361100000000e+001,'05/12','10/21','05/24','05/12','05/02','10/07','10/21','10/28','0117','0135','0153')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('251825','NE','PLATTE','COLUMBUS 3 NE',4.146388888000000e+001,-9.732777800000000e+001,'05/10','10/22','05/16','05/10','04/23','10/11','10/22','11/02','0128','0142','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('252000','NE','GARDEN','CRESCENT LAKE NWR',4.176083333000000e+001,-1.024372220000000e+002,'05/25','10/08','06/11','05/25','05/13','09/28','10/08','10/17','0089','0113','0128')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('252020','NE','SALINE','CRETE',4.061944444000000e+001,-9.694694400000000e+001,'05/08','10/21','05/15','05/08','04/24','10/13','10/21','11/03','0129','0148','0172')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('252065','NE','HITCHCOCK','CULBERTSON',4.023333333000000e+001,-1.008291670000000e+002,'05/19','10/12','05/29','05/19','05/08','10/06','10/12','10/26','0113','0125','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('252100','NE','FRONTIER','CURTIS 3NNE',4.067416666000000e+001,-1.004936110000000e+002,'05/21','10/06','06/02','05/21','05/13','10/05','10/06','10/20','0103','0118','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('252145','NE','CHEYENNE','DALTON',4.140861111000000e+001,-1.029661110000000e+002,'05/20','10/16','06/09','05/20','05/11','10/03','10/16','10/24','0097','0118','0143')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('252205','NE','BUTLER','DAVID CITY',4.124916666000000e+001,-9.713277800000000e+001,'05/12','10/23','05/18','05/12','04/30','10/10','10/23','11/04','0126','0145','0165')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('252647','NE','SHERIDAN','ELLSWORTH 15 NNE',4.226500000000000e+001,-1.022133330000000e+002,'05/31','10/07','06/16','05/31','05/14','09/28','10/07','10/16','0087','0108','0131')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('252741','NE','CHASE','ENDERS LAKE',4.041805555000000e+001,-1.015147220000000e+002,'05/20','10/11','06/07','05/20','05/13','10/03','10/11','10/26','0104','0123','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('252805','NE','HOLT','EWING',4.226111111000000e+001,-9.834166700000000e+001,'05/17','10/09','05/26','05/17','05/10','10/02','10/09','10/21','0112','0126','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('252820','NE','JEFFERSON','FAIRBURY 5S',4.007388888000000e+001,-9.716694400000000e+001,'05/10','10/25','05/18','05/10','04/26','10/11','10/25','11/07','0128','0148','0173')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('253050','NE','DODGE','FREMONT',4.143000000000000e+001,-9.646694400000000e+001,'05/09','10/22','05/12','05/09','04/28','10/07','10/22','10/30','0131','0142','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('253175','NE','FILLMORE','GENEVA',4.053138888000000e+001,-9.759638900000000e+001,'05/06','10/26','05/13','05/06','04/22','10/12','10/26','11/05','0131','0153','0173')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('253185','NE','NANCE','GENOA 2 W',4.145138888000000e+001,-9.776444400000000e+001,'05/15','10/15','05/24','05/15','05/09','10/04','10/15','10/21','0115','0131','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('253355','NE','SHERIDAN','GORDON 6N',4.289472222000000e+001,-1.022036110000000e+002,'06/01','10/08','06/14','06/01','05/15','09/30','10/08','10/22','0087','0103','0132')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('253365','NE','DAWSON','GOTHENBURG',4.093944444000000e+001,-1.001513890000000e+002,'05/16','10/13','05/26','05/16','05/08','10/05','10/13','10/26','0118','0131','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('253395','NE','HALL','GRAND ISLAND CTR NE AP',4.096111111000000e+001,-9.831361100000000e+001,'05/10','10/22','05/17','05/10','04/29','10/09','10/22','10/30','0125','0145','0165')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('253425','NE','GREELEY','GREELEY',4.154611111000000e+001,-9.853305600000000e+001,'05/16','10/08','06/15','05/16','05/14','10/05','10/08','10/21','0088','0124','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('253515','NE','DUNDY','HAIGLER',4.001361111000000e+001,-1.019408330000000e+002,'05/19','10/23','05/23','05/19','05/07','10/09','10/23','10/31','0121','0132','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('253595','NE','HARLAN','HARLAN CO LAKE',4.008916666000000e+001,-9.921333300000001e+001,'05/11','10/20','05/21','05/11','04/29','10/11','10/20','10/31','0124','0142','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('253605','NE','BANNER','HARRISBURG 12WNW',4.163305555000000e+001,-1.039541670000000e+002,'06/08','09/28','06/29','06/08','05/19','09/25','09/28','10/08','0068','0100','0123')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('253615','NE','SIOUX','HARRISON',4.268583333000000e+001,-1.038841670000000e+002,'06/16','09/30','06/24','06/16','05/28','09/24','09/30','10/13','0077','0090','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('253630','NE','CEDAR','HARTINGTON',4.261666666000000e+001,-9.726083300000001e+001,'05/13','10/21','05/20','05/13','05/05','10/07','10/21','10/29','0121','0143','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('253660','NE','ADAMS','HASTINGS 4N',4.064722222000000e+001,-9.838361100000000e+001,'05/06','10/24','05/13','05/06','04/23','10/09','10/24','11/05','0134','0155','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('253690','NE','HAYES','HAYES CENTER 1NW',4.052333333000000e+001,-1.010344440000000e+002,'05/14','10/23','05/19','05/14','05/03','10/06','10/23','11/02','0123','0142','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('253710','NE','SHERIDAN','HAY SPRINGS',4.268277777000000e+001,-1.026927780000000e+002,'05/29','10/05','06/11','05/29','05/13','09/28','10/05','10/16','0095','0113','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('253715','NE','SHERIDAN','HAY SPRINGS 12 S',4.251194444000000e+001,-1.026944440000000e+002,'05/29','10/02','06/11','05/29','05/15','09/25','10/02','10/10','0092','0108','0128')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('253735','NE','THAYER','HEBRON',4.017500000000000e+001,-9.759027800000000e+001,'05/11','10/23','05/18','05/11','04/23','10/10','10/23','11/05','0129','0150','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('253755','NE','BOX BUTTE','HEMINGFORD',4.232083333000000e+001,-1.030733330000000e+002,'05/22','10/12','06/08','05/22','05/08','09/29','10/12','10/24','0100','0120','0142')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('253810','NE','LINCOLN','HERSHEY 5 SSE',4.110555555000000e+001,-1.009775000000000e+002,'05/19','10/17','05/25','05/19','05/09','10/06','10/17','10/28','0118','0126','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('253910','NE','PHELPS','HOLDREGE',4.045166666000000e+001,-9.938027800000000e+001,'05/12','10/24','05/18','05/12','04/25','10/13','10/24','11/04','0128','0138','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('254110','NE','CHASE','IMPERIAL',4.052083333000000e+001,-1.016550000000000e+002,'05/15','10/18','05/20','05/15','05/04','10/08','10/18','10/27','0122','0136','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('254335','NE','BUFFALO','KEARNEY 4 NE',4.072583333000000e+001,-9.901333300000000e+001,'05/15','10/16','05/25','05/15','05/04','10/07','10/16','10/31','0118','0134','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('254440','NE','KIMBALL','KIMBALL 2NE',4.124527777000000e+001,-1.036344440000000e+002,'05/19','10/06','06/11','05/19','05/13','09/27','10/06','10/19','0099','0122','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('254455','NE','KEITH','KINGSLEY DAM',4.120972222000000e+001,-1.016705560000000e+002,'05/13','10/25','05/19','05/13','05/05','10/13','10/25','11/03','0127','0140','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('254795','NE','LANCASTER','LINCOLN AP',4.085083333000000e+001,-9.674750000000000e+001,'05/12','10/21','05/15','05/12','04/29','10/11','10/21','11/03','0128','0144','0167')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('254900','NE','CHEYENNE','LODGEPOLE',4.114888888000000e+001,-1.026361110000000e+002,'05/18','10/10','06/02','05/18','05/11','09/30','10/10','10/23','0107','0123','0139')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('254985','NE','SHERMAN','LOUP CITY',4.128083333000000e+001,-9.896805600000000e+001,'05/16','10/12','05/30','05/16','05/09','10/07','10/12','10/24','0111','0129','0143')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('255080','NE','MADISON','MADISON',4.182916666000000e+001,-9.745000000000000e+001,'05/17','10/12','05/26','05/17','05/11','10/04','10/12','10/22','0112','0124','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('255090','NE','PERKINS','MADRID',4.085083333000000e+001,-1.015427780000000e+002,'05/16','10/16','05/24','05/16','05/07','10/03','10/16','10/27','0118','0128','0156')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('255310','NE','RED WILLOW','MC COOK',4.021555555000000e+001,-1.006202780000000e+002,'05/12','10/22','05/20','05/12','05/02','10/10','10/22','10/31','0125','0141','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('255362','NE','SAUNDERS','MEAD 6S',4.114305555000000e+001,-9.648083300000000e+001,'05/13','10/20','05/19','05/13','05/04','10/07','10/20','10/27','0124','0137','0156')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('255388','NE','FRONTIER','MEDICINE CREEK DAM',4.037611111000000e+001,-1.002227780000000e+002,'05/15','10/13','05/25','05/15','05/06','10/04','10/13','10/26','0120','0133','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('255470','NE','CHERRY','MERRIMAN',4.291944444000000e+001,-1.017088890000000e+002,'05/25','10/08','06/11','05/25','05/15','09/29','10/08','10/20','0094','0113','0132')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('255565','NE','KEARNEY','MINDEN',4.051555555000000e+001,-9.895138900000001e+001,'05/14','10/18','05/18','05/14','05/01','10/09','10/18','10/30','0128','0136','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('255810','NE','OTOE','NEBRASKA CITY 2NW',4.069861111000000e+001,-9.588666700000000e+001,'05/05','10/30','05/13','05/05','04/19','10/17','10/30','11/13','0132','0156','0182')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('255925','NE','ROCK','NEWPORT',4.260083333000000e+001,-9.933333300000000e+001,'05/13','10/18','05/23','05/13','05/07','10/04','10/18','10/27','0119','0130','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('255995','NE','MADISON','NORFOLK AP',4.198555555000000e+001,-9.743527800000000e+001,'05/12','10/18','05/21','05/12','05/02','10/06','10/18','10/28','0122','0140','0158')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('256065','NE','LINCOLN','NORTH PLATTE RGNL AP',4.112138888000000e+001,-1.006694440000000e+002,'05/23','10/05','06/02','05/23','05/15','10/01','10/05','10/20','0106','0119','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('256075','NE','LINCOLN','NORTH PLATTE EXP FARM',4.105694444000000e+001,-1.007494440000000e+002,'05/17','10/17','05/24','05/17','05/07','10/06','10/17','10/27','0118','0131','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('256135','NE','ANTELOPE','OAKDALE',4.206777777000000e+001,-9.796750000000000e+001,'05/18','10/10','06/03','05/18','05/10','10/01','10/10','10/23','0104','0126','0143')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('256167','NE','CUSTER','OCONTO',4.114388888000000e+001,-9.976333300000000e+001,'05/19','10/14','06/04','05/19','05/13','10/03','10/14','10/22','0108','0126','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('256200','NE','KEITH','OGALLALA',4.112750000000000e+001,-1.017205560000000e+002,'05/18','10/16','05/22','05/18','05/07','10/05','10/16','10/25','0115','0124','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('256255','NE','DOUGLAS','OMAHA EPPLEY AIRFIELD',4.131027777000000e+001,-9.589916700000001e+001,'05/09','10/22','05/16','05/09','04/25','10/10','10/22','11/05','0129','0143','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('256290','NE','HOLT','O NEILL',4.245944444000000e+001,-9.865638900000000e+001,'05/15','10/12','05/27','05/15','05/08','10/04','10/12','10/25','0114','0126','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('256375','NE','POLK','OSCEOLA',4.118388888000000e+001,-9.755000000000000e+001,'05/12','10/20','05/17','05/12','04/30','10/08','10/20','10/30','0124','0141','0158')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('256385','NE','GARDEN','OSHKOSH',4.140138888000000e+001,-1.023463890000000e+002,'05/23','10/05','06/04','05/23','05/14','10/01','10/05','10/17','0104','0117','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('256570','NE','PAWNEE','PAWNEE CITY',4.012166666000000e+001,-9.615583300000000e+001,'05/05','10/27','05/15','05/05','04/22','10/13','10/27','11/09','0136','0155','0171')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('256970','NE','BLAINE','PURDUM',4.206500000000000e+001,-1.002472220000000e+002,'05/25','10/07','06/08','05/25','05/13','10/01','10/07','10/19','0095','0116','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('257040','NE','BUFFALO','RAVENNA',4.103194444000000e+001,-9.892138900000001e+001,'05/15','10/10','06/01','05/15','05/12','10/04','10/10','10/21','0109','0128','0142')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('257070','NE','WEBSTER','RED CLOUD',4.009777777000000e+001,-9.851972200000000e+001,'05/16','10/13','05/27','05/16','05/01','10/03','10/13','10/22','0115','0131','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('257110','NE','FRONTIER','RED WILLOW DAM',4.035750000000000e+001,-1.006608330000000e+002,'05/17','10/11','05/28','05/17','05/10','10/04','10/11','10/24','0114','0129','0153')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('257415','NE','SHERIDAN','RUSHVILLE',4.275472222000000e+001,-1.024794440000000e+002,'05/22','10/06','06/11','05/22','05/15','10/01','10/06','10/20','0092','0117','0130')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('257515','NE','HOWARD','SAINT PAUL',4.120777777000000e+001,-9.846083299999999e+001,'05/12','10/21','05/16','05/12','04/28','10/09','10/21','10/31','0125','0136','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('257665','NE','SCOTTS BLUFF','SCOTTSBLUFF AP',4.187055555000000e+001,-1.035930560000000e+002,'05/19','10/10','05/31','05/19','05/12','10/01','10/10','10/22','0109','0122','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('257715','NE','SEWARD','SEWARD',4.089972222000000e+001,-9.709083300000000e+001,'05/08','10/26','05/14','05/08','04/26','10/14','10/26','11/05','0133','0153','0172')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('257830','NE','CHEYENNE','SIDNEY 6 NNW',4.122944444000000e+001,-1.030213890000000e+002,'05/27','10/06','06/16','05/27','05/16','10/01','10/06','10/17','0081','0113','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('258395','NE','OTOE','SYRACUSE',4.066611111000000e+001,-9.618916700000000e+001,'05/10','10/18','05/16','05/10','04/30','10/08','10/18','10/29','0127','0143','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('258465','NE','JOHNSON','TECUMSEH 1S',4.035444444000000e+001,-9.619388900000000e+001,'05/12','10/22','05/20','05/12','04/29','10/08','10/22','10/28','0124','0142','0159')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('258480','NE','BURT','TEKAMAH',4.177666666000000e+001,-9.623277800000000e+001,'05/07','10/24','05/17','05/07','04/23','10/10','10/24','11/02','0128','0149','0167')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('258628','NE','HITCHCOCK','TRENTON DAM',4.017388888000000e+001,-1.010611110000000e+002,'05/16','10/21','05/21','05/16','04/30','10/08','10/21','10/31','0121','0139','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('258755','NE','CHERRY','VALENTINE NWR',4.257111111000000e+001,-1.006930560000000e+002,'05/20','10/10','06/04','05/20','05/09','09/28','10/10','10/25','0104','0128','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('258760','NE','CHERRY','VALENTINE MILLER AP',4.287833333000000e+001,-1.005500000000000e+002,'05/24','10/07','06/10','05/24','05/15','09/29','10/07','10/19','0094','0119','0132')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('258915','NE','DIXON','WAKEFIELD',4.226472222000000e+001,-9.686666700000001e+001,'05/13','10/12','05/23','05/13','05/11','10/02','10/12','10/23','0117','0132','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('258920','NE','LINCOLN','WALLACE 2W',4.084333333000000e+001,-1.012094440000000e+002,'05/20','10/09','06/02','05/20','05/13','10/01','10/09','10/19','0108','0119','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('258935','NE','THURSTON','WALTHILL 1E',4.215055555000000e+001,-9.647555600000000e+001,'05/19','10/07','06/01','05/19','05/10','10/01','10/07','10/24','0104','0130','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('259200','NE','CUMING','WEST POINT',4.184500000000000e+001,-9.671416700000000e+001,'05/11','10/18','05/24','05/11','05/07','10/06','10/18','10/27','0117','0137','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('260150','NV','NYE','AMARGOSA FARMS-GAREY',3.657166666000000e+001,-1.164619440000000e+002,'04/29','11/23','05/17','04/29','04/18','11/13','11/23','12/11','0153','0181','0195')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('260438','NV','ELKO','ARTHUR 4NW',4.078083333000000e+001,-1.151852780000000e+002,'06/24','10/01','07/16','06/24','06/16','09/23','10/01','10/15','0035','0072','0096')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('260507','NV','LANDER','AUSTIN #2',3.949305555000000e+001,-1.170675000000000e+002,'06/16','10/13','06/26','06/16','06/09','10/02','10/13','10/29','0074','0095','0113')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('260691','NV','LANDER','BATTLE MOUNTAIN 4SE',4.061166666000000e+001,-1.168916670000000e+002,'06/21','10/01','07/09','06/21','06/03','09/18','10/01','10/09','0042','0073','0105')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('260795','NV','EUREKA','BEOWAWE',4.059027777000000e+001,-1.164750000000000e+002,'06/17','10/01','07/10','06/17','06/10','09/17','10/01','10/08','0047','0083','0098')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('261358','NV','LINCOLN','CALIENTE',3.761277777000000e+001,-1.145263890000000e+002,'05/25','10/27','06/08','05/25','05/15','10/12','10/27','11/07','0104','0131','0152')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('261485','NV','CARSON (CITY)','CARSON CITY',3.914638888000000e+001,-1.197677780000000e+002,'06/19','10/16','07/06','06/19','05/26','09/28','10/16','10/25','0052','0090','0124')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('262229','NV','HUMBOLDT','DENIO',4.198916666000000e+001,-1.186338890000000e+002,'06/28','09/29','07/09','06/28','06/01','09/18','09/29','10/16','0047','0072','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('262243','NV','CLARK','DESERT NWR',3.643777777000000e+001,-1.153597220000000e+002,'04/21','11/19','05/07','04/21','04/07','11/10','11/19','12/01','0171','0195','0224')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('262394','NV','HUMBOLDT','DUFURRENA - DENIO 22WSW',4.186777777000000e+001,-1.190147220000000e+002,'07/05','09/16','07/20','07/05','06/18','09/06','09/16','09/28','0025','0059','0085')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('262431','NV','ESMERALDA','DYER',3.761500000000000e+001,-1.180105560000000e+002,'06/02','10/14','06/23','06/02','05/21','10/07','10/14','10/28','0082','0110','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('262573','NV','ELKO','ELKO RGNL AP',4.082888888000000e+001,-1.157886110000000e+002,'07/02','09/26','07/23','07/02','06/09','09/18','09/26','10/11','0020','0061','0095')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('262631','NV','WHITE PINE','ELY AIRPORT',3.929527777000000e+001,-1.148466670000000e+002,'07/05','09/21','07/15','07/05','06/21','09/13','09/21','10/05','0034','0054','0083')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('262708','NV','EUREKA','EUREKA',3.951694444000000e+001,-1.159622220000000e+002,'06/20','10/11','07/03','06/20','06/10','09/29','10/11','10/23','0064','0089','0108')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('262780','NV','CHURCHILL','FALLON EXP STN',3.945722222000000e+001,-1.187811110000000e+002,'06/04','10/16','06/26','06/04','05/16','10/06','10/16','10/25','0077','0110','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('263090','NV','WASHOE','GERLACH',4.065138888000000e+001,-1.193563890000000e+002,'05/20','10/22','06/11','05/20','05/06','10/13','10/22','11/02','0102','0134','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('263114','NV','ELKO','GIBBS RCH JARBIDGE24SE',4.156972222000000e+001,-1.152111110000000e+002,'07/11','09/18','07/24','07/11','06/30','09/04','09/18','09/24','0017','0044','0064')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('263205','NV','DOUGLAS','GLENBROOK',3.907527777000000e+001,-1.199411110000000e+002,'06/25','10/27','07/12','06/25','06/08','10/08','10/27','11/08','0050','0092','0116')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('263957','NV','PERSHING','IMLAY',4.065638888000000e+001,-1.181630560000000e+002,'05/31','10/13','06/16','05/31','05/15','10/05','10/13','10/23','0087','0116','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('264236','NV','HUMBOLDT','KINGS RIVER VALLEY',4.174361111000000e+001,-1.182258330000000e+002,'06/24','10/06','07/05','06/24','06/01','09/22','10/06','10/15','0052','0076','0115')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('264349','NV','CHURCHILL','LAHONTAN DAM',3.946888888000000e+001,-1.190644440000000e+002,'05/27','11/05','06/15','05/27','05/08','10/31','11/05','11/10','0102','0132','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('264436','NV','CLARK','LAS VEGAS AP',3.607194444000000e+001,-1.151633330000000e+002,'03/19','12/11','04/01','03/19','02/20','12/02','12/11','00/00','0225','0250','0281')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('264527','NV','HUMBOLDT','LEONARD CREEK RCH',4.151666666000000e+001,-1.187191670000000e+002,'06/07','10/18','06/18','06/07','05/17','10/10','10/18','11/05','0085','0110','0139')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('264698','NV','PERSHING','LOVELOCK',4.019055555000000e+001,-1.184766670000000e+002,'05/28','10/16','06/14','05/28','05/14','10/08','10/16','10/27','0092','0115','0142')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('264700','NV','PERSHING','LOVELOCK DERBY FLD AP',4.006805555000000e+001,-1.185691670000000e+002,'05/28','10/16','06/18','05/28','05/18','10/06','10/16','10/22','0086','0115','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('264745','NV','WHITE PINE','LUND',3.886777777000000e+001,-1.150163890000000e+002,'06/19','10/06','07/04','06/19','06/04','09/24','10/06','10/18','0059','0090','0112')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('264935','NV','HUMBOLDT','MCDERMITT',4.199527777000000e+001,-1.177200000000000e+002,'07/18','09/28','07/27','07/18','06/30','09/07','09/28','10/07','0012','0038','0070')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('264950','NV','WHITE PINE','MCGILL',3.941361111000000e+001,-1.147733330000000e+002,'06/19','10/15','06/26','06/19','05/31','10/01','10/15','10/22','0070','0082','0119')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('265168','NV','MINERAL','MINA',3.838444444000000e+001,-1.181055560000000e+002,'05/19','10/31','06/04','05/19','05/05','10/17','10/31','11/07','0110','0144','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('265191','NV','DOUGLAS','MINDEN',3.895472222000000e+001,-1.197758330000000e+002,'07/02','10/05','07/13','07/02','06/05','09/16','10/05','10/16','0042','0074','0102')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('265352','NV','ELKO','MONTELLO 2NE',4.127833333000000e+001,-1.141708330000000e+002,'07/01','09/23','07/13','07/01','06/11','09/14','09/23','10/07','0039','0060','0095')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('265818','NV','HUMBOLDT','OROVADA 3 W',4.156777777000000e+001,-1.178386110000000e+002,'06/16','10/03','07/11','06/16','05/24','09/22','10/03','10/17','0045','0089','0118')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('265880','NV','LINCOLN','PAHRANAGAT WR',3.726916666000000e+001,-1.151197220000000e+002,'05/06','11/13','05/27','05/06','04/17','11/05','11/13','11/21','0143','0170','0195')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('265890','NV','NYE','PAHRUMP',3.627861111000000e+001,-1.160033330000000e+002,'04/25','11/16','05/12','04/25','04/02','11/06','11/16','11/25','0153','0180','0217')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('266252','NV','LINCOLN','PIOCHE',3.793444444000000e+001,-1.144500000000000e+002,'06/06','10/30','06/18','06/06','05/18','10/20','10/30','11/12','0098','0122','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('266779','NV','WASHOE','RENO AP',3.948388888000000e+001,-1.197711110000000e+002,'06/13','10/27','07/04','06/13','05/20','10/10','10/27','11/07','0054','0096','0132')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('267123','NV','ELKO','RUBY LAKE NWR',4.020222222000000e+001,-1.154930560000000e+002,'06/21','10/03','06/27','06/21','06/04','09/21','10/03','10/16','0064','0079','0113')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('267175','NV','WHITE PINE','RUTH',3.927638888000000e+001,-1.149911110000000e+002,'07/10','09/14','07/27','07/10','06/26','09/06','09/14','09/27','0014','0047','0073')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('267192','NV','PERSHING','RYE PATCH DAM',4.046611111000000e+001,-1.183047220000000e+002,'06/23','10/06','07/13','06/23','05/27','09/18','10/06','10/15','0043','0080','0117')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('267369','NV','CLARK','SEARCHLIGHT',3.546611111000000e+001,-1.149216670000000e+002,'04/18','12/07','05/01','04/18','03/13','11/25','12/07','01/08','0182','0209','0264')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('267463','NV','ESMERALDA','SILVERPEAK',3.775083333000000e+001,-1.176375000000000e+002,'05/13','10/30','05/26','05/13','04/29','10/20','10/30','11/10','0120','0146','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('267620','NV','NYE','SMOKEY VALLEY - CARVERS',3.878388888000000e+001,-1.171738890000000e+002,'06/14','10/11','06/28','06/14','05/29','10/02','10/11','10/20','0072','0096','0118')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('267908','NV','NYE','SUNNYSIDE - LUND 31S',3.842305555000000e+001,-1.150225000000000e+002,'06/16','10/06','06/28','06/16','05/27','09/29','10/06','10/19','0074','0090','0121')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('267953','NV','WASHOE','SUTCLIFFE',3.995083333000000e+001,-1.195986110000000e+002,'05/20','11/26','06/07','05/20','05/09','11/09','11/26','12/08','0100','0133','0153')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('268170','NV','NYE','TONOPAH AIRPORT',3.805111111000000e+001,-1.170902780000000e+002,'06/02','10/28','06/17','06/02','05/21','10/19','10/28','11/07','0099','0126','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('268346','NV','ELKO','TUSCARORA',4.131444444000000e+001,-1.162225000000000e+002,'07/06','09/30','07/22','07/06','06/14','09/15','09/30','10/11','0027','0054','0095')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('268761','NV','STOREY','VIRGINIA CITY',3.931277777000000e+001,-1.196483330000000e+002,'06/10','11/03','06/20','06/10','05/30','10/21','11/03','11/13','0087','0109','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('269171','NV','HUMBOLDT','WINNEMUCCA AP',4.090166666000000e+001,-1.178080560000000e+002,'06/29','09/29','07/12','06/29','06/12','09/18','09/29','10/10','0038','0069','0093')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('269229','NV','LYON','YERINGTON',3.899916666000000e+001,-1.191575000000000e+002,'05/31','10/22','06/19','05/31','05/21','10/10','10/22','11/04','0090','0113','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('270681','NH','GRAFTON','BENTON 5 SW',4.403416666000000e+001,-7.194861100000000e+001,'06/03','10/06','06/21','06/03','05/16','09/23','10/06','10/14','0076','0104','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('270690','NH','COOS','BERLIN',4.444861111000000e+001,-7.118416700000000e+001,'06/01','10/08','06/19','06/01','05/14','09/21','10/08','10/16','0077','0110','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('271647','NH','COOS','COLEBROOK 3SW',4.486111111000000e+001,-7.154000000000001e+001,'06/27','09/26','07/20','06/27','06/06','09/14','09/26','10/11','0025','0059','0108')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('271683','NH','MERRIMACK','CONCORD ASOS',4.319527777000000e+001,-7.150111100000000e+001,'06/06','10/05','06/15','06/06','05/15','09/26','10/05','10/14','0072','0102','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('272174','NH','STRAFFORD','DURHAM',4.315000000000000e+001,-7.095000000000000e+001,'05/27','10/08','06/14','05/27','05/15','09/29','10/08','10/23','0086','0113','0139')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('272800','NH','ROCKINGHAM','EPPING',4.303027777000000e+001,-7.108388900000000e+001,'05/28','10/05','06/15','05/28','05/18','09/27','10/05','10/19','0085','0114','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('272999','NH','COOS','FIRST CONNECTICUT LAKE',4.508750000000000e+001,-7.128722200000000e+001,'06/22','09/22','07/18','06/22','06/05','09/17','09/22','10/11','0027','0073','0109')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('273850','NH','GRAFTON','HANOVER',4.370333333000000e+001,-7.228472200000000e+001,'05/25','10/17','06/10','05/25','05/12','10/04','10/17','10/31','0098','0125','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('274399','NH','CHESHIRE','KEENE',4.293888888000000e+001,-7.232472199999999e+001,'05/27','10/09','06/13','05/27','05/14','09/27','10/09','10/19','0089','0119','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('274480','NH','BELKNAP','LAKEPORT 2',4.354916666000000e+001,-7.146416700000000e+001,'05/24','10/19','06/14','05/24','05/07','10/11','10/19','11/05','0094','0126','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('274556','NH','COOS','LANCASTER',4.449111111000000e+001,-7.157250000000001e+001,'06/16','10/03','07/05','06/16','05/26','09/21','10/03','10/11','0054','0084','0118')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('275211','NH','HILLSBOROUGH','MASSABESIC LAKE',4.298916666000000e+001,-7.139333300000000e+001,'05/24','10/13','06/09','05/24','05/16','10/02','10/13','10/28','0093','0114','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('275629','NH','MERRIMACK','MT SUNAPEE',4.333361111000000e+001,-7.208250000000000e+001,'05/23','10/13','06/09','05/23','05/09','10/06','10/13','10/26','0096','0123','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('275639','NH','COOS','MT WASHINGTON',4.426666666000000e+001,-7.129944399999999e+001,'07/24','09/09','08/02','07/24','06/30','08/20','09/09','09/18','0002','0024','0058')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('275712','NH','HILLSBOROUGH','NASHUA 2 NNW',4.279138888000000e+001,-7.147361100000001e+001,'05/20','10/14','06/06','05/20','05/10','10/03','10/14','10/27','0098','0130','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('276234','NH','COOS','NORTH STRATFORD',4.475000000000000e+001,-7.163027800000000e+001,'06/13','09/29','06/26','06/13','05/27','09/19','09/29','10/20','0066','0087','0122')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('276818','NH','COOS','PINKHAM NOTCH',4.426333333000000e+001,-7.125500000000000e+001,'06/05','10/08','06/30','06/05','05/23','09/22','10/08','10/14','0056','0102','0125')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('280311','NJ','ATLANTIC','ATLANTIC CITY INTL AP',3.944944444000000e+001,-7.456722200000000e+001,'05/10','11/03','05/18','05/10','05/01','10/20','11/03','11/13','0137','0151','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('280325','NJ','ATLANTIC','ATLANTIC CITY',3.937916666000000e+001,-7.442416700000000e+001,'04/18','12/01','04/23','04/18','04/05','11/20','12/01','12/14','0179','0195','0216')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('281335','NJ','ESSEX','CANOE BROOK',4.074361111000000e+001,-7.435388900000000e+001,'05/13','10/29','05/25','05/13','04/29','10/15','10/29','11/09','0125','0146','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('281351','NJ','CAPE MAY','CAPE MAY 2 NW',3.895361111000000e+001,-7.493583300000000e+001,'04/19','11/20','05/04','04/19','04/06','11/10','11/20','12/06','0169','0193','0228')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('281582','NJ','PASSAIC','CHARLOTTEBURG RESERVE',4.103472222000000e+001,-7.442333300000000e+001,'05/18','10/18','05/30','05/18','05/01','10/06','10/18','11/02','0111','0132','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('282023','NJ','UNION','CRANFORD',4.066694444000000e+001,-7.432305599999999e+001,'05/17','10/29','05/26','05/17','05/02','10/19','10/29','11/10','0124','0143','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('282768','NJ','ESSEX','ESSEX FELLS SVC BLDG',4.083138888000000e+001,-7.428583300000000e+001,'05/07','11/02','05/22','05/07','04/28','10/17','11/02','11/15','0125','0151','0176')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('283029','NJ','HUNTERDON','FLEMINGTON 5 NNW',4.056305555000000e+001,-7.488305600000000e+001,'05/15','10/26','05/27','05/15','04/30','10/15','10/26','11/12','0123','0145','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('283181','NJ','MONMOUTH','FREEHOLD-MARLBORO',4.031416666000000e+001,-7.425111100000000e+001,'05/03','11/06','05/15','05/03','04/29','10/26','11/06','11/18','0138','0164','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('283951','NJ','MERCER','HIGHTSTOWN 2 W',4.026500000000000e+001,-7.456416700000000e+001,'05/06','10/28','05/20','05/06','04/23','10/18','10/28','11/12','0129','0153','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('284229','NJ','BURLINGTON','INDIAN MILLS 2 W',3.981444444000000e+001,-7.478833299999999e+001,'05/17','10/19','05/27','05/17','05/02','10/08','10/19','11/07','0117','0137','0165')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('284635','NJ','HUNTERDON','LAMBERTVILLE',4.036666666000000e+001,-7.494722200000000e+001,'05/08','10/30','05/21','05/08','04/28','10/18','10/30','11/09','0133','0148','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('284887','NJ','PASSAIC','LITTLE FALLS',4.088583333000000e+001,-7.422611100000000e+001,'04/29','11/02','05/15','04/29','04/16','10/22','11/02','11/18','0140','0167','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('284987','NJ','MONMOUTH','LONG BRANCH OAKHURST',4.027972222000000e+001,-7.400472200000000e+001,'05/02','11/10','05/14','05/02','04/18','11/03','11/10','11/24','0145','0167','0194')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('285581','NJ','CUMBERLAND','MILVILLE FAA AP',3.936666666000000e+001,-7.506666700000000e+001,'05/04','11/09','05/15','05/04','04/18','10/25','11/09','11/19','0144','0163','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('285728','NJ','BURLINGTON','MOORESTOWN',3.995111111000000e+001,-7.496972200000000e+001,'05/08','11/03','05/20','05/08','04/27','10/22','11/03','11/15','0132','0155','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('286026','NJ','ESSEX','NEWARK INTL AP',4.068250000000000e+001,-7.416944400000000e+001,'04/15','11/23','04/24','04/15','04/07','11/10','11/23','12/06','0179','0194','0225')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('286055','NJ','MIDDLESEX','NEW BRUNSWICK 3 SE',4.047194444000000e+001,-7.443638900000001e+001,'05/01','11/01','05/16','05/01','04/17','10/22','11/01','11/18','0140','0164','0191')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('287079','NJ','UNION','PLAINFIELD',4.060361111000000e+001,-7.440250000000000e+001,'05/04','11/05','05/16','05/04','04/17','10/20','11/05','11/11','0139','0158','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('287865','NJ','MONMOUTH','SANDY HOOK',4.046333333000000e+001,-7.400555600000000e+001,'04/26','11/23','05/02','04/26','04/21','11/12','11/23','12/16','0157','0168','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('287936','NJ','CUMBERLAND','SEABROOK FARMS',3.948722222000000e+001,-7.522000000000000e+001,'04/23','11/12','05/06','04/23','04/12','10/29','11/12','11/26','0150','0178','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('288644','NJ','SUSSEX','SUSSEX 2 NW',4.122138888000000e+001,-7.466000000000000e+001,'05/21','10/17','06/05','05/21','05/05','10/03','10/17','10/31','0105','0129','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('288816','NJ','OCEAN','TOMS RIVER',3.995000000000000e+001,-7.421666700000000e+001,'05/07','10/30','05/21','05/07','04/27','10/19','10/30','11/15','0131','0155','0181')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('289187','NJ','PASSAIC','WANAQUE RAYMOND DAM',4.104444444000000e+001,-7.429333300000000e+001,'05/07','11/02','05/16','05/07','04/20','10/22','11/02','11/13','0135','0160','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('290041','NM','RIO ARRIBA','ABIQUIU DAM',3.624027777000000e+001,-1.064277780000000e+002,'05/20','10/29','05/31','05/20','05/07','10/21','10/29','11/09','0122','0142','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('290234','NM','BERNALILLO','ALBUQUERQUE INTL AP',3.504194444000000e+001,-1.066155560000000e+002,'05/03','11/11','05/16','05/03','04/23','11/02','11/11','11/21','0151','0168','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('290377','NM','UNION','AMISTAD 5 SSW',3.587416666000000e+001,-1.031819440000000e+002,'05/11','10/23','05/17','05/11','05/02','10/14','10/23','11/06','0133','0145','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('290417','NM','HIDALGO','ANIMAS 3ESE',3.193805555000000e+001,-1.087688890000000e+002,'05/10','11/11','05/23','05/10','05/02','11/02','11/11','11/19','0150','0165','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('290600','NM','EDDY','ARTESIA 6S',3.275472222000000e+001,-1.043836110000000e+002,'04/28','11/06','05/10','04/28','04/16','10/29','11/06','11/17','0148','0172','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('290640','NM','SOCORRO','AUGUSTINE 2E',3.407500000000000e+001,-1.076211110000000e+002,'06/22','10/09','07/06','06/22','06/07','10/04','10/09','10/14','0060','0090','0109')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('290692','NM','SAN JUAN','AZTEC RUINS NM',3.683500000000000e+001,-1.080005560000000e+002,'06/11','10/17','06/22','06/11','05/30','10/08','10/17','11/01','0087','0100','0128')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('290818','NM','CATRON','BEAVERHEAD R/S',3.342861111000000e+001,-1.081000000000000e+002,'06/23','10/07','07/12','06/23','06/13','10/01','10/07','10/18','0059','0091','0111')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('290858','NM','SAN MIGUEL','BELL RANCH',3.552972222000000e+001,-1.040936110000000e+002,'05/09','10/31','05/16','05/09','04/27','10/19','10/31','11/11','0138','0159','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('290983','NM','SOCORRO','BINGHAM 2 NE',3.391138888000000e+001,-1.063494440000000e+002,'05/17','11/04','05/27','05/17','05/03','10/23','11/04','11/10','0133','0151','0171')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('290992','NM','CHAVES','BITTER LAKES WR',3.345944444000000e+001,-1.044041670000000e+002,'05/09','11/01','05/19','05/09','04/25','10/20','11/01','11/10','0135','0157','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('291138','NM','SOCORRO','BOSQUE DEL APACHE',3.380444444000000e+001,-1.068908330000000e+002,'05/18','10/26','05/27','05/18','05/03','10/18','10/26','11/06','0128','0144','0166')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('291469','NM','EDDY','CARLSBAD',3.234777777000000e+001,-1.042225000000000e+002,'04/20','11/18','04/27','04/20','04/05','11/07','11/18','12/02','0173','0190','0216')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('291475','NM','EDDY','CAVERN CITY AIRPORT',3.233361111000000e+001,-1.042580560000000e+002,'04/17','11/16','04/24','04/17','04/04','11/09','11/16','11/29','0182','0193','0217')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('291480','NM','EDDY','CARLSBAD CAVERNS',3.217833333000000e+001,-1.044433330000000e+002,'04/21','11/25','04/23','04/21','04/07','11/11','11/25','12/08','0176','0196','0216')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('291515','NM','LINCOLN','CARRIZOZO 1SW',3.363083333000000e+001,-1.058963890000000e+002,'05/12','11/01','05/24','05/12','05/01','10/23','11/01','11/10','0135','0152','0172')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('291630','NM','TAOS','CERRO',3.674083333000000e+001,-1.055955560000000e+002,'06/14','10/04','06/26','06/14','06/05','09/26','10/04','10/13','0074','0095','0113')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('291647','NM','SAN JUAN','CHACO CANYON NATL MON',3.602861111000000e+001,-1.079105560000000e+002,'06/23','10/08','06/28','06/23','06/04','09/28','10/08','10/14','0078','0092','0113')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('291664','NM','RIO ARRIBA','CHAMA',3.691777777000000e+001,-1.065780560000000e+002,'07/09','09/28','07/19','07/09','06/26','09/17','09/28','10/04','0032','0055','0084')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('291813','NM','COLFAX','CIMARRON 4 SW',3.646611111000000e+001,-1.049455560000000e+002,'05/28','10/10','06/10','05/28','05/15','10/02','10/10','10/21','0099','0118','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('291910','NM','GRANT','CLIFF 11 SE',3.283388888000000e+001,-1.085047220000000e+002,'05/26','11/02','06/09','05/26','05/12','10/20','11/02','11/09','0117','0142','0158')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('291918','NM','TORRANCE','CLINES CORNERS 7SE',3.493194444000000e+001,-1.055872220000000e+002,'05/31','10/16','06/13','05/31','05/21','10/06','10/16','10/26','0103','0120','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('291963','NM','CURRY','CLOVIS 13 N',3.459888888000000e+001,-1.032161110000000e+002,'05/08','11/02','05/15','05/08','04/23','10/25','11/02','11/19','0136','0159','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('292030','NM','SAN MIGUEL','CONCHAS DAM',3.540722222000000e+001,-1.041905560000000e+002,'04/22','11/10','05/08','04/22','04/13','11/03','11/10','11/20','0156','0186','0205')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('292241','NM','SANDOVAL','CUBA',3.601055555000000e+001,-1.069683330000000e+002,'06/30','10/02','07/15','06/30','06/19','09/24','10/02','10/08','0042','0069','0095')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('292510','NM','GUADALUPE','DILIA',3.518416666000000e+001,-1.050569440000000e+002,'05/17','10/27','05/25','05/17','05/04','10/14','10/27','11/07','0125','0148','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('292608','NM','RIO ARRIBA','DULCE',3.693583333000000e+001,-1.070000000000000e+002,'07/12','10/01','07/21','07/12','06/22','09/22','10/01','10/05','0032','0054','0089')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('292700','NM','COLFAX','EAGLE NEST',3.655750000000000e+001,-1.052627780000000e+002,'07/13','09/21','07/31','07/13','06/26','09/06','09/21','09/29','0013','0042','0078')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('292785','NM','CIBOLA','EL MORRO NATL MON',3.503805555000000e+001,-1.083491670000000e+002,'06/22','10/06','06/30','06/22','06/06','10/02','10/06','10/14','0067','0093','0113')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('292820','NM','RIO ARRIBA','EL RITO',3.634666666000000e+001,-1.061877780000000e+002,'06/17','10/19','06/23','06/17','05/29','10/10','10/19','11/01','0088','0103','0130')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('292837','NM','RIO ARRIBA','EL VADO DAM',3.659277777000000e+001,-1.067300000000000e+002,'06/28','10/01','07/17','06/28','06/17','09/20','10/01','10/05','0041','0076','0094')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('292848','NM','SIERRA','ELEPHANT BUTTE DAM',3.314611111000000e+001,-1.071844440000000e+002,'04/14','11/23','04/25','04/14','03/31','11/16','11/23','12/07','0185','0202','0226')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('292854','NM','ROOSEVELT','ELIDA',3.394027777000000e+001,-1.036572220000000e+002,'05/09','11/06','05/18','05/09','04/24','10/24','11/06','11/16','0132','0154','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('292865','NM','CHAVES','ELK',3.291611111000000e+001,-1.053380560000000e+002,'05/16','10/26','05/28','05/16','05/06','10/13','10/26','11/06','0119','0143','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('293060','NM','TORRANCE','ESTANCIA 4N',3.482416666000000e+001,-1.060344440000000e+002,'06/03','10/12','06/16','06/03','05/24','10/04','10/12','10/22','0097','0113','0132')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('293157','NM','GRANT','FAYWOOD',3.263166666000000e+001,-1.078636110000000e+002,'05/04','11/11','05/25','05/04','04/24','11/03','11/11','11/18','0144','0168','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('293340','NM','SAN JUAN','FRUITLAND',3.673805555000000e+001,-1.083483330000000e+002,'05/31','10/15','06/20','05/31','05/21','10/10','10/15','10/30','0084','0116','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('293488','NM','MORA','GASCON',3.589166666000000e+001,-1.054480560000000e+002,'06/20','10/05','06/28','06/20','06/09','09/27','10/05','10/11','0056','0082','0106')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('293530','NM','GRANT','GILA HOT SPRINGS',3.319750000000000e+001,-1.082075000000000e+002,'06/07','10/19','06/27','06/07','05/21','10/06','10/19','11/02','0090','0119','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('293649','NM','SOCORRO','GRAN QUIVIRA NATL MON',3.425944444000000e+001,-1.060930560000000e+002,'05/17','10/21','05/25','05/17','05/11','10/14','10/21','11/03','0122','0134','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('293682','NM','CIBOLA','GRANTS AP',3.516638888000000e+001,-1.078991670000000e+002,'06/09','10/12','06/21','06/09','05/25','10/05','10/12','10/22','0085','0109','0131')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('293775','NM','GRANT','HACHITA',3.191750000000000e+001,-1.083247220000000e+002,'05/11','11/12','05/23','05/11','04/27','11/04','11/12','11/21','0152','0165','0191')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('294026','NM','LEA','HOBBS',3.272638888000000e+001,-1.031313890000000e+002,'04/16','11/26','04/25','04/16','04/11','11/14','11/26','12/02','0178','0192','0212')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('294346','NM','LEA','JAL',3.211027777000000e+001,-1.031872220000000e+002,'04/23','11/18','04/29','04/23','04/12','11/12','11/18','11/30','0175','0191','0202')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('294426','NM','DONA ANA','JORNADA EXP RANGE',3.261611111000000e+001,-1.067402780000000e+002,'05/16','11/03','05/24','05/16','05/03','10/26','11/03','11/11','0138','0153','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('294742','NM','COLFAX','LAKE MALOYA',3.698250000000000e+001,-1.043752780000000e+002,'06/14','10/02','07/01','06/14','05/24','09/25','10/02','10/13','0063','0095','0120')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('294960','NM','RIO ARRIBA','LINDRITH 1 WSW',3.630416666000000e+001,-1.070541670000000e+002,'06/27','10/16','07/02','06/27','06/14','09/30','10/16','10/22','0065','0081','0100')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('295079','NM','HIDALGO','LORDSBURG 4 SE',3.230944444000000e+001,-1.086530560000000e+002,'05/15','11/08','05/23','05/15','05/05','10/31','11/08','11/16','0145','0160','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('295084','NM','LOS ALAMOS','LOS ALAMOS',3.586444444000000e+001,-1.063213890000000e+002,'05/28','10/23','06/05','05/28','05/14','10/10','10/23','11/04','0111','0128','0145')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('295150','NM','VALENCIA','LOS LUNAS 3 SSW',3.476750000000000e+001,-1.067611110000000e+002,'05/18','10/28','05/29','05/18','05/02','10/17','10/28','11/06','0124','0149','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('295273','NM','CATRON','LUNA RS',3.382250000000000e+001,-1.089416670000000e+002,'07/06','09/30','07/17','07/06','06/26','09/18','09/30','10/07','0037','0057','0085')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('295290','NM','RIO ARRIBA','LYBROOK',3.623027777000000e+001,-1.075472220000000e+002,'06/02','10/23','06/15','06/02','05/27','10/16','10/23','11/02','0094','0116','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('295370','NM','LEA','MALJAMAR',3.285666666000000e+001,-1.037625000000000e+002,'04/30','11/13','05/08','04/30','04/16','11/05','11/13','11/21','0151','0174','0190')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('295490','NM','COLFAX','MAXWELL 3 NW',3.656972222000000e+001,-1.045866670000000e+002,'06/05','10/08','06/16','06/05','05/22','10/04','10/08','10/21','0094','0110','0132')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('295560','NM','MCKINLEY','MCGAFFEY 5 SE',3.533638888000000e+001,-1.084447220000000e+002,'06/30','09/30','07/10','06/30','06/22','09/21','09/30','10/07','0048','0076','0091')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('295937','NM','HARDING','MOSQUERO 1 NE',3.580222222000000e+001,-1.039438890000000e+002,'05/16','10/21','05/29','05/16','05/05','10/14','10/21','11/03','0119','0135','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('296115','NM','GUADALUPE','NEWKIRK',3.507000000000000e+001,-1.042575000000000e+002,'05/12','11/02','05/19','05/12','04/25','10/21','11/02','11/12','0131','0147','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('296275','NM','MORA','OCATE 2 NW',3.618388888000000e+001,-1.050608330000000e+002,'06/19','10/02','07/05','06/19','06/04','09/26','10/02','10/08','0063','0093','0113')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('296465','NM','SAN JUAN','OTIS',3.633388888000000e+001,-1.078408330000000e+002,'05/26','10/25','06/12','05/26','05/22','10/18','10/25','11/07','0105','0128','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('296676','NM','SAN MIGUEL','PECOS NM',3.554888888000000e+001,-1.056886110000000e+002,'06/08','10/09','06/14','06/08','05/23','10/02','10/09','10/20','0094','0108','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('296687','NM','TORRANCE','PEDERNAL 9 E',3.461527777000000e+001,-1.054738890000000e+002,'05/27','10/15','06/03','05/27','05/21','10/08','10/15','10/26','0113','0123','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('297008','NM','ROOSEVELT','PORTALES',3.417416666000000e+001,-1.033519440000000e+002,'05/02','11/05','05/15','05/02','04/20','10/22','11/05','11/17','0140','0164','0191')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('297180','NM','CATRON','QUEMADO',3.434472222000000e+001,-1.084922220000000e+002,'06/28','10/07','07/06','06/28','06/16','09/30','10/07','10/12','0054','0081','0106')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('297226','NM','QUAY','RAGLAND 3 SSW',3.478000000000000e+001,-1.037491670000000e+002,'05/11','11/01','05/16','05/11','05/02','10/22','11/01','11/12','0135','0155','0176')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('297254','NM','LINCOLN','RAMON 8 SW',3.415083333000000e+001,-1.050044440000000e+002,'05/14','10/25','05/27','05/14','05/06','10/12','10/25','11/03','0121','0140','0156')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('297279','NM','COLFAX','RATON FLTR PLT',3.691944444000000e+001,-1.044325000000000e+002,'05/21','10/19','06/06','05/21','05/12','10/10','10/19','10/30','0105','0131','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('297323','NM','TAOS','RED RIVER',3.671000000000000e+001,-1.054163890000000e+002,'07/08','09/22','07/31','07/08','06/19','09/01','09/22','10/01','0005','0047','0083')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('297340','NM','GRANT','REDROCK 1 NNE',3.270472222000000e+001,-1.087280560000000e+002,'05/20','11/06','05/30','05/20','05/05','10/30','11/06','11/18','0139','0154','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('297638','NM','HARDING','ROY',3.594222222000000e+001,-1.042013890000000e+002,'05/16','10/24','05/27','05/16','05/08','10/15','10/24','11/03','0121','0140','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('297649','NM','LINCOLN','RUIDOSO',3.336777777000000e+001,-1.056611110000000e+002,'06/23','10/12','07/06','06/23','06/06','10/05','10/12','10/18','0061','0087','0118')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('297867','NM','QUAY','SAN JON',3.510861111000000e+001,-1.033283330000000e+002,'05/06','11/04','05/14','05/06','04/17','10/22','11/04','11/13','0143','0166','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('298107','NM','GUADALUPE','SANTA ROSA',3.493583333000000e+001,-1.046805560000000e+002,'05/07','11/06','05/16','05/07','04/23','10/23','11/06','11/15','0136','0162','0183')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('298387','NM','SOCORRO','SOCORRO',3.408277777000000e+001,-1.068830560000000e+002,'05/12','10/30','05/23','05/12','04/30','10/19','10/30','11/10','0134','0157','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('298501','NM','COLFAX','SPRINGER',3.636277777000000e+001,-1.045850000000000e+002,'05/30','10/09','06/17','05/30','05/17','10/04','10/09','10/23','0096','0118','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('298518','NM','SANTA FE','STANLEY 2 NNE',3.517666666000000e+001,-1.059438890000000e+002,'05/28','10/13','06/12','05/28','05/21','10/05','10/13','10/21','0100','0119','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('298713','NM','LEA','TATUM',3.324222222000000e+001,-1.033611110000000e+002,'05/10','11/06','05/17','05/10','04/26','10/23','11/06','11/18','0136','0156','0183')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('298845','NM','RIO ARRIBA','TIERRA AMARILLA 4 N',3.676638888000000e+001,-1.065536110000000e+002,'07/08','09/28','07/19','07/08','06/21','09/18','09/28','10/04','0036','0058','0090')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('299085','NM','TAOS','TRES PIEDRAS',3.665111111000000e+001,-1.059725000000000e+002,'06/29','09/28','07/14','06/29','06/13','09/21','09/28','10/10','0045','0075','0100')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('299128','NM','SIERRA','TRUTH OR CONSEQUENCES',3.314055555000000e+001,-1.072322220000000e+002,'04/24','11/16','05/06','04/24','04/15','11/07','11/16','11/27','0167','0186','0209')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('299156','NM','QUAY','TUCUMCARI 4 NE',3.520055555000000e+001,-1.036866670000000e+002,'04/27','11/08','05/14','04/27','04/15','10/24','11/08','11/16','0146','0177','0195')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('299165','NM','OTERO','TULAROSA',3.307194444000000e+001,-1.060411110000000e+002,'04/24','11/19','05/10','04/24','04/19','11/05','11/19','11/24','0162','0186','0200')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('299330','NM','MORA','VALMORA',3.581666666000000e+001,-1.049244440000000e+002,'06/01','10/11','06/18','06/01','05/19','10/04','10/11','10/21','0090','0114','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('299686','NM','OTERO','WHITE SANDS NATL MON',3.278222222000000e+001,-1.061758330000000e+002,'05/12','10/30','05/23','05/12','05/01','10/21','10/30','11/12','0134','0157','0172')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('299691','NM','GRANT','WHITE SIGNAL',3.255638888000000e+001,-1.083666670000000e+002,'05/25','11/04','06/06','05/25','05/05','10/24','11/04','11/13','0122','0143','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('299806','NM','SIERRA','WINSTON',3.334972222000000e+001,-1.076491670000000e+002,'05/30','10/18','06/10','05/30','05/15','10/09','10/18','10/29','0106','0126','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('299820','NM','SANDOVAL','WOLF CANYON',3.594777777000000e+001,-1.067469440000000e+002,'07/11','09/23','07/27','07/11','06/28','09/11','09/23','10/02','0011','0043','0076')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('299851','NM','DE BACA','YESO 2 S',3.440305555000000e+001,-1.046127780000000e+002,'05/13','10/29','05/20','05/13','05/01','10/16','10/29','11/16','0130','0148','0177')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('299897','NM','MCKINLEY','ZUNI',3.507055555000000e+001,-1.088388890000000e+002,'06/09','10/19','06/21','06/09','06/02','10/07','10/19','10/27','0091','0108','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('300023','NY','STEUBEN','ADDISON',4.210138888000000e+001,-7.723444400000000e+001,'06/04','10/15','06/24','06/04','05/17','10/03','10/15','11/01','0079','0113','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('300042','NY','ALBANY','ALBANY INTL AP',4.274305555000000e+001,-7.380916700000000e+001,'05/15','10/13','06/01','05/15','05/01','10/04','10/13','11/03','0112','0139','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('300055','NY','ORLEANS','ALBION 2 NE',4.327222222000000e+001,-7.816638900000000e+001,'05/11','10/26','06/02','05/11','05/01','10/13','10/26','11/14','0117','0144','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('300063','NY','ALBANY','ALCOVE DAM',4.246972222000000e+001,-7.392666700000000e+001,'05/28','10/14','06/14','05/28','05/11','10/03','10/14','10/25','0083','0109','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('300085','NY','ALLEGANY','ALFRED',4.224972222000000e+001,-7.775833299999999e+001,'06/07','10/05','06/20','06/07','05/25','09/28','10/05','10/20','0069','0099','0122')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('300093','NY','CATTARAUGUS','ALLEGANY SP',4.210027777000000e+001,-7.874972200000001e+001,'06/13','10/09','06/21','06/13','05/26','10/01','10/09','10/28','0077','0099','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('300183','NY','ALLEGANY','ANGELICA',4.230333333000000e+001,-7.801888900000000e+001,'06/14','10/04','06/26','06/14','05/26','09/25','10/04','10/24','0066','0096','0123')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('300321','NY','CAYUGA','AUBURN',4.293277777000000e+001,-7.654472199999999e+001,'05/25','10/24','06/04','05/25','05/10','10/10','10/24','11/08','0107','0124','0158')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('300331','NY','CAYUGA','AURORA RSCH FARM',4.273388888000000e+001,-7.665916700000000e+001,'05/12','10/31','06/02','05/12','05/01','10/15','10/31','11/16','0113','0146','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('300343','NY','LIVINGSTON','AVON',4.292027777000000e+001,-7.775583300000000e+001,'05/15','10/22','06/01','05/15','05/02','10/10','10/22','11/10','0117','0143','0167')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('300443','NY','GENESEE','BATAVIA',4.303027777000000e+001,-7.816916700000000e+001,'05/17','10/25','06/02','05/17','04/28','10/08','10/25','11/09','0112','0139','0171')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('300448','NY','STEUBEN','BATH',4.234888888000000e+001,-7.734777800000001e+001,'05/30','10/12','06/15','05/30','05/16','09/30','10/12','10/25','0088','0111','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('300668','NY','HERKIMER','BIG MOOSE 3 SE',4.380000000000000e+001,-7.486666700000001e+001,'06/11','10/03','07/03','06/11','05/29','09/18','10/03','10/05','0043','0085','0112')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('300687','NY','BROOME','BINGHAMTON GREATER AP',4.220666666000000e+001,-7.598000000000000e+001,'05/12','10/24','06/04','05/12','04/29','10/12','10/24','11/08','0111','0143','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('300785','NY','ONEIDA','BOONVILLE 4 SSW',4.343611111000000e+001,-7.536972200000000e+001,'06/01','10/14','06/21','06/01','05/08','09/30','10/14','10/24','0087','0116','0143')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('300889','NY','SUFFOLK','BRIDGEHAMPTON',4.094611111000000e+001,-7.230694400000000e+001,'05/09','11/03','05/21','05/09','04/21','10/23','11/03','11/19','0137','0152','0188')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('301012','NY','ERIE','BUFFALO NIAGARA INTL',4.294083333000000e+001,-7.873583300000000e+001,'05/06','11/02','05/22','05/06','04/24','10/18','11/02','11/16','0129','0158','0182')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('301110','NY','ONEIDA','CAMDEN',4.333055555000000e+001,-7.584166700000000e+001,'06/14','10/15','06/24','06/14','05/23','09/25','10/15','10/26','0067','0090','0125')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('301152','NY','ONTARIO','CANANDAIGUA 3 S',4.284527777000000e+001,-7.728083300000000e+001,'05/11','11/01','05/24','05/11','04/28','10/21','11/01','11/16','0132','0149','0177')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('301185','NY','ST. LAWRENCE','CANTON 4 SE',4.457722222000000e+001,-7.510972200000001e+001,'06/05','10/06','06/22','06/05','05/14','09/24','10/06','10/16','0072','0103','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('301708','NY','SARATOGA','CONKLINGVILLE DAM',4.332027777000000e+001,-7.392555600000000e+001,'05/22','10/26','06/04','05/22','05/05','10/12','10/26','11/09','0111','0134','0156')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('301752','NY','OTSEGO','COOPERSTOWN',4.271666666000000e+001,-7.492666700000000e+001,'06/06','10/05','06/19','06/06','05/19','09/25','10/05','10/17','0079','0108','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('301966','NY','CLINTON','DANNEMORA',4.471916666000000e+001,-7.372055600000000e+001,'05/26','10/15','06/06','05/26','05/09','10/05','10/15','11/01','0106','0125','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('301974','NY','LIVINGSTON','DANSVILLE',4.256555555000000e+001,-7.771750000000000e+001,'05/28','10/20','06/08','05/28','05/09','10/06','10/20','11/04','0101','0126','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('302060','NY','DELAWARE','DEPOSIT',4.206277777000000e+001,-7.542638900000000e+001,'06/03','10/13','06/16','06/03','05/17','09/30','10/13','10/28','0088','0119','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('302129','NY','WESTCHESTER','DOBBS FERRY-ARDSLEY',4.100722222000000e+001,-7.383444400000001e+001,'05/02','11/08','05/14','05/02','04/17','10/27','11/08','11/27','0141','0165','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('302610','NY','CHEMUNG','ELMIRA',4.209972222000000e+001,-7.683583299999999e+001,'05/22','10/18','06/09','05/22','05/12','10/05','10/18','11/03','0103','0125','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('303025','NY','CATTARAUGUS','FRANKLINVILLE',4.232972222000000e+001,-7.846333300000001e+001,'06/11','10/07','06/24','06/11','05/31','09/28','10/07','10/23','0072','0093','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('303033','NY','CHAUTAUQUA','FREDONIA',4.244972222000000e+001,-7.931194400000000e+001,'05/14','11/05','05/26','05/14','04/27','10/21','11/05','11/22','0127','0152','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('303184','NY','ONTARIO','GENEVA RSCH FARM',4.287666666000000e+001,-7.703083300000000e+001,'05/10','10/29','05/26','05/10','04/27','10/16','10/29','11/13','0125','0150','0176')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('303284','NY','WARREN','GLENS FALLS FARM',4.333333333000000e+001,-7.373333300000000e+001,'05/29','10/12','06/14','05/29','05/11','10/02','10/12','10/22','0079','0110','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('303294','NY','WARREN','GLENS FALLS AP',4.335000000000000e+001,-7.361666700000001e+001,'05/18','10/11','06/07','05/18','05/08','10/03','10/11','10/24','0097','0131','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('303346','NY','ST. LAWRENCE','GOUVERNEUR 3 NW',4.435388888000000e+001,-7.551222199999999e+001,'06/04','10/04','06/22','06/04','05/17','09/25','10/04','10/17','0069','0105','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('303773','NY','LIVINGSTON','HEMLOCK',4.274416666000000e+001,-7.760833300000000e+001,'05/25','10/23','06/12','05/25','05/10','10/12','10/23','11/05','0090','0121','0156')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('304025','NY','COLUMBIA','HUDSON COR.FACILITY',4.225000000000000e+001,-7.380000000000000e+001,'05/15','10/24','05/28','05/15','05/05','10/10','10/24','11/11','0119','0142','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('304102','NY','HAMILTON','INDIAN LAKE 2SW',4.375500000000000e+001,-7.426916700000000e+001,'06/15','09/29','07/01','06/15','05/29','09/23','09/29','10/18','0055','0088','0122')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('304174','NY','TOMPKINS','ITHACA CORNELL UNIV',4.244916666000000e+001,-7.644916700000000e+001,'05/28','10/17','06/15','05/28','05/12','10/03','10/17','10/30','0089','0123','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('304207','NY','CHAUTAUQUA','JAMESTOWN 4 ENE',4.211000000000000e+001,-7.915916700000000e+001,'06/07','10/19','06/25','06/07','05/21','09/30','10/19','11/06','0077','0103','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('304555','NY','ESSEX','LAKE PLACID 2 S',4.424444444000000e+001,-7.398555600000000e+001,'06/22','09/23','07/22','06/22','06/04','09/11','09/23','10/11','0022','0074','0109')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('304731','NY','SULLIVAN','LIBERTY 1 NE',4.180166666000000e+001,-7.474000000000000e+001,'05/27','10/12','06/14','05/27','05/11','09/30','10/12','11/02','0089','0118','0145')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('304791','NY','HERKIMER','LITTLE FALLS CITY RES',4.306027777000000e+001,-7.486861100000000e+001,'05/21','10/11','06/11','05/21','05/07','09/30','10/11','10/27','0092','0124','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('304808','NY','CATTARAUGUS','LITTLE VALLEY',4.224722222000000e+001,-7.881250000000000e+001,'06/08','10/15','06/19','06/08','05/17','10/02','10/15','10/31','0084','0112','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('304912','NY','LEWIS','LOWVILLE',4.379750000000000e+001,-7.548166700000000e+001,'06/02','10/07','06/16','06/02','05/20','09/27','10/07','10/23','0079','0113','0132')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('305310','NY','ORANGE','MIDDLETOWN 2 NW',4.146027777000000e+001,-7.444888899999999e+001,'04/28','11/01','05/12','04/28','04/18','10/20','11/01','11/19','0139','0163','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('305334','NY','DUTCHESS','MILLBROOK',4.185527777000000e+001,-7.367000000000000e+001,'05/29','10/16','06/09','05/29','05/14','09/30','10/16','10/30','0096','0118','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('305377','NY','NASSAU','MINEOLA',4.073277777000000e+001,-7.361833300000001e+001,'04/23','11/28','05/05','04/23','04/11','11/07','11/28','12/12','0160','0187','0215')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('305426','NY','ULSTER','MOHONK LAKE',4.176805555000000e+001,-7.415500000000000e+001,'05/04','11/06','05/14','05/04','04/24','10/23','11/06','11/13','0140','0162','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('305512','NY','MADISON','MORRISVILLE 6 SW',4.284166666000000e+001,-7.572638900000000e+001,'05/30','10/09','06/24','05/30','05/12','09/27','10/09','11/01','0077','0112','0145')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('305597','NY','LIVINGSTON','MT MORRIS 2 W',4.273138888000000e+001,-7.790527800000000e+001,'05/16','10/24','06/02','05/16','04/30','10/08','10/24','11/08','0114','0141','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('305714','NY','ESSEX','NEWCOMB',4.397083333000000e+001,-7.422194399999999e+001,'06/18','10/04','07/04','06/18','05/29','09/21','10/04','10/14','0051','0081','0117')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('305796','NY','KINGS','NY AVE V BROOKLYN',4.059388888000000e+001,-7.398083300000000e+001,'04/13','12/03','04/21','04/13','04/07','11/21','12/03','12/13','0187','0206','0226')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('305801','NY','NEW YORK','NY CITY CNTRL PARK',4.077888888000000e+001,-7.396916700000000e+001,'04/13','12/02','04/24','04/13','04/09','11/13','12/02','12/13','0187','0203','0226')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('305803','NY','QUEENS','NEW YORK JFK INTL AP',4.063861111000000e+001,-7.376222199999999e+001,'04/11','12/04','04/19','04/11','04/06','11/13','12/04','12/10','0191','0209','0228')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('305811','NY','QUEENS','NEW YORK LA GUARDIA AP',4.077944444000000e+001,-7.388027800000000e+001,'04/12','12/04','04/20','04/12','04/03','11/22','12/04','12/15','0189','0213','0235')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('306085','NY','CHENANGO','NORWICH',4.251166666000000e+001,-7.551972200000000e+001,'06/05','10/07','06/16','06/05','05/15','10/01','10/07','10/26','0080','0109','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('306164','NY','ST. LAWRENCE','OGDENSBURG 4 NE',4.472805555000000e+001,-7.544416699999999e+001,'05/18','10/14','06/08','05/18','05/07','10/09','10/14','10/23','0103','0134','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('306184','NY','HERKIMER','OLD FORGE',4.370250000000000e+001,-7.498388900000001e+001,'07/01','09/28','07/19','07/01','06/12','09/19','09/28','10/13','0029','0062','0095')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('306314','NY','OSWEGO','OSWEGO EAST',4.346222222000000e+001,-7.649333300000001e+001,'05/11','10/31','05/26','05/11','04/26','10/21','10/31','11/16','0126','0148','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('306538','NY','CLINTON','PERU 2 WSW',4.456583333000000e+001,-7.356999999999999e+001,'05/25','10/11','06/11','05/25','05/09','10/02','10/11','10/21','0095','0124','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('306774','NY','ORANGE','PORT JERVIS',4.138000000000000e+001,-7.468472199999999e+001,'05/18','10/21','05/28','05/18','05/02','10/07','10/21','11/04','0119','0141','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('306820','NY','DUTCHESS','POUGHKEEPSIE 7NNW',4.172666666000000e+001,-7.392000000000000e+001,'05/14','10/24','05/28','05/14','04/27','10/06','10/24','11/04','0116','0135','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('307134','NY','SUFFOLK','RIVERHEAD RSCH FM',4.096194444000000e+001,-7.271583300000000e+001,'04/28','11/14','05/08','04/28','04/12','10/31','11/14','12/03','0157','0181','0216')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('307167','NY','MONROE','ROCHESTER INTL AP',4.311666666000000e+001,-7.767666700000000e+001,'05/12','10/27','05/28','05/12','04/29','10/14','10/27','11/13','0120','0147','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('307484','NY','SARATOGA','SARATOGA SPRINGS 4 SW',4.303333333000000e+001,-7.381666700000000e+001,'05/20','10/10','06/08','05/20','05/08','09/30','10/10','10/22','0098','0127','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('307633','NY','SUFFOLK','SETAUKET STRONG',4.095861111000000e+001,-7.310472200000000e+001,'05/01','11/15','05/07','05/01','04/12','10/28','11/15','11/12','0140','0173','0204')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('307842','NY','WAYNE','SODUS CTR',4.320777777000000e+001,-7.701277800000000e+001,'05/14','10/28','06/05','05/14','04/27','10/10','10/28','11/06','0115','0139','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('308383','NY','ONONDAGA','SYRACUSE HANCOCK  AP',4.311111111000000e+001,-7.610388900000000e+001,'05/08','10/28','05/24','05/08','04/28','10/09','10/28','11/09','0121','0148','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('308962','NY','WYOMING','WARSAW 6 SW',4.268555555000000e+001,-7.822027799999999e+001,'05/29','10/15','06/10','05/29','05/11','10/04','10/15','11/02','0096','0113','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('309000','NY','JEFFERSON','WATERTOWN',4.397611111000000e+001,-7.587527799999999e+001,'05/14','10/18','06/05','05/14','04/30','10/07','10/18','10/31','0111','0139','0165')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('309005','NY','JEFFERSON','WATERTOWN AP',4.399222222000000e+001,-7.602166699999999e+001,'06/02','10/10','06/15','06/02','05/11','09/30','10/10','10/17','0087','0111','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('309389','NY','WASHINGTON','WHITEHALL',4.355750000000000e+001,-7.340111100000000e+001,'05/11','10/19','05/27','05/11','04/30','10/08','10/19','11/07','0123','0142','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('309670','NY','WESTCHESTER','YORKTOWN HEIGHTS 1W',4.126638888000000e+001,-7.379750000000000e+001,'04/29','11/04','05/16','04/29','04/18','10/22','11/04','11/15','0139','0162','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('310090','NC','STANLY','ALBEMARLE',3.539916666000000e+001,-8.019944400000000e+001,'04/27','11/11','05/11','04/27','04/12','10/30','11/11','11/22','0152','0176','0200')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('310241','NC','WARREN','ARCOLA',3.629111111000000e+001,-7.798222199999999e+001,'04/28','11/06','05/14','04/28','04/17','10/28','11/06','11/22','0147','0171','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('310286','NC','RANDOLPH','ASHEBORO 2 W',3.570444444000000e+001,-7.983777800000000e+001,'04/20','11/18','05/03','04/20','04/12','11/03','11/18','11/28','0167','0190','0214')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('310300','NC','BUNCOMBE','ASHEVILLE AP',3.543194444000000e+001,-8.253749999999999e+001,'05/08','10/26','05/18','05/08','04/19','10/19','10/26','11/18','0139','0159','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('310301','NC','BUNCOMBE','ASHEVILLE',3.559527777000000e+001,-8.255666700000000e+001,'04/26','11/10','05/09','04/26','04/14','10/23','11/10','11/27','0155','0175','0200')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('310506','NC','AVERY','BANNER ELK',3.616166666000000e+001,-8.187416700000000e+001,'06/01','10/17','06/15','06/01','05/20','10/11','10/17','10/24','0094','0117','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('310576','NC','PAMLICO','BAYBORO 3 SW',3.513111111000000e+001,-7.681611100000001e+001,'04/18','11/27','04/30','04/18','04/03','11/13','11/27','12/09','0166','0190','0225')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('310724','NC','BUNCOMBE','BENT CREEK',3.550444444000000e+001,-8.259666700000000e+001,'05/12','10/24','05/27','05/12','04/29','10/15','10/24','11/07','0124','0147','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('311055','NC','TRANSYLVANIA','BREVARD',3.522833333000000e+001,-8.273583300000000e+001,'05/10','10/25','05/27','05/10','05/06','10/16','10/25','11/09','0128','0147','0167')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('311239','NC','ALAMANCE','BURLINGTON FIRE STN #5',3.606027777000000e+001,-7.944805599999999e+001,'04/21','11/18','05/01','04/21','04/15','11/01','11/18','11/29','0160','0177','0200')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('311458','NC','DARE','CAPE HATTERAS AP',3.523250000000000e+001,-7.562194400000000e+001,'04/07','01/01','04/21','04/07','03/31','12/10','01/01','01/25','0202','0230','0250')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('311564','NC','HAYWOOD','CATALOOCHEE',3.563750000000000e+001,-8.309555600000000e+001,'05/21','10/17','06/08','05/21','05/09','10/13','10/17','10/28','0104','0134','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('311606','NC','CARTERET','CEDAR ISLAND',3.498333333000000e+001,-7.630000000000000e+001,'04/08','12/18','04/20','04/08','03/20','12/03','12/18','01/05','0198','0223','0256')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('311624','NC','YANCEY','CELO 2 S',3.582972222000000e+001,-8.217694400000001e+001,'05/30','10/18','06/14','05/30','05/13','10/11','10/18','10/23','0097','0121','0143')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('311677','NC','ORANGE','CHAPEL HILL 2 W',3.590861111000000e+001,-7.907944400000000e+001,'04/30','11/09','05/12','04/30','04/17','10/29','11/09','11/21','0146','0167','0191')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('311690','NC','MECKLENBURG','CHARLOTTE DOUGLAS AP',3.522361111000000e+001,-8.095527800000001e+001,'04/15','11/27','04/30','04/15','04/04','11/13','11/27','12/05','0173','0196','0224')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('311820','NC','JOHNSTON','CLAYTON WTP',3.564083333000000e+001,-7.846333300000001e+001,'04/27','11/18','05/13','04/27','04/13','11/06','11/18','11/29','0160','0183','0210')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('311881','NC','SAMPSON','CLINTON 2 NE',3.502472222000000e+001,-7.827583300000001e+001,'04/17','11/13','05/02','04/17','04/04','11/03','11/13','12/06','0166','0187','0213')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('311975','NC','CABARRUS','CONCORD',3.541111111000000e+001,-8.058333300000000e+001,'04/23','11/16','05/02','04/23','04/11','11/02','11/16','11/29','0164','0187','0209')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('312102','NC','MACON','COWEETA EXP STN',3.505916666000000e+001,-8.343138900000000e+001,'05/17','10/18','06/01','05/17','05/03','10/13','10/18','11/01','0119','0140','0165')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('312200','NC','JACKSON','CULLOWHEE',3.531166666000000e+001,-8.317472200000000e+001,'05/17','10/27','05/25','05/17','05/04','10/17','10/27','11/11','0128','0145','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('312238','NC','STOKES','DANBURY',3.641472222000000e+001,-8.021694400000000e+001,'05/03','11/01','05/14','05/03','04/22','10/22','11/01','11/19','0143','0164','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('312500','NC','HARNETT','DUNN 4 NW',3.532472222000000e+001,-7.868805600000000e+001,'04/18','11/17','05/02','04/18','04/05','11/04','11/17','12/01','0164','0187','0212')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('312515','NC','DURHAM','DURHAM',3.604250000000000e+001,-7.896250000000001e+001,'04/27','11/11','05/09','04/27','04/14','11/04','11/11','11/21','0155','0175','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('312635','NC','CHOWAN','EDENTON',3.601638888000000e+001,-7.655166700000000e+001,'04/09','12/03','04/20','04/09','03/30','11/13','12/03','12/17','0187','0213','0235')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('312719','NC','PASQUOTANK','ELIZABETH CITY',3.630972222000000e+001,-7.620500000000000e+001,'04/19','11/24','04/26','04/19','04/01','11/15','11/24','12/17','0176','0201','0236')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('312732','NC','BLADEN','ELIZABETHTOWN 3 SW',3.460444444000000e+001,-7.864805600000000e+001,'04/14','11/22','05/01','04/14','04/03','11/04','11/22','12/07','0171','0194','0220')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('312837','NC','BUNCOMBE','ENKA',3.554055555000000e+001,-8.265305600000001e+001,'05/14','10/24','05/26','05/14','04/16','10/16','10/24','11/07','0129','0148','0191')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('313017','NC','CUMBERLAND','FAYETTEVILLE PWC',3.505833333000000e+001,-7.885833300000000e+001,'04/13','11/21','04/30','04/13','04/02','11/05','11/21','12/06','0173','0197','0224')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('313106','NC','HENDERSON','FLETCHER 3 W',3.542666666000000e+001,-8.255750000000001e+001,'05/12','10/25','05/23','05/12','04/29','10/15','10/25','11/05','0128','0149','0176')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('313228','NC','MACON','FRANKLIN',3.518027777000000e+001,-8.339277800000001e+001,'05/18','10/26','05/29','05/18','05/03','10/19','10/26','11/04','0123','0142','0166')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('313356','NC','GASTON','GASTONIA',3.526555555000000e+001,-8.114333300000000e+001,'04/26','11/19','05/06','04/26','04/07','11/06','11/19','12/05','0164','0182','0212')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('313510','NC','WAYNE','GOLDSBORO 4 SE',3.534444444000000e+001,-7.796472200000000e+001,'04/11','11/24','04/25','04/11','03/28','11/11','11/24','12/11','0178','0199','0229')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('313565','NC','AVERY','GRANDFATHER MTN',3.609555555000000e+001,-8.183111100000001e+001,'05/25','10/16','06/07','05/25','05/17','10/12','10/16','10/30','0107','0128','0145')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('313630','NC','GUILFORD','GREENSBORO  AP',3.609694444000000e+001,-7.994333300000000e+001,'04/25','11/13','05/07','04/25','04/14','11/01','11/13','11/27','0158','0183','0203')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('313638','NC','PITT','GREENVILLE',3.564000000000000e+001,-7.739833299999999e+001,'04/12','11/18','04/25','04/12','04/01','11/05','11/18','12/09','0175','0196','0215')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('313784','NC','RICHMOND','HAMLET',3.488722222000000e+001,-7.969222200000000e+001,'04/28','11/07','05/09','04/28','04/17','11/01','11/07','11/24','0152','0175','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('313969','NC','VANCE','HENDERSON 2 NNW',3.634805555000000e+001,-7.841194400000001e+001,'05/09','11/03','05/14','05/09','04/26','10/17','11/03','11/14','0143','0157','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('313976','NC','HENDERSON','HENDERSONVILLE 1 NE',3.532972222000000e+001,-8.244916700000000e+001,'05/05','11/05','05/14','05/05','04/22','10/21','11/05','11/20','0143','0161','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('314020','NC','BURKE','HICKORY FAA AP',3.574250000000000e+001,-8.138194400000000e+001,'04/27','11/16','05/06','04/27','04/06','11/01','11/16','11/30','0158','0179','0208')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('314055','NC','MACON','HIGHLANDS',3.505666666000000e+001,-8.319833300000001e+001,'05/19','10/27','05/28','05/19','04/27','10/12','10/27','11/08','0126','0139','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('314063','NC','GUILFORD','HIGH POINT',3.596722222000000e+001,-7.997222200000000e+001,'04/21','11/19','05/02','04/21','04/13','10/30','11/19','11/26','0161','0182','0206')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('314456','NC','NORTHAMPTON','JACKSON',3.639666666000000e+001,-7.742388900000000e+001,'04/22','11/14','05/05','04/22','04/14','10/31','11/14','11/23','0159','0178','0200')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('314464','NC','MONTGOMERY','JACKSON SPRINGS 5 WNW',3.518583333000000e+001,-7.967722200000000e+001,'04/16','11/24','04/30','04/16','04/08','11/12','11/24','12/07','0165','0191','0216')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('314496','NC','ASHE','JEFFERSON 2 E',3.641611111000000e+001,-8.142861100000000e+001,'05/24','10/16','06/10','05/24','05/17','10/09','10/16','10/24','0102','0125','0145')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('314684','NC','LENOIR','KINSTON 7 SE',3.519666666000000e+001,-7.754333300000000e+001,'04/22','11/17','05/08','04/22','04/08','11/06','11/17','12/01','0158','0176','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('314689','NC','LENOIR','KINSTON AG RSCH',3.529750000000000e+001,-7.757222200000000e+001,'04/15','11/19','05/02','04/15','04/08','11/07','11/19','12/06','0166','0189','0212')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('314860','NC','SCOTLAND','LAURINBURG',3.475083333000000e+001,-7.946638900000001e+001,'04/16','11/20','05/01','04/16','04/07','11/08','11/20','12/04','0167','0191','0215')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('314938','NC','CALDWELL','LENOIR',3.591500000000000e+001,-8.153777800000000e+001,'04/30','11/06','05/12','04/30','04/09','10/24','11/06','11/24','0148','0170','0204')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('314962','NC','BERTIE','LEWISTON',3.613250000000000e+001,-7.717083300000000e+001,'04/29','11/18','05/08','04/29','04/14','11/06','11/18','12/06','0153','0173','0194')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('314970','NC','DAVIDSON','LEXINGTON',3.584583333000000e+001,-8.025972200000000e+001,'04/28','11/04','05/10','04/28','04/19','10/25','11/04','11/21','0149','0169','0195')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('314996','NC','LINCOLN','LINCOLNTON 4 W',3.546055555000000e+001,-8.132888900000000e+001,'04/27','11/11','05/07','04/27','04/15','10/30','11/11','11/24','0154','0178','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('315123','NC','FRANKLIN','LOUISBURG',3.610277777000000e+001,-7.830388900000000e+001,'05/08','11/06','05/20','05/08','04/22','10/21','11/06','11/16','0131','0156','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('315177','NC','ROBESON','LUMBERTON',3.462694444000000e+001,-7.902500000000001e+001,'04/28','11/18','05/12','04/28','04/15','11/08','11/18','11/29','0146','0172','0190')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('315303','NC','DARE','MANTEO AP',3.591722222000000e+001,-7.570000000000000e+001,'05/10','12/20','05/16','05/10','04/30','12/07','12/20','01/09','0170','0186','0222')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('315340','NC','MCDOWELL','MARION 2 NW',3.566305555000000e+001,-8.202916700000000e+001,'05/02','11/14','05/16','05/02','04/19','10/31','11/14','11/29','0142','0165','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('315356','NC','MADISON','MARSHALL',3.580361111000000e+001,-8.266583300000001e+001,'05/16','10/24','05/24','05/16','05/02','10/15','10/24','11/09','0129','0146','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('315771','NC','UNION','MONROE 2 SE',3.497972222000000e+001,-8.052333299999999e+001,'04/28','11/07','05/07','04/28','04/09','11/01','11/07','11/24','0155','0172','0205')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('315830','NC','CARTERET','MOREHEAD CITY 2 WNW',3.473361111000000e+001,-7.673583300000000e+001,'04/16','11/29','04/26','04/16','04/05','11/22','11/29','12/22','0186','0205','0236')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('315838','NC','BURKE','MORGANTON',3.572972222000000e+001,-8.167277799999999e+001,'05/04','10/28','05/16','05/04','04/21','10/21','10/28','11/14','0140','0159','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('315890','NC','SURRY','MT AIRY 2 W',3.649916666000000e+001,-8.065083300000001e+001,'05/11','10/31','05/15','05/11','04/20','10/19','10/31','11/13','0141','0155','0188')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('316001','NC','CHEROKEE','MURPHY',3.509611111000000e+001,-8.402388900000000e+001,'05/16','10/26','05/26','05/16','04/30','10/20','10/26','11/12','0128','0145','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('316108','NC','CRAVEN','NEW BERN - ASOS',3.506777777000000e+001,-7.704805600000000e+001,'04/08','11/29','04/18','04/08','03/16','11/16','11/29','12/20','0186','0218','0252')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('316256','NC','WILKES','NORTH WILKESBORO',3.616305555000000e+001,-8.114944400000000e+001,'05/09','11/02','05/19','05/09','04/19','10/17','11/02','11/12','0134','0157','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('316341','NC','SWAIN','OCONALUFTEE',3.551583333000000e+001,-8.330555600000000e+001,'05/25','10/17','06/01','05/25','05/09','10/10','10/17','10/28','0113','0128','0152')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('316805','NC','TRANSYLVANIA','PISGAH FOREST 3 NE',3.527194444000000e+001,-8.264749999999999e+001,'05/16','10/24','05/27','05/16','05/03','10/17','10/24','11/08','0128','0145','0167')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('316853','NC','WASHINGTON','PLYMOUTH 5 E',3.587222222000000e+001,-7.665916700000000e+001,'04/22','11/17','05/07','04/22','04/11','11/07','11/17','12/05','0159','0183','0206')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('317069','NC','WAKE','RALEIGH  AP',3.589222222000000e+001,-7.878194400000000e+001,'04/25','11/10','05/08','04/25','04/12','11/01','11/10','11/27','0157','0176','0206')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('317079','NC','WAKE','RALEIGH STATE UNIV',3.579444444000000e+001,-7.869888899999999e+001,'04/16','11/25','04/26','04/16','04/05','11/12','11/25','12/12','0175','0196','0222')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('317202','NC','ROCKINGHAM','REIDSVILLE 2 NW',3.638250000000000e+001,-7.969472200000000e+001,'04/24','11/14','05/08','04/24','04/10','10/27','11/14','11/29','0156','0179','0197')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('317516','NC','PERSON','ROXBORO 7 ESE',3.634638888000000e+001,-7.888583300000001e+001,'04/30','11/15','05/10','04/30','04/20','11/02','11/15','11/24','0147','0166','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('317615','NC','ROWAN','SALISBURY',3.568361111000000e+001,-8.048222199999999e+001,'04/26','11/09','05/11','04/26','04/10','10/27','11/09','11/24','0150','0177','0202')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('317845','NC','CLEVELAND','SHELBY 2 NNE',3.531444444000000e+001,-8.153361099999999e+001,'04/28','11/06','05/08','04/28','04/15','10/24','11/06','11/22','0153','0174','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('317924','NC','CHATHAM','SILER CITY 2 N',3.576055555000000e+001,-7.946222200000000e+001,'05/05','11/11','05/15','05/05','04/21','10/30','11/11','11/28','0144','0163','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('317994','NC','JOHNSTON','SMITHFIELD',3.551638888000000e+001,-7.834583300000000e+001,'04/22','11/08','05/04','04/22','04/05','11/01','11/08','11/28','0157','0176','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('318113','NC','BRUNSWICK','SOUTHPORT 5 N',3.399472222000000e+001,-7.800777800000000e+001,'04/15','11/23','04/28','04/15','04/07','11/11','11/23','12/06','0170','0201','0222')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('471078','WI','GREEN','BRODHEAD',4.261805555000000e+001,-8.938611100000000e+001,'05/23','10/12','06/06','05/23','05/08','10/07','10/12','10/26','0104','0126','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('471205','WI','RACINE','BURLINGTON',4.265083333000000e+001,-8.825444400000001e+001,'05/25','10/16','06/04','05/25','05/10','10/11','10/16','11/02','0114','0131','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('471280','WI','MONROE','CASHTON',4.374472222000000e+001,-9.077833300000000e+001,'05/19','10/22','05/28','05/19','05/07','10/07','10/22','11/04','0115','0132','0158')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('471416','WI','DANE','CHARMANY FARM',4.305972222000000e+001,-8.948194400000000e+001,'05/20','10/22','05/27','05/20','05/05','10/10','10/22','11/03','0114','0130','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('471568','WI','CALUMET','CHILTON',4.403277777000000e+001,-8.814694400000001e+001,'05/23','10/17','06/06','05/23','05/10','10/07','10/17','11/08','0110','0129','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('471676','WI','WAUPACA','CLINTONVILLE',4.462277777000000e+001,-8.874833300000000e+001,'05/22','10/11','06/08','05/22','05/12','10/02','10/11','10/26','0098','0124','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('471847','WI','SAWYER','COUDERAY 7 W',4.580027777000000e+001,-9.145944400000001e+001,'06/23','10/01','07/08','06/23','06/11','09/23','10/01','10/13','0051','0072','0094')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('471897','WI','MARINETTE','CRIVITZ HIGH FALLS',4.535750000000000e+001,-8.819194400000001e+001,'06/07','10/02','06/29','06/07','05/27','09/24','10/02','10/18','0061','0095','0124')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('471923','WI','BARRON','CUMBERLAND',4.553333333000000e+001,-9.202222200000000e+001,'05/19','10/13','05/31','05/19','05/04','10/04','10/13','11/01','0109','0128','0153')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('471978','WI','BURNETT','DANBURY',4.600861111000000e+001,-9.237361100000000e+001,'06/07','10/03','06/16','06/07','05/21','09/22','10/03','10/10','0077','0101','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('472001','WI','LAFAYETTE','DARLINGTON',4.267805555000000e+001,-9.010638899999999e+001,'05/24','10/13','06/05','05/24','05/08','10/01','10/13','10/28','0105','0127','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('472173','WI','IOWA','DODGEVILLE',4.296083333000000e+001,-9.011611100000000e+001,'05/21','10/13','06/07','05/21','05/07','10/05','10/13','10/27','0106','0130','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('472314','WI','VILAS','EAGLE RIVER',4.591694444000000e+001,-8.925638900000000e+001,'06/11','10/02','06/24','06/11','05/31','09/20','10/02','10/13','0069','0097','0118')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('472428','WI','CHIPPEWA','EAU CLAIRE C V R AP',4.486638888000000e+001,-9.148777800000001e+001,'05/21','10/10','06/08','05/21','05/11','10/04','10/10','10/17','0104','0125','0145')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('472556','WI','PIERCE','ELLSWORTH 1 E',4.473027777000000e+001,-9.245861100000001e+001,'05/21','10/14','06/06','05/21','05/10','10/03','10/14','10/26','0095','0125','0139')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('472839','WI','FOND DU LAC','FOND DU LAC',4.379527777000000e+001,-8.845333300000000e+001,'05/10','10/24','05/25','05/10','04/26','10/13','10/24','11/09','0129','0149','0172')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('472869','WI','JEFFERSON','FT ATKINSON',4.290500000000000e+001,-8.885888900000001e+001,'05/21','10/15','06/05','05/21','05/10','10/07','10/15','11/02','0107','0129','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('472889','WI','DOUGLAS','FOXBORO',4.648555555000000e+001,-9.228749999999999e+001,'06/27','09/27','07/03','06/27','06/11','09/16','09/27','10/05','0048','0072','0103')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('473038','WI','VERNON','GENOA DAM 8',4.357055555000000e+001,-9.122944400000000e+001,'05/08','10/23','05/20','05/08','04/26','10/14','10/23','11/08','0131','0145','0171')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('473058','WI','WASHINGTON','GERMANTOWN',4.323888888000000e+001,-8.812222199999999e+001,'05/31','10/12','06/16','05/31','05/18','10/05','10/12','10/24','0079','0118','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('473186','WI','DOUGLAS','GORDON',4.624500000000000e+001,-9.180472200000000e+001,'06/17','09/25','07/06','06/17','06/07','09/18','09/25','10/05','0041','0076','0101')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('473244','WI','BURNETT','GRANTSBURG',4.577277777000000e+001,-9.268861100000000e+001,'05/21','10/07','06/15','05/21','05/11','09/29','10/07','10/18','0088','0124','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('473269','WI','BROWN','GREEN BAY A S INTL AP',4.447944444000000e+001,-8.813666700000000e+001,'05/17','10/16','06/06','05/17','05/07','10/03','10/16','11/02','0110','0134','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('473332','WI','IRON','SAXON 1WSW',4.648583333000000e+001,-9.043722200000001e+001,'06/14','10/07','06/29','06/14','05/31','09/24','10/07','10/18','0059','0096','0122')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('473405','WI','WAUSHARA','HANCOCK EXP FARM',4.411861111000000e+001,-8.953583300000000e+001,'05/27','10/09','06/11','05/27','05/15','10/01','10/09','10/20','0098','0120','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('473453','WI','WASHINGTON','HARTFORD 2 W',4.333111111000000e+001,-8.841138900000000e+001,'05/29','10/13','06/14','05/29','05/12','09/29','10/13','10/20','0093','0120','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('473698','WI','CHIPPEWA','HOLCOMBE',4.522361111000000e+001,-9.112694400000000e+001,'06/01','10/10','06/10','06/01','05/09','10/01','10/10','10/24','0095','0113','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('473756','WI','DODGE','HORICON',4.344055555000000e+001,-8.863249999999999e+001,'05/16','10/13','06/02','05/16','05/05','10/03','10/13','11/01','0108','0135','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('474080','WI','TAYLOR','JUMP RIVER 3E',4.534972222000000e+001,-9.074833300000000e+001,'06/23','09/29','07/09','06/23','06/12','09/20','09/29','10/12','0033','0063','0094')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('474174','WI','KENOSHA','KENOSHA',4.256083333000000e+001,-8.781555600000000e+001,'05/13','11/06','05/26','05/13','04/30','10/20','11/06','11/14','0128','0145','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('474195','WI','KEWAUNEE','KEWAUNEE',4.446277777000000e+001,-8.750500000000000e+001,'05/20','10/22','06/08','05/20','05/07','10/10','10/22','11/12','0107','0135','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('474370','WI','LA CROSSE','LA CROSSE MUNI AP',4.387888888000000e+001,-9.125277800000001e+001,'05/14','10/23','05/24','05/14','04/29','10/11','10/23','11/05','0126','0144','0166')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('474482','WI','JEFFERSON','LAKE MILLS',4.308027777000000e+001,-8.889666699999999e+001,'05/20','10/21','06/01','05/20','05/13','10/06','10/21','11/04','0117','0135','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('474546','WI','GRANT','LANCASTER 4 WSW',4.282777777000000e+001,-9.078888900000000e+001,'05/13','10/19','05/25','05/13','04/30','10/10','10/19','11/01','0123','0144','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('474582','WI','FOREST','LAONA 6 SW',4.551194444000000e+001,-8.875944400000000e+001,'06/18','10/01','07/01','06/18','05/31','09/26','10/01','10/16','0056','0086','0116')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('474894','WI','POLK','LUCK',4.557333333000000e+001,-9.248500000000000e+001,'05/28','10/06','06/13','05/28','05/16','09/27','10/06','10/19','0090','0113','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('474937','WI','CRAWFORD','LYNXVILLE DAM 9',4.321166666000000e+001,-9.109861100000001e+001,'05/04','10/31','05/14','05/04','04/25','10/18','10/31','11/09','0141','0156','0173')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('474953','WI','ASHLAND','MADELINE ISLAND',4.677805555000000e+001,-9.076527800000000e+001,'06/12','10/14','06/23','06/12','05/26','10/05','10/14','10/30','0084','0106','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('474961','WI','DANE','MADISON DANE CO AP',4.314055555000000e+001,-8.934527799999999e+001,'05/27','10/12','06/13','05/27','05/12','10/02','10/12','10/26','0098','0126','0143')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('475017','WI','MANITOWOC','MANITOWOC',4.408694444000000e+001,-8.765222200000000e+001,'05/16','10/24','05/30','05/16','05/02','10/13','10/24','11/11','0121','0141','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('475091','WI','MARINETTE','MARINETTE',4.509833333000000e+001,-8.762361100000000e+001,'05/19','10/17','06/07','05/19','05/07','10/08','10/17','11/05','0100','0132','0153')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('475120','WI','WOOD','MARSHFIELD EXP FARM',4.463194444000000e+001,-9.013138900000000e+001,'05/27','10/09','06/13','05/27','05/17','10/02','10/09','10/20','0078','0119','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('475164','WI','JACKSON','MATHER 3 NW',4.417472222000000e+001,-9.034833300000000e+001,'05/29','10/12','06/14','05/29','05/10','09/29','10/12','10/21','0087','0112','0143')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('475178','WI','JUNEAU','MAUSTON 1 SE',4.379000000000000e+001,-9.005972199999999e+001,'05/28','10/12','06/10','05/28','05/14','10/02','10/12','10/23','0093','0117','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('475255','WI','TAYLOR','MEDFORD',4.513083333000000e+001,-9.034388900000000e+001,'06/01','10/06','06/14','06/01','05/14','09/25','10/06','10/16','0090','0108','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('475286','WI','ASHLAND','MELLEN 4 NE',4.636888888000000e+001,-9.064166700000000e+001,'06/19','10/01','06/29','06/19','06/06','09/26','10/01','10/08','0059','0089','0111')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('475335','WI','DUNN','MENOMONIE',4.487416666000000e+001,-9.193638900000001e+001,'05/26','10/09','06/10','05/26','05/10','10/01','10/09','10/22','0098','0120','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('475364','WI','LINCOLN','MERRILL',4.517861111000000e+001,-8.966166699999999e+001,'06/12','10/06','06/26','06/12','05/24','09/24','10/06','10/13','0061','0091','0125')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('475474','WI','MILWAUKEE','MILWAUKEE MT MARY CLG',4.307194444000000e+001,-8.802944400000000e+001,'05/10','10/29','05/24','05/10','04/25','10/14','10/29','11/14','0130','0149','0181')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('475479','WI','MILWAUKEE','MILWAUKEE MITCHELL AP',4.295500000000000e+001,-8.790444400000000e+001,'05/10','11/05','05/19','05/10','04/24','10/20','11/05','11/14','0135','0154','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('475516','WI','ONEIDA','MINOCQUA',4.588638888000000e+001,-8.973222199999999e+001,'06/11','10/10','06/21','06/11','05/23','09/24','10/10','10/20','0081','0102','0124')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('475563','WI','BUFFALO','MONDOVI',4.456472222000000e+001,-9.167194400000000e+001,'05/31','10/09','06/11','05/31','05/14','09/27','10/09','10/19','0094','0119','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('475581','WI','MARQUETTE','MONTELLO',4.378055555000000e+001,-8.931694400000001e+001,'05/29','10/12','06/09','05/29','05/12','10/02','10/12','10/23','0101','0122','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('475786','WI','JUNEAU','NECEDAH',4.402611111000000e+001,-9.008138900000000e+001,'06/02','10/02','06/18','06/02','05/19','09/27','10/02','10/14','0074','0106','0130')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('475808','WI','CLARK','NEILLSVILLE 3 SW',4.452972222000000e+001,-9.063833300000000e+001,'06/06','10/01','06/24','06/06','05/24','09/24','10/01','10/14','0073','0101','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('475932','WI','OUTAGAMIE','NEW LONDON',4.435888888000000e+001,-8.871888900000000e+001,'05/27','10/12','06/08','05/27','05/10','09/30','10/12','10/29','0103','0125','0145')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('476200','WI','WAUKESHA','OCONOMOWOC',4.310027777000000e+001,-8.850361100000001e+001,'05/20','10/15','05/30','05/20','05/02','10/06','10/15','11/02','0116','0134','0156')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('476208','WI','OCONTO','OCONTO 4 W',4.489194444000000e+001,-8.795500000000000e+001,'05/31','10/09','06/13','05/31','05/15','09/28','10/09','10/23','0096','0117','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('476330','WI','WINNEBAGO','OSHKOSH',4.402055555000000e+001,-8.855805599999999e+001,'05/13','10/26','05/27','05/13','05/03','10/09','10/26','11/08','0119','0137','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('476357','WI','CLARK','OWEN 2N',4.498000000000000e+001,-9.055444400000000e+001,'06/05','10/07','06/17','06/05','05/17','09/28','10/07','10/19','0079','0101','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('476398','WI','PRICE','PARK FALLS DNR HQ',4.593361111000000e+001,-9.045055600000001e+001,'06/03','10/04','06/20','06/03','05/17','09/26','10/04','10/14','0084','0106','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('476678','WI','SHEBOYGAN','PLYMOUTH',4.373000000000000e+001,-8.797138900000000e+001,'05/23','10/16','06/09','05/23','05/11','10/10','10/16','11/05','0113','0132','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('476718','WI','COLUMBIA','PORTAGE',4.352777777000000e+001,-8.943416700000000e+001,'05/26','10/15','06/13','05/26','05/14','10/07','10/15','10/31','0088','0119','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('476764','WI','OZAUKEE','PORT WASHINGTON',4.339444444000000e+001,-8.786361100000001e+001,'05/10','11/04','05/24','05/10','04/28','10/19','11/04','11/14','0131','0148','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('476827','WI','CRAWFORD','PRAIRIE DU CHIEN',4.305138888000000e+001,-9.113500000000001e+001,'05/15','10/15','05/27','05/15','05/01','10/09','10/15','10/31','0120','0141','0158')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('476859','WI','PRICE','PRENTICE #2',4.454472222000000e+001,-9.030166700000000e+001,'06/18','09/30','07/05','06/18','06/08','09/21','09/30','10/10','0038','0076','0102')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('476922','WI','RACINE','RACINE',4.270222222000000e+001,-8.778611100000001e+001,'05/08','11/06','05/20','05/08','04/23','10/21','11/06','11/15','0136','0158','0191')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('477052','WI','SAUK','REEDSBURG',4.352305555000000e+001,-9.000027799999999e+001,'05/24','10/20','05/30','05/24','05/09','10/05','10/20','10/28','0105','0121','0143')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('477092','WI','VILAS','REST LAKE',4.612222222000000e+001,-8.987722200000000e+001,'06/10','10/06','06/28','06/10','05/29','09/26','10/06','10/19','0066','0090','0117')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('477113','WI','ONEIDA','RHINELANDER',4.559861111000000e+001,-8.945083300000000e+001,'06/03','10/04','06/13','06/03','05/16','09/26','10/04','10/20','0087','0107','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('477132','WI','BARRON','RICE LAKE',4.541638888000000e+001,-9.177194400000001e+001,'06/02','10/08','06/12','06/02','05/20','09/28','10/08','10/17','0091','0112','0131')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('477158','WI','RICHLAND','RICHLAND CTR',4.333138888000000e+001,-9.038888900000001e+001,'05/22','10/11','06/10','05/22','05/14','10/03','10/11','10/21','0098','0125','0142')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('477174','WI','BARRON','RIDGELAND 1 NNE',4.521416666000000e+001,-9.188750000000000e+001,'06/07','10/06','06/18','06/07','05/20','09/26','10/06','10/13','0079','0103','0131')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('477226','WI','PIERCE','RIVER FALLS',4.485416666000000e+001,-9.261222200000000e+001,'05/20','10/10','06/06','05/20','05/08','10/03','10/10','10/25','0103','0128','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('477349','WI','MARATHON','ROSHOLT 9 NNE',4.475111111000000e+001,-8.924500000000001e+001,'06/06','10/03','06/20','06/06','05/21','09/26','10/03','10/16','0072','0102','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('477464','WI','POLK','ST CROIX FALLS',4.541166666000000e+001,-9.264638900000000e+001,'05/22','10/11','06/06','05/22','05/12','10/02','10/11','10/27','0101','0126','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('477480','WI','VILAS','ST GERMAIN',4.591555555000000e+001,-8.948944400000001e+001,'06/05','10/06','06/25','06/05','05/23','09/27','10/06','10/19','0080','0108','0132')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('477708','WI','SHAWANO','SHAWANO 2SSW',4.476305555000000e+001,-8.861833300000001e+001,'06/03','10/07','06/19','06/03','05/19','09/25','10/07','10/15','0079','0112','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('477892','WI','DOUGLAS','SOLON SPRINGS',4.635750000000000e+001,-9.183166700000000e+001,'06/13','09/28','06/24','06/13','05/25','09/22','09/28','10/11','0072','0093','0122')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('477997','WI','MONROE','SPARTA',4.393638888000000e+001,-9.081638900000000e+001,'05/26','10/11','06/11','05/26','05/17','10/01','10/11','10/18','0095','0115','0139')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('478027','WI','WASHBURN','SPOONER AG RES STN',4.582361111000000e+001,-9.187611100000000e+001,'06/09','10/04','06/19','06/09','05/21','09/26','10/04','10/13','0073','0101','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('478171','WI','PORTAGE','STEVENS POINT',4.451138888000000e+001,-8.958555600000000e+001,'05/18','10/10','06/02','05/18','05/07','10/01','10/10','10/25','0104','0131','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('478229','WI','DANE','STOUGHTON',4.291083333000000e+001,-8.921333300000001e+001,'05/16','10/17','06/03','05/16','05/04','10/09','10/17','10/26','0110','0130','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('478267','WI','DOOR','STURGEON BAY EXP FARM',4.487972222000000e+001,-8.733555600000000e+001,'05/24','10/27','06/10','05/24','05/08','10/09','10/27','11/11','0108','0132','0153')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('478349','WI','DOUGLAS','SUPERIOR',4.670000000000000e+001,-9.201666700000000e+001,'05/27','10/13','06/16','05/27','05/14','10/04','10/13','10/27','0087','0121','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('478589','WI','TREMPEALEAU','TREMPEALEAU DAM 6',4.399944444000000e+001,-9.143777799999999e+001,'05/13','10/17','05/25','05/13','04/30','10/09','10/17','10/30','0123','0137','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('478672','WI','MANITOWOC','TWO RIVERS',4.414305555000000e+001,-8.756777800000000e+001,'05/11','10/28','05/27','05/11','05/01','10/12','10/28','11/13','0125','0147','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('478827','WI','VERNON','VIROQUA',4.355944444000000e+001,-9.087611100000000e+001,'05/29','10/11','06/16','05/29','05/17','09/28','10/11','10/14','0088','0116','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('478905','WI','DOOR','WASHINGTON IS',4.535805555000000e+001,-8.689111100000000e+001,'06/04','10/25','06/21','06/04','05/19','10/15','10/25','11/05','0090','0116','0142')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('478919','WI','JEFFERSON','WATERTOWN',4.317416666000000e+001,-8.873638900000000e+001,'05/14','10/17','06/01','05/14','05/01','10/08','10/17','11/06','0114','0140','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('478937','WI','WAUKESHA','WAUKESHA',4.300638888000000e+001,-8.824916700000000e+001,'05/11','10/29','05/28','05/11','04/28','10/14','10/29','11/12','0124','0144','0173')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('478951','WI','WAUPACA','WAUPACA',4.435472222000000e+001,-8.905916700000000e+001,'05/19','10/15','06/05','05/19','05/03','10/05','10/15','10/30','0110','0134','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('479190','WI','JEFFERSON','WHITEWATER',4.285083333000000e+001,-8.872472200000000e+001,'05/25','10/17','06/07','05/25','05/10','10/02','10/17','11/01','0103','0128','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('479236','WI','ONEIDA','WILLOW RSVR',4.570805555000000e+001,-8.984888900000000e+001,'06/11','10/06','06/28','06/11','05/30','09/26','10/06','10/23','0052','0086','0113')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('479304','WI','SAWYER','WINTER',4.588333333000000e+001,-9.106999999999999e+001,'06/14','09/30','06/27','06/14','06/02','09/20','09/30','10/12','0058','0089','0119')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('479319','WI','COLUMBIA','WISCONSIN DELLS',4.360888888000000e+001,-8.976666700000000e+001,'05/30','10/15','06/10','05/30','05/11','10/02','10/15','10/27','0100','0122','0145')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('479335','WI','WOOD','WISCONSIN RAPIDS',4.438805555000000e+001,-8.980555600000000e+001,'05/26','10/06','06/14','05/26','05/12','09/29','10/06','10/16','0086','0116','0139')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('480027','WY','LINCOLN','AFTON',4.272916666000000e+001,-1.109297220000000e+002,'07/19','09/13','08/01','07/19','06/28','08/29','09/13','09/25','0000','0026','0065')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('480140','WY','TETON','ALTA 1 NNW',4.377277777000000e+001,-1.110338890000000e+002,'07/15','09/25','07/23','07/15','06/21','09/16','09/25','10/02','0018','0040','0077')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('480540','WY','BIG HORN','BASIN',4.438000000000000e+001,-1.080350000000000e+002,'05/31','10/02','06/13','05/31','05/14','09/23','10/02','10/16','0088','0107','0132')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('480552','WY','NATRONA','BATES CREEK #2',4.263388888000000e+001,-1.063775000000000e+002,'06/19','09/30','06/26','06/19','05/24','09/25','09/30','10/09','0072','0093','0120')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('480740','WY','JOHNSON','BILLY CREEK',4.412416666000000e+001,-1.067319440000000e+002,'06/11','09/26','07/08','06/11','05/26','09/20','09/26','10/06','0053','0095','0116')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('480761','WY','SWEETWATER','BITTER CREEK 4 NE',4.158944444000000e+001,-1.085086110000000e+002,'07/10','09/20','07/22','07/10','06/23','09/11','09/20','09/30','0021','0037','0077')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('480778','WY','HOT SPRINGS','BLACK MTN',4.365611111000000e+001,-1.077375000000000e+002,'06/13','10/06','06/19','06/13','05/27','10/01','10/06','10/16','0081','0096','0119')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('480865','WY','SUBLETTE','BONDURANT',4.322777777000000e+001,-1.104358330000000e+002,'08/02','08/12','08/03','08/02','07/28','08/06','08/12','08/25','0000','0000','0007')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('481000','WY','FREMONT','BOYSEN DAM',4.340527777000000e+001,-1.081633330000000e+002,'05/24','10/20','06/05','05/24','05/13','10/06','10/20','11/02','0106','0123','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('481165','WY','JOHNSON','BUFFALO',4.435472222000000e+001,-1.066991670000000e+002,'06/01','10/01','06/24','06/01','05/16','09/26','10/01','10/15','0075','0105','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('481175','WY','PARK','BUFFALO BILL DAM',4.450750000000000e+001,-1.091675000000000e+002,'06/04','10/22','06/17','06/04','05/20','10/06','10/22','10/31','0087','0114','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('481220','WY','SHERIDAN','BURGESS JUNCTION',4.477416666000000e+001,-1.075216670000000e+002,'07/29','09/05','08/03','07/29','07/18','08/20','09/05','09/21','0000','0006','0040')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('481284','WY','FREMONT','BURRIS',4.336555555000000e+001,-1.092755560000000e+002,'06/21','09/27','07/11','06/21','05/28','09/17','09/27','10/07','0042','0077','0113')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('481570','WY','NATRONA','CASPER-NATRONA COUNTY AP',4.289777777000000e+001,-1.064738890000000e+002,'06/08','09/29','06/22','06/08','05/18','09/25','09/29','10/12','0077','0102','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('481675','WY','LARAMIE','CHEYENNE WSFO AP',4.115000000000000e+001,-1.048166670000000e+002,'05/26','10/08','06/14','05/26','05/14','09/29','10/08','10/22','0092','0116','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('481730','WY','PLATTE','CHUGWATER',4.175944444000000e+001,-1.048222220000000e+002,'06/15','09/30','07/07','06/15','05/26','09/25','09/30','10/05','0047','0088','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('481736','WY','UINTA','CHURCH BUTTES GAS PLT',4.139750000000000e+001,-1.100855560000000e+002,'06/24','09/30','07/09','06/24','06/07','09/27','09/30','10/12','0054','0076','0101')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('481775','WY','PARK','CLARK 3NE',4.493666666000000e+001,-1.091375000000000e+002,'06/10','09/27','06/28','06/10','05/28','09/24','09/27','10/09','0067','0092','0111')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('481816','WY','SHERIDAN','CLEARMONT 5 SW',4.457805555000000e+001,-1.064472220000000e+002,'06/24','09/27','07/07','06/24','05/26','09/18','09/27','10/03','0052','0075','0112')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('481840','WY','PARK','CODY',4.451472222000000e+001,-1.090450000000000e+002,'06/01','10/03','06/18','06/01','05/17','09/25','10/03','10/17','0087','0106','0130')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('481850','WY','PARK','CODY 12SE',4.441388888000000e+001,-1.089005560000000e+002,'06/14','09/30','06/29','06/14','05/20','09/21','09/30','10/06','0061','0092','0120')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('481905','WY','CROOK','COLONY',4.487111111000000e+001,-1.041533330000000e+002,'05/25','10/11','06/06','05/25','05/15','09/27','10/11','10/27','0101','0118','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('482415','WY','BIG HORN','DEAVER',4.489194444000000e+001,-1.085930560000000e+002,'06/04','09/29','06/21','06/04','05/20','09/23','09/29','10/12','0075','0098','0119')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('482466','WY','CROOK','DEVILS TWR #2',4.458333333000000e+001,-1.047147220000000e+002,'06/25','09/27','07/08','06/25','05/30','09/18','09/27','10/01','0044','0071','0108')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('482580','WY','CAMPBELL','DILLINGER',4.409916666000000e+001,-1.051175000000000e+002,'06/20','09/27','07/04','06/20','05/26','09/23','09/27','10/09','0061','0084','0113')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('482595','WY','FREMONT','DIVERSION DAM',4.322805555000000e+001,-1.089488890000000e+002,'06/12','09/29','06/29','06/12','05/23','09/24','09/29','10/09','0063','0094','0121')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('482715','WY','FREMONT','DUBOIS',4.353972222000000e+001,-1.096552780000000e+002,'07/14','09/17','07/30','07/14','06/24','08/30','09/17','09/27','0007','0038','0074')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('482725','WY','CONVERSE','DULL CTR 1SE',4.341166666000000e+001,-1.049613890000000e+002,'06/13','10/01','06/21','06/13','05/15','09/25','10/01','10/11','0083','0093','0130')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('482995','WY','CARBON','ELK MTN',4.168777777000000e+001,-1.064136110000000e+002,'06/20','09/23','07/12','06/20','06/05','09/17','09/23','10/03','0041','0081','0105')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('483031','WY','BIG HORN','EMBLEM',4.449722222000000e+001,-1.083905560000000e+002,'05/25','10/01','06/15','05/25','05/12','09/26','10/01','10/17','0087','0112','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('483100','WY','UINTA','EVANSTON 1 E',4.126500000000000e+001,-1.109508330000000e+002,'07/11','09/24','07/23','07/11','06/19','09/14','09/24','10/01','0020','0047','0084')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('483170','WY','SWEETWATER','FARSON 5N',4.218666666000000e+001,-1.094452780000000e+002,'07/14','09/15','07/23','07/14','06/22','08/31','09/15','09/20','0016','0033','0065')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('483396','WY','LINCOLN','FONTENELLE DAM',4.181833333000000e+001,-1.100563890000000e+002,'07/16','09/12','07/27','07/16','07/08','09/02','09/12','09/22','0017','0033','0055')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('483855','WY','CAMPBELL','GILLETTE 4SE',4.426444444000000e+001,-1.054919440000000e+002,'05/30','10/03','06/21','05/30','05/16','09/25','10/03','10/18','0084','0112','0128')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('484065','WY','SWEETWATER','GREEN RIVER',4.151666666000000e+001,-1.094702780000000e+002,'06/23','09/25','07/13','06/23','06/11','09/12','09/25','09/29','0034','0062','0096')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('484760','WY','CROOK','HULETT',4.468555555000000e+001,-1.046027780000000e+002,'06/18','09/28','06/29','06/18','05/24','09/20','09/28','10/15','0073','0087','0117')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('484910','WY','TETON','JACKSON',4.348361111000000e+001,-1.107594440000000e+002,'07/26','09/01','08/02','07/26','07/11','08/18','09/01','09/16','0000','0012','0042')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('484925','WY','FREMONT','JEFFREY CITY',4.249416666000000e+001,-1.078291670000000e+002,'06/23','09/23','07/11','06/23','06/08','09/18','09/23','09/30','0045','0073','0097')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('485055','WY','JOHNSON','KAYCEE',4.371444444000000e+001,-1.066375000000000e+002,'06/09','09/29','07/01','06/09','05/18','09/23','09/29','10/14','0066','0098','0123')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('485105','WY','LINCOLN','KEMMERER 2 N',4.181666666000000e+001,-1.105333330000000e+002,'07/13','09/18','07/26','07/13','07/01','09/07','09/18','09/28','0012','0038','0060')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('485252','WY','LINCOLN','LA BARGE',4.226444444000000e+001,-1.101950000000000e+002,'07/12','09/13','07/29','07/12','06/24','08/29','09/13','09/26','0010','0043','0067')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('485345','WY','TETON','LAKE YELLOWSTONE',4.456194444000000e+001,-1.103986110000000e+002,'08/01','08/30','08/03','08/01','07/21','08/13','08/30','09/12','0000','0002','0026')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('485390','WY','FREMONT','LANDER AP',4.281527777000000e+001,-1.087261110000000e+002,'06/06','10/05','06/19','06/06','05/17','09/26','10/05','10/18','0086','0105','0130')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('485435','WY','ALBANY','LARAMIE 2 NW',4.134083333000000e+001,-1.056069440000000e+002,'07/01','09/19','07/17','07/01','06/16','09/08','09/19','09/27','0027','0051','0080')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('485506','WY','SHERIDAN','LEITER 9N',4.485000000000000e+001,-1.062888890000000e+002,'05/26','10/09','06/08','05/26','05/10','10/01','10/09','10/21','0095','0117','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('485770','WY','BIG HORN','LOVELL',4.483750000000000e+001,-1.084041670000000e+002,'06/01','10/04','06/14','06/01','05/09','09/27','10/04','10/18','0083','0104','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('486120','WY','CARBON','MEDICINE BOW',4.189777777000000e+001,-1.062016670000000e+002,'06/27','09/24','07/11','06/27','06/06','09/15','09/24','10/01','0042','0068','0096')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('486195','WY','NATRONA','MIDWEST',4.341305555000000e+001,-1.062772220000000e+002,'06/02','10/01','06/23','06/02','05/16','09/26','10/01','10/11','0061','0093','0128')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('486395','WY','CROOK','MOORCROFT 3S',4.421694444000000e+001,-1.049291670000000e+002,'06/09','09/26','06/24','06/09','05/23','09/25','09/26','10/09','0072','0100','0122')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('486428','WY','TETON','MOOSE',4.365361111000000e+001,-1.107169440000000e+002,'07/19','09/11','07/30','07/19','07/05','08/22','09/11','09/22','0004','0024','0052')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('486440','WY','TETON','MORAN 5WNW',4.385666666000000e+001,-1.105888890000000e+002,'07/18','09/12','07/29','07/18','06/27','08/25','09/12','09/24','0009','0031','0065')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('486555','WY','UINTA','MTN VIEW',4.127083333000000e+001,-1.103305560000000e+002,'06/30','09/25','07/19','06/30','06/12','09/16','09/25','10/02','0030','0062','0095')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('486660','WY','WESTON','NEWCASTLE',4.384972222000000e+001,-1.041886110000000e+002,'05/27','10/05','06/20','05/27','05/12','09/27','10/05','10/21','0087','0111','0132')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('487115','WY','FREMONT','PAVILLION',4.324583333000000e+001,-1.086941670000000e+002,'06/06','10/03','06/26','06/06','05/25','09/24','10/03','10/19','0074','0106','0121')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('487200','WY','GOSHEN','PHILLIPS',4.162638888000000e+001,-1.044936110000000e+002,'06/10','10/04','06/23','06/10','05/21','09/25','10/04','10/13','0075','0095','0120')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('487260','WY','SUBLETTE','PINEDALE',4.287472222000000e+001,-1.098591670000000e+002,'07/21','09/04','08/03','07/21','06/30','08/17','09/04','09/13','0000','0017','0052')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('487548','WY','CAMPBELL','RECLUSE 11NNW',4.490861111000000e+001,-1.057363890000000e+002,'06/24','09/26','07/10','06/24','06/06','09/15','09/26','10/03','0041','0075','0098')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('487555','WY','NIOBRARA','REDBIRD',4.324500000000000e+001,-1.042880560000000e+002,'06/05','09/27','06/21','06/05','05/15','09/25','09/27','10/09','0074','0100','0125')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('487760','WY','FREMONT','RIVERTON',4.303083333000000e+001,-1.083741670000000e+002,'06/18','09/28','07/02','06/18','05/23','09/21','09/28','10/06','0058','0082','0121')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('487845','WY','SWEETWATER','ROCK SPRINGS AP',4.159444444000000e+001,-1.090527780000000e+002,'06/13','09/30','06/24','06/13','05/29','09/26','09/30','10/13','0070','0092','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('488155','WY','SHERIDAN','SHERIDAN AP',4.476944444000000e+001,-1.069688890000000e+002,'06/02','09/29','06/26','06/02','05/18','09/22','09/29','10/14','0076','0107','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('488160','WY','SHERIDAN','SHERIDAN FLD STA',4.484055555000000e+001,-1.068383330000000e+002,'06/18','09/28','07/04','06/18','05/27','09/22','09/28','10/08','0063','0084','0116')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('488315','WY','TETON','SNAKE RIVER',4.413333333000000e+001,-1.106658330000000e+002,'08/02','08/19','08/01','08/02','07/24','08/08','08/19','09/02','0000','0000','0016')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('488385','WY','FREMONT','SOUTH PASS CITY',4.246666666000000e+001,-1.088000000000000e+002,'07/24','09/11','08/01','07/24','07/05','09/01','09/11','09/18','0000','0014','0047')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('488705','WY','CROOK','SUNDANCE',4.441250000000000e+001,-1.043605560000000e+002,'06/16','09/28','07/02','06/16','05/19','09/22','09/28','10/15','0068','0091','0124')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('488758','WY','PARK','SUNSHINE 3NE',4.407611111000000e+001,-1.089547220000000e+002,'07/14','09/17','07/28','07/14','06/26','09/06','09/17','09/27','0014','0043','0071')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('488808','WY','ALBANY','SYBILLE RSCH UNIT',4.176444444000000e+001,-1.053750000000000e+002,'06/17','10/01','06/21','06/17','05/27','09/26','10/01','10/08','0076','0091','0116')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('488852','WY','WASHAKIE','TENSLEEP 4NE',4.406472222000000e+001,-1.073819440000000e+002,'05/28','10/10','06/14','05/28','05/16','09/28','10/10','10/23','0092','0111','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('488858','WY','WASHAKIE','TENSLEEP 16SSE',4.381111111000000e+001,-1.073650000000000e+002,'06/14','09/28','06/30','06/14','05/23','09/18','09/28','10/03','0059','0088','0117')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('488875','WY','HOT SPRINGS','THERMOPOLIS',4.364833333000000e+001,-1.082036110000000e+002,'05/08','10/16','05/25','05/08','04/28','10/09','10/16','10/31','0120','0142','0159')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('488888','WY','HOT SPRINGS','THERMOPOLIS 25WNW',4.371250000000000e+001,-1.086963890000000e+002,'06/27','09/23','07/11','06/27','06/11','09/16','09/23','09/30','0042','0069','0094')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('489025','WY','PARK','TOWER FALLS',4.491666666000000e+001,-1.104202780000000e+002,'08/02','08/29','08/03','08/02','07/23','08/09','08/29','09/11','0000','0003','0020')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('489205','WY','WESTON','UPTON',4.409277777000000e+001,-1.046113890000000e+002,'06/20','09/30','06/29','06/20','05/23','09/26','09/30','10/10','0067','0085','0116')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('489459','WY','SWEETWATER','WAMSUTTER',4.166666666000000e+001,-1.079666670000000e+002,'06/26','09/26','07/09','06/26','06/14','09/19','09/26','09/29','0042','0068','0090')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('489580','WY','CAMPBELL','WESTON 1 E',4.464055555000000e+001,-1.053052780000000e+002,'06/09','09/27','06/28','06/09','05/19','09/19','09/27','10/08','0072','0095','0124')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('489615','WY','PLATTE','WHEATLAND 4 N',4.211055555000000e+001,-1.049491670000000e+002,'05/30','10/01','06/15','05/30','05/14','09/26','10/01','10/12','0086','0109','0132')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('489770','WY','WASHAKIE','WORLAND',4.401083333000000e+001,-1.079686110000000e+002,'05/23','10/08','06/13','05/23','05/09','09/28','10/08','10/23','0092','0116','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('489785','WY','WASHAKIE','WORLAND FAA AP',4.396583333000000e+001,-1.079508330000000e+002,'05/23','10/12','06/08','05/23','05/07','09/30','10/12','10/21','0094','0119','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('489905','WY','PARK','YELLOWSTONE PK MAMMOTH',4.497666666000000e+001,-1.106963890000000e+002,'06/28','09/26','07/18','06/28','06/13','09/16','09/26','10/03','0029','0064','0089')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('500243','AK','ANCHORAGE BOROUGH','ALYESKA',6.095833333000000e+001,-1.491108330000000e+002,'06/02','10/06','06/19','06/02','05/11','09/26','10/06','10/15','0072','0106','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('500280','AK','ANCHORAGE BOROUGH','ANCHORAGE INTL AP',6.116888888000000e+001,-1.500277780000000e+002,'05/19','10/07','06/03','05/19','05/05','09/27','10/07','10/13','0090','0120','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('500352','AK','PRINCE OF WALES-OUTER KETCHIKA','ANNETTE WSO AP',5.503888888000000e+001,-1.315786110000000e+002,'05/02','11/11','05/23','05/02','04/06','10/25','11/11','12/02','0132','0171','0211')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('500464','AK','JUNEAU BOROUGH','AUKE BAY',5.838138888000000e+001,-1.346450000000000e+002,'05/19','10/31','06/04','05/19','04/26','10/16','10/31','11/25','0115','0133','0171')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('500546','AK','NORTH SLOPE BOROUGH','BARROW WSO AP',7.128333333000001e+001,-1.567813890000000e+002,'08/01','08/21','08/01','08/01','07/21','08/08','08/21','09/14','0000','0000','0019')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('500657','AK','KETCHIKAN GATEWAY BOROUGH','BEAVER FALLS',5.538000000000000e+001,-1.314683330000000e+002,'05/07','11/15','06/02','05/07','04/12','10/26','11/15','12/10','0126','0163','0202')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('500707','AK','MATANUSKA-SUSITNA BOROUGH','BENS FARM',6.156333333000000e+001,-1.491541670000000e+002,'06/04','09/28','06/21','06/04','05/20','09/14','09/28','10/08','0060','0088','0113')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('500754','AK','BETHEL','BETHEL AP',6.078500000000000e+001,-1.618291670000000e+002,'06/10','09/28','06/27','06/10','05/26','09/19','09/28','10/09','0061','0089','0115')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('500761','AK','YUKON-KOYUKUK','BETTLES AP',6.691611111000000e+001,-1.515088890000000e+002,'06/22','09/09','07/11','06/22','05/24','08/31','09/09','09/25','0031','0060','0103')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('500770','AK','SOUTHEAST FAIRBANKS','BIG DELTA FAA/ASOS AP',6.399444444000000e+001,-1.457213890000000e+002,'06/07','09/10','06/17','06/07','05/19','08/31','09/10','10/02','0063','0081','0106')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('502102','AK','ALEUTIANS EAST BOROUGH','COLD BAY AP',5.522083333000000e+001,-1.627325000000000e+002,'06/11','10/20','07/06','06/11','05/21','10/06','10/20','11/03','0063','0104','0143')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('502107','AK','FAIRBANKS NORTH STAR BOROUGH','COLLEGE OBSY',6.486027777000000e+001,-1.478483330000000e+002,'06/07','09/13','06/30','06/07','05/21','09/02','09/13','09/28','0047','0079','0104')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('502112','AK','FAIRBANKS NORTH STAR BOROUGH','COLLEGE 5 NW',6.492500000000000e+001,-1.478802780000000e+002,'05/27','09/23','06/18','05/27','05/20','09/08','09/23','10/03','0062','0096','0112')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('502177','AK','VALDEZ-CORDOVA','CORDOVA AP',6.048888888000000e+001,-1.454511110000000e+002,'06/01','09/29','07/06','06/01','05/21','09/13','09/29','10/11','0048','0100','0121')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('502968','AK','FAIRBANKS NORTH STAR BOROUGH','FAIRBANKS INTL AP',6.480388888000000e+001,-1.478761110000000e+002,'05/23','09/21','06/02','05/23','05/15','09/08','09/21','10/05','0079','0099','0119')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('503294','AK','SKAGWAY-HOONAH-ANGOON','GLACIER BAY',5.845611111000000e+001,-1.358691670000000e+002,'05/20','10/26','06/14','05/20','05/01','10/09','10/26','11/23','0093','0130','0159')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('503299','AK','ANCHORAGE BOROUGH','GLEN ALPS',6.110000000000000e+001,-1.496936110000000e+002,'06/16','09/28','07/03','06/16','05/29','09/13','09/28','10/09','0046','0078','0109')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('503304','AK','VALDEZ-CORDOVA','GLENNALLEN KCAM',6.210861111000000e+001,-1.455327780000000e+002,'08/03','08/19','08/07','08/03','07/15','08/10','08/19','08/26','0000','0001','0028')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('503465','AK','VALDEZ-CORDOVA','GULKANA AP',6.215916666000000e+001,-1.454588890000000e+002,'07/03','08/31','07/29','07/03','06/05','08/21','08/31','09/12','0010','0044','0079')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('503665','AK','KENAI PENINSULA BOROUGH','HOMER AP',5.964194444000000e+001,-1.514908330000000e+002,'06/05','10/08','06/30','06/05','05/18','09/23','10/08','10/15','0063','0103','0132')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('503905','AK','LAKE AND PENINSULA BOROUGH','ILIAMNA AP',5.974944444000000e+001,-1.549088890000000e+002,'06/01','10/05','06/15','06/01','05/20','09/30','10/05','10/17','0077','0109','0130')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('504100','AK','JUNEAU BOROUGH','JUNEAU AP',5.835666666000000e+001,-1.345638890000000e+002,'05/24','10/22','06/12','05/24','05/05','10/07','10/22','11/07','0086','0120','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('504546','AK','KENAI PENINSULA BOROUGH','KENAI AP',6.057972222000000e+001,-1.512391670000000e+002,'06/10','09/26','07/19','06/10','05/24','09/12','09/26','10/09','0029','0078','0111')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('504766','AK','BRISTOL BAY BOROUGH','KING SALMON AP',5.868277777000000e+001,-1.566563890000000e+002,'06/13','09/29','07/11','06/13','05/26','09/15','09/29','10/08','0038','0076','0109')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('504812','AK','KODIAK ISLAND BOROUGH','KITOI BAY',5.819138888000000e+001,-1.523722220000000e+002,'06/03','10/10','06/21','06/03','05/23','10/02','10/10','10/24','0076','0110','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('505076','AK','','KOTZEBUE WSO AP',6.686666666000001e+001,-1.626333330000000e+002,'06/21','10/03','07/07','06/21','06/12','09/20','10/03','10/07','0050','0081','0098')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('505519','AK','SITKA BOROUGH','LITTLE PORT WALTER',5.639361111000000e+001,-1.346625000000000e+002,'05/21','11/14','06/12','05/21','04/21','10/17','11/14','12/11','0110','0141','0203')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('505733','AK','MATANUSKA-SUSITNA BOROUGH','MATANUSKA EXPERIMENT FARM',6.156638888000000e+001,-1.492541670000000e+002,'05/30','09/30','06/17','05/30','05/19','09/15','09/30','10/07','0068','0094','0119')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('505769','AK','YUKON-KOYUKUK','MCGRATH AP',6.295750000000000e+001,-1.556102780000000e+002,'06/02','09/15','06/29','06/02','05/18','09/04','09/15','10/01','0050','0084','0113')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('505778','AK','','MCKINLEY PARK',6.371750000000000e+001,-1.489691670000000e+002,'07/11','09/01','08/07','07/11','06/13','08/18','09/01','09/09','0000','0031','0071')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('506496','AK','NOME','NOME WSO AP',6.451111111000000e+001,-1.654400000000000e+002,'07/02','09/19','07/25','07/02','06/07','09/06','09/19','10/03','0018','0049','0090')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('506581','AK','FAIRBANKS NORTH STAR BOROUGH','NORTH POLE',6.475805555000000e+001,-1.473252780000000e+002,'06/14','09/02','07/23','06/14','06/01','08/24','09/02','09/18','0018','0065','0088')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('506586','AK','SOUTHEAST FAIRBANKS','NORTHWAY AP',6.296166666000000e+001,-1.419377780000000e+002,'06/11','09/08','07/03','06/11','05/24','08/27','09/08','09/18','0042','0073','0099')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('506870','AK','MATANUSKA-SUSITNA BOROUGH','PALMER JOB CORPS',6.158888888000000e+001,-1.490991670000000e+002,'05/25','10/06','06/16','05/25','05/13','09/23','10/06','10/10','0077','0103','0126')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('507570','AK','LAKE AND PENINSULA BOROUGH','PORT ALSWORTH',6.020361111000000e+001,-1.543163890000000e+002,'07/02','09/26','07/20','07/02','06/11','09/04','09/26','10/07','0026','0056','0090')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('507783','AK','MATANUSKA-SUSITNA BOROUGH','PUNTILLA',6.209111111000000e+001,-1.527350000000000e+002,'07/26','08/30','08/05','07/26','07/05','08/19','08/30','09/20','0000','0014','0042')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('508118','AK','ALEUTIANS WEST','ST PAUL ISLAND AP',5.715527777000000e+001,-1.702222220000000e+002,'07/07','10/07','07/30','07/07','06/12','09/20','10/07','10/21','0018','0063','0104')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('508494','AK','SITKA BOROUGH','SITKA AIRPORT',5.704805555000000e+001,-1.353647220000000e+002,'04/29','11/18','05/24','04/29','04/12','11/01','11/18','12/13','0133','0172','0213')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('508594','AK','VALDEZ-CORDOVA','SNOWSHOE LAKE',6.203027777000000e+001,-1.466930560000000e+002,'08/07','08/18','08/06','08/07','07/23','08/09','08/18','08/29','0000','0000','0013')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('508976','AK','MATANUSKA-SUSITNA BOROUGH','TALKEETNA AP',6.232000000000000e+001,-1.500950000000000e+002,'06/03','09/24','06/20','06/03','05/21','09/08','09/24','10/08','0062','0088','0113')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('509014','AK','YUKON-KOYUKUK','TANANA AP',6.517444444000000e+001,-1.521069440000000e+002,'06/27','09/08','07/23','06/27','05/27','08/27','09/08','09/19','0016','0049','0088')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('509313','AK','SOUTHEAST FAIRBANKS','TOK',6.335194444000000e+001,-1.430422220000000e+002,'08/02','08/22','08/09','08/02','07/07','08/13','08/22','09/03','0000','0006','0039')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('509385','AK','VALDEZ-CORDOVA','TONSINA',6.165111111000000e+001,-1.451702780000000e+002,'07/24','08/23','08/05','07/24','06/24','08/14','08/23','09/07','0000','0012','0057')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('509641','AK','','UNIVERSITY EXP STN',6.485694444000001e+001,-1.478611110000000e+002,'06/10','09/09','07/01','06/10','05/27','08/31','09/09','09/28','0041','0077','0101')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('509686','AK','VALDEZ-CORDOVA','VALDEZ WSO',6.113027777000000e+001,-1.463516670000000e+002,'05/15','10/12','06/08','05/15','04/28','10/02','10/12','10/29','0093','0127','0166')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('509790','AK','MATANUSKA-SUSITNA BOROUGH','WHITES CROSSING',6.170666666000000e+001,-1.499977780000000e+002,'06/17','09/15','07/15','06/17','05/30','08/28','09/15','09/27','0026','0064','0090')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('509919','AK','WRANGELL-PETERSBURG','WRANGELL AIRPORT',5.647333333000000e+001,-1.323875000000000e+002,'05/26','11/12','06/15','05/26','04/25','10/29','11/12','11/30','0094','0130','0182')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('511004','HI','MAUI','HALEAKALA RS 338',2.076027777000000e+001,-1.562469440000000e+002,'04/14','00/00','06/19','04/14','00/00','00/00','00/00','00/00','0128','0266','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('511125','HI','MAUI','HANA AP 355',2.079472222000000e+001,-1.560152780000000e+002,'00/00','00/00','00/00','00/00','00/00','00/00','00/00','00/00','9999','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('511303','HI','HAWAII','HAWAII VOL NP HQ 54',1.943000000000000e+001,-1.552566670000000e+002,'00/00','00/00','12/28','00/00','00/00','00/00','00/00','00/00','9999','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('511492','HI','HAWAII','HILO INTL AP 87',1.971916666000000e+001,-1.550530560000000e+002,'00/00','00/00','00/00','00/00','00/00','00/00','00/00','00/00','9999','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('511919','HI','HONOLULU','HONOLULU WSFO AP 703',2.132388888000000e+001,-1.579294440000000e+002,'00/00','00/00','00/00','00/00','00/00','00/00','00/00','00/00','9999','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('512572','HI','MAUI','KAHULUI WSO AP 398',2.089972222000000e+001,-1.564286110000000e+002,'00/00','00/00','00/00','00/00','00/00','00/00','00/00','00/00','9999','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('513099','HI','KAUAI','KANALOHULUHULU 1075',2.212972222000000e+001,-1.596586110000000e+002,'03/01','00/00','04/01','03/01','00/00','00/00','00/00','00/00','0281','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('515011','HI','HAWAII','KULANI CAMP 79',1.954944444000000e+001,-1.553011110000000e+002,'02/09','00/00','04/04','02/09','00/00','00/00','00/00','00/00','0218','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('515177','HI','MAUI','LAHAINA 361',2.087888888000000e+001,-1.566741670000000e+002,'00/00','00/00','00/00','00/00','00/00','00/00','00/00','00/00','9999','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('515580','HI','KAUAI','LIHUE WSO AP 1020.1',2.198388888000000e+001,-1.593405560000000e+002,'00/00','00/00','00/00','00/00','00/00','00/00','00/00','00/00','9999','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('516128','HI','HONOLULU','MANOA LYON ARBO 785.2',2.133305555000000e+001,-1.578025000000000e+002,'00/00','00/00','00/00','00/00','00/00','00/00','00/00','00/00','9999','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('516198','HI','HAWAII','MAUNA LOA SLOPE OBS 39',1.953611111000000e+001,-1.555766670000000e+002,'07/07','12/18','08/10','07/07','04/20','09/15','12/18','02/06','0000','0070','0243')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('516534','HI','MAUI','MOLOKAI AP 524',2.115444444000000e+001,-1.570961110000000e+002,'00/00','00/00','00/00','00/00','00/00','00/00','00/00','00/00','9999','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('516588','HI','HAWAII','NAALEHU 14',1.906472222000000e+001,-1.555886110000000e+002,'00/00','00/00','00/00','00/00','00/00','00/00','00/00','00/00','9999','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('517166','HI','HAWAII','OPIHIHALE NO 2 24.1',1.927055555000000e+001,-1.558747220000000e+002,'00/00','00/00','00/00','00/00','00/00','00/00','00/00','00/00','9999','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('519397','HI','HONOLULU','WAIKIKI 717.2',2.127166666000000e+001,-1.578166670000000e+002,'00/00','00/00','00/00','00/00','00/00','00/00','00/00','00/00','9999','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('519523','HI','HONOLULU','WAIMANALO EXP F 795.1',2.133555555000000e+001,-1.577113890000000e+002,'00/00','00/00','00/00','00/00','00/00','00/00','00/00','00/00','9999','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('010160','AL','TALLAPOOSA','ALEXANDER CITY',3.294527777000000e+001,-8.594805599999999e+001,'04/17','11/22','04/22','04/17','03/25','11/07','11/22','12/05','0179','0199','0231')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('010178','AL','PICKENS','ALICEVILLE',3.312722222000000e+001,-8.815500000000000e+001,'04/17','11/18','04/24','04/17','03/31','11/03','11/18','12/07','0174','0197','0226')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('010252','AL','COVINGTON','ANDALUSIA 3 W',3.130722222000000e+001,-8.652249999999999e+001,'04/18','11/26','04/28','04/18','03/28','11/09','11/26','12/10','0167','0192','0226')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('010272','AL','CALHOUN','ANNISTON ARPT ASOS',3.358722222000000e+001,-8.585555600000001e+001,'04/14','11/16','04/22','04/14','03/29','11/08','11/16','12/04','0181','0196','0230')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('010369','AL','CLAY','ASHLAND 3 ENE',3.329416666000000e+001,-8.577888900000001e+001,'04/24','11/17','05/01','04/24','04/13','10/30','11/17','12/03','0163','0183','0208')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('010402','AL','ESCAMBIA','ATMORE',3.118194444000000e+001,-8.743888900000000e+001,'03/31','12/07','04/12','03/31','03/16','11/25','12/07','01/08','0203','0229','0266')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('010505','AL','TUSCALOOSA','BANKHEAD LOCK & DAM',3.345277777000000e+001,-8.735722199999999e+001,'04/17','11/22','04/24','04/17','04/13','11/14','11/22','12/07','0172','0195','0211')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('010583','AL','BALDWIN','BAY MINETTE',3.088388888000000e+001,-8.778527800000001e+001,'03/24','12/15','04/09','03/24','03/18','11/24','12/15','01/10','0207','0233','0259')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('010655','AL','LIMESTONE','BELLE MINA 2 N',3.469083333000000e+001,-8.688249999999999e+001,'04/16','11/14','04/24','04/16','04/04','11/01','11/14','11/28','0174','0185','0216')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('010831','AL','JEFFERSON','BIRMINGHAM AP ASOS',3.356555555000000e+001,-8.674500000000001e+001,'04/19','11/22','04/24','04/19','04/03','11/07','11/22','12/04','0176','0198','0225')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('011084','AL','ESCAMBIA','BREWTON 3 SSE',3.105805555000000e+001,-8.705472200000000e+001,'04/21','11/24','04/26','04/21','03/27','11/02','11/24','12/06','0172','0187','0225')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('011099','AL','JACKSON','BRIDGEPORT 5 NW',3.497861111000000e+001,-8.580083300000000e+001,'04/27','11/06','05/15','04/27','04/13','10/24','11/06','11/20','0144','0168','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('011324','AL','TALLAPOOSA','CAMP HILL 2NW',3.282361111000000e+001,-8.565611100000000e+001,'04/22','11/08','05/05','04/22','04/08','10/31','11/08','11/28','0157','0179','0206')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('011566','AL','WASHINGTON','CHATOM',3.147138888000000e+001,-8.825027799999999e+001,'04/15','11/30','04/20','04/15','03/26','11/13','11/30','12/12','0179','0200','0236')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('011620','AL','TALLADEGA','CHILDERSBURG WTR PL',3.328500000000000e+001,-8.634305600000000e+001,'04/19','11/10','04/30','04/19','04/09','10/28','11/10','11/27','0164','0185','0211')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('011694','AL','CHILTON','CLANTON',3.282027777000000e+001,-8.665222200000000e+001,'04/14','11/20','04/27','04/14','03/29','11/06','11/20','12/07','0174','0200','0232')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('011725','AL','BARBOUR','CLAYTON',3.187083333000000e+001,-8.545000000000000e+001,'04/06','12/01','04/18','04/06','03/25','11/23','12/01','12/26','0186','0212','0241')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('011803','AL','MOBILE','CODEN',3.038777777000000e+001,-8.822805600000000e+001,'03/27','12/13','04/08','03/27','03/11','12/03','12/13','01/09','0209','0231','0261')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('012245','AL','MARENGO','DEMOPOLIS L&D',3.251916666000000e+001,-8.788000000000000e+001,'04/06','12/01','04/18','04/06','03/24','11/11','12/01','12/15','0189','0210','0233')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('012675','AL','COFFEE','ENTERPRISE 4 W',3.129750000000000e+001,-8.589972200000000e+001,'03/25','12/11','04/16','03/25','03/14','11/24','12/11','01/10','0203','0233','0266')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('012730','AL','BARBOUR','EUFAULA WILDLIFE REF',3.201111111000000e+001,-8.509000000000000e+001,'04/16','11/24','04/25','04/16','03/23','11/02','11/24','12/10','0174','0194','0230')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('012758','AL','CONECUH','EVERGREEN',3.144500000000000e+001,-8.695333300000000e+001,'04/02','12/04','04/14','04/02','03/19','11/19','12/04','12/24','0199','0222','0253')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('012813','AL','BALDWIN','FAIRHOPE 2 NE',3.054666666000000e+001,-8.788083300000000e+001,'03/13','12/22','03/31','03/13','03/06','12/05','12/22','01/22','0225','0256','0277')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('013154','AL','ETOWAH','GADSDEN',3.402194444000000e+001,-8.598777800000001e+001,'04/15','11/27','04/22','04/15','04/02','11/08','11/27','12/14','0177','0206','0228')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('013160','AL','GREENE','GAINESVILLE LOCK',3.283472222000000e+001,-8.813416700000001e+001,'04/06','11/23','04/15','04/06','03/16','11/10','11/23','12/13','0190','0213','0245')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('013511','AL','HALE','GREENSBORO',3.270194444000000e+001,-8.758166700000000e+001,'04/11','11/28','04/22','04/11','03/28','11/11','11/28','12/18','0185','0209','0228')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('013519','AL','BUTLER','GREENVILLE',3.179000000000000e+001,-8.660861100000000e+001,'04/09','12/03','04/17','04/09','03/24','11/21','12/03','12/24','0195','0215','0248')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('013573','AL','MARSHALL','GUNTERSVILLE',3.433444444000000e+001,-8.632972200000000e+001,'04/16','11/23','04/25','04/16','04/02','11/10','11/23','12/10','0176','0203','0232')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('013620','AL','MARION','HALEYVILLE',3.423138888000000e+001,-8.763527800000000e+001,'04/16','11/20','04/23','04/16','04/09','11/04','11/20','12/03','0172','0186','0206')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('013645','AL','MARION','HAMILTON 3 S',3.409666666000000e+001,-8.799138900000000e+001,'04/30','10/28','05/16','04/30','04/19','10/19','10/28','11/16','0141','0164','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('013761','AL','HENRY','HEADLAND',3.136250000000000e+001,-8.533972200000000e+001,'03/28','12/02','04/16','03/28','03/18','11/22','12/02','12/28','0190','0216','0244')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('013775','AL','CLEBURNE','HEFLIN',3.364833333000000e+001,-8.560055600000000e+001,'04/24','11/05','05/14','04/24','04/15','10/24','11/05','11/20','0147','0174','0195')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('013816','AL','CRENSHAW','HIGHLAND HOME',3.188138888000000e+001,-8.625027799999999e+001,'04/03','12/03','04/17','04/03','03/21','11/18','12/03','12/18','0193','0216','0242')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('014064','AL','MADISON','HUNTSVILLE INTL AP',3.464388888000000e+001,-8.678611100000001e+001,'04/12','11/19','04/24','04/12','04/02','11/05','11/19','11/27','0175','0197','0227')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('014193','AL','CLARKE','JACKSON',3.152527777000000e+001,-8.792777800000000e+001,'03/31','11/30','04/16','03/31','03/15','11/18','11/30','01/04','0193','0219','0255')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('014502','AL','CHAMBERS','LAFAYETTE 2W',3.290694444000000e+001,-8.543361100000000e+001,'04/15','11/16','04/26','04/15','04/06','11/03','11/16','11/28','0170','0192','0217')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('014798','AL','SUMTER','LIVINGSTON',3.258111111000000e+001,-8.818972200000000e+001,'04/13','11/19','04/25','04/13','03/27','11/04','11/19','12/04','0169','0193','0231')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('015121','AL','DALLAS','MARION JUNCTION 2 NE',3.247138888000000e+001,-8.723138899999999e+001,'04/09','11/23','04/17','04/09','03/21','11/09','11/23','12/08','0183','0208','0240')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('015478','AL','MOBILE','MOBILE REGIONAL AP',3.068833333000000e+001,-8.824555599999999e+001,'03/21','12/19','04/03','03/21','03/13','12/01','12/19','01/13','0223','0244','0265')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('015550','AL','MONTGOMERY','MONTGOMERY AP ASOS',3.229972222000000e+001,-8.640750000000000e+001,'03/26','11/29','04/19','03/26','03/15','11/20','11/29','12/20','0188','0223','0250')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('015635','AL','LAWRENCE','MOULTON 2',3.448833333000000e+001,-8.729888900000000e+001,'04/18','11/09','04/30','04/18','04/08','10/29','11/09','11/26','0169','0185','0209')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('015749','AL','COLBERT','MUSCLE SHOALS AP',3.474416666000000e+001,-8.759972200000000e+001,'04/12','11/20','04/22','04/12','04/02','11/05','11/20','12/03','0177','0199','0224')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('016121','AL','BLOUNT','ONEONTA',3.394777777000000e+001,-8.646916700000000e+001,'04/21','11/13','05/01','04/21','04/09','10/25','11/13','11/27','0164','0181','0213')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('016129','AL','LEE','OPELIKA',3.265916666000000e+001,-8.544916700000000e+001,'04/16','11/23','05/02','04/16','04/05','11/10','11/23','12/25','0167','0191','0224')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('016988','AL','BALDWIN','ROBERTSDALE',3.056527777000000e+001,-8.770166700000000e+001,'03/22','12/16','04/06','03/22','03/11','11/25','12/16','12/31','0212','0239','0265')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('017020','AL','COOSA','ROCKFORD 3 ESE',3.287111111000000e+001,-8.617583300000000e+001,'04/20','11/17','04/28','04/20','04/08','11/08','11/17','11/27','0172','0185','0212')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('017025','AL','RANDOLPH','ROCK MILLS',3.315805555000000e+001,-8.529111100000000e+001,'04/26','11/15','04/30','04/26','04/08','10/30','11/15','12/05','0162','0174','0207')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('017131','AL','FRANKLIN','RUSSELLVILLE NO 2',3.451000000000000e+001,-8.773194400000000e+001,'04/25','11/13','05/07','04/25','04/14','10/22','11/13','11/25','0154','0174','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('017157','AL','CULLMAN','SAINT BERNARD',3.417361111000000e+001,-8.681333300000000e+001,'04/29','11/02','05/11','04/29','04/18','10/20','11/02','11/19','0150','0172','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('017207','AL','DEKALB','SAND MT SUBSTN',3.428777777000000e+001,-8.596805600000000e+001,'04/18','11/13','04/29','04/18','04/09','10/24','11/13','11/27','0163','0184','0207')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('017304','AL','JACKSON','SCOTTSBORO',3.467361111000000e+001,-8.605361100000000e+001,'04/26','11/08','05/07','04/26','04/11','10/29','11/08','11/23','0156','0174','0202')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('017366','AL','DALLAS','SELMA',3.241111111000000e+001,-8.701444400000000e+001,'03/26','12/03','04/13','03/26','03/14','11/23','12/03','12/30','0199','0230','0261')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('017999','AL','TALLADEGA','SYLACAUGA 4 NE',3.320527777000000e+001,-8.621138900000000e+001,'04/19','11/12','05/04','04/19','04/06','10/24','11/12','11/29','0158','0181','0212')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('018024','AL','TALLADEGA','TALLADEGA',3.341638888000000e+001,-8.613500000000001e+001,'04/25','11/15','05/07','04/25','04/10','10/29','11/15','11/26','0160','0180','0209')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('018178','AL','CLARKE','THOMASVILLE',3.191722222000000e+001,-8.773472200000001e+001,'04/01','12/02','04/13','04/01','03/20','11/18','12/02','12/18','0196','0216','0245')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('018209','AL','CHILTON','THORSBY EXP STN',3.292055555000000e+001,-8.667083300000000e+001,'04/09','11/24','04/20','04/09','03/22','11/10','11/24','12/11','0185','0208','0238')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('018323','AL','PIKE','TROY',3.180750000000000e+001,-8.597222200000000e+001,'04/01','12/11','04/16','04/01','03/16','11/19','12/11','12/26','0198','0226','0255')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('018380','AL','TUSCALOOSA','TUSCALOOSA ACFD',3.321194444000000e+001,-8.761611100000000e+001,'04/09','11/28','04/22','04/09','03/20','11/19','11/28','12/11','0182','0208','0244')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('018438','AL','BULLOCK','UNION SPRINGS 9 S',3.201416666000000e+001,-8.574638899999999e+001,'04/11','11/24','04/17','04/11','03/16','11/12','11/24','12/09','0186','0205','0245')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('018469','AL','DEKALB','VALLEY HEAD',3.456666666000000e+001,-8.561277800000001e+001,'05/07','10/27','05/21','05/07','04/21','10/18','10/27','11/13','0132','0154','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('018517','AL','LAMAR','VERNON',3.373916666000000e+001,-8.812750000000000e+001,'04/27','11/06','05/08','04/27','04/15','10/22','11/06','11/19','0153','0171','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('020060','AZ','MARICOPA','AGUILA',3.394333333000000e+001,-1.131875000000000e+002,'04/18','12/04','05/06','04/18','03/24','11/17','12/04','12/15','0173','0205','0245')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('020080','AZ','PIMA','AJO',3.236972222000000e+001,-1.128600000000000e+002,'02/11','00/00','03/11','02/11','01/25','00/00','00/00','00/00','0249','0288','0319')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('020159','AZ','APACHE','ALPINE',3.384916666000000e+001,-1.091469440000000e+002,'07/07','10/01','07/18','07/07','07/04','09/18','10/01','10/07','0032','0058','0082')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('020287','AZ','PIMA','ANVIL RCH',3.197916666000000e+001,-1.113830560000000e+002,'04/19','11/22','05/05','04/19','04/02','11/15','11/22','12/08','0169','0196','0229')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('020586','AZ','YAVAPAI','BAGDAD',3.459722222000000e+001,-1.131738890000000e+002,'05/18','12/10','05/28','05/18','04/23','11/26','12/10','12/30','0134','0151','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('020632','AZ','MARICOPA','BARTLETT DAM',3.380972222000000e+001,-1.116497220000000e+002,'03/08','00/00','04/06','03/08','02/03','12/26','00/00','00/00','0236','0280','0324')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('020672','AZ','MOHAVE','BEAVER DAM',3.689694444000000e+001,-1.139425000000000e+002,'04/21','11/26','05/03','04/21','03/29','11/16','11/26','12/07','0178','0198','0236')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('020750','AZ','NAVAJO','BETATAKIN',3.667777777000000e+001,-1.105411110000000e+002,'05/28','11/01','06/13','05/28','05/16','10/22','11/01','11/06','0105','0129','0152')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('020808','AZ','GRAHAM','BLACK RIVER PUMPS',3.347833333000000e+001,-1.097516670000000e+002,'05/29','10/31','06/07','05/29','05/18','10/27','10/31','11/07','0119','0138','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('020871','AZ','COCONINO','BLUE RIDGE RS',3.461083333000000e+001,-1.111922220000000e+002,'06/24','10/08','07/06','06/24','06/10','10/02','10/08','10/24','0060','0078','0110')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('020949','AZ','LA PAZ','BOUSE',3.394305555000000e+001,-1.140241670000000e+002,'03/30','12/06','04/13','03/30','03/07','11/25','12/06','12/30','0206','0232','0266')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('020958','AZ','COCHISE','BOWIE',3.232500000000000e+001,-1.094916670000000e+002,'04/21','11/19','05/09','04/21','04/04','11/14','11/19','12/05','0164','0197','0224')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('021001','AZ','COCONINO','BRIGHT ANGEL RS',3.621472222000000e+001,-1.120619440000000e+002,'07/03','10/05','07/14','07/03','06/19','09/24','10/05','10/20','0036','0068','0099')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('021231','AZ','SANTA CRUZ','CANELO 1 NW',3.155888888000000e+001,-1.105294440000000e+002,'05/16','11/07','05/30','05/16','05/06','11/01','11/07','11/18','0138','0156','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('021248','AZ','APACHE','CANYON DE CHELLY',3.615333333000000e+001,-1.095394440000000e+002,'06/02','10/21','06/21','06/02','05/20','10/12','10/21','11/03','0094','0117','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('021282','AZ','MARICOPA','CAREFREE',3.381611111000000e+001,-1.119019440000000e+002,'03/20','01/14','04/13','03/20','02/12','12/16','01/14','00/00','0213','0261','0311')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('021314','AZ','PINAL','CASA GRANDE NM',3.299472222000000e+001,-1.115366670000000e+002,'04/10','12/04','04/29','04/10','03/13','11/24','12/04','12/23','0186','0212','0261')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('021330','AZ','COCHISE','CASCABEL',3.232222222000000e+001,-1.104147220000000e+002,'05/11','11/16','05/24','05/11','04/30','11/07','11/16','11/24','0152','0166','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('021353','AZ','YAVAPAI','CASTLE HOT SPRINGS',3.398250000000000e+001,-1.123616670000000e+002,'03/15','01/17','04/11','03/15','02/08','12/15','01/17','00/00','0221','0254','0315')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('021574','AZ','COCONINO','CHEVELON RS',3.454000000000000e+001,-1.109152780000000e+002,'06/11','10/21','06/21','06/11','05/31','10/08','10/21','11/02','0084','0112','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('021654','AZ','YAVAPAI','CHINO VALLEY',3.475694444000000e+001,-1.124566670000000e+002,'05/25','11/04','06/06','05/25','05/14','10/21','11/04','11/14','0118','0146','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('021664','AZ','COCHISE','CHIRICAHUA NM',3.200611111000000e+001,-1.093572220000000e+002,'05/19','11/16','05/29','05/19','05/04','11/09','11/16','11/27','0146','0164','0195')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('021849','AZ','GREENLEE','CLIFTON',3.305611111000000e+001,-1.093072220000000e+002,'04/21','12/06','05/02','04/21','03/27','11/24','12/06','12/19','0178','0205','0239')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('021920','AZ','MOHAVE','COLORADO CITY',3.699361111000000e+001,-1.129719440000000e+002,'05/27','11/05','06/03','05/27','05/08','10/26','11/05','11/14','0121','0141','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('022109','AZ','YAVAPAI','CORDES',3.430500000000000e+001,-1.121650000000000e+002,'05/05','11/23','05/20','05/05','04/16','11/17','11/23','12/16','0159','0186','0212')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('022140','AZ','COCHISE','CORONADO NM HQ',3.134555555000000e+001,-1.102541670000000e+002,'05/05','11/19','05/12','05/05','04/23','11/12','11/19','12/07','0165','0177','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('022664','AZ','COCHISE','DOUGLAS BISBEE INTL AP',3.145833333000000e+001,-1.096061110000000e+002,'04/27','11/14','05/12','04/27','04/21','11/07','11/14','11/27','0164','0187','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('022754','AZ','GREENLEE','DUNCAN',3.274805555000000e+001,-1.091213890000000e+002,'05/19','11/04','06/05','05/19','05/11','10/28','11/04','11/13','0129','0151','0165')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('023010','AZ','COCONINO','FLAGSTAFF AP',3.514416666000000e+001,-1.116663890000000e+002,'06/23','10/04','07/07','06/23','06/17','09/29','10/04','10/22','0054','0089','0107')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('023150','AZ','GRAHAM','FT THOMAS 2 SW',3.300944444000000e+001,-1.099855560000000e+002,'05/07','11/16','05/17','05/07','04/16','11/09','11/16','11/29','0155','0171','0199')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('023160','AZ','COCONINO','FT VALLEY',3.526805555000000e+001,-1.117427780000000e+002,'07/17','09/24','07/22','07/17','07/09','09/09','09/24','10/03','0023','0030','0056')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('023303','AZ','APACHE','GANADO',3.571638888000000e+001,-1.095661110000000e+002,'06/09','10/18','06/21','06/09','05/25','10/07','10/18','10/31','0092','0114','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('023393','AZ','MARICOPA','GILA BEND',3.294805555000000e+001,-1.127130560000000e+002,'02/22','01/21','03/24','02/22','02/15','12/19','01/21','00/00','0246','0282','0312')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('023828','AZ','COCONINO','HAPPY JACK RS',3.474333333000000e+001,-1.114138890000000e+002,'06/25','10/10','07/07','06/25','06/12','09/28','10/10','10/24','0051','0084','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('023961','AZ','NAVAJO','HEBER BLACK MESA RS',3.439250000000000e+001,-1.105580560000000e+002,'06/20','10/16','07/06','06/20','06/12','10/02','10/16','10/28','0065','0096','0113')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('024453','AZ','YAVAPAI','JEROME',3.475222222000000e+001,-1.121113890000000e+002,'05/01','12/05','05/12','05/01','04/14','11/19','12/05','12/28','0168','0189','0218')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('024586','AZ','NAVAJO','KEAMS CANYON',3.581111111000000e+001,-1.101916670000000e+002,'06/13','10/21','06/24','06/13','05/24','10/11','10/21','11/05','0091','0106','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('024675','AZ','PIMA','KITT PEAK',3.196000000000000e+001,-1.115972220000000e+002,'05/13','11/25','05/28','05/13','04/30','11/14','11/25','12/02','0143','0175','0191')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('024702','AZ','YUMA','KOFA MINE',3.327416666000000e+001,-1.139652780000000e+002,'02/02','00/00','03/08','02/02','12/31','00/00','00/00','00/00','0276','0322','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('024829','AZ','MARICOPA','LAVEEN 3 SSE',3.333694444000000e+001,-1.121472220000000e+002,'03/08','01/14','04/02','03/08','02/18','12/10','01/14','00/00','0231','0261','0291')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('024977','AZ','MARICOPA','LITCHFIELD PARK',3.349916666000000e+001,-1.123630560000000e+002,'03/13','12/17','04/12','03/13','02/16','12/04','12/17','00/00','0208','0259','0301')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('025270','AZ','PINAL','MARICOPA 4 N',3.311388888000000e+001,-1.120302780000000e+002,'04/03','12/04','04/22','04/03','03/09','11/21','12/04','12/18','0195','0226','0261')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('025412','AZ','NAVAJO','MC NARY 2N',3.411416666000000e+001,-1.098588890000000e+002,'06/17','10/20','06/27','06/17','06/08','10/07','10/20','11/01','0076','0100','0126')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('025512','AZ','GILA','MIAMI',3.340444444000000e+001,-1.108700000000000e+002,'04/17','12/06','04/25','04/17','03/08','11/23','12/06','01/03','0189','0212','0267')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('025635','AZ','YAVAPAI','MONTEZUMA CASTLE NM',3.461055555000000e+001,-1.118380560000000e+002,'05/17','11/13','05/22','05/17','04/27','11/04','11/13','11/20','0137','0154','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('025700','AZ','MARICOPA','MORMON FLAT',3.355444444000000e+001,-1.114425000000000e+002,'03/17','00/00','04/12','03/17','01/30','12/25','00/00','00/00','0229','0267','0337')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('025924','AZ','SANTA CRUZ','NOGALES 6 N',3.145527777000000e+001,-1.109680560000000e+002,'05/18','11/11','05/27','05/18','05/01','11/04','11/11','11/22','0147','0158','0190')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('026132','AZ','PIMA','ORGAN PIPE CACTUS NM',3.195555555000000e+001,-1.128002780000000e+002,'03/20','12/26','04/14','03/20','02/20','12/08','12/26','00/00','0215','0252','0295')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('026180','AZ','COCONINO','PAGE',3.692083333000000e+001,-1.114483330000000e+002,'05/03','11/24','05/15','05/03','04/13','11/12','11/24','12/10','0157','0183','0210')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('026250','AZ','LA PAZ','PARKER',3.415472222000000e+001,-1.142897220000000e+002,'02/23','01/15','03/13','02/23','02/02','12/13','01/15','00/00','0256','0284','0314')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('026323','AZ','GILA','PAYSON',3.423250000000000e+001,-1.113447220000000e+002,'05/29','11/03','06/07','05/29','05/15','10/30','11/03','11/15','0120','0142','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('026353','AZ','COCHISE','PEARCE - SUNSITES',3.193555555000000e+001,-1.098377780000000e+002,'04/30','11/15','05/16','04/30','04/22','11/08','11/15','11/29','0158','0182','0200')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('026468','AZ','NAVAJO','PETRIFIED FOREST NP',3.479944444000000e+001,-1.098850000000000e+002,'05/25','11/02','06/03','05/25','05/14','10/20','11/02','11/10','0121','0144','0159')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('026471','AZ','COCONINO','PHANTOM RANCH',3.613833333000000e+001,-1.120958330000000e+002,'04/17','01/04','04/28','04/17','04/05','12/15','01/04','00/00','0193','0220','0258')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('026481','AZ','MARICOPA','PHOENIX AP',3.342777777000000e+001,-1.120038890000000e+002,'02/09','00/00','02/26','02/09','01/07','01/15','00/00','00/00','0280','0309','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('026616','AZ','MOHAVE','PIPE SPRINGS NATL MON',3.685861111000000e+001,-1.127386110000000e+002,'05/21','10/31','06/01','05/21','05/15','10/16','10/31','11/08','0119','0136','0153')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('026653','AZ','GILA','PLEASANT VALLEY R S',3.409888888000000e+001,-1.109441670000000e+002,'06/13','10/30','06/28','06/13','06/03','10/13','10/30','11/05','0082','0111','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('026716','AZ','COCHISE','PORTAL 4 SW',3.188277777000000e+001,-1.092058330000000e+002,'05/26','10/30','06/08','05/26','05/13','10/19','10/30','11/08','0114','0140','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('026796','AZ','YAVAPAI','PRESCOTT',3.457055555000000e+001,-1.124322220000000e+002,'05/23','11/04','06/07','05/23','05/16','10/20','11/04','11/14','0115','0136','0152')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('026865','AZ','LA PAZ','QUARTZSITE',3.366500000000000e+001,-1.142272220000000e+002,'03/01','12/23','03/22','03/01','02/17','12/06','12/23','00/00','0243','0271','0300')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('027281','AZ','GILA','ROOSEVELT 1 WNW',3.367305555000000e+001,-1.111508330000000e+002,'03/15','00/00','04/11','03/15','02/12','12/26','00/00','00/00','0224','0268','0323')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('027370','AZ','PINAL','SACATON',3.307222222000000e+001,-1.117661110000000e+002,'04/03','12/12','04/28','04/03','03/04','11/30','12/12','01/16','0189','0223','0271')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('027390','AZ','GRAHAM','SAFFORD AGRICULTRL CTR',3.281500000000000e+001,-1.096808330000000e+002,'04/25','11/17','05/08','04/25','04/09','11/08','11/17','11/28','0165','0190','0212')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('027435','AZ','APACHE','SAINT JOHNS',3.451722222000000e+001,-1.094027780000000e+002,'05/20','10/29','06/06','05/20','05/08','10/18','10/29','11/07','0115','0140','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('027480','AZ','GILA','SAN CARLOS RSVR',3.318194444000000e+001,-1.105261110000000e+002,'04/10','12/11','05/01','04/10','03/18','11/26','12/11','01/15','0190','0226','0263')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('027488','AZ','APACHE','SANDERS',3.522388888000000e+001,-1.093222220000000e+002,'06/10','10/29','06/26','06/10','05/23','10/16','10/29','11/04','0082','0108','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('027560','AZ','COCHISE','SAN SIMON',3.227138888000000e+001,-1.092255560000000e+002,'05/03','11/12','05/12','05/03','04/20','11/03','11/12','11/21','0157','0174','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('027619','AZ','PIMA','SASABE',3.148305555000000e+001,-1.115436110000000e+002,'04/21','12/06','05/10','04/21','03/26','11/26','12/06','12/25','0178','0209','0243')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('027716','AZ','YAVAPAI','SELIGMAN',3.533222222000000e+001,-1.128797220000000e+002,'06/06','10/31','07/02','06/06','05/29','10/17','10/31','11/09','0083','0124','0145')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('027855','AZ','NAVAJO','SHOW LOW AP',3.426388888000000e+001,-1.100075000000000e+002,'05/31','10/30','06/15','05/31','05/18','10/17','10/30','11/06','0104','0128','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('028012','AZ','NAVAJO','SNOWFLAKE',3.450805555000000e+001,-1.100838890000000e+002,'05/29','10/24','06/18','05/29','05/21','10/11','10/24','11/02','0096','0127','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('028162','AZ','APACHE','SPRINGERVILLE',3.413111111000000e+001,-1.092750000000000e+002,'06/29','10/07','07/01','06/29','06/07','09/30','10/07','10/15','0066','0087','0113')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('028214','AZ','MARICOPA','STEWART MOUNTAIN',3.355750000000000e+001,-1.115358330000000e+002,'03/18','12/13','04/14','03/18','03/02','12/03','12/13','00/00','0210','0247','0278')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('028329','AZ','COCONINO','SUNSET CRATER NM',3.536944444000000e+001,-1.115436110000000e+002,'07/02','09/28','07/20','07/02','06/28','09/16','09/28','10/10','0032','0055','0072')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('028396','AZ','YUMA','TACNA 3 NE',3.272250000000000e+001,-1.139191670000000e+002,'03/26','12/05','04/12','03/26','02/26','11/22','12/05','01/08','0208','0236','0273')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('028468','AZ','APACHE','TEEC NOS POS',3.692333333000000e+001,-1.090900000000000e+002,'05/12','11/03','05/20','05/12','04/30','10/26','11/03','11/13','0132','0151','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('028499','AZ','MARICOPA','TEMPE ASU',3.342583333000000e+001,-1.119216670000000e+002,'03/18','00/00','04/13','03/18','02/19','12/16','00/00','00/00','0210','0249','0288')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('028619','AZ','COCHISE','TOMBSTONE',3.171194444000000e+001,-1.100686110000000e+002,'04/16','12/09','04/29','04/16','03/24','11/20','12/09','12/28','0183','0208','0248')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('028792','AZ','COCONINO','TUBA CITY',3.613055555000000e+001,-1.112436110000000e+002,'05/21','11/11','06/08','05/21','05/06','10/29','11/11','11/20','0113','0146','0166')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('028796','AZ','PIMA','TUCSON CAMP AVE EXP',3.228166666000000e+001,-1.109441670000000e+002,'04/11','12/04','05/01','04/11','03/19','11/19','12/04','12/20','0182','0215','0251')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('028820','AZ','PIMA','TUCSON INTL AP',3.213138888000000e+001,-1.109552780000000e+002,'03/18','12/19','04/13','03/18','02/22','12/05','12/19','00/00','0215','0252','0286')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('028865','AZ','SANTA CRUZ','TUMACACORI NM',3.156777777000000e+001,-1.110497220000000e+002,'05/03','11/24','05/16','05/03','04/06','11/12','11/24','12/07','0158','0187','0221')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('029114','AZ','COCONINO','WAHWEAP',3.699527777000000e+001,-1.114913890000000e+002,'04/26','11/25','05/03','04/26','04/09','11/16','11/25','12/09','0170','0191','0220')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('029158','AZ','YAVAPAI','WALNUT CREEK',3.492805555000000e+001,-1.128097220000000e+002,'06/15','10/22','06/30','06/15','05/31','10/08','10/22','11/02','0078','0101','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('029287','AZ','MARICOPA','WICKENBURG',3.397916666000000e+001,-1.127402780000000e+002,'04/26','11/28','05/11','04/26','04/12','11/17','11/28','12/15','0165','0193','0225')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('029309','AZ','MOHAVE','WIKIEUP',3.470611111000000e+001,-1.136136110000000e+002,'04/24','12/02','05/09','04/24','04/04','11/17','12/02','12/27','0171','0198','0232')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('029334','AZ','COCHISE','WILLCOX',3.225527777000000e+001,-1.098369440000000e+002,'05/11','11/10','05/24','05/11','05/02','11/02','11/10','11/16','0148','0164','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('029359','AZ','COCONINO','WILLIAMS',3.524055555000000e+001,-1.121902780000000e+002,'06/06','10/27','06/20','06/06','05/29','10/18','10/27','11/06','0092','0111','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('029439','AZ','NAVAJO','WINSLOW AP',3.502805555000000e+001,-1.107208330000000e+002,'05/22','11/04','05/30','05/22','05/10','10/26','11/04','11/13','0126','0143','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('029542','AZ','COCONINO','WUPATKI NM',3.552472222000000e+001,-1.113702780000000e+002,'05/06','11/12','05/18','05/06','04/21','11/05','11/12','11/22','0151','0172','0199')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('029634','AZ','MARICOPA','YOUNGTOWN',3.359500000000000e+001,-1.123013890000000e+002,'02/28','01/04','03/21','02/28','02/05','12/12','01/04','00/00','0244','0281','0320')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('029645','AZ','MOHAVE','YUCCA 1 NNE',3.487750000000000e+001,-1.141344440000000e+002,'04/05','12/11','04/28','04/05','03/06','11/30','12/11','00/00','0195','0231','0274')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('029654','AZ','YUMA','YUMA PROVING GROUND',3.283555555000000e+001,-1.143941670000000e+002,'01/31','00/00','02/26','01/31','01/16','00/00','00/00','00/00','0277','0316','0345')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('030064','AR','LAWRENCE','ALICIA 2NNE',3.592888888000000e+001,-9.105833300000001e+001,'04/16','11/18','04/24','04/16','04/05','11/04','11/18','12/03','0167','0189','0221')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('030130','AR','SALINE','ALUM FORK',3.479611111000000e+001,-9.284166700000000e+001,'04/16','11/22','04/19','04/16','03/31','11/10','11/22','12/02','0184','0199','0223')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('030220','AR','CLARK','ARKADELPHIA 2 N',3.414333333000000e+001,-9.305888899999999e+001,'04/15','11/18','04/19','04/15','04/04','11/04','11/18','12/02','0174','0189','0215')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('030240','AR','ARKANSAS','ARKANSAS POST',3.402500000000000e+001,-9.134444400000000e+001,'04/04','12/04','04/14','04/04','03/22','11/14','12/04','12/15','0194','0212','0238')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('030458','AR','INDEPENDENCE','BATESVILLE LVSTK',3.583055555000000e+001,-9.179444400000000e+001,'04/19','11/07','04/28','04/19','04/11','10/27','11/07','11/26','0164','0181','0207')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('030460','AR','INDEPENDENCE','BATESVILLE L&D 1',3.576000000000000e+001,-9.163888900000001e+001,'04/19','11/08','05/03','04/19','04/09','10/27','11/08','11/25','0159','0184','0207')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('030536','AR','JACKSON','BEEDEVILLE 4 NE',3.545833333000000e+001,-9.105611100000000e+001,'04/13','11/21','04/20','04/13','04/02','11/03','11/21','12/06','0171','0198','0226')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('030582','AR','SALINE','BENTON',3.456750000000000e+001,-9.260055600000000e+001,'04/17','11/15','04/27','04/17','04/05','10/29','11/15','11/30','0166','0185','0211')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('030764','AR','GARLAND','BLAKELY MTN DAM',3.456972222000000e+001,-9.319472200000000e+001,'04/19','11/13','05/01','04/19','04/10','10/25','11/13','11/27','0161','0184','0206')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('030798','AR','YELL','BLUE MTN DAM',3.511611111000000e+001,-9.365055600000000e+001,'04/17','11/19','04/23','04/17','04/04','11/04','11/19','11/29','0172','0189','0218')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('030806','AR','MISSISSIPPI','BLYTHEVILLE',3.592388888000000e+001,-8.990444400000000e+001,'04/08','11/30','04/15','04/08','03/25','11/15','11/30','12/15','0191','0208','0234')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('030936','AR','MONROE','BRINKLEY',3.488222222000000e+001,-9.121527800000000e+001,'04/11','11/25','04/14','04/11','03/27','11/09','11/25','12/10','0185','0204','0234')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('031102','AR','LONOKE','CABOT',3.498166666000000e+001,-9.200638900000000e+001,'04/17','11/12','04/27','04/17','04/08','10/29','11/12','11/25','0167','0189','0203')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('031132','AR','IZARD','CALICO ROCK 2 WSW',3.610916666000000e+001,-9.216361100000000e+001,'05/03','10/31','05/17','05/03','04/19','10/14','10/31','11/14','0132','0157','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('031152','AR','OUACHITA','CAMDEN 1',3.359000000000000e+001,-9.282361100000000e+001,'04/11','11/22','04/16','04/11','03/29','11/10','11/22','12/06','0181','0203','0226')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('031442','AR','MONROE','CLARENDON',3.468000000000000e+001,-9.122083300000000e+001,'04/12','11/20','04/19','04/12','03/25','11/06','11/20','12/07','0180','0196','0232')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('031596','AR','FAULKNER','CONWAY',3.508333333000000e+001,-9.242944400000000e+001,'04/14','11/18','04/22','04/14','04/04','11/05','11/18','12/03','0172','0197','0215')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('031632','AR','CLAY','CORNING',3.641972222000000e+001,-9.058583299999999e+001,'04/15','11/13','04/30','04/15','04/04','10/28','11/13','11/30','0158','0189','0213')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('031730','AR','ASHLEY','CROSSETT 2 SSE',3.311111111000000e+001,-9.194805599999999e+001,'04/18','11/13','04/23','04/18','04/05','11/01','11/13','12/01','0168','0183','0208')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('031838','AR','YELL','DARDANELLE',3.523416666000000e+001,-9.316750000000000e+001,'04/15','11/16','04/26','04/15','04/05','10/31','11/16','12/02','0167','0194','0214')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('031948','AR','SEVIER','DEQUEEN',3.404638888000000e+001,-9.434805600000000e+001,'04/14','11/20','04/24','04/14','04/03','11/06','11/20','12/02','0170','0197','0214')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('031962','AR','CHICOT','DERMOTT 3 NE',3.355972222000000e+001,-9.138500000000001e+001,'04/10','11/23','04/21','04/10','03/28','11/05','11/23','12/09','0180','0198','0232')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('031968','AR','PRAIRIE','DES ARC',3.497722222000000e+001,-9.149777800000000e+001,'04/11','11/27','04/16','04/11','03/25','11/14','11/27','12/14','0187','0204','0237')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('032148','AR','DESHA','DUMAS',3.388472222000000e+001,-9.153166700000000e+001,'03/31','11/29','04/15','03/31','03/20','11/17','11/29','12/12','0196','0219','0242')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('032300','AR','UNION','EL DORADO GOODWIN FLD',3.322083333000000e+001,-9.281416700000000e+001,'04/12','11/23','04/18','04/12','04/01','11/11','11/23','12/04','0183','0200','0221')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('032355','AR','CHICOT','EUDORA',3.311444444000000e+001,-9.126277800000000e+001,'04/05','11/30','04/15','04/05','03/17','11/20','11/30','12/18','0191','0211','0249')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('032356','AR','CARROLL','EUREKA SPRINGS 3 WNW',3.641638888000000e+001,-9.379166700000000e+001,'04/21','11/13','05/01','04/21','04/09','11/01','11/13','11/30','0159','0184','0209')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('032366','AR','SHARP','EVENING SHADE 1 NNE',3.607166666000000e+001,-9.161694400000000e+001,'05/03','10/25','05/12','05/03','04/16','10/16','10/25','11/08','0141','0158','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('032444','AR','WASHINGTON','FAYETTEVILLE EXP STN',3.610055555000000e+001,-9.417444399999999e+001,'04/25','11/09','05/08','04/25','04/13','10/25','11/09','11/25','0145','0172','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('032540','AR','DALLAS','FORDYCE',3.382277777000000e+001,-9.239888900000000e+001,'04/13','11/19','04/21','04/13','04/01','11/06','11/19','12/04','0179','0195','0219')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('032574','AR','SEBASTIAN','FT SMITH RGNL AP',3.533305555000000e+001,-9.436250000000000e+001,'04/14','11/13','04/25','04/14','04/07','11/01','11/13','11/29','0166','0192','0213')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('032794','AR','SEARCY','GILBERT',3.599138888000000e+001,-9.271472200000000e+001,'05/03','10/25','05/14','05/03','04/23','10/16','10/25','11/12','0136','0153','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('032930','AR','BENTON','GRAVETTE',3.642611111000000e+001,-9.444805599999999e+001,'05/01','11/03','05/11','05/01','04/16','10/20','11/03','11/18','0142','0159','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('032978','AR','CLEBURNE','GREERS FERRY DAM',3.552055555000000e+001,-9.199972200000001e+001,'04/16','11/19','04/29','04/16','04/05','11/03','11/19','12/02','0169','0192','0214')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('033165','AR','BOONE','HARRISON BOONE CO AP',3.626666666000000e+001,-9.315666700000000e+001,'04/17','11/17','04/27','04/17','04/08','11/03','11/17','12/03','0167','0185','0207')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('033242','AR','PHILLIPS','HELENA',3.452111111000000e+001,-9.059000000000000e+001,'04/07','11/29','04/17','04/07','03/25','11/15','11/29','12/10','0190','0208','0235')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('033428','AR','HEMPSTEAD','HOPE 3 NE',3.370888888000000e+001,-9.355611100000000e+001,'04/13','11/21','04/17','04/13','04/01','11/09','11/21','12/05','0183','0200','0221')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('033466','AR','GARLAND','HOT SPRINGS 1 NNE',3.451277777000000e+001,-9.304861099999999e+001,'04/12','11/22','04/18','04/12','04/01','11/14','11/22','12/12','0185','0204','0227')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('033734','AR','CRAIGHEAD','JONESBORO 2 NE',3.584888888000000e+001,-9.065888900000000e+001,'04/13','11/15','04/21','04/13','03/30','11/03','11/15','12/03','0176','0203','0222')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('033821','AR','MISSISSIPPI','KEISER',3.568722222000000e+001,-9.009638900000000e+001,'04/13','11/17','04/24','04/13','03/30','10/31','11/17','12/04','0169','0193','0220')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('033862','AR','LONOKE','KEO',3.460333333000000e+001,-9.199277800000000e+001,'04/05','11/28','04/15','04/05','03/22','11/15','11/28','12/14','0195','0213','0240')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('034106','AR','BOONE','LEAD HILL',3.641944444000000e+001,-9.291583300000001e+001,'05/02','10/31','05/17','05/02','04/21','10/21','10/31','11/21','0134','0151','0177')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('034134','AR','GRANT','LEOLA',3.417416666000000e+001,-9.259472200000000e+001,'04/17','11/13','04/26','04/17','04/07','10/27','11/13','11/29','0171','0186','0208')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('034248','AR','PULASKI','LITTLE ROCK ADAMS FLD',3.472722222000000e+001,-9.223888900000000e+001,'04/09','11/27','04/16','04/09','03/26','11/14','11/27','12/10','0191','0211','0234')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('034548','AR','COLUMBIA','MAGNOLIA',3.329500000000000e+001,-9.323250000000000e+001,'04/15','11/23','04/19','04/15','04/07','11/04','11/23','12/01','0176','0193','0216')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('034562','AR','HOT SPRING','MALVERN',3.439472222000000e+001,-9.283638900000000e+001,'04/16','11/18','04/25','04/16','04/08','11/03','11/18','12/03','0164','0194','0211')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('034572','AR','FULTON','MAMMOTH SPRING',3.649472222000000e+001,-9.153500000000000e+001,'05/03','10/27','05/14','05/03','04/17','10/16','10/27','11/09','0138','0158','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('034638','AR','LEE','MARIANNA 2 S',3.473916666000000e+001,-9.076638900000000e+001,'04/10','11/19','04/18','04/10','03/30','11/03','11/19','12/09','0180','0199','0228')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('034666','AR','SEARCY','MARSHALL',3.591555555000000e+001,-9.263944400000000e+001,'04/26','11/05','05/04','04/26','04/23','10/25','11/05','11/29','0150','0174','0194')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('034756','AR','POLK','MENA',3.457305555000000e+001,-9.424944400000000e+001,'04/17','11/16','04/29','04/17','04/11','11/02','11/16','11/28','0164','0186','0206')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('034900','AR','DREW','MONTICELLO MUNI AP',3.363611111000000e+001,-9.175555600000000e+001,'04/15','11/22','04/26','04/15','04/05','11/03','11/22','12/10','0163','0192','0217')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('034938','AR','CONWAY','MORRILTON',3.515805555000000e+001,-9.276722200000000e+001,'04/16','11/15','04/25','04/16','04/02','11/03','11/15','11/27','0164','0190','0209')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('035036','AR','BAXTER','MTN HOME 1 NNW',3.634583333000000e+001,-9.239388900000000e+001,'04/20','11/12','04/30','04/20','04/10','10/27','11/12','11/26','0158','0179','0204')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('035046','AR','STONE','MTN VIEW',3.584444444000000e+001,-9.209777800000001e+001,'04/26','11/01','05/06','04/26','04/13','10/20','11/01','11/22','0150','0169','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('035079','AR','PIKE','MURFREESBORO 1W',3.407833333000000e+001,-9.370194400000000e+001,'04/16','11/19','04/19','04/16','04/07','11/07','11/19','12/04','0172','0201','0215')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('035112','AR','HOWARD','NASHVILLE',3.392944444000000e+001,-9.385833300000000e+001,'04/14','11/27','04/21','04/14','04/05','11/11','11/27','12/10','0181','0199','0218')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('035186','AR','JACKSON','NEWPORT',3.560416666000000e+001,-9.127444400000000e+001,'04/08','11/24','04/17','04/08','03/25','11/09','11/24','12/09','0184','0207','0233')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('035200','AR','PERRY','NIMROD DAM',3.495527777000000e+001,-9.315944399999999e+001,'04/15','11/17','04/28','04/15','04/09','11/03','11/17','11/30','0170','0189','0209')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('035754','AR','JEFFERSON','PINE BLUFF',3.422555555000000e+001,-9.201888900000000e+001,'04/03','11/29','04/16','04/03','03/21','11/16','11/29','12/16','0189','0214','0242')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('035820','AR','RANDOLPH','POCAHONTAS 1',3.626388888000000e+001,-9.096805600000000e+001,'04/17','11/16','04/30','04/17','04/05','10/29','11/16','11/30','0168','0193','0215')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('035866','AR','ASHLEY','PORTLAND',3.325111111000000e+001,-9.150583300000000e+001,'04/07','11/28','04/14','04/07','03/21','11/15','11/28','12/11','0190','0210','0239')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('035908','AR','NEVADA','PRESCOTT 2 NNW',3.382027777000000e+001,-9.338777800000000e+001,'04/09','11/25','04/15','04/09','03/28','11/14','11/25','12/12','0189','0207','0226')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('036253','AR','DESHA','ROHWER 2 NNE',3.381027777000000e+001,-9.127777800000000e+001,'04/06','11/22','04/15','04/06','03/24','11/10','11/22','12/07','0185','0201','0231')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('036376','AR','ARKANSAS','SAINT CHARLES',3.437027777000000e+001,-9.112416700000000e+001,'04/10','11/22','04/15','04/10','03/24','11/12','11/22','12/10','0191','0202','0236')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('036506','AR','WHITE','SEARCY',3.526833333000000e+001,-9.171638900000001e+001,'04/16','11/11','04/25','04/16','04/03','11/02','11/11','11/29','0167','0190','0217')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('036768','AR','DALLAS','SPARKMAN',3.391527777000000e+001,-9.282666700000000e+001,'04/18','11/21','04/23','04/18','04/01','11/03','11/21','12/06','0168','0186','0217')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('036920','AR','ARKANSAS','STUTTGART 9 ESE',3.447444444000000e+001,-9.141722200000000e+001,'04/09','11/26','04/20','04/09','03/22','11/10','11/26','12/12','0188','0209','0241')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('036928','AR','LOGAN','SUBIACO',3.530277777000000e+001,-9.363694400000000e+001,'04/12','11/21','04/22','04/12','04/01','11/08','11/21','12/01','0179','0196','0220')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('037048','AR','MILLER','TEXARKANA WEBB FLD',3.345361111000000e+001,-9.400749999999999e+001,'04/06','12/02','04/15','04/06','03/21','11/17','12/02','12/23','0194','0214','0244')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('037488','AR','SCOTT','WALDRON',3.489916666000000e+001,-9.419416699999999e+001,'04/19','11/08','05/03','04/19','04/11','10/23','11/08','11/22','0150','0171','0194')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('037712','AR','CRITTENDEN','WEST MEMPHIS',3.512416666000000e+001,-9.018055600000000e+001,'04/13','11/23','04/23','04/13','03/29','11/06','11/23','12/08','0173','0199','0231')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('038052','AR','CROSS','WYNNE',3.525472222000000e+001,-9.079638900000001e+001,'04/14','11/15','04/21','04/14','04/02','10/29','11/15','12/02','0170','0193','0221')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('040029','CA','MODOC','ADIN RS',4.119361111000000e+001,-1.209447220000000e+002,'06/26','10/06','07/19','06/26','06/05','09/19','10/06','10/21','0032','0072','0108')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('040136','CA','SAN DIEGO','ALPINE',3.283583333000000e+001,-1.167775000000000e+002,'03/28','00/00','04/22','03/28','01/28','01/07','00/00','00/00','0212','0257','0335')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('040161','CA','MODOC','ALTURAS',4.149305555000000e+001,-1.205527780000000e+002,'07/18','09/14','07/31','07/18','06/26','08/26','09/14','09/29','0005','0037','0073')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('040212','CA','NAPA','ANGWIN PAC UNION COL',3.857305555000000e+001,-1.224405560000000e+002,'05/28','01/02','06/06','05/28','04/06','11/30','01/02','00/00','0151','0169','0244')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('040232','CA','CONTRA COSTA','ANTIOCH PUMPING PLANT #3',3.798555555000000e+001,-1.217458330000000e+002,'03/13','12/25','05/02','03/13','02/09','12/14','12/25','00/00','0191','0250','0296')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('040343','CA','TULARE','ASH MTN',3.649138888000000e+001,-1.188252780000000e+002,'04/13','12/22','05/08','04/13','03/03','12/04','12/22','00/00','0191','0226','0292')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('040379','CA','FRESNO','AUBERRY 2 NW',3.709194444000000e+001,-1.195127780000000e+002,'05/05','12/10','05/24','05/05','03/29','11/29','12/10','00/00','0166','0199','0252')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('040383','CA','PLACER','AUBURN',3.890722222000000e+001,-1.210838890000000e+002,'04/02','12/23','05/03','04/02','02/07','11/30','12/23','00/00','0189','0232','0312')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('040442','CA','KERN','BAKERSFIELD AP',3.543444444000000e+001,-1.190541670000000e+002,'02/24','01/06','04/05','02/24','01/27','12/05','01/06','00/00','0227','0277','0321')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('040449','CA','FRESNO','BALCH PWR HOUSE',3.690916666000000e+001,-1.190883330000000e+002,'04/18','12/31','05/11','04/18','02/27','12/08','12/31','00/00','0182','0222','0307')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('040609','CA','RIVERSIDE','BEAUMONT #2',3.392861111000000e+001,-1.169813890000000e+002,'04/23','12/22','05/09','04/23','03/18','11/30','12/22','01/24','0178','0218','0269')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('040693','CA','ALAMEDA','BERKELEY',3.787444444000000e+001,-1.222605560000000e+002,'01/18','00/00','02/27','01/18','00/00','00/00','00/00','00/00','0303','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('040738','CA','TRINITY','BIG BAR 4 E',4.074055555000000e+001,-1.232077780000000e+002,'05/19','11/17','06/02','05/19','04/29','10/27','11/17','12/24','0119','0157','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('040741','CA','SAN BERNARDINO','BIG BEAR LAKE',3.424416666000000e+001,-1.169038890000000e+002,'06/22','10/12','07/14','06/22','06/09','09/22','10/12','10/25','0040','0089','0111')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('040822','CA','INYO','BISHOP AP',3.737111111000000e+001,-1.183580560000000e+002,'05/25','10/31','06/14','05/25','05/16','10/20','10/31','11/08','0101','0137','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('040897','CA','PLACER','BLUE CANYON NYACK AP',3.927750000000000e+001,-1.207102780000000e+002,'06/05','11/21','06/20','06/05','05/20','11/06','11/21','12/05','0105','0131','0167')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('040924','CA','RIVERSIDE','BLYTHE',3.361305555000000e+001,-1.145972220000000e+002,'02/21','12/31','03/14','02/21','02/09','12/07','12/31','00/00','0243','0280','0313')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('040927','CA','RIVERSIDE','BLYTHE ASOS',3.361861111000000e+001,-1.147141670000000e+002,'02/18','00/00','03/06','02/18','01/20','12/23','00/00','00/00','0267','0287','0330')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('040931','CA','NEVADA','BOCA',3.938861111000000e+001,-1.200936110000000e+002,'08/01','08/16','08/03','08/01','07/22','08/09','08/16','09/12','0000','0002','0019')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('040943','CA','MONO','BODIE CA ST HISTORIC PARK',3.821194444000000e+001,-1.190141670000000e+002,'08/02','08/14','08/03','08/02','08/04','08/07','08/14','08/23','0000','0000','0003')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('040983','CA','SAN DIEGO','BORREGO DESERT PARK',3.323138888000000e+001,-1.164144440000000e+002,'03/02','00/00','04/19','03/02','02/19','02/02','00/00','00/00','0236','0299','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('041018','CA','NEVADA','BOWMAN DAM',3.945388888000000e+001,-1.206555560000000e+002,'06/21','11/13','06/29','06/21','05/30','10/28','11/13','11/21','0095','0107','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('041072','CA','MONO','BRIDGEPORT',3.825750000000000e+001,-1.192286110000000e+002,'07/31','09/07','08/04','07/31','07/23','08/23','09/07','09/22','0000','0009','0024')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('041194','CA','LOS ANGELES','BURBANK VLY PUMP PLT',3.418666666000000e+001,-1.183480560000000e+002,'03/17','00/00','04/09','03/17','02/13','12/25','00/00','00/00','0218','0254','0339')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('041214','CA','SHASTA','BURNEY',4.088027777000000e+001,-1.216547220000000e+002,'07/22','09/13','08/06','07/22','07/04','08/28','09/13','10/02','0000','0023','0063')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('041244','CA','KERN','BUTTONWILLOW',3.540472222000000e+001,-1.194730560000000e+002,'03/22','12/07','04/16','03/22','02/18','11/25','12/07','12/18','0199','0229','0275')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('041253','CA','SANTA BARBARA','CACHUMA LAKE',3.458250000000000e+001,-1.199816670000000e+002,'04/01','12/23','04/30','04/01','02/10','11/27','12/23','00/00','0187','0239','0301')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('041277','CA','CALAVERAS','CALAVERAS BIG TREES',3.827694444000000e+001,-1.203113890000000e+002,'06/19','11/10','06/28','06/19','05/24','10/30','11/10','11/26','0088','0111','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('041312','CA','NAPA','CALISTOGA',3.859611111000000e+001,-1.226013890000000e+002,'04/28','12/11','06/05','04/28','03/14','11/11','12/11','01/16','0121','0170','0223')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('041316','CA','SISKIYOU','CALLAHAN',4.131111111000000e+001,-1.228044440000000e+002,'06/23','10/14','07/09','06/23','05/28','10/04','10/14','11/05','0052','0091','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('041424','CA','SAN DIEGO','CAMPO',3.262333333000000e+001,-1.164727780000000e+002,'06/16','11/12','07/13','06/16','05/08','10/22','11/12','11/30','0054','0106','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('041428','CA','CALAVERAS','CAMP PARDEE',3.824861111000000e+001,-1.208433330000000e+002,'03/11','01/17','04/24','03/11','02/05','12/14','01/17','00/00','0205','0268','0326')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('041497','CA','PLUMAS','CANYON DAM',4.017055555000000e+001,-1.210886110000000e+002,'06/18','10/22','07/10','06/18','05/27','10/04','10/22','11/05','0048','0093','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('041614','CA','MODOC','CEDARVILLE',4.153055555000000e+001,-1.201802780000000e+002,'06/13','10/12','06/28','06/13','05/22','10/03','10/12','10/26','0069','0100','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('041697','CA','TUOLUMNE','CHERRY VALLEY DAM',3.797472222000000e+001,-1.199161110000000e+002,'06/09','11/13','06/16','06/09','05/19','11/05','11/13','12/01','0109','0133','0165')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('041700','CA','PLUMAS','CHESTER',4.030333333000000e+001,-1.212422220000000e+002,'07/02','10/04','07/22','07/02','06/08','09/20','10/04','10/24','0019','0061','0108')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('041715','CA','BUTTE','CHICO UNIV FARM',3.969111111000000e+001,-1.218211110000000e+002,'04/24','12/01','05/06','04/24','03/13','11/20','12/01','01/10','0165','0196','0258')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('041758','CA','SAN DIEGO','CHULA VISTA',3.264000000000000e+001,-1.170858330000000e+002,'01/22','00/00','02/28','01/22','00/00','00/00','00/00','00/00','0291','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('041806','CA','LAKE','CLEARLAKE 4 SE',3.892388888000000e+001,-1.225672220000000e+002,'05/06','11/14','05/30','05/06','04/17','11/04','11/14','12/06','0133','0168','0205')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('041838','CA','SONOMA','CLOVERDALE',3.880000000000000e+001,-1.230175000000000e+002,'04/07','01/01','05/06','04/07','02/10','12/10','01/01','00/00','0179','0217','0284')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('041864','CA','FRESNO','COALINGA',3.613555555000000e+001,-1.203605560000000e+002,'04/04','12/08','05/03','04/04','03/04','11/24','12/08','00/00','0184','0220','0270')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('041912','CA','PLACER','COLFAX',3.909111111000000e+001,-1.209480560000000e+002,'05/09','12/04','05/21','05/09','04/12','11/19','12/04','12/24','0156','0181','0223')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('041948','CA','COLUSA','COLUSA 2 SSW',3.918750000000000e+001,-1.220269440000000e+002,'04/16','12/20','05/05','04/16','03/02','12/02','12/20','00/00','0179','0211','0272')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('042012','CA','KINGS','CORCORAN IRRIG DIST',3.609750000000000e+001,-1.195816670000000e+002,'04/06','12/06','04/22','04/06','02/12','11/24','12/06','01/06','0192','0218','0283')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('042081','CA','MENDOCINO','COVELO',3.981583333000000e+001,-1.232444440000000e+002,'05/24','11/05','06/15','05/24','05/01','10/22','11/05','11/18','0100','0142','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('042147','CA','DEL NORTE','CRESCENT CITY 3 NNW',4.179583333000000e+001,-1.242147220000000e+002,'04/17','01/27','05/16','04/17','02/24','12/19','01/27','00/00','0175','0230','0337')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('042214','CA','LOS ANGELES','CULVER CITY',3.400527777000000e+001,-1.184136110000000e+002,'00/00','00/00','03/01','00/00','00/00','00/00','00/00','00/00','0313','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('042239','CA','SAN DIEGO','CUYAMACA',3.298972222000000e+001,-1.165872220000000e+002,'06/03','11/10','06/18','06/03','05/11','10/25','11/10','11/26','0096','0132','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('042257','CA','SAN BERNARDINO','DAGGETT AP',3.485361111000000e+001,-1.167858330000000e+002,'03/11','12/19','03/26','03/11','02/22','11/29','12/19','01/01','0230','0256','0275')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('042294','CA','YOLO','DAVIS 2 WSW EXP FARM',3.853500000000000e+001,-1.217761110000000e+002,'04/08','12/27','04/28','04/08','02/24','11/26','12/27','00/00','0186','0226','0282')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('042319','CA','INYO','DEATH VALLEY',3.646222222000000e+001,-1.168669440000000e+002,'02/16','12/28','03/08','02/16','02/01','12/19','12/28','00/00','0252','0289','0328')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('042402','CA','BUTTE','DE SABLA',3.987166666000000e+001,-1.216108330000000e+002,'05/27','11/24','06/07','05/27','05/02','11/07','11/24','12/09','0109','0143','0183')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('042467','CA','NEVADA','DONNER MEM SP',3.932388888000000e+001,-1.202330560000000e+002,'07/24','09/14','08/02','07/24','07/09','08/22','09/14','10/09','0003','0020','0062')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('042500','CA','SIERRA','DOWNIEVILLE',3.956333333000000e+001,-1.208238890000000e+002,'06/02','11/07','06/22','06/02','05/05','10/18','11/07','11/18','0096','0125','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('042506','CA','LASSEN','DOYLE 4 SSE',3.997166666000000e+001,-1.200827780000000e+002,'06/30','10/10','07/14','06/30','06/05','09/20','10/10','10/23','0042','0078','0116')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('042598','CA','RIVERSIDE','EAGLE MTN',3.380888888000000e+001,-1.154508330000000e+002,'01/21','00/00','02/13','01/21','12/19','00/00','00/00','00/00','0303','0350','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('042709','CA','SAN DIEGO','EL CAPITAN DAM',3.288388888000000e+001,-1.168163890000000e+002,'03/19','00/00','04/22','03/19','02/16','01/07','00/00','00/00','0208','0263','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('042713','CA','IMPERIAL','EL CENTRO 2 SSW',3.276694444000000e+001,-1.155616670000000e+002,'02/16','00/00','04/01','02/16','01/23','01/01','00/00','00/00','0238','0300','0333')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('042805','CA','RIVERSIDE','ELSINORE',3.366916666000000e+001,-1.173319440000000e+002,'04/13','12/24','05/01','04/13','02/25','12/02','12/24','00/00','0192','0225','0287')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('042910','CA','HUMBOLDT','EUREKA WFO WOODLEY IS',4.080972222000000e+001,-1.241602780000000e+002,'03/12','01/21','04/19','03/12','01/18','12/18','01/21','00/00','0209','0274','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('042934','CA','SOLANO','FAIRFIELD',3.827361111000000e+001,-1.220677780000000e+002,'03/16','01/04','04/26','03/16','02/02','12/09','01/04','00/00','0203','0255','0306')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('042941','CA','LOS ANGELES','FAIRMONT',3.470500000000000e+001,-1.184241670000000e+002,'05/05','12/11','05/21','05/05','04/03','11/26','12/11','01/14','0162','0200','0249')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('043083','CA','FRESNO','FIVE POINTS 5 SSW',3.636416666000000e+001,-1.201561110000000e+002,'04/17','12/09','05/06','04/17','03/11','11/27','12/09','01/18','0179','0215','0262')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('043157','CA','MODOC','FT BIDWELL',4.152000000000000e+001,-1.200900000000000e+002,'06/22','10/09','07/07','06/22','06/01','09/26','10/09','10/22','0047','0081','0117')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('043161','CA','MENDOCINO','FT BRAGG 5 N',3.950916666000000e+001,-1.237566670000000e+002,'04/12','01/11','05/16','04/12','02/26','11/29','01/11','00/00','0170','0229','0332')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('043182','CA','SISKIYOU','FT JONES RS',4.160000000000000e+001,-1.228477780000000e+002,'07/10','10/04','07/22','07/10','06/06','09/16','10/04','10/17','0032','0056','0109')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('043191','CA','SONOMA','FT ROSS',3.851500000000000e+001,-1.232447220000000e+002,'05/18','00/00','06/19','05/18','03/01','01/05','00/00','00/00','0124','0206','0325')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('043257','CA','FRESNO','FRESNO YOSEMITE INT''L',3.678000000000000e+001,-1.197194440000000e+002,'03/20','01/01','04/13','03/20','02/06','12/01','01/01','00/00','0211','0246','0300')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('043261','CA','FRESNO','FRIANT GOVERNMENT CAMP',3.699694444000000e+001,-1.197072220000000e+002,'05/01','12/19','05/10','05/01','03/23','11/25','12/19','00/00','0178','0194','0262')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('043384','CA','EL DORADO','GEORGETOWN RS',3.893305555000000e+001,-1.208008330000000e+002,'05/21','11/30','06/06','05/21','04/24','11/17','11/30','12/19','0129','0163','0204')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('043417','CA','SANTA CLARA','GILROY',3.700305555000000e+001,-1.215608330000000e+002,'03/20','12/27','04/28','03/20','02/13','11/28','12/27','00/00','0193','0245','0297')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('043463','CA','KERN','GLENNVILLE',3.572694444000000e+001,-1.187005560000000e+002,'06/15','11/08','06/21','06/15','05/14','10/24','11/08','11/19','0092','0115','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('043551','CA','TULARE','GRANT GROVE',3.673944444000000e+001,-1.189630560000000e+002,'06/24','11/02','06/29','06/24','06/06','10/13','11/02','11/14','0079','0101','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('043573','CA','NEVADA','GRASS VALLEY #2',3.920416666000000e+001,-1.210680560000000e+002,'05/12','11/25','05/29','05/12','04/17','11/11','11/25','12/07','0130','0172','0212')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('043578','CA','SONOMA','GRATON',3.843055555000000e+001,-1.228647220000000e+002,'04/29','11/23','06/06','04/29','03/11','11/09','11/23','01/04','0119','0187','0252')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('043710','CA','INYO','HAIWEE',3.613888888000000e+001,-1.179527780000000e+002,'04/28','11/23','05/17','04/28','04/03','11/09','11/23','12/08','0156','0183','0223')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('043714','CA','SAN MATEO','HALF MOON BAY',3.747250000000000e+001,-1.224433330000000e+002,'03/07','00/00','04/28','03/07','02/02','01/19','00/00','00/00','0213','0306','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('043747','CA','KINGS','HANFORD 1 S',3.631583333000000e+001,-1.196369440000000e+002,'04/02','12/09','04/24','04/02','02/26','11/22','12/09','01/23','0190','0228','0271')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('043761','CA','SISKIYOU','HAPPY CAMP RS',4.180416666000000e+001,-1.233758330000000e+002,'06/02','11/03','06/20','06/02','05/10','10/25','11/03','12/05','0088','0127','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('043824','CA','SHASTA','HAT CREEK',4.093166666000000e+001,-1.215433330000000e+002,'06/21','10/11','07/11','06/21','05/27','09/20','10/11','10/23','0046','0086','0128')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('043855','CA','RIVERSIDE','HAYFIELD PUMPING PLT',3.370444444000000e+001,-1.156288890000000e+002,'03/26','12/20','04/08','03/26','02/21','12/08','12/20','00/00','0221','0247','0291')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('043875','CA','SONOMA','HEALDSBURG',3.861750000000000e+001,-1.228730560000000e+002,'03/04','01/06','04/15','03/04','01/30','12/03','01/06','00/00','0210','0265','0322')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('043914','CA','SAN DIEGO','HENSHAW DAM',3.323722222000000e+001,-1.167613890000000e+002,'05/28','11/09','06/29','05/28','04/27','10/30','11/09','11/28','0075','0136','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('043939','CA','TUOLUMNE','HETCH HETCHY',3.796138888000000e+001,-1.197830560000000e+002,'05/26','11/23','06/09','05/26','04/28','11/11','11/23','12/10','0117','0143','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('044211','CA','RIVERSIDE','IDYLLWILD FIRE DEPT',3.375722222000000e+001,-1.167066670000000e+002,'06/19','11/06','06/29','06/19','06/01','10/18','11/06','11/20','0075','0111','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('044223','CA','IMPERIAL','IMPERIAL',3.284888888000000e+001,-1.155666670000000e+002,'02/05','00/00','02/22','02/05','01/07','00/00','00/00','00/00','0282','0319','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('044232','CA','INYO','INDEPENDENCE',3.679805555000000e+001,-1.182036110000000e+002,'05/06','11/17','05/19','05/06','04/12','11/07','11/17','11/30','0153','0173','0209')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('044259','CA','RIVERSIDE','INDIO FIRE STN',3.370861111000000e+001,-1.162152780000000e+002,'02/12','00/00','03/19','02/12','02/01','12/25','00/00','00/00','0251','0287','0313')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('044278','CA','KERN','INYOKERN',3.565138888000000e+001,-1.178213890000000e+002,'04/24','11/23','05/17','04/24','04/05','11/11','11/23','12/07','0155','0193','0223')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('044297','CA','SAN BERNARDINO','IRON MTN',3.414722222000000e+001,-1.151219440000000e+002,'01/30','00/00','03/04','01/30','01/06','00/00','00/00','00/00','0264','0316','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('044374','CA','MODOC','JESS VALLEY',4.126833333000000e+001,-1.202947220000000e+002,'07/06','09/29','07/21','07/06','06/17','09/12','09/29','10/14','0024','0055','0093')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('044500','CA','MARIN','KENTFIELD',3.795694444000000e+001,-1.225438890000000e+002,'03/15','00/00','04/22','03/15','02/23','12/16','00/00','00/00','0211','0275','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('044523','CA','KERN','KERN RIVER PH 3',3.578305555000000e+001,-1.184388890000000e+002,'04/21','11/25','05/12','04/21','04/04','11/13','11/25','12/07','0167','0198','0226')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('044555','CA','MONTEREY','KING CITY',3.620694444000000e+001,-1.211377780000000e+002,'04/28','12/01','05/28','04/28','03/25','11/14','12/01','12/23','0144','0186','0239')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('044838','CA','SISKIYOU','LAVA BEDS NM',4.170194444000000e+001,-1.215011110000000e+002,'06/26','10/13','07/15','06/26','06/09','10/02','10/13','11/05','0038','0079','0120')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('044890','CA','TULARE','LEMON COVE',3.638166666000000e+001,-1.190263890000000e+002,'04/03','12/19','05/02','04/03','02/05','11/28','12/19','00/00','0188','0228','0306')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('044957','CA','TULARE','LINDSAY',3.620333333000000e+001,-1.190544440000000e+002,'04/12','12/03','05/04','04/12','02/27','11/18','12/03','12/26','0175','0214','0273')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('044997','CA','ALAMEDA','LIVERMORE',3.769222222000000e+001,-1.217691670000000e+002,'04/07','12/23','05/14','04/07','03/01','12/01','12/23','00/00','0170','0217','0276')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('045026','CA','TULARE','LODGEPOLE',3.660444444000000e+001,-1.187325000000000e+002,'07/16','10/01','07/27','07/16','06/23','09/11','10/01','10/21','0012','0032','0090')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('045032','CA','SAN JOAQUIN','LODI',3.810611111000000e+001,-1.212877780000000e+002,'03/31','12/06','04/26','03/31','02/24','11/24','12/06','01/10','0180','0230','0282')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('045064','CA','SANTA BARBARA','LOMPOC',3.465388888000000e+001,-1.204513890000000e+002,'03/23','01/16','05/04','03/23','02/05','12/06','01/16','00/00','0190','0259','0329')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('045085','CA','LOS ANGELES','LONG BCH DAUGHERTY AP',3.381166666000000e+001,-1.181463890000000e+002,'01/08','00/00','02/13','01/08','00/00','00/00','00/00','00/00','0308','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('045114','CA','LOS ANGELES','LOS ANGELES INTL AP',3.393805555000000e+001,-1.183888890000000e+002,'00/00','00/00','01/16','00/00','00/00','00/00','00/00','00/00','9999','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('045115','CA','LOS ANGELES','LOS ANGELES DWTN USC',3.405111111000000e+001,-1.182352780000000e+002,'00/00','00/00','01/29','00/00','00/00','00/00','00/00','00/00','9999','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('045118','CA','MERCED','LOS BANOS',3.705638888000000e+001,-1.208666670000000e+002,'03/06','12/23','04/14','03/06','02/10','12/01','12/23','01/19','0210','0258','0294')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('045123','CA','SANTA CLARA','LOS GATOS',3.723194444000000e+001,-1.219591670000000e+002,'03/24','12/30','04/30','03/24','02/10','12/01','12/30','00/00','0192','0244','0314')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('045233','CA','MADERA','MADERA',3.695388888000000e+001,-1.200377780000000e+002,'03/31','12/06','04/22','03/31','02/17','11/22','12/06','01/05','0186','0227','0281')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('045311','CA','SHASTA','MANZANITA LAKE',4.054111111000000e+001,-1.215766670000000e+002,'07/18','10/09','07/30','07/18','06/20','09/10','10/09','11/01','0012','0049','0098')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('045360','CA','NAPA','MARKLEY COVE',3.849166666000000e+001,-1.221241670000000e+002,'04/11','12/19','05/05','04/11','02/22','11/25','12/19','01/16','0190','0222','0286')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('045378','CA','CONTRA COSTA','MARTINEZ WTP',3.801305555000000e+001,-1.221141670000000e+002,'03/27','00/00','04/25','03/27','01/28','12/07','00/00','00/00','0205','0254','0341')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('045449','CA','SISKIYOU','MC CLOUD',4.125138888000000e+001,-1.221383330000000e+002,'06/15','10/18','07/10','06/15','05/25','10/01','10/18','11/01','0060','0100','0139')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('045502','CA','RIVERSIDE','MECCA FIRE STN',3.357138888000000e+001,-1.160766670000000e+002,'03/08','12/25','03/26','03/08','02/09','12/04','12/25','00/00','0232','0261','0292')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('045532','CA','MERCED','MERCED',3.728583333000000e+001,-1.205116670000000e+002,'04/10','12/04','05/04','04/10','03/16','11/28','12/04','01/02','0166','0214','0256')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('045679','CA','TEHAMA','MINERAL',4.034583333000000e+001,-1.216091670000000e+002,'07/18','09/29','07/30','07/18','06/21','08/24','09/29','10/16','0010','0035','0092')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('045738','CA','STANISLAUS','MODESTO AP',3.762416666000000e+001,-1.209505560000000e+002,'03/03','01/02','04/05','03/03','02/02','12/07','01/02','00/00','0219','0268','0313')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('045756','CA','KERN','MOJAVE',3.504916666000000e+001,-1.181619440000000e+002,'04/17','11/26','05/11','04/17','03/28','11/14','11/26','12/06','0168','0200','0234')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('045795','CA','MONTEREY','MONTEREY',3.659027777000000e+001,-1.219100000000000e+002,'01/27','00/00','03/24','01/27','12/15','00/00','00/00','00/00','0278','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('045866','CA','SAN LUIS OBISPO','MORRO BAY FIRE DEPT',3.536722222000000e+001,-1.208455560000000e+002,'03/03','00/00','05/08','03/03','01/29','02/28','00/00','00/00','0213','0281','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('045915','CA','CONTRA COSTA','MT DIABLO JUNCTION',3.787916666000000e+001,-1.219302780000000e+002,'05/02','01/14','05/13','05/02','03/07','12/12','01/14','00/00','0185','0219','0315')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('045933','CA','SANTA CLARA','MT HAMILTON',3.734361111000000e+001,-1.216425000000000e+002,'06/06','12/12','06/17','06/06','05/14','11/15','12/12','01/06','0121','0151','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('045941','CA','SISKIYOU','MOUNT HEBRON RANGER STN',4.178361111000000e+001,-1.220447220000000e+002,'07/23','09/14','08/01','07/23','06/24','09/02','09/14','10/03','0008','0022','0071')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('045983','CA','SISKIYOU','MT SHASTA',4.132055555000000e+001,-1.223080560000000e+002,'06/13','10/17','07/05','06/13','05/19','10/02','10/17','11/06','0067','0102','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046006','CA','LOS ANGELES','MT WILSON CBS',3.423083333000000e+001,-1.180711110000000e+002,'06/06','01/09','06/13','06/06','05/15','11/24','01/09','12/28','0122','0146','0182')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046074','CA','NAPA','NAPA STATE HOSPITAL',3.827777777000000e+001,-1.222647220000000e+002,'04/06','01/05','05/05','04/06','02/08','11/30','01/05','00/00','0188','0227','0310')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046118','CA','SAN BERNARDINO','NEEDLES AP',3.476750000000000e+001,-1.146188890000000e+002,'02/09','00/00','03/06','02/09','01/18','12/26','00/00','00/00','0267','0306','0357')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046136','CA','NEVADA','NEVADA CITY',3.924666666000000e+001,-1.210008330000000e+002,'05/27','11/29','06/12','05/27','04/26','11/15','11/29','12/26','0113','0145','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046144','CA','ALAMEDA','NEWARK',3.751472222000000e+001,-1.220325000000000e+002,'01/31','00/00','03/15','01/31','01/08','00/00','00/00','00/00','0267','0326','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046168','CA','STANISLAUS','NEWMAN',3.728111111000000e+001,-1.210177780000000e+002,'04/04','12/14','04/27','04/04','02/28','11/28','12/14','01/13','0194','0228','0269')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046175','CA','ORANGE','NEWPORT BEACH HARBOR',3.360250000000000e+001,-1.178802780000000e+002,'00/00','00/00','01/30','00/00','00/00','00/00','00/00','00/00','0332','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046252','CA','MADERA','NORTH FORK RS',3.723277777000000e+001,-1.195097220000000e+002,'05/28','11/19','06/09','05/28','05/08','11/05','11/19','12/04','0129','0156','0188')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046336','CA','ALAMEDA','OAKLAND MUSEUM',3.779833333000000e+001,-1.222641670000000e+002,'01/17','00/00','02/21','01/17','00/00','00/00','00/00','00/00','0308','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046377','CA','SAN DIEGO','OCEANSIDE MARINA',3.320972222000000e+001,-1.173950000000000e+002,'01/27','00/00','03/20','01/27','00/00','00/00','00/00','00/00','0264','0335','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046399','CA','VENTURA','OJAI',3.444777777000000e+001,-1.192275000000000e+002,'04/09','12/18','05/08','04/09','02/17','11/26','12/18','00/00','0174','0224','0291')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046498','CA','HUMBOLDT','ORICK PRAIRIE CREEK PK',4.136194444000000e+001,-1.240191670000000e+002,'05/31','11/26','06/21','05/31','04/12','10/27','11/26','01/25','0088','0145','0229')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046506','CA','GLENN','ORLAND',3.974583333000000e+001,-1.221997220000000e+002,'04/12','12/17','05/06','04/12','03/02','12/01','12/17','01/19','0187','0226','0286')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046508','CA','HUMBOLDT','ORLEANS',4.130888888000000e+001,-1.235316670000000e+002,'04/29','12/16','05/15','04/29','03/14','11/26','12/16','01/21','0155','0192','0255')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046521','CA','BUTTE','OROVILLE',3.951777777000000e+001,-1.215530560000000e+002,'04/03','01/01','05/13','04/03','02/14','12/12','01/01','00/00','0178','0231','0304')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046624','CA','LOS ANGELES','PALMDALE',3.458833333000000e+001,-1.180938890000000e+002,'05/02','11/26','05/16','05/02','04/06','11/14','11/26','12/09','0151','0183','0225')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046635','CA','RIVERSIDE','PALM SPRINGS',3.382750000000000e+001,-1.165097220000000e+002,'03/07','00/00','03/23','03/07','01/13','01/18','00/00','00/00','0262','0309','0359')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046646','CA','SANTA CLARA','PALO ALTO',3.744361111000000e+001,-1.221402780000000e+002,'03/16','01/15','04/22','03/16','02/01','12/06','01/15','00/00','0202','0258','0330')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046657','CA','SAN DIEGO','PALOMAR MTN OBSVTRY',3.337805555000000e+001,-1.168400000000000e+002,'06/06','12/01','06/18','06/06','05/15','11/22','12/01','12/27','0120','0146','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046685','CA','BUTTE','PARADISE',3.975361111000000e+001,-1.216238890000000e+002,'04/14','12/30','05/06','04/14','02/19','12/03','12/30','00/00','0185','0228','0306')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046699','CA','SAN BERNARDINO','PARKER RSVR',3.429027777000000e+001,-1.141708330000000e+002,'01/26','00/00','03/03','01/26','12/21','00/00','00/00','00/00','0284','0331','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046719','CA','LOS ANGELES','PASADENA',3.414805555000000e+001,-1.181444440000000e+002,'02/08','00/00','03/19','02/08','01/06','00/00','00/00','00/00','0264','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046730','CA','SAN LUIS OBISPO','PASO ROBLES',3.562777777000000e+001,-1.206855560000000e+002,'05/14','11/16','06/08','05/14','04/06','11/04','11/16','12/11','0118','0160','0217')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046742','CA','SAN LUIS OBISPO','PASO ROBLES MUNI AP',3.566972222000000e+001,-1.206283330000000e+002,'05/11','11/19','05/24','05/11','04/01','11/09','11/19','12/17','0147','0175','0227')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046826','CA','SONOMA','PETALUMA AIRPORT',3.825777777000000e+001,-1.226077780000000e+002,'04/15','12/26','05/12','04/15','03/16','12/04','12/26','00/00','0166','0217','0264')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('046926','CA','SAN BENITO','PINNACLES NM',3.648166666000000e+001,-1.211822220000000e+002,'05/18','11/20','06/15','05/18','04/19','10/31','11/20','12/13','0112','0161','0215')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047050','CA','LOS ANGELES','POMONA/FAIRPLEX',3.408166666000000e+001,-1.177658330000000e+002,'03/05','00/00','04/08','03/05','01/30','12/16','00/00','00/00','0226','0288','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047085','CA','PLUMAS','PORTOLA',3.980527777000000e+001,-1.204719440000000e+002,'07/18','09/20','07/29','07/18','07/03','08/23','09/20','10/16','0006','0028','0064')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047109','CA','MENDOCINO','POTTER VALLEY P H',3.936194444000000e+001,-1.231286110000000e+002,'05/10','11/23','06/01','05/10','04/06','11/04','11/23','12/18','0133','0175','0217')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047150','CA','MONTEREY','PRIEST VALLEY',3.618833333000000e+001,-1.206952780000000e+002,'06/11','10/31','07/06','06/11','05/26','10/19','10/31','11/17','0082','0116','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047195','CA','PLUMAS','QUINCY',3.993666666000000e+001,-1.209475000000000e+002,'07/10','10/06','07/28','07/10','06/01','09/15','10/06','10/22','0007','0043','0100')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047253','CA','KERN','RANDSBURG',3.536916666000000e+001,-1.176525000000000e+002,'04/14','12/17','05/08','04/14','04/05','11/28','12/17','01/10','0181','0209','0245')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047292','CA','TEHAMA','RED BLUFF MUNI AP',4.015194444000000e+001,-1.222536110000000e+002,'03/29','12/21','04/26','03/29','02/19','11/27','12/21','00/00','0196','0243','0301')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047306','CA','SAN BERNARDINO','REDLANDS',3.405277777000000e+001,-1.171894440000000e+002,'03/08','00/00','04/21','03/08','01/28','12/21','00/00','00/00','0207','0267','0318')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047339','CA','SAN MATEO','REDWOOD CITY',3.747666666000000e+001,-1.222386110000000e+002,'02/28','01/25','04/09','02/28','02/01','12/15','01/25','00/00','0217','0281','0342')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047404','CA','HUMBOLDT','RICHARDSON GR SP',4.002611111000000e+001,-1.237930560000000e+002,'04/13','12/30','05/08','04/13','02/15','11/19','12/30','00/00','0176','0222','0293')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047414','CA','CONTRA COSTA','RICHMOND',3.791916666000000e+001,-1.223772220000000e+002,'02/10','00/00','03/12','02/10','00/00','00/00','00/00','00/00','0264','0332','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047470','CA','RIVERSIDE','RIVERSIDE FIRE STN 3',3.395111111000000e+001,-1.173880560000000e+002,'03/07','00/00','04/11','03/07','01/19','12/19','00/00','00/00','0226','0272','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047630','CA','SACRAMENTO','SACRAMENTO AP ASOS',3.850694444000000e+001,-1.214950000000000e+002,'03/20','01/01','04/18','03/20','02/07','12/02','01/01','00/00','0213','0250','0306')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047633','CA','SACRAMENTO','SACRAMENTO 5ESE',3.855555555000000e+001,-1.214169440000000e+002,'02/13','00/00','03/14','02/13','01/06','12/22','00/00','00/00','0257','0296','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047643','CA','NAPA','SAINT HELENA',3.850666666000000e+001,-1.224713890000000e+002,'04/21','12/27','05/10','04/21','02/24','11/27','12/27','00/00','0175','0209','0281')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047668','CA','MONTEREY','SALINAS #2',3.665944444000000e+001,-1.216655560000000e+002,'03/12','01/19','04/15','03/12','02/02','12/15','01/19','00/00','0208','0267','0355')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047669','CA','MONTEREY','SALINAS AP',3.666361111000000e+001,-1.216080560000000e+002,'03/01','01/06','04/21','03/01','01/24','12/09','01/06','00/00','0205','0271','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047735','CA','LOS ANGELES','SANDBERG',3.474361111000000e+001,-1.187241670000000e+002,'05/24','12/09','06/01','05/24','05/03','11/22','12/09','01/01','0140','0168','0197')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047740','CA','SAN DIEGO','SAN DIEGO WSO AP',3.273361111000000e+001,-1.171830560000000e+002,'00/00','00/00','12/28','00/00','00/00','00/00','00/00','00/00','9999','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047767','CA','SAN FRANCISCO','SAN FRANCISCO OCEANSD',3.772805555000000e+001,-1.225052780000000e+002,'02/02','00/00','03/10','02/02','00/00','00/00','00/00','00/00','0279','0339','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047769','CA','SAN MATEO','SAN FRANCISCO INTL AP',3.761972222000000e+001,-1.223647220000000e+002,'01/23','00/00','02/24','01/23','00/00','00/00','00/00','00/00','0294','0351','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047772','CA','SAN FRANCISCO','SAN FRANCISCO DWTN',3.777055555000000e+001,-1.224269440000000e+002,'12/22','00/00','01/30','12/22','00/00','00/00','00/00','00/00','9999','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047785','CA','LOS ANGELES','SAN GABRIEL FIRE DEPT',3.410611111000000e+001,-1.181000000000000e+002,'02/20','00/00','03/26','02/20','01/22','12/31','00/00','00/00','0244','0302','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047821','CA','SANTA CLARA','SAN JOSE',3.735916666000000e+001,-1.219238890000000e+002,'02/10','00/00','03/17','02/10','01/16','12/27','00/00','00/00','0243','0301','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047851','CA','SAN LUIS OBISPO','SAN LUIS OBISPO POLY U',3.530388888000000e+001,-1.206650000000000e+002,'03/29','00/00','05/10','03/29','01/16','01/06','00/00','00/00','0196','0247','0352')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047880','CA','MARIN','SAN RAFAEL CIVIC CTR',3.799833333000000e+001,-1.225372220000000e+002,'04/15','00/00','05/16','04/15','03/21','01/08','00/00','00/00','0192','0242','0365')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047888','CA','ORANGE','SANTA ANA FIRE STN',3.374416666000000e+001,-1.178666670000000e+002,'00/00','00/00','02/25','00/00','00/00','00/00','00/00','00/00','0298','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047902','CA','SANTA BARBARA','SANTA BARBARA',3.441666666000000e+001,-1.196844440000000e+002,'01/28','00/00','03/19','01/28','00/00','00/00','00/00','00/00','0276','0334','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047905','CA','SANTA BARBARA','SANTA BARBARA MUNI AP',3.442583333000000e+001,-1.198425000000000e+002,'02/18','00/00','03/25','02/18','01/19','12/17','00/00','00/00','0231','0279','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047916','CA','SANTA CRUZ','SANTA CRUZ',3.699055555000000e+001,-1.219911110000000e+002,'03/16','00/00','05/07','03/16','02/07','12/12','00/00','00/00','0183','0257','0306')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047946','CA','SANTA BARBARA','SANTA MARIA PUBLIC AP',3.489944444000000e+001,-1.204486110000000e+002,'04/28','12/25','05/22','04/28','02/21','11/30','12/25','00/00','0166','0207','0289')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047953','CA','LOS ANGELES','SANTA MONICA PIER',3.400750000000000e+001,-1.184997220000000e+002,'00/00','00/00','00/00','00/00','00/00','00/00','00/00','00/00','9999','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('047965','CA','SONOMA','SANTA ROSA',3.843805555000000e+001,-1.226977780000000e+002,'04/05','01/08','05/01','04/05','02/19','12/03','01/08','00/00','0184','0228','0291')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('048045','CA','HUMBOLDT','SCOTIA',4.048305555000000e+001,-1.241036110000000e+002,'03/23','01/25','04/30','03/23','02/03','12/06','01/25','00/00','0192','0250','0322')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('048135','CA','SHASTA','SHASTA DAM',4.071416666000000e+001,-1.224161110000000e+002,'04/01','01/24','04/21','04/01','01/29','12/25','01/24','00/00','0208','0242','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('048218','CA','SIERRA','SIERRAVILLE RS',3.958333333000000e+001,-1.203705560000000e+002,'07/11','09/22','07/28','07/11','06/17','08/30','09/22','10/12','0012','0054','0088')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('048351','CA','SONOMA','SONOMA',3.829944444000000e+001,-1.224622220000000e+002,'04/19','12/20','05/21','04/19','03/04','11/24','12/20','01/19','0146','0206','0275')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('048353','CA','TUOLUMNE','SONORA',3.796722222000000e+001,-1.203872220000000e+002,'05/17','11/22','06/09','05/17','05/01','11/10','11/22','12/07','0118','0164','0200')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('048380','CA','MARIPOSA','SO ENTR YOSEMITE NP',3.750722222000000e+001,-1.196330560000000e+002,'06/14','11/01','07/05','06/14','05/27','10/11','11/01','11/16','0074','0109','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('048558','CA','SAN JOAQUIN','STOCKTON AP',3.788916666000000e+001,-1.212258330000000e+002,'03/14','12/17','04/16','03/14','02/14','11/29','12/17','00/00','0209','0254','0293')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('048560','CA','SAN JOAQUIN','STOCKTON FIRE STA 4',3.799944444000000e+001,-1.213177780000000e+002,'04/10','12/15','05/23','04/10','03/03','11/29','12/15','00/00','0142','0213','0275')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('048587','CA','GLENN','STONY GORGE RSVR',3.958583333000000e+001,-1.225338890000000e+002,'04/29','11/27','05/19','04/29','03/30','11/13','11/27','12/23','0153','0191','0233')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('048606','CA','YUBA','STRAWBERRY VALLEY',3.956305555000000e+001,-1.211077780000000e+002,'06/09','11/12','06/26','06/09','05/15','10/29','11/12','11/28','0092','0119','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('048702','CA','LASSEN','SUSANVILLE 2SW',4.041666666000000e+001,-1.206630560000000e+002,'06/17','10/08','07/17','06/17','06/01','09/26','10/08','10/24','0038','0081','0115')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('048758','CA','PLACER','TAHOE CITY',3.916777777000000e+001,-1.201427780000000e+002,'07/07','10/11','07/18','07/07','06/16','09/12','10/11','10/29','0027','0066','0106')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('048762','CA','EL DORADO','SOUTH LAKE TAHOE AP',3.889833333000000e+001,-1.199947220000000e+002,'07/30','09/09','08/04','07/30','07/05','08/20','09/09','10/07','0000','0005','0053')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('048839','CA','KERN','TEJON RANCHO',3.502333333000000e+001,-1.187497220000000e+002,'04/06','12/15','04/29','04/06','03/01','11/29','12/15','01/16','0189','0227','0274')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('048917','CA','TULARE','THREE RVRS EDISON PH 1',3.646500000000000e+001,-1.188619440000000e+002,'04/22','12/07','05/05','04/22','03/11','11/21','12/07','00/00','0185','0213','0264')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('048973','CA','LOS ANGELES','TORRANCE AP',3.380166666000000e+001,-1.183411110000000e+002,'01/15','00/00','02/26','01/15','00/00','00/00','00/00','00/00','0314','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('048999','CA','SAN JOAQUIN','TRACY CARBONA',3.768194444000000e+001,-1.213466670000000e+002,'03/19','12/29','04/27','03/19','02/08','11/30','12/29','01/17','0200','0249','0304')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('049001','CA','ALAMEDA','TRACY PUMPING PLT',3.779666666000000e+001,-1.215827780000000e+002,'03/08','12/28','04/04','03/08','02/11','12/06','12/28','00/00','0220','0258','0299')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('049035','CA','SAN BERNARDINO','TRONA',3.576361111000000e+001,-1.173908330000000e+002,'03/30','01/16','04/16','03/30','03/03','12/30','01/16','00/00','0207','0233','0270')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('049043','CA','NEVADA','TRUCKEE RS',3.933305555000000e+001,-1.201730560000000e+002,'07/22','09/21','07/31','07/22','07/04','08/26','09/21','10/10','0003','0028','0060')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('049053','CA','SISKIYOU','TULELAKE',4.196000000000000e+001,-1.214744440000000e+002,'06/29','09/23','07/25','06/29','06/05','09/10','09/23','10/10','0022','0065','0101')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('049099','CA','SAN BERNARDINO','TWENTYNINE PALMS',3.412805555000000e+001,-1.160369440000000e+002,'04/04','12/08','04/25','04/04','03/02','11/25','12/08','01/03','0190','0225','0263')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('049111','CA','SANTA BARBARA','TWITCHELL DAM',3.498805555000000e+001,-1.203211110000000e+002,'04/03','00/00','05/21','04/03','02/15','12/11','00/00','00/00','0168','0235','0292')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('049122','CA','MENDOCINO','UKIAH',3.914666666000000e+001,-1.232102780000000e+002,'04/17','12/05','05/11','04/17','03/10','11/13','12/05','01/16','0171','0203','0266')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('049152','CA','LOS ANGELES','U C L A',3.406972222000000e+001,-1.184427780000000e+002,'00/00','00/00','12/23','00/00','00/00','00/00','00/00','00/00','9999','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('049325','CA','SAN BERNARDINO','VICTORVILLE PUMP PT',3.453500000000000e+001,-1.173058330000000e+002,'04/24','11/15','05/25','04/24','03/31','11/07','11/15','12/01','0150','0189','0226')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('049367','CA','TULARE','VISALIA',3.632833333000000e+001,-1.192991670000000e+002,'03/02','12/31','04/05','03/02','02/05','12/07','12/31','00/00','0222','0267','0315')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('049378','CA','SAN DIEGO','VISTA 2 NNE',3.322944444000000e+001,-1.172269440000000e+002,'02/15','00/00','04/01','02/15','01/12','00/00','00/00','00/00','0250','0313','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('049452','CA','KERN','WASCO',3.558916666000000e+001,-1.193519440000000e+002,'03/21','12/07','04/13','03/21','02/11','11/24','12/07','01/03','0206','0243','0294')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('049473','CA','SANTA CRUZ','WATSONVILLE WTR WKS',3.693083333000000e+001,-1.217691670000000e+002,'04/03','01/16','04/29','04/03','01/27','12/05','01/16','00/00','0192','0232','0338')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('049490','CA','TRINITY','WEAVERVILLE',4.072222222000000e+001,-1.229330560000000e+002,'06/10','10/23','06/30','06/10','05/20','10/07','10/23','11/10','0068','0110','0143')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('049621','CA','SHASTA','WHISKEYTOWN RSVR',4.061166666000000e+001,-1.225280560000000e+002,'04/10','12/20','05/06','04/10','03/03','12/04','12/20','00/00','0183','0220','0287')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('049684','CA','MENDOCINO','WILLITS 1 NE',3.941944444000000e+001,-1.233425000000000e+002,'06/05','10/28','07/02','06/05','05/10','10/15','10/28','11/30','0060','0124','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('049694','CA','HUMBOLDT','WILLOW CREEK 1 NW',4.094666666000000e+001,-1.236363890000000e+002,'05/17','12/10','06/01','05/17','04/27','11/10','12/10','01/15','0120','0152','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('049699','CA','GLENN','WILLOWS 6 W',3.952305555000000e+001,-1.223058330000000e+002,'04/24','12/11','05/12','04/24','03/19','11/24','12/11','01/07','0177','0214','0269')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('049742','CA','YOLO','WINTERS',3.852277777000000e+001,-1.219683330000000e+002,'03/20','01/04','04/19','03/20','01/27','12/05','01/04','00/00','0204','0260','0318')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('049781','CA','YOLO','WOODLAND 1 WNW',3.868277777000000e+001,-1.217941670000000e+002,'02/28','12/28','04/20','02/28','02/01','12/05','12/28','00/00','0206','0267','0307')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('049855','CA','MARIPOSA','YOSEMITE PARK HQ',3.775000000000000e+001,-1.195897220000000e+002,'06/04','11/14','06/18','06/04','05/02','10/31','11/14','11/30','0109','0130','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('049866','CA','SISKIYOU','YREKA',4.170361111000000e+001,-1.226408330000000e+002,'06/07','10/19','06/30','06/07','05/17','10/12','10/19','11/06','0072','0111','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('050109','CO','WASHINGTON','AKRON 4 E',4.015500000000000e+001,-1.031416670000000e+002,'05/23','10/08','06/07','05/23','05/13','10/02','10/08','10/24','0102','0120','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('050130','CO','ALAMOSA','ALAMOSA-BERGMAN FIELD',3.743888888000000e+001,-1.058613890000000e+002,'06/23','09/28','07/14','06/23','06/14','09/17','09/28','10/02','0041','0080','0101')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('050214','CO','GARFIELD','ALTENBERN',3.950083333000000e+001,-1.083794440000000e+002,'06/20','10/06','07/12','06/20','05/30','09/30','10/06','10/19','0048','0088','0115')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('050263','CO','PARK','ANTERO RSVR',3.899333333000000e+001,-1.058919440000000e+002,'07/23','09/09','08/04','07/23','07/02','08/19','09/09','09/24','0000','0018','0062')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('050454','CO','PARK','BAILEY',3.940472222000000e+001,-1.054766670000000e+002,'07/13','09/23','07/21','07/13','06/16','09/09','09/23','09/30','0020','0047','0084')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('050797','CO','GUNNISON','BLUE MESA LAKE',3.846666666000000e+001,-1.071677780000000e+002,'06/25','09/26','07/11','06/25','06/20','09/20','09/26','10/07','0040','0069','0079')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('050834','CO','YUMA','BONNY DAM 2NE',3.965666666000000e+001,-1.021191670000000e+002,'05/21','10/19','05/31','05/21','05/07','10/07','10/19','10/27','0114','0127','0153')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('050848','CO','BOULDER','BOULDER',3.999194444000000e+001,-1.052666670000000e+002,'05/14','10/16','05/31','05/14','05/07','10/08','10/16','10/30','0113','0131','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('050945','CO','WELD','BRIGGSDALE',4.063500000000000e+001,-1.043266670000000e+002,'06/09','10/03','06/28','06/09','05/30','10/01','10/03','10/16','0074','0105','0121')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('051071','CO','CHAFFEE','BUENA VISTA 2S',3.882472222000000e+001,-1.061275000000000e+002,'06/25','10/02','07/10','06/25','06/06','09/23','10/02','10/12','0040','0071','0100')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('051121','CO','KIT CARSON','BURLINGTON',3.930611111000000e+001,-1.022608330000000e+002,'05/17','10/23','05/23','05/17','05/03','10/11','10/23','10/31','0122','0132','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('051179','CO','ADAMS','BYERS 5 ENE',3.974027777000000e+001,-1.041275000000000e+002,'05/23','10/09','06/13','05/23','05/12','10/01','10/09','10/16','0096','0118','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('051186','CO','CLEAR CREEK','CABIN CREEK',3.965527777000000e+001,-1.057088890000000e+002,'07/15','09/24','08/01','07/15','06/27','09/09','09/24','10/05','0002','0044','0070')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('051268','CO','BACA','CAMPO 7 S',3.701583333000000e+001,-1.025550000000000e+002,'05/09','10/27','05/21','05/09','05/02','10/15','10/27','11/07','0122','0141','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('051294','CO','FREMONT','CANON CITY',3.846000000000000e+001,-1.052255560000000e+002,'05/24','10/18','06/04','05/24','05/04','10/11','10/18','11/02','0115','0128','0153')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('051401','CO','DOUGLAS','CASTLE ROCK',3.941055555000000e+001,-1.049058330000000e+002,'06/11','10/07','06/16','06/11','05/19','09/30','10/07','10/14','0088','0098','0126')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('051528','CO','JEFFERSON','CHEESMAN',3.922027777000000e+001,-1.052783330000000e+002,'07/06','10/02','07/18','07/06','06/14','09/21','10/02','10/07','0022','0048','0090')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('051564','CO','CHEYENNE','CHEYENNE WELLS',3.882194444000000e+001,-1.023508330000000e+002,'05/20','10/17','05/27','05/20','05/07','10/07','10/17','10/31','0116','0127','0158')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('051609','CO','MONTROSE','CIMARRON',3.844416666000000e+001,-1.075591670000000e+002,'07/10','09/21','07/23','07/10','06/19','09/08','09/21','10/03','0018','0042','0080')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('051660','CO','LAKE','CLIMAX',3.936722222000000e+001,-1.061897220000000e+002,'07/28','09/07','08/03','07/28','07/15','08/18','09/07','09/21','0000','0016','0044')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('051713','CO','GUNNISON','COCHETOPA CREEK',3.844611111000000e+001,-1.067611110000000e+002,'07/14','09/17','08/02','07/14','06/24','08/29','09/17','09/28','0001','0037','0068')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('051772','CO','MESA','COLORADO NM',3.910138888000000e+001,-1.087338890000000e+002,'05/26','10/27','06/09','05/26','05/08','10/20','10/27','11/13','0112','0134','0166')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('051778','CO','EL PASO','COLORADO SPGS MUNI AP',3.881000000000000e+001,-1.046883330000000e+002,'05/15','10/15','05/30','05/15','05/05','10/10','10/15','10/27','0112','0131','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('051886','CO','MONTEZUMA','CORTEZ',3.734444444000000e+001,-1.085930560000000e+002,'06/11','10/13','06/23','06/11','05/23','10/03','10/13','10/26','0086','0107','0131')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('051959','CO','GUNNISON','CRESTED BUTTE',3.887388888000000e+001,-1.069769440000000e+002,'07/31','08/30','08/03','07/31','07/06','08/09','08/30','09/16','0000','0004','0049')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('052184','CO','RIO GRANDE','DEL NORTE 2E',3.767416666000000e+001,-1.063247220000000e+002,'06/12','10/04','06/30','06/12','05/30','09/24','10/04','10/17','0073','0100','0119')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('052220','CO','DENVER','DENVER-STAPELTON',3.976333333000000e+001,-1.048694440000000e+002,'05/13','10/21','05/27','05/13','05/07','10/09','10/21','11/01','0115','0132','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('052281','CO','SUMMIT','DILLON 1 E',3.962611111000000e+001,-1.060352780000000e+002,'07/27','09/07','08/06','07/27','07/04','08/13','09/07','09/24','0000','0012','0053')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('052286','CO','MOFFAT','DINOSAUR NATL MONUMNT',4.024416666000000e+001,-1.089719440000000e+002,'06/12','10/12','06/18','06/12','05/28','10/02','10/12','10/25','0086','0103','0123')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('052446','CO','KIOWA','EADS',3.847583333000000e+001,-1.027769440000000e+002,'05/13','10/18','05/29','05/13','05/02','10/10','10/18','10/29','0117','0136','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('052790','CO','JEFFERSON','EVERGREEN',3.963805555000000e+001,-1.053150000000000e+002,'06/18','09/28','07/10','06/18','06/02','09/20','09/28','10/11','0052','0086','0108')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('052932','CO','KIT CARSON','FLAGLER 1S',3.928138888000000e+001,-1.030613890000000e+002,'05/24','10/11','06/13','05/24','05/15','10/04','10/11','10/23','0097','0118','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('053005','CO','LARIMER','FT COLLINS',4.061472222000000e+001,-1.051313890000000e+002,'05/15','10/17','05/27','05/15','05/02','10/04','10/17','10/26','0118','0130','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('053016','CO','LA PLATA','FT LEWIS',3.723083333000000e+001,-1.080513890000000e+002,'06/30','10/02','07/11','06/30','06/19','09/25','10/02','10/15','0054','0076','0096')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('053038','CO','MORGAN','FT MORGAN',4.026000000000000e+001,-1.038155560000000e+002,'05/12','10/18','05/20','05/12','05/03','10/08','10/18','10/29','0126','0138','0159')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('053146','CO','MESA','FRUITA',3.916527777000000e+001,-1.087330560000000e+002,'05/29','10/15','06/13','05/29','05/18','10/03','10/15','10/30','0099','0117','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('053246','CO','MESA','GATEWAY',3.868250000000000e+001,-1.089722220000000e+002,'05/20','11/01','05/28','05/20','05/01','10/16','11/01','11/09','0122','0138','0166')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('053261','CO','CLEAR CREEK','GEORGETOWN',3.970527777000000e+001,-1.056997220000000e+002,'07/03','10/01','07/08','07/03','06/20','09/22','10/01','10/07','0046','0067','0093')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('053359','CO','GARFIELD','GLENWOOD SPGS #2',3.951805555000000e+001,-1.073172220000000e+002,'06/08','10/11','06/27','06/08','05/28','10/04','10/11','10/20','0074','0100','0118')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('053488','CO','MESA','GRAND JUNCTION REGIONAL AP',3.913416666000000e+001,-1.085400000000000e+002,'05/09','11/03','05/30','05/09','04/27','10/27','11/03','11/14','0128','0149','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('053489','CO','MESA','GRAND JUNCTION 6 ESE',3.904222222000000e+001,-1.084663890000000e+002,'05/19','11/03','06/06','05/19','04/29','10/19','11/03','11/11','0113','0140','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('053496','CO','GRAND','GRAND LAKE 1 NW',4.026694444000000e+001,-1.058322220000000e+002,'07/31','09/06','08/04','07/31','07/11','08/12','09/06','09/22','0000','0003','0042')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('053500','CO','GRAND','GRAND LAKE 6 SSW',4.018500000000000e+001,-1.058666670000000e+002,'07/13','09/14','08/01','07/13','06/22','08/29','09/14','09/30','0001','0038','0078')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('053530','CO','PARK','GRANT',3.946083333000000e+001,-1.056786110000000e+002,'07/05','09/23','07/22','07/05','06/19','09/05','09/23','10/01','0014','0054','0086')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('053541','CO','ALAMOSA','GREAT SAND DUNES NM',3.773333333000000e+001,-1.055119440000000e+002,'06/13','10/06','06/27','06/13','05/29','09/28','10/06','10/18','0073','0097','0121')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('053553','CO','WELD','GREELEY UNC',4.040222222000000e+001,-1.046991670000000e+002,'05/13','10/14','05/26','05/13','05/03','10/04','10/14','10/25','0117','0133','0153')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('053592','CO','SUMMIT','GREEN MT DAM',3.987888888000000e+001,-1.063333330000000e+002,'07/13','09/28','07/28','07/13','06/30','09/09','09/28','10/05','0008','0036','0057')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('053662','CO','GUNNISON','GUNNISON 3SW',3.852527777000000e+001,-1.069672220000000e+002,'07/16','09/19','07/31','07/16','06/23','08/29','09/19','09/28','0003','0034','0068')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('053867','CO','ROUTT','HAYDEN',4.049277777000000e+001,-1.072547220000000e+002,'06/20','10/03','07/06','06/20','06/08','09/25','10/03','10/10','0052','0080','0103')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('053951','CO','MINERAL','HERMIT 7 ESE',3.777166666000000e+001,-1.071097220000000e+002,'08/03','08/30','08/05','08/03','07/15','08/13','08/30','09/19','0000','0000','0035')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('054082','CO','PHILLIPS','HOLYOKE',4.054527777000000e+001,-1.023411110000000e+002,'05/14','10/16','05/26','05/14','05/06','10/04','10/16','10/27','0114','0131','0156')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('054388','CO','BENT','JOHN MARTIN DAM',3.806333333000000e+001,-1.029297220000000e+002,'05/13','10/20','05/18','05/13','04/25','10/11','10/20','10/28','0123','0140','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('054413','CO','SEDGWICK','JULESBURG',4.098666666000000e+001,-1.022705560000000e+002,'05/19','10/13','05/28','05/19','05/09','10/04','10/13','10/26','0114','0125','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('054452','CO','JEFFERSON','KASSLER',3.949000000000000e+001,-1.050952780000000e+002,'05/28','10/12','06/07','05/28','05/09','10/06','10/12','10/29','0106','0117','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('054603','CO','CHEYENNE','KIT CARSON',3.876583333000000e+001,-1.028030560000000e+002,'05/23','10/12','06/08','05/23','05/12','10/05','10/12','10/25','0105','0123','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('054664','CO','GRAND','KREMMLING',4.005750000000000e+001,-1.063680560000000e+002,'07/10','09/20','08/03','07/10','06/17','09/01','09/20','09/28','0000','0040','0079')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('054720','CO','OTERO','LA JUNTA MUNICIPAL AP',3.804944444000000e+001,-1.035122220000000e+002,'05/09','10/25','05/17','05/09','04/24','10/14','10/25','11/06','0133','0147','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('054742','CO','PARK','LAKE GEORGE 8 SW',3.890750000000000e+001,-1.054705560000000e+002,'06/27','09/27','07/12','06/27','06/10','09/20','09/27','10/07','0042','0073','0099')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('054762','CO','JEFFERSON','LAKEWOOD',3.974888888000000e+001,-1.051205560000000e+002,'05/24','10/14','06/04','05/24','05/17','10/06','10/14','10/24','0105','0121','0139')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('054770','CO','PROWERS','LAMAR',3.809361111000000e+001,-1.026305560000000e+002,'05/15','10/18','05/23','05/15','04/27','10/10','10/18','11/02','0125','0136','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('054834','CO','BENT','LAS ANIMAS',3.806361111000000e+001,-1.032152780000000e+002,'05/15','10/21','05/25','05/15','04/28','10/11','10/21','11/01','0120','0137','0165')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('054945','CO','LOGAN','LEROY 9 WSW',4.048972222000000e+001,-1.030822220000000e+002,'05/19','10/14','05/31','05/19','05/14','10/03','10/14','10/26','0110','0127','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('055322','CO','CONEJOS','MANASSA',3.717416666000000e+001,-1.059391670000000e+002,'06/25','09/30','07/11','06/25','06/16','09/15','09/30','10/04','0036','0066','0094')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('055446','CO','MOFFAT','MAYBELL',4.051583333000000e+001,-1.080947220000000e+002,'06/28','09/24','07/14','06/28','06/12','09/13','09/24','10/01','0038','0064','0094')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('055531','CO','MONTEZUMA','MESA VERDE NP',3.719861111000000e+001,-1.084883330000000e+002,'06/06','10/27','06/14','06/06','05/26','10/15','10/27','11/06','0100','0116','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('055706','CO','RIO GRANDE','MONTE VISTA 2W',3.758111111000000e+001,-1.061872220000000e+002,'06/21','09/30','07/05','06/21','06/07','09/21','09/30','10/10','0054','0078','0109')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('055722','CO','MONTROSE','MONTROSE #2',3.848583333000000e+001,-1.078791670000000e+002,'05/22','10/21','06/10','05/22','05/07','10/09','10/21','11/05','0107','0129','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('056266','CO','MESA','PALISADE',3.911361111000000e+001,-1.083505560000000e+002,'05/14','11/06','06/02','05/14','04/21','10/30','11/06','11/18','0126','0157','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('056306','CO','DELTA','PAONIA 1 SW',3.885222222000000e+001,-1.076236110000000e+002,'06/02','10/26','06/14','06/02','05/17','10/13','10/26','11/06','0098','0122','0145')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('056740','CO','PUEBLO','PUEBLO MEM AP',3.829000000000000e+001,-1.044983330000000e+002,'05/14','10/20','05/26','05/14','05/02','10/09','10/20','10/27','0120','0134','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('056832','CO','RIO BLANCO','RANGELY 1 E',4.008944444000000e+001,-1.087716670000000e+002,'06/07','10/12','06/19','06/07','05/21','10/05','10/12','10/24','0083','0105','0125')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('057167','CO','OTERO','ROCKY FORD 2 SE',3.803916666000000e+001,-1.036933330000000e+002,'05/11','10/14','05/25','05/11','05/01','10/06','10/14','10/26','0121','0136','0158')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('057287','CO','EL PASO','RUSH 1N',3.886111111000000e+001,-1.040938890000000e+002,'06/13','10/09','06/20','06/13','05/31','10/02','10/09','10/17','0078','0088','0105')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('057309','CO','EL PASO','RUXTON PARK',3.884166666000000e+001,-1.049741670000000e+002,'07/25','09/13','08/06','07/25','06/23','08/24','09/13','09/25','0000','0025','0071')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('057515','CO','SEDGWICK','SEDGWICK 5 S',4.085916666000000e+001,-1.025166670000000e+002,'05/15','10/19','05/26','05/15','05/05','10/06','10/19','10/29','0117','0130','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('057656','CO','SAN JUAN','SILVERTON',3.780888888000000e+001,-1.076633330000000e+002,'07/31','09/12','08/06','07/31','07/18','08/16','09/12','09/24','0000','0003','0028')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('057936','CO','ROUTT','STEAMBOAT SPRINGS',4.048833333000000e+001,-1.068233330000000e+002,'07/16','09/18','08/03','07/16','06/24','09/03','09/18','09/28','0000','0035','0070')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('058008','CO','KIT CARSON','STRATTON',3.930472222000000e+001,-1.026002780000000e+002,'05/17','10/14','05/27','05/17','05/04','10/06','10/14','10/28','0114','0131','0158')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('058064','CO','LAKE','SUGARLOAF RSVR',3.924944444000000e+001,-1.063713890000000e+002,'07/27','09/10','08/04','07/27','07/02','08/18','09/10','09/26','0000','0015','0055')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('058157','CO','PUEBLO','TACONY 13 SE',3.834222222000000e+001,-1.040566670000000e+002,'05/19','10/14','05/25','05/19','05/04','10/06','10/14','10/25','0116','0128','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('058184','CO','GUNNISON','TAYLOR PARK',3.881833333000000e+001,-1.066086110000000e+002,'07/15','09/15','08/06','07/15','07/05','08/20','09/15','09/29','0000','0031','0053')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('058204','CO','SAN MIGUEL','TELLURIDE 4WNW',3.794916666000000e+001,-1.078736110000000e+002,'07/09','09/23','07/29','07/09','06/27','09/01','09/23','10/01','0010','0041','0077')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('058429','CO','LAS ANIMAS','TRINIDAD',3.717861111000000e+001,-1.044869440000000e+002,'05/23','10/17','06/03','05/23','05/10','10/10','10/17','11/01','0110','0124','0153')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('058434','CO','LAS ANIMAS','TRINIDAD AP',3.726222222000000e+001,-1.043377780000000e+002,'05/18','10/17','06/02','05/18','05/05','10/08','10/17','11/03','0114','0130','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('058501','CO','LAKE','TWIN LAKES RESERVOIR',3.909361111000000e+001,-1.063513890000000e+002,'07/14','09/23','07/28','07/14','06/27','09/04','09/23','10/06','0006','0023','0064')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('058560','CO','MONTROSE','URAVAN',3.837611111000000e+001,-1.087422220000000e+002,'05/19','10/24','06/01','05/19','04/28','10/11','10/24','11/07','0115','0139','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('058582','CO','LA PLATA','VALLECITO DAM',3.738416666000000e+001,-1.075822220000000e+002,'06/25','09/30','07/10','06/25','06/14','09/22','09/30','10/13','0051','0082','0094')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('058756','CO','JACKSON','WALDEN',4.074416666000000e+001,-1.062791670000000e+002,'07/25','09/03','08/06','07/25','07/07','08/13','09/03','09/18','0000','0011','0044')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('058781','CO','HUERFANO','WALSENBURG 1 NW',3.763027777000000e+001,-1.047955560000000e+002,'05/23','10/14','06/03','05/23','05/11','10/07','10/14','10/26','0105','0123','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('058793','CO','BACA','WALSH 1 W',3.738222222000000e+001,-1.022986110000000e+002,'05/12','10/24','05/17','05/12','05/01','10/14','10/24','11/03','0127','0146','0165')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('058839','CO','LARIMER','WATERDALE',4.042555555000000e+001,-1.052102780000000e+002,'05/18','10/09','06/15','05/18','05/10','10/03','10/09','10/24','0097','0124','0142')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('058931','CO','CUSTER','WESTCLIFFE',3.813111111000000e+001,-1.054661110000000e+002,'07/01','09/20','07/22','07/01','06/18','09/07','09/20','10/01','0019','0059','0086')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('059243','CO','YUMA','WRAY',4.005833333000000e+001,-1.022188890000000e+002,'05/20','10/16','05/26','05/20','05/07','10/02','10/16','10/24','0115','0132','0152')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('059265','CO','ROUTT','YAMPA',4.015611111000000e+001,-1.069091670000000e+002,'07/04','09/26','07/22','07/04','06/21','09/13','09/26','10/03','0024','0055','0079')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('059295','CO','YUMA','YUMA',4.012361111000000e+001,-1.027216670000000e+002,'05/16','10/18','05/31','05/16','05/03','10/04','10/18','10/27','0108','0128','0158')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('060806','CT','FAIRFIELD','BRIDGEPORT SIKORSKY AP',4.115833333000000e+001,-7.312888900000000e+001,'04/22','11/19','05/01','04/22','04/07','11/01','11/19','12/05','0161','0189','0216')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('060973','CT','HARTFORD','BURLINGTON',4.179444444000000e+001,-7.293194400000000e+001,'05/18','10/24','05/26','05/18','05/04','10/08','10/24','11/06','0125','0138','0159')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('061762','CT','FAIRFIELD','DANBURY',4.140000000000000e+001,-7.341666700000000e+001,'05/15','10/22','05/26','05/15','04/29','10/07','10/22','11/08','0119','0140','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('062658','CT','LITCHFIELD','FALLS VILLAGE',4.195000000000000e+001,-7.336666700000001e+001,'06/01','10/11','06/17','06/01','05/14','09/29','10/11','10/23','0085','0113','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('063207','CT','NEW LONDON','GROTON',4.135111111000000e+001,-7.203888900000000e+001,'04/28','11/03','05/18','04/28','04/20','10/22','11/03','11/20','0139','0163','0190')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('063456','CT','HARTFORD','HARTFORD',4.193805555000000e+001,-7.268250000000001e+001,'05/10','10/22','05/22','05/10','04/22','10/12','10/22','11/07','0128','0146','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('065445','CT','LITCHFIELD','NORFOLK 2 SW',4.197250000000000e+001,-7.322083300000000e+001,'05/23','10/19','06/07','05/23','05/08','10/03','10/19','10/30','0101','0130','0153')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('065910','CT','NEW LONDON','NORWICH PUB UTIL PLT',4.152694444000000e+001,-7.206416700000000e+001,'05/10','10/22','05/27','05/10','04/26','10/10','10/22','11/07','0125','0150','0171')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('067373','CT','LITCHFIELD','SHEPAUG DAM',4.171666666000000e+001,-7.330000000000000e+001,'05/18','10/19','06/07','05/18','05/02','10/08','10/19','10/31','0109','0136','0156')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('067970','CT','FAIRFIELD','STAMFORD 5 N',4.112472222000000e+001,-7.354750000000000e+001,'05/11','10/23','05/25','05/11','04/26','10/12','10/23','11/08','0126','0149','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('068138','CT','TOLLAND','STORRS',4.179500000000000e+001,-7.222861100000000e+001,'05/09','11/02','05/23','05/09','04/27','10/13','11/02','11/15','0131','0148','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('069388','CT','WINDHAM','WEST THOMPSON LAKE',4.194416666000000e+001,-7.190305600000001e+001,'05/25','10/13','06/06','05/25','05/07','10/04','10/13','10/25','0102','0129','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('072730','DE','KENT','DOVER',3.925833333000000e+001,-7.551666700000000e+001,'04/20','11/16','05/01','04/20','04/10','11/01','11/16','11/28','0159','0184','0208')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('075320','DE','SUSSEX','LEWES',3.877555555000000e+001,-7.513888900000001e+001,'04/20','11/19','04/30','04/20','04/10','11/11','11/19','12/09','0166','0188','0211')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('076410','DE','NEW CASTLE','NEWARK UNIV FARM',3.966944444000000e+001,-7.575138900000000e+001,'04/29','11/07','05/14','04/29','04/20','10/24','11/07','11/23','0144','0169','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('079595','DE','NEW CASTLE','WILMINGTON NEW CASTLE CO AP',3.967277777000000e+001,-7.560083299999999e+001,'04/21','11/14','05/07','04/21','04/14','10/30','11/14','11/24','0152','0185','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('080211','FL','FRANKLIN','APALACHICOLA AIRPORT',2.972583333000000e+001,-8.502055600000000e+001,'03/12','01/12','03/28','03/12','02/23','12/21','01/12','00/00','0236','0267','0295')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('080228','FL','DESOTO','ARCADIA',2.721805555000000e+001,-8.187388900000001e+001,'03/10','00/00','03/23','03/10','02/19','01/20','00/00','00/00','0247','0289','0313')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('080236','FL','HIGHLANDS','ARCHBOLD BIO STN',2.718194444000000e+001,-8.135083299999999e+001,'03/31','01/13','04/17','03/31','03/15','01/04','01/13','00/00','0228','0259','0293')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('080369','FL','HIGHLANDS','AVON PARK 2 W',2.759472222000000e+001,-8.152666700000000e+001,'03/04','00/00','03/27','03/04','02/15','01/19','00/00','00/00','0255','0291','0321')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('080478','FL','POLK','BARTOW',2.789861111000000e+001,-8.184333300000000e+001,'02/25','00/00','03/13','02/25','02/06','02/01','00/00','00/00','0273','0299','0330')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('080945','FL','MANATEE','BRADENTON 5 ESE',2.744666666000000e+001,-8.250138900000000e+001,'02/22','00/00','03/11','02/22','02/02','02/02','00/00','00/00','0276','0306','0336')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('081046','FL','HERNANDO','BROOKSVILLE CHIN HILL',2.861638888000000e+001,-8.236583300000000e+001,'03/07','01/25','03/20','03/07','02/20','01/09','01/25','00/00','0256','0284','0317')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('081163','FL','SUMTER','BUSHNELL 1 E',2.866638888000000e+001,-8.208944400000000e+001,'03/19','01/11','03/29','03/19','03/03','12/24','01/11','02/14','0233','0262','0291')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('081276','FL','PALM BEACH','CANAL POINT USDA',2.686388888000000e+001,-8.062555600000000e+001,'02/01','00/00','02/26','02/01','00/00','00/00','00/00','00/00','0325','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('081544','FL','WASHINGTON','CHIPLEY',3.078361111000000e+001,-8.548472200000001e+001,'03/23','12/07','04/15','03/23','03/09','11/20','12/07','12/28','0197','0229','0263')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('081641','FL','LAKE','CLERMONT 9 S',2.845527777000000e+001,-8.172333300000000e+001,'02/28','00/00','03/15','02/28','02/13','01/18','00/00','00/00','0268','0302','0318')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('081978','FL','PUTNAM','CRESCENT CITY',2.942916666000000e+001,-8.151583300000000e+001,'03/08','02/16','03/21','03/08','02/16','01/20','02/16','00/00','0266','0286','0320')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('081986','FL','OKALOOSA','CRESTVIEW BOB SIKES AP',3.077972222000000e+001,-8.652249999999999e+001,'04/07','12/15','04/22','04/07','03/17','11/25','12/15','12/28','0181','0214','0247')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('082008','FL','DIXIE','CROSS CITY 1 E',2.963333333000000e+001,-8.310527800000000e+001,'03/29','12/14','04/15','03/29','03/09','12/07','12/14','01/22','0200','0230','0266')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('082158','FL','VOLUSIA','DAYTONA BEACH INTL AP',2.918277777000000e+001,-8.104833300000000e+001,'03/08','02/07','03/20','03/08','02/12','01/10','02/07','00/00','0257','0288','0329')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('082229','FL','VOLUSIA','DELAND 1 SSE',2.901805555000000e+001,-8.131055600000001e+001,'03/27','01/21','04/10','03/27','03/05','12/25','01/21','00/00','0216','0253','0290')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('082298','FL','HENDRY','DEVILS GARDEN',2.660333333000000e+001,-8.112916700000000e+001,'03/09','00/00','03/20','03/09','02/22','02/07','00/00','00/00','0273','0303','0326')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('082850','FL','COLLIER','EVERGLADES',2.584888888000000e+001,-8.138972200000001e+001,'01/31','00/00','02/21','01/31','01/18','00/00','00/00','00/00','0309','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('082915','FL','PUTNAM','FEDERAL POINT',2.975500000000000e+001,-8.153888900000000e+001,'03/06','02/04','03/22','03/06','02/23','01/06','02/04','00/00','0252','0283','0312')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('083020','FL','MONROE','FLAMINGO RS',2.514222222000000e+001,-8.091444400000000e+001,'01/25','00/00','02/25','01/25','00/00','00/00','00/00','00/00','0319','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('083163','FL','BROWARD','FT LAUDERDALE',2.610194444000000e+001,-8.020111100000000e+001,'01/24','00/00','02/11','01/24','00/00','00/00','00/00','00/00','0338','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('083186','FL','LEE','FT MYERS PAGE FLD AP',2.658500000000000e+001,-8.186138900000000e+001,'01/29','00/00','02/20','01/29','00/00','00/00','00/00','00/00','0313','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('083207','FL','ST. LUCIE','FT PIERCE',2.744166666000000e+001,-8.035083299999999e+001,'02/26','00/00','03/15','02/26','02/06','02/22','00/00','00/00','0278','0315','0347')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('083326','FL','ALACHUA','GAINESVILLE RGNL AP',2.969194444000000e+001,-8.227555600000000e+001,'03/12','12/31','04/09','03/12','02/25','12/20','12/31','02/14','0222','0261','0285')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('083470','FL','BAKER','GLEN ST MARY 1 W',3.027166666000000e+001,-8.218555600000001e+001,'03/26','12/15','04/13','03/26','03/08','12/03','12/15','01/18','0204','0235','0269')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('083909','FL','MIAMI-DADE','HIALEAH',2.581750000000000e+001,-8.028583300000000e+001,'01/26','00/00','02/06','01/26','00/00','00/00','00/00','00/00','9999','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('083956','FL','ALACHUA','HIGH SPRINGS',2.982861111000000e+001,-8.259722200000000e+001,'03/27','12/21','04/11','03/27','03/12','12/09','12/21','01/16','0203','0233','0261')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('084289','FL','CITRUS','INVERNESS 3 SE',2.880277777000000e+001,-8.231250000000000e+001,'03/20','01/19','04/06','03/20','02/25','12/26','01/19','00/00','0222','0258','0294')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('084358','FL','DUVAL','JACKSONVILLE INTL AP',3.049500000000000e+001,-8.169361100000000e+001,'03/21','12/24','03/30','03/21','03/04','12/10','12/24','01/27','0221','0248','0283')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('084366','FL','DUVAL','JACKSONVILLE BEACH',3.028750000000000e+001,-8.139277800000001e+001,'03/03','02/04','03/12','03/03','03/01','01/10','02/04','00/00','0259','0287','0305')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('084394','FL','HAMILTON','JASPER',3.052277777000000e+001,-8.294472200000000e+001,'03/25','12/14','04/12','03/25','03/10','11/27','12/14','01/09','0202','0230','0266')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('084570','FL','MONROE','KEY WEST INTL AP',2.455500000000000e+001,-8.175222200000000e+001,'00/00','00/00','00/00','00/00','00/00','00/00','00/00','00/00','9999','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('084625','FL','OSCEOLA','KISSIMMEE 2',2.827638888000000e+001,-8.142388900000000e+001,'02/26','00/00','03/15','02/26','02/09','01/28','00/00','00/00','0275','0307','0331')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('084662','FL','HENDRY','LA BELLE',2.674583333000000e+001,-8.142638900000000e+001,'03/11','00/00','03/20','03/11','02/17','01/25','00/00','00/00','0273','0300','0328')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('084731','FL','COLUMBIA','LAKE CITY 2 E',3.018527777000000e+001,-8.259416700000000e+001,'03/21','12/18','04/10','03/21','03/06','12/09','12/18','01/23','0206','0243','0278')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('085076','FL','LAKE','LISBON',2.887277777000000e+001,-8.178444399999999e+001,'03/05','02/02','03/17','03/05','02/13','01/11','02/02','00/00','0262','0283','0326')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('085099','FL','SUWANNEE','LIVE OAK',3.028888888000000e+001,-8.296500000000000e+001,'03/29','12/12','04/14','03/29','03/15','12/02','12/12','01/10','0203','0225','0267')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('085275','FL','MADISON','MADISON',3.046527777000000e+001,-8.340222200000000e+001,'03/14','12/20','04/11','03/14','03/07','12/09','12/20','01/21','0207','0247','0273')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('085539','FL','LAFAYETTE','MAYO',3.010638888000000e+001,-8.318194400000000e+001,'03/26','12/13','04/14','03/26','03/10','11/28','12/13','01/03','0204','0229','0271')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('085612','FL','BREVARD','MELBOURNE WFO',2.811361111000000e+001,-8.065388900000001e+001,'02/23','00/00','03/14','02/23','02/07','02/07','00/00','00/00','0283','0318','0350')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('085658','FL','DADE','MIAMI BEACH',2.580638888000000e+001,-8.013361100000000e+001,'00/00','00/00','01/24','00/00','00/00','00/00','00/00','00/00','9999','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('085663','FL','MIAMI-DADE','MIAMI INTL AP',2.579055555000000e+001,-8.031638900000000e+001,'01/16','00/00','01/27','01/16','00/00','00/00','00/00','00/00','9999','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('085895','FL','GLADES','MOORE HAVEN LOCK 1',2.684000000000000e+001,-8.108722200000000e+001,'02/17','00/00','03/05','02/17','01/28','00/00','00/00','00/00','0294','0332','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('085973','FL','POLK','MTN LAKE',2.793777777000000e+001,-8.159916699999999e+001,'03/10','02/10','03/23','03/10','02/21','01/17','02/10','00/00','0255','0284','0309')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('086065','FL','SARASOTA','MYAKKA RIVER SP',2.724166666000000e+001,-8.231611100000001e+001,'03/07','00/00','03/19','03/07','02/11','01/14','00/00','00/00','0265','0293','0334')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('086078','FL','COLLIER','NAPLES',2.616861111000000e+001,-8.171583300000000e+001,'02/03','00/00','03/01','02/03','01/17','00/00','00/00','00/00','0308','0337','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('086240','FL','OKALOOSA','NICEVILLE',3.053166666000000e+001,-8.649277800000000e+001,'04/02','12/06','04/17','04/02','03/22','11/22','12/06','01/06','0195','0226','0251')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('086414','FL','MARION','OCALA',2.916361111000000e+001,-8.207777800000000e+001,'03/21','01/11','04/06','03/21','03/08','12/22','01/11','02/15','0213','0243','0278')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('086880','FL','MANATEE','PARRISH',2.760888888000000e+001,-8.234777800000001e+001,'03/01','00/00','03/17','03/01','02/04','01/16','00/00','00/00','0272','0304','0338')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('086997','FL','ESCAMBIA','PENSACOLA RGNL AP',3.047805555000000e+001,-8.718694400000000e+001,'03/13','01/07','03/27','03/13','03/02','12/18','01/07','02/02','0231','0262','0287')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('087025','FL','TAYLOR','PERRY',3.009861111000000e+001,-8.357416700000000e+001,'04/04','12/10','04/19','04/04','03/15','12/02','12/10','12/28','0200','0218','0252')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('087205','FL','HILLSBOROUGH','PLANT CITY',2.802361111000000e+001,-8.214222200000000e+001,'03/08','02/09','03/28','03/08','02/14','01/18','02/09','00/00','0246','0283','0320')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('087397','FL','CHARLOTTE','PUNTA GORDA 4 ESE',2.691638888000000e+001,-8.199833300000000e+001,'02/13','00/00','03/06','02/13','01/26','02/12','00/00','00/00','0294','0321','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('087429','FL','GADSDEN','QUINCY 3 SSW',3.054972222000000e+001,-8.458361100000001e+001,'03/20','12/17','04/13','03/20','03/14','12/06','12/17','01/23','0211','0241','0266')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('087760','FL','MIAMI-DADE','ROYAL PALM RS',2.538666666000000e+001,-8.059361100000000e+001,'01/31','00/00','02/07','01/31','00/00','00/00','00/00','00/00','0338','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('087851','FL','PASCO','SAINT LEO',2.833777777000000e+001,-8.226000000000001e+001,'03/01','02/08','03/08','03/01','02/12','01/07','02/08','00/00','0271','0299','0325')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('087886','FL','PINELLAS','ST PETERSBURG',2.776277777000000e+001,-8.262611100000000e+001,'01/27','00/00','02/14','01/27','12/29','00/00','00/00','00/00','0325','0365','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('087982','FL','SEMINOLE','SANFORD',2.881472222000000e+001,-8.127777800000000e+001,'03/05','00/00','03/16','03/05','02/10','01/23','00/00','00/00','0269','0292','0332')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('088620','FL','MARTIN','STUART',2.718972222000000e+001,-8.023972200000000e+001,'02/23','00/00','03/03','02/23','02/15','00/00','00/00','00/00','0310','0320','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('088758','FL','LEON','TALLAHASSEE WSO AP',3.039305555000000e+001,-8.435333300000001e+001,'04/10','12/10','04/24','04/10','03/23','11/18','12/10','12/22','0184','0206','0243')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('088780','FL','MIAMI-DADE','TAMIAMI TRL 40 MI BEND',2.576083333000000e+001,-8.082416700000000e+001,'01/14','00/00','02/13','01/14','00/00','00/00','00/00','00/00','0335','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('088788','FL','HILLSBOROUGH','TAMPA INTL AP',2.796194444000000e+001,-8.254027800000000e+001,'02/22','00/00','03/09','02/22','01/27','01/27','00/00','00/00','0280','0312','0365')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('088824','FL','PINELLAS','TARPON SPGS SEWAGE PL',2.815222222000000e+001,-8.275388900000000e+001,'02/26','00/00','03/15','02/26','01/28','01/06','00/00','00/00','0275','0303','0346')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('088841','FL','MONROE','TAVERNIER',2.500694444000000e+001,-8.052111100000001e+001,'00/00','00/00','01/05','00/00','00/00','00/00','00/00','00/00','9999','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('088942','FL','BREVARD','TITUSVILLE',2.862416666000000e+001,-8.081583300000000e+001,'03/04','00/00','03/13','03/04','02/21','01/19','00/00','00/00','0280','0296','0320')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('089120','FL','LEVY','USHER TWR',2.940833333000000e+001,-8.281861100000000e+001,'03/31','12/20','04/07','03/31','03/07','12/07','12/20','01/31','0209','0227','0267')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('089176','FL','SARASOTA','VENICE',2.710055555000000e+001,-8.243638900000001e+001,'02/09','00/00','02/28','02/09','01/26','00/00','00/00','00/00','0294','0335','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('089214','FL','INDIAN RIVER','VERO BEACH INTL AP',2.765305555000000e+001,-8.024277800000000e+001,'02/21','00/00','03/17','02/21','02/03','00/00','00/00','00/00','0290','0317','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('089219','FL','INDIAN RIVER','VERO BEACH 4SE',2.765277777000000e+001,-8.040305600000001e+001,'02/23','00/00','03/09','02/23','01/28','02/13','00/00','00/00','0289','0313','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('089401','FL','HARDEE','WAUCHULA',2.754777777000000e+001,-8.179944399999999e+001,'03/05','00/00','03/26','03/05','02/17','01/14','00/00','00/00','0258','0293','0316')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('089430','FL','HERNANDO','WEEKI WACHEE',2.851750000000000e+001,-8.257555600000001e+001,'03/19','01/20','04/01','03/19','02/28','01/04','01/20','00/00','0231','0261','0296')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('089525','FL','PALM BEACH','WEST PALM BCH INTL AP',2.668472222000000e+001,-8.009944400000001e+001,'02/08','00/00','02/24','02/08','00/00','00/00','00/00','00/00','0315','9999','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('089566','FL','GULF','WEWAHITCHKA',3.011916666000000e+001,-8.520416700000000e+001,'03/18','12/26','04/08','03/18','03/07','12/09','12/26','01/21','0208','0248','0279')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('090140','GA','DOUGHERTY','ALBANY 3 SE',3.153388888000000e+001,-8.414888900000000e+001,'04/11','12/02','04/26','04/11','03/22','11/20','12/02','12/19','0176','0204','0237')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('090181','GA','BARTOW','ALLATOONA DAM 2',3.416500000000000e+001,-8.473000000000000e+001,'04/17','11/18','04/28','04/17','04/06','11/05','11/18','12/07','0171','0195','0210')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('090211','GA','BACON','ALMA BACON CO AP',3.153583333000000e+001,-8.250666699999999e+001,'03/24','12/19','04/12','03/24','03/10','11/28','12/19','01/19','0202','0232','0268')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('090253','GA','SUMTER','AMERICUS',3.206027777000000e+001,-8.423222199999999e+001,'04/09','12/02','04/19','04/09','03/22','11/14','12/02','12/26','0189','0208','0243')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('090311','GA','COLUMBIA','APPLING 2 NW',3.356194444000000e+001,-8.233888900000000e+001,'04/26','11/12','05/10','04/26','04/16','10/30','11/12','12/03','0153','0175','0202')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('090406','GA','TURNER','ASHBURN 3 ENE',3.170027777000000e+001,-8.362305600000001e+001,'03/24','12/13','04/07','03/24','03/09','11/23','12/13','01/10','0205','0236','0270')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('090435','GA','CLARKE','ATHENS BEN EPPS AP',3.394805555000000e+001,-8.332750000000000e+001,'04/08','11/24','04/24','04/08','03/27','11/17','11/24','12/12','0183','0203','0243')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('090451','GA','FULTON','ATLANTA HARTSFIELD AP',3.363000000000000e+001,-8.444166700000000e+001,'04/14','12/01','04/18','04/14','03/26','11/18','12/01','01/02','0189','0208','0244')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('090495','GA','RICHMOND','AUGUSTA BUSH FLD AP',3.336444444000000e+001,-8.196333300000001e+001,'04/15','11/24','04/27','04/15','04/02','11/03','11/24','12/11','0174','0196','0227')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('090969','GA','UNION','BLAIRSVILLE EXP STN',3.485444444000000e+001,-8.394444400000000e+001,'05/20','10/22','05/24','05/20','05/03','10/17','10/22','11/03','0129','0138','0165')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('091266','GA','BULLOCH','BROOKLET 1 W',3.237500000000000e+001,-8.167305600000000e+001,'03/30','12/04','04/14','03/30','03/11','11/27','12/04','12/31','0195','0227','0264')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('091340','GA','GLYNN','BRUNSWICK',3.116805555000000e+001,-8.150222200000000e+001,'03/16','01/03','04/04','03/16','03/05','12/17','01/03','00/00','0225','0259','0287')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('091345','GA','GLYNN','BRUNSWICK-MCKINNON AP',3.115222222000000e+001,-8.139083300000000e+001,'03/09','01/15','03/19','03/09','03/02','12/20','01/15','02/15','0241','0272','0298')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('091500','GA','MITCHELL','CAMILLA 3SE',3.119027777000000e+001,-8.420361100000000e+001,'03/26','12/10','04/12','03/26','03/15','11/18','12/10','01/06','0193','0231','0259')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('091640','GA','CARROLL','CARROLLTON',3.359722222000000e+001,-8.508055600000000e+001,'04/26','11/18','05/12','04/26','04/10','10/30','11/18','12/02','0153','0177','0206')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('091665','GA','BARTOW','CARTERSVILLE',3.420416666000000e+001,-8.479250000000000e+001,'04/23','11/07','05/08','04/23','04/09','10/31','11/07','11/23','0154','0174','0205')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('091732','GA','POLK','CEDARTOWN',3.405888888000000e+001,-8.523388900000001e+001,'04/22','11/09','05/03','04/22','04/12','10/27','11/09','11/26','0160','0178','0212')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('091982','GA','RABUN','CLAYTON 1 SSW',3.486194444000000e+001,-8.340638900000000e+001,'05/17','11/01','05/22','05/17','04/28','10/20','11/01','11/15','0133','0146','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('092153','GA','MILLER','COLQUITT 2 W',3.116805555000000e+001,-8.476638900000000e+001,'03/28','12/08','04/15','03/28','03/11','11/23','12/08','01/01','0193','0229','0261')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('092166','GA','MUSCOGEE','COLUMBUS METO AP',3.251611111000000e+001,-8.494222200000000e+001,'03/28','12/06','04/16','03/28','03/12','11/27','12/06','01/08','0200','0230','0267')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('092180','GA','BANKS','COMMERCE 4 NNW',3.426250000000000e+001,-8.348944400000001e+001,'04/20','11/17','05/04','04/20','04/06','11/02','11/17','12/03','0163','0185','0215')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('092266','GA','CRISP','CORDELE',3.198500000000000e+001,-8.377472200000000e+001,'03/30','12/02','04/17','03/30','03/13','11/23','12/02','12/28','0189','0223','0253')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('092283','GA','HABERSHAM','CORNELIA',3.451805555000000e+001,-8.352861100000000e+001,'05/05','11/13','05/15','05/05','04/16','10/28','11/13','11/28','0141','0162','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('092318','GA','NEWTON','COVINGTON',3.359722222000000e+001,-8.384361100000000e+001,'04/20','12/02','04/26','04/20','03/31','11/12','12/02','12/12','0173','0195','0232')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('092450','GA','RANDOLPH','CUTHBERT',3.176722222000000e+001,-8.479305600000001e+001,'03/28','12/04','04/11','03/28','03/13','11/30','12/04','01/07','0210','0230','0264')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('092485','GA','PAULDING','DALLAS 7 NE',3.398805555000000e+001,-8.474750000000000e+001,'04/24','11/08','05/06','04/24','04/14','10/26','11/08','11/26','0160','0177','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('092783','GA','COFFEE','DOUGLAS',3.148888888000000e+001,-8.282055600000000e+001,'03/26','12/06','04/13','03/26','03/11','11/28','12/06','12/28','0198','0229','0256')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('092966','GA','DODGE','EASTMAN 1 W',3.220027777000000e+001,-8.320583300000000e+001,'03/30','12/06','04/16','03/30','03/13','11/27','12/06','12/31','0194','0225','0253')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('093060','GA','ELBERT','ELBERTON 2 N',3.414055555000000e+001,-8.285500000000000e+001,'05/03','11/03','05/15','05/03','04/16','10/23','11/03','11/22','0145','0167','0195')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('093465','GA','CHARLTON','FOLKSTON 9 SW',3.074000000000000e+001,-8.212777800000001e+001,'03/27','12/16','04/07','03/27','03/14','12/01','12/16','01/08','0212','0234','0263')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('093538','GA','LIBERTY','FT STEWART',3.187166666000000e+001,-8.162888900000000e+001,'03/22','12/15','04/07','03/22','03/08','11/29','12/15','01/20','0215','0240','0272')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('093621','GA','HALL','GAINESVILLE',3.430055555000000e+001,-8.386000000000000e+001,'04/18','11/28','04/29','04/18','04/05','11/14','11/28','12/19','0173','0201','0222')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('093754','GA','TATTNALL','GLENNVILLE 3NW',3.198805555000000e+001,-8.195222200000001e+001,'03/24','12/13','04/06','03/24','03/07','11/30','12/13','01/11','0216','0239','0272')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('094133','GA','HART','HARTWELL',3.435194444000000e+001,-8.293000000000001e+001,'04/09','12/01','04/27','04/09','03/25','11/20','12/01','12/12','0181','0209','0235')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('094170','GA','PULASKI','HAWKINSVILLE',3.228416666000000e+001,-8.346805600000000e+001,'04/04','12/01','04/20','04/04','03/19','11/15','12/01','12/24','0182','0214','0236')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('094230','GA','WHITE','HELEN',3.469972222000000e+001,-8.372611100000000e+001,'05/08','11/07','05/20','05/08','04/21','10/20','11/07','11/17','0135','0159','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('094429','GA','CLINCH','HOMERVILLE 5 N',3.107666666000000e+001,-8.280027800000001e+001,'04/02','11/29','04/20','04/02','03/13','11/17','11/29','12/26','0189','0219','0251')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('094594','GA','WILKINSON','IRWINTON 4 WNW',3.282944444000000e+001,-8.323888900000000e+001,'04/09','12/02','04/27','04/09','03/23','11/24','12/02','12/23','0181','0212','0250')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('094648','GA','PICKENS','JASPER 1 NNW',3.447583333000000e+001,-8.444611100000000e+001,'05/01','11/15','05/14','05/01','04/12','11/02','11/15','12/01','0146','0171','0200')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('094676','GA','WAYNE','JESUP 8 S',3.150750000000000e+001,-8.186277800000001e+001,'04/02','12/02','04/21','04/02','03/21','11/18','12/02','12/31','0181','0215','0239')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('094941','GA','WALKER','LAFAYETTE 3SW',3.466388888000000e+001,-8.532027800000000e+001,'04/29','11/07','05/12','04/29','04/14','10/23','11/07','11/27','0149','0172','0203')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('094949','GA','TROUP','LA GRANGE 1N',3.305361111000000e+001,-8.503166700000000e+001,'04/18','11/16','04/27','04/18','04/05','11/01','11/16','12/05','0170','0189','0225')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('095314','GA','JEFFERSON','LOUISVILLE 1 E',3.301250000000000e+001,-8.239138900000000e+001,'04/14','11/29','04/20','04/14','03/19','11/11','11/29','12/13','0184','0202','0244')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('095443','GA','BIBB','MACON MIDDLE GA AP',3.268472222000000e+001,-8.365277800000000e+001,'04/07','11/25','04/20','04/07','03/17','11/13','11/25','12/17','0183','0212','0252')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('095863','GA','BURKE','MIDVILLE EXP STN',3.287527777000000e+001,-8.221555600000001e+001,'04/02','12/01','04/20','04/02','03/17','11/14','12/01','12/12','0179','0213','0245')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('095874','GA','BALDWIN','MILLEDGEVILLE',3.308305555000000e+001,-8.324972200000001e+001,'04/18','11/21','04/29','04/18','04/01','11/04','11/21','12/06','0171','0198','0223')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('095988','GA','JASPER','MONTICELLO',3.333277777000000e+001,-8.369750000000001e+001,'04/11','11/28','04/21','04/11','03/23','11/18','11/28','12/17','0184','0202','0234')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('096087','GA','COLQUITT','MOULTRIE 2 ESE',3.117694444000000e+001,-8.374916700000000e+001,'03/25','12/23','04/06','03/25','03/10','11/27','12/23','01/07','0212','0234','0267')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('096219','GA','BRANTLEY','NAHUNTA 6NE',3.127388888000000e+001,-8.191972199999999e+001,'04/05','12/08','04/17','04/05','03/15','11/23','12/08','01/01','0193','0220','0256')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('096335','GA','COWETA','NEWNAN 5N',3.345444444000000e+001,-8.481777800000000e+001,'04/17','11/21','04/28','04/17','04/04','11/02','11/21','12/01','0169','0191','0219')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('097087','GA','SUMTER','PLAINS SW GA EXP STN',3.204666666000000e+001,-8.437111100000000e+001,'04/03','12/04','04/20','04/03','03/16','11/14','12/04','12/21','0189','0217','0247')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('097600','GA','FLOYD','ROME',3.424527777000000e+001,-8.515138900000000e+001,'04/21','11/12','05/03','04/21','04/08','10/30','11/12','11/27','0166','0179','0207')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('097777','GA','WASHINGTON','SANDERSVILLE',3.297444444000000e+001,-8.280444400000000e+001,'04/11','11/29','04/23','04/11','03/30','11/10','11/29','12/21','0177','0205','0234')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('097808','GA','MCINTOSH','SAPELO ISLAND',3.139722222000000e+001,-8.128111100000000e+001,'03/18','01/03','04/01','03/18','03/06','12/10','01/03','02/10','0229','0253','0286')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('097847','GA','CHATHAM','SAVANNAH INTL AP',3.213000000000000e+001,-8.120999999999999e+001,'03/20','12/14','04/11','03/20','03/08','11/27','12/14','01/18','0206','0238','0267')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('098064','GA','GREENE','SILOAM 3N',3.356361111000000e+001,-8.307666700000000e+001,'04/18','11/24','04/30','04/18','04/04','11/08','11/24','12/06','0170','0196','0227')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('098535','GA','TALBOT','TALBOTTON',3.268750000000000e+001,-8.451972200000000e+001,'04/20','11/16','05/04','04/20','04/03','10/31','11/16','12/04','0162','0186','0217')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('098661','GA','UPSON','THOMASTON',3.290277777000000e+001,-8.433666700000001e+001,'04/13','11/24','04/24','04/13','03/26','11/09','11/24','12/09','0183','0202','0236')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('098666','GA','THOMAS','THOMASVILLE 7 NE',3.091388888000000e+001,-8.386111099999999e+001,'03/22','12/16','04/10','03/22','03/09','11/29','12/16','01/09','0210','0240','0271')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('098703','GA','TIFT','TIFTON',3.144611111000000e+001,-8.347666700000001e+001,'03/21','12/17','04/08','03/21','03/09','12/01','12/17','01/10','0211','0242','0265')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('098740','GA','STEPHENS','TOCCOA',3.457861111000000e+001,-8.333194399999999e+001,'04/18','11/27','05/07','04/18','04/10','11/11','11/27','12/06','0161','0190','0213')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('098950','GA','OCONEE','U OF GA PLT SCI',3.387222222000000e+001,-8.353583300000000e+001,'04/13','11/22','04/25','04/13','04/03','11/09','11/22','12/08','0175','0200','0229')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('099141','GA','WARREN','WARRENTON',3.340277777000000e+001,-8.262222199999999e+001,'04/14','11/25','04/21','04/14','04/01','11/13','11/25','12/08','0184','0200','0237')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('099157','GA','WILKES','WASHINGTON 2 ESE',3.372638888000000e+001,-8.270583300000000e+001,'04/18','11/30','04/29','04/18','04/04','11/07','11/30','12/09','0176','0194','0226')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('099186','GA','PIERCE','WAYCROSS 4 NE',3.125138888000000e+001,-8.231277799999999e+001,'04/08','11/28','04/25','04/08','03/29','11/19','11/28','01/02','0179','0206','0237')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('099194','GA','BURKE','WAYNESBORO 2 S',3.307250000000000e+001,-8.200611100000000e+001,'04/19','11/21','04/27','04/19','03/31','11/05','11/21','12/04','0175','0189','0228')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('099291','GA','TROUP','WEST POINT',3.286944444000000e+001,-8.518916700000000e+001,'04/09','11/29','04/23','04/09','03/24','11/11','11/29','12/15','0178','0207','0237')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('100010','ID','BINGHAM','ABERDEEN EXP STN',4.295361111000000e+001,-1.128252780000000e+002,'06/24','09/24','07/10','06/24','05/23','09/14','09/24','10/06','0042','0075','0116')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('100375','ID','BUTTE','ARCO',4.363555555000000e+001,-1.132988890000000e+002,'06/30','09/23','07/16','06/30','06/07','09/17','09/23','10/05','0037','0063','0095')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('100470','ID','FREMONT','ASHTON 1N',4.404250000000000e+001,-1.112738890000000e+002,'06/29','09/26','07/16','06/29','06/14','09/14','09/26','10/09','0034','0066','0094')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('100528','ID','SHOSHONE','AVERY RS #2',4.725250000000000e+001,-1.159205560000000e+002,'06/09','10/10','07/04','06/09','05/16','10/02','10/10','10/28','0062','0093','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('100667','ID','KOOTENAI','BAYVIEW MODEL BASIN',4.798027777000000e+001,-1.165594440000000e+002,'06/14','10/06','07/07','06/14','05/18','09/21','10/06','10/21','0050','0085','0124')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('100915','ID','BINGHAM','BLACKFOOT FIRE DEPT',4.319694444000000e+001,-1.123530560000000e+002,'06/15','10/04','06/29','06/15','05/23','09/23','10/04','10/16','0062','0090','0124')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('101018','ID','ADA','BOISE LUCKY PEAK DAM',4.352527777000000e+001,-1.160541670000000e+002,'05/22','10/23','06/13','05/22','04/30','10/11','10/23','11/10','0098','0132','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('101022','ID','ADA','BOISE AIR TERMINAL',4.356666666000000e+001,-1.162405560000000e+002,'05/30','10/21','06/18','05/30','05/13','10/08','10/21','11/04','0087','0120','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('101079','ID','BOUNDARY','BONNERS FERRY',4.869277777000000e+001,-1.163102780000000e+002,'06/10','10/08','06/29','06/10','05/09','09/29','10/08','10/18','0063','0096','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('101180','ID','ADAMS','BROWNLEE DAM',4.483638888000000e+001,-1.168980560000000e+002,'05/06','11/17','05/21','05/06','04/08','10/31','11/17','12/02','0136','0170','0206')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('101195','ID','OWYHEE','BRUNEAU',4.288194444000000e+001,-1.158016670000000e+002,'05/19','10/20','06/12','05/19','05/10','10/03','10/20','10/30','0100','0130','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('101303','ID','CASSIA','BURLEY MUNI AP',4.254166666000000e+001,-1.137661110000000e+002,'05/22','10/16','06/24','05/22','05/14','10/02','10/16','10/29','0076','0119','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('101363','ID','BONNER','CABINET GORGE',4.808638888000000e+001,-1.160572220000000e+002,'05/29','10/16','06/25','05/29','05/12','10/02','10/16','11/06','0074','0114','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('101408','ID','WASHINGTON','CAMBRIDGE',4.457333333000000e+001,-1.166752780000000e+002,'06/18','10/07','06/30','06/18','05/19','09/25','10/07','10/20','0064','0094','0131')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('101514','ID','VALLEY','CASCADE 1 NW',4.452277777000000e+001,-1.160480560000000e+002,'07/15','09/14','07/28','07/15','07/03','09/05','09/14','09/27','0015','0038','0065')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('101551','ID','TWIN FALLS','CASTLEFORD 2 N',4.255027777000000e+001,-1.148661110000000e+002,'06/07','10/08','06/25','06/07','05/17','09/29','10/08','10/27','0078','0104','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('101671','ID','CUSTER','CHILLY BARTON FLAT',4.397722222000000e+001,-1.138288890000000e+002,'07/12','09/16','07/23','07/12','06/25','09/03','09/16','09/28','0019','0046','0076')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('101956','ID','KOOTENAI','COEUR D''ALENE',4.768222222000000e+001,-1.167966670000000e+002,'05/22','10/18','06/09','05/22','05/05','10/04','10/18','11/11','0099','0129','0159')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('102187','ID','ADAMS','COUNCIL',4.474416666000000e+001,-1.164325000000000e+002,'06/12','10/12','07/05','06/12','05/16','09/28','10/12','10/22','0067','0107','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('102260','ID','BUTTE','CRATERS OF THE MOON',4.346500000000000e+001,-1.135580560000000e+002,'06/30','10/01','07/10','06/30','06/13','09/24','10/01','10/09','0048','0071','0104')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('102444','ID','CANYON','DEER FLAT DAM',4.357638888000000e+001,-1.167475000000000e+002,'05/25','10/27','06/09','05/25','05/03','10/14','10/27','11/07','0104','0129','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('102575','ID','IDAHO','DIXIE',4.555250000000000e+001,-1.154605560000000e+002,'08/03','08/23','08/04','08/03','07/23','08/07','08/23','09/10','0000','0000','0022')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('102676','ID','TETON','DRIGGS',4.373055555000000e+001,-1.111125000000000e+002,'07/12','09/19','07/22','07/12','06/16','09/09','09/19','09/27','0020','0045','0083')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('102707','ID','CLARK','DUBOIS EXP STN',4.424361111000000e+001,-1.122005560000000e+002,'06/22','10/01','07/07','06/22','06/08','09/23','10/01','10/18','0059','0087','0112')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('102845','ID','CLEARWATER','DWORSHAK FISH HATCH',4.650222222000000e+001,-1.163216670000000e+002,'05/05','11/02','05/30','05/05','04/12','10/20','11/02','11/29','0116','0154','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('102875','ID','IDAHO','ELK CITY 1NE',4.583555555000000e+001,-1.154611110000000e+002,'07/31','09/05','08/04','07/31','07/07','08/21','09/05','09/24','0000','0009','0051')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('102892','ID','CLEARWATER','ELK RIVER 1 S',4.677444444000000e+001,-1.161761110000000e+002,'06/30','09/25','07/17','06/30','06/05','09/12','09/25','10/14','0035','0061','0102')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('102942','ID','GEM','EMMETT 2 E',4.385444444000000e+001,-1.164663890000000e+002,'05/25','10/24','06/17','05/25','05/07','10/07','10/24','11/11','0092','0125','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('103108','ID','CAMAS','FAIRFIELD RS',4.334277777000000e+001,-1.147900000000000e+002,'07/09','09/18','07/25','07/09','06/26','09/09','09/18','10/01','0017','0043','0070')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('103143','ID','IDAHO','FENN RS',4.609305555000000e+001,-1.155355560000000e+002,'05/27','10/30','06/18','05/27','04/29','10/08','10/30','11/22','0088','0125','0172')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('103297','ID','BINGHAM','FT HALL 1 NNE',4.304277777000000e+001,-1.124133330000000e+002,'06/18','10/05','06/29','06/18','05/26','09/22','10/05','10/14','0066','0088','0122')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('103448','ID','BOISE','GARDEN VALLEY',4.410111111000000e+001,-1.159694440000000e+002,'07/01','09/25','07/20','07/01','06/10','09/10','09/25','10/04','0023','0060','0095')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('103554','ID','LEMHI','GIBBONSVILLE',4.553944444000000e+001,-1.139275000000000e+002,'07/07','09/21','07/23','07/07','06/19','09/13','09/21','10/02','0025','0054','0084')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('103631','ID','ELMORE','GLENNS FERRY',4.294027777000000e+001,-1.153230560000000e+002,'06/07','10/08','06/25','06/07','05/22','09/27','10/08','10/21','0071','0097','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('103732','ID','CARIBOU','GRACE',4.258722222000000e+001,-1.117275000000000e+002,'06/30','09/26','07/14','06/30','06/11','09/14','09/26','10/04','0037','0066','0094')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('103771','ID','IDAHO','GRANGEVILLE',4.594138888000000e+001,-1.161175000000000e+002,'06/11','10/02','07/05','06/11','05/23','09/25','10/02','10/22','0060','0092','0123')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('103964','ID','JEFFERSON','HAMER 4 NW',4.396638888000000e+001,-1.122641670000000e+002,'07/07','09/17','07/22','07/07','06/17','09/09','09/17','09/29','0023','0052','0084')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('104140','ID','JEROME','HAZELTON',4.259722222000000e+001,-1.141377780000000e+002,'05/30','10/09','06/25','05/30','05/13','09/28','10/09','10/28','0075','0111','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('104150','ID','CLEARWATER','HEADQUARTERS',4.663111111000000e+001,-1.158086110000000e+002,'07/07','09/27','07/25','07/07','06/04','09/10','09/27','10/09','0024','0053','0104')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('104295','ID','TWIN FALLS','HOLLISTER',4.235277777000000e+001,-1.145738890000000e+002,'06/27','10/04','07/09','06/27','06/04','09/25','10/04','10/21','0061','0082','0115')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('104384','ID','BUTTE','HOWE',4.378277777000000e+001,-1.130033330000000e+002,'06/12','09/28','07/10','06/12','05/28','09/14','09/28','10/08','0044','0085','0112')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('104442','ID','BOISE','IDAHO CITY',4.383833333000000e+001,-1.158319440000000e+002,'07/10','09/19','07/23','07/10','06/21','09/06','09/19','09/30','0017','0046','0082')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('104455','ID','BONNEVILLE','IDAHO FALLS - KIFI',4.351333333000000e+001,-1.120127780000000e+002,'06/16','10/02','06/28','06/16','05/24','09/23','10/02','10/14','0067','0092','0124')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('104456','ID','BONNEVILLE','IDAHO FALLS 16 SE',4.334555555000000e+001,-1.117847220000000e+002,'07/13','09/17','07/24','07/13','06/27','09/03','09/17','09/30','0020','0040','0073')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('104460','ID','BUTTE','IDAHO FALLS 46 W',4.353166666000000e+001,-1.129422220000000e+002,'07/06','09/23','07/17','07/06','06/21','09/12','09/23','10/01','0033','0060','0082')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('104598','ID','FREMONT','ISLAND PARK',4.441888888000000e+001,-1.113713890000000e+002,'07/22','09/09','07/28','07/22','06/30','08/28','09/09','09/23','0012','0027','0060')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('104670','ID','JEROME','JEROME',4.273250000000000e+001,-1.145191670000000e+002,'06/01','10/19','06/16','06/01','05/06','10/06','10/19','11/03','0097','0116','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('104831','ID','SHOSHONE','KELLOGG',4.753388888000000e+001,-1.161222220000000e+002,'05/27','10/12','06/24','05/27','05/05','10/03','10/12','10/27','0074','0114','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('105177','ID','LEMHI','LEADORE NO.2',4.468305555000000e+001,-1.133622220000000e+002,'07/22','09/19','08/01','07/22','07/05','08/28','09/19','09/25','0004','0023','0055')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('105241','ID','NEZ PERCE','LEWISTON AP',4.637472222000000e+001,-1.170155560000000e+002,'05/01','11/09','05/18','05/01','04/15','10/22','11/09','12/02','0134','0163','0200')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('105275','ID','BEAR LAKE','LIFTON PUMPING STN',4.212305555000000e+001,-1.113138890000000e+002,'06/08','09/29','06/29','06/08','05/16','09/18','09/29','10/08','0061','0096','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('105462','ID','CUSTER','MACKAY LOST RIVER RS',4.391805555000000e+001,-1.136316670000000e+002,'07/05','09/25','07/21','07/05','06/10','09/14','09/25','10/07','0031','0060','0103')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('105559','ID','ONEIDA','MALAD CITY',4.214916666000000e+001,-1.122872220000000e+002,'06/25','09/30','07/13','06/25','06/01','09/15','09/30','10/04','0037','0075','0109')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('105685','ID','LEMHI','MAY 2SSE',4.456638888000000e+001,-1.138952780000000e+002,'07/01','09/22','07/12','07/01','06/17','09/13','09/22','10/04','0035','0062','0084')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('105708','ID','VALLEY','MC CALL',4.488694444000000e+001,-1.161047220000000e+002,'07/17','09/11','07/29','07/17','06/30','08/29','09/11','09/22','0009','0027','0063')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('105716','ID','BANNOCK','MCCAMMON',4.264472222000000e+001,-1.121919440000000e+002,'06/10','10/01','07/02','06/10','05/17','09/24','10/01','10/13','0064','0095','0128')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('105897','ID','CUSTER','MIDDLE FORK LODGE',4.471888888000000e+001,-1.150150000000000e+002,'07/10','09/25','07/19','07/10','06/20','09/09','09/25','10/07','0031','0058','0088')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('105980','ID','MINIDOKA','MINIDOKA DAM',4.267666666000000e+001,-1.135002780000000e+002,'06/02','10/12','06/24','06/02','05/13','09/30','10/12','10/31','0075','0111','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('106152','ID','LATAH','MOSCOW U OF I',4.672805555000000e+001,-1.169558330000000e+002,'06/21','10/05','07/18','06/21','05/25','09/21','10/05','10/24','0037','0087','0125')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('106174','ID','ELMORE','MTN HOME',4.312611111000000e+001,-1.157119440000000e+002,'06/03','10/16','06/26','06/03','05/15','10/01','10/16','10/28','0083','0113','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('106388','ID','ADAMS','NEW MEADOWS RS',4.497138888000000e+001,-1.162933330000000e+002,'07/21','09/10','07/31','07/21','06/25','08/26','09/10','09/22','0005','0030','0065')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('106424','ID','LEWIS','NEZPERCE',4.623583333000000e+001,-1.162466670000000e+002,'06/16','10/02','07/09','06/16','05/21','09/20','10/02','10/21','0053','0089','0119')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('106542','ID','CASSIA','OAKLEY',4.223416666000000e+001,-1.138980560000000e+002,'06/13','10/13','06/29','06/13','05/19','09/29','10/13','10/26','0072','0100','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('106844','ID','CANYON','PARMA EXP STN',4.380222222000000e+001,-1.169441670000000e+002,'05/29','10/08','06/16','05/29','05/08','10/01','10/08','10/26','0083','0120','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('106877','ID','MINIDOKA','PAUL 1ENE',4.262833333000000e+001,-1.137622220000000e+002,'06/01','10/07','06/25','06/01','05/13','09/30','10/07','10/26','0072','0104','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('106891','ID','PAYETTE','PAYETTE',4.407638888000000e+001,-1.169311110000000e+002,'05/31','10/18','06/14','05/31','05/05','10/08','10/18','10/31','0090','0113','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('107040','ID','BLAINE','PICABO',4.331111111000000e+001,-1.140741670000000e+002,'07/05','09/28','07/18','07/05','06/15','09/12','09/28','10/06','0032','0063','0093')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('107046','ID','CLEARWATER','PIERCE',4.649222222000000e+001,-1.158005560000000e+002,'07/17','09/14','07/31','07/17','06/11','09/02','09/14','10/01','0014','0040','0089')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('107211','ID','POWER','POCATELLO RGNL AP',4.292027777000000e+001,-1.125711110000000e+002,'06/11','10/01','07/02','06/11','05/24','09/25','10/01','10/17','0063','0094','0124')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('107264','ID','BOUNDARY','PORTHILL',4.899944444000000e+001,-1.164991670000000e+002,'05/27','10/06','06/13','05/27','05/11','09/25','10/06','10/19','0087','0116','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('107301','ID','LATAH','POTLATCH 3 NNE',4.696027777000000e+001,-1.168550000000000e+002,'07/12','09/16','08/03','07/12','06/11','09/01','09/16','09/29','0007','0045','0087')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('107320','ID','IDAHO','POWELL',4.651000000000000e+001,-1.147111110000000e+002,'07/01','09/20','07/23','07/01','06/11','09/06','09/20','10/07','0017','0061','0091')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('107346','ID','FRANKLIN','PRESTON',4.209333333000000e+001,-1.118683330000000e+002,'06/08','10/09','06/30','06/08','05/16','09/30','10/09','10/26','0050','0071','0097')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('107386','ID','BONNER','PRIEST RIVER EXP STN',4.835138888000000e+001,-1.168355560000000e+002,'06/18','09/28','07/13','06/18','05/18','09/13','09/28','10/14','0041','0081','0119')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('107648','ID','OWYHEE','REYNOLDS',4.320638888000000e+001,-1.167494440000000e+002,'06/24','10/04','07/09','06/24','06/04','09/28','10/04','10/21','0054','0083','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('107673','ID','LINCOLN','RICHFIELD',4.305277777000000e+001,-1.141580560000000e+002,'06/21','10/04','07/06','06/21','06/02','09/20','10/04','10/14','0058','0087','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('107706','ID','IDAHO','RIGGINS',4.542388888000000e+001,-1.163150000000000e+002,'05/15','11/05','06/02','05/15','04/29','10/19','11/05','11/25','0098','0126','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('108022','ID','FREMONT','SAINT ANTHONY',4.395166666000000e+001,-1.116788890000000e+002,'07/06','09/25','07/19','07/06','06/14','09/13','09/25','10/02','0026','0053','0092')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('108062','ID','BENEWAH','SAINT MARIES',4.731638888000000e+001,-1.165788890000000e+002,'05/31','10/08','07/01','05/31','05/14','09/30','10/08','10/30','0067','0105','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('108080','ID','LEMHI','SALMON-KSRA',4.518750000000000e+001,-1.139008330000000e+002,'06/13','10/02','06/29','06/13','05/21','09/21','10/02','10/15','0068','0095','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('108137','ID','BONNER','SANDPOINT EXP STN',4.829416666000000e+001,-1.165627780000000e+002,'06/04','10/03','07/01','06/04','05/14','09/24','10/03','10/20','0058','0099','0132')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('108380','ID','LINCOLN','SHOSHONE 1 WNW',4.293833333000000e+001,-1.144169440000000e+002,'06/04','10/10','06/27','06/04','05/22','10/01','10/10','10/21','0074','0108','0132')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('108395','ID','LEMHI','SHOUP',4.537666666000000e+001,-1.142775000000000e+002,'06/05','10/11','06/27','06/05','05/17','10/01','10/11','10/25','0066','0104','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('108676','ID','CUSTER','STANLEY',4.422055555000000e+001,-1.149341670000000e+002,'08/02','08/19','08/03','08/02','07/25','08/06','08/19','09/04','0000','0000','0012')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('108928','ID','ADA','SWAN FALLS P H',4.324361111000000e+001,-1.163783330000000e+002,'05/20','11/05','05/26','05/20','04/23','10/24','11/05','11/22','0127','0146','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('108937','ID','BONNEVILLE','SWAN VALLEY 2 E',4.344472222000000e+001,-1.112938890000000e+002,'07/12','09/17','07/27','07/12','06/28','09/02','09/17','09/28','0009','0041','0065')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('109065','ID','TETON','TETONIA EXP STN',4.385638888000000e+001,-1.112769440000000e+002,'07/15','09/17','07/26','07/15','06/22','09/07','09/17','09/25','0016','0036','0073')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('109303','ID','TWIN FALLS','TWIN FALLS 6 E',4.254583333000000e+001,-1.143461110000000e+002,'05/29','10/10','06/23','05/29','05/16','09/28','10/10','10/28','0077','0114','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('109498','ID','SHOSHONE','WALLACE',4.747527777000000e+001,-1.159313890000000e+002,'06/06','10/04','07/03','06/06','05/15','09/26','10/04','10/26','0063','0101','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('109560','ID','IDAHO','WARREN',4.526583333000000e+001,-1.156788890000000e+002,'08/01','08/18','08/02','08/01','07/27','08/07','08/18','09/04','0000','0000','0014')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('109638','ID','WASHINGTON','WEISER',4.424555555000000e+001,-1.169697220000000e+002,'06/05','10/11','06/25','06/05','05/16','10/02','10/11','10/27','0075','0109','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('109846','ID','LEWIS','WINCHESTER',4.623750000000000e+001,-1.166225000000000e+002,'07/15','09/30','07/24','07/15','06/10','09/14','09/30','10/04','0019','0043','0095')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('109951','ID','VALLEY','YELLOWPINE 7 S',4.485416666000000e+001,-1.155113890000000e+002,'07/26','09/02','08/03','07/26','07/09','08/14','09/02','09/19','0000','0016','0047')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('110072','IL','MERCER','ALEDO',4.119611111000000e+001,-9.074777800000000e+001,'05/05','10/27','05/20','05/05','04/21','10/15','10/27','11/07','0131','0151','0176')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('110137','IL','MADISON','ALTON MELVIN PRICE L&D',3.886611111000000e+001,-9.014611100000001e+001,'04/17','11/18','04/25','04/17','04/13','11/04','11/18','12/03','0168','0187','0202')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('110187','IL','UNION','ANNA 2 NNE',3.748138888000000e+001,-8.923444400000000e+001,'04/24','11/07','05/03','04/24','04/14','10/29','11/07','11/23','0157','0177','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('110338','IL','KANE','AURORA',4.178055555000000e+001,-8.830916700000000e+001,'05/16','10/20','05/30','05/16','04/24','10/12','10/20','11/08','0122','0144','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('110442','IL','COOK','BARRINGTON 3SW',4.211527777000000e+001,-8.816388900000000e+001,'05/21','10/22','06/04','05/21','05/06','10/15','10/22','11/10','0114','0134','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('110510','IL','ST. CLAIR','BELLEVILLE SIU RSCH',3.852000000000000e+001,-8.984666700000000e+001,'04/28','10/30','05/12','04/28','04/20','10/15','10/30','11/08','0136','0159','0172')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('110993','IL','MASSAC','BROOKPORT DAM 52',3.712750000000000e+001,-8.865305600000001e+001,'04/23','11/06','05/04','04/23','04/15','10/22','11/06','11/22','0156','0171','0199')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('111160','IL','ST. CLAIR','CAHOKIA',3.856694444000000e+001,-9.019416699999999e+001,'04/26','11/02','05/11','04/26','04/16','10/22','11/02','11/20','0142','0165','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('111166','IL','ALEXANDER','CAIRO 3N',3.704222222000000e+001,-8.918555600000001e+001,'04/11','11/23','04/21','04/11','04/05','11/10','11/23','12/05','0177','0193','0221')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('111265','IL','JACKSON','CARBONDALE SEWAGE PLT',3.773083333000000e+001,-8.916583300000001e+001,'04/29','10/29','05/10','04/29','04/16','10/16','10/29','11/11','0142','0158','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('111280','IL','MACOUPIN','CARLINVILLE',3.928833333000000e+001,-8.987027800000000e+001,'05/01','10/26','05/16','05/01','04/17','10/16','10/26','11/12','0137','0157','0183')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('111290','IL','CLINTON','CARLYLE RSVR',3.863083333000000e+001,-8.936583300000000e+001,'04/24','11/05','05/03','04/24','04/16','10/25','11/05','11/19','0156','0173','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('111436','IL','COLES','CHARLESTON',3.947611111000000e+001,-8.816527800000000e+001,'05/03','11/01','05/18','05/03','04/15','10/18','11/01','11/15','0136','0160','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('111475','IL','MCLEAN','CHENOA',4.073944444000000e+001,-8.871083299999999e+001,'05/09','10/23','05/23','05/09','04/24','10/12','10/23','11/09','0128','0147','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('111549','IL','COOK','CHICAGO OHARE AP',4.199500000000000e+001,-8.793361100000000e+001,'05/10','10/28','05/26','05/10','04/24','10/17','10/28','11/14','0125','0147','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('111577','IL','COOK','CHICAGO MIDWAY AP 3SW',4.173722222000000e+001,-8.777750000000000e+001,'05/06','11/10','05/15','05/06','04/21','10/26','11/10','11/20','0144','0159','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('112140','IL','VERMILION','DANVILLE',4.013888888000000e+001,-8.764833299999999e+001,'05/11','10/21','05/23','05/11','04/25','10/15','10/21','11/10','0132','0146','0176')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('112193','IL','MACON','DECATUR WTP',3.982888888000000e+001,-8.895055600000001e+001,'05/11','10/26','05/20','05/11','04/23','10/16','10/26','11/10','0130','0146','0176')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('112223','IL','DEKALB','DE KALB',4.193416666000000e+001,-8.877555600000000e+001,'05/15','10/22','05/27','05/15','05/01','10/13','10/22','11/10','0118','0138','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('112348','IL','LEE','DIXON 1 NW',4.184722222000000e+001,-8.950472200000000e+001,'05/13','10/21','05/27','05/13','05/01','10/10','10/21','11/06','0121','0142','0166')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('112353','IL','POPE','DIXON SPRINGS AG CTR',3.743888888000000e+001,-8.866777800000000e+001,'04/27','10/30','05/14','04/27','04/18','10/20','10/30','11/15','0141','0168','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('112483','IL','PERRY','DU QUOIN 4 SE',3.798777777000000e+001,-8.919305600000000e+001,'04/25','11/02','05/10','04/25','04/15','10/17','11/02','11/12','0146','0166','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('112687','IL','EFFINGHAM','EFFINGHAM 3SW',3.911861111000000e+001,-8.862416700000000e+001,'05/03','10/31','05/14','05/03','04/16','10/18','10/31','11/14','0138','0161','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('112931','IL','WAYNE','FAIRFIELD RADIO WFIW',3.838055555000000e+001,-8.832638900000001e+001,'04/30','10/27','05/16','04/30','04/16','10/16','10/27','11/12','0137','0159','0190')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('113290','IL','WHITESIDE','FULTON L&D #13',4.189777777000000e+001,-9.015444400000000e+001,'04/26','11/04','05/08','04/26','04/17','10/23','11/04','11/14','0146','0165','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('113320','IL','KNOX','GALESBURG',4.094638888000000e+001,-9.038555599999999e+001,'04/30','10/27','05/18','04/30','04/19','10/13','10/27','11/12','0134','0158','0182')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('113335','IL','HENRY','GALVA',4.117388888000000e+001,-9.003500000000000e+001,'05/05','10/29','05/16','05/05','04/21','10/19','10/29','11/14','0136','0153','0182')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('113384','IL','HENRY','GENESEO',4.145111111000000e+001,-9.014861100000000e+001,'05/04','10/29','05/20','05/04','04/22','10/15','10/29','11/13','0133','0154','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('113455','IL','HENDERSON','GLADSTONE DAM 18',4.088222222000000e+001,-9.102333299999999e+001,'04/28','11/08','05/15','04/28','04/15','10/23','11/08','11/15','0141','0166','0194')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('113879','IL','SALINE','HARRISBURG',3.774083333000000e+001,-8.852444400000000e+001,'04/24','11/02','05/09','04/24','04/14','10/19','11/02','11/14','0150','0167','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('113940','IL','MASON','HAVANA',4.030305555000000e+001,-9.006555600000000e+001,'05/03','10/24','05/16','05/03','04/16','10/15','10/24','11/10','0133','0154','0182')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('114108','IL','MONTGOMERY','HILLSBORO',3.915000000000000e+001,-8.948333300000000e+001,'04/25','10/30','05/09','04/25','04/17','10/21','10/30','11/20','0145','0166','0183')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('114198','IL','VERMILION','HOOPESTON 1NE',4.047416666000000e+001,-8.765638900000000e+001,'05/08','10/31','05/22','05/08','04/26','10/14','10/31','11/13','0130','0152','0177')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('114442','IL','MORGAN','JACKSONVILLE 2E',3.973472222000000e+001,-9.019777800000000e+001,'05/07','10/23','05/21','05/07','04/17','10/16','10/23','11/09','0129','0152','0182')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('114489','IL','JERSEY','JERSEYVILLE 2 SW',3.910527777000000e+001,-9.034194400000000e+001,'05/03','10/22','05/15','05/03','04/19','10/15','10/22','11/07','0135','0156','0176')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('114710','IL','HENRY','KEWANEE 1 E',4.124277777000000e+001,-8.989972200000000e+001,'05/10','10/24','05/22','05/10','04/29','10/16','10/24','11/05','0124','0144','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('114823','IL','HANCOCK','LA HARPE',4.058388888000000e+001,-9.096861100000000e+001,'05/05','10/24','05/14','05/05','04/22','10/13','10/24','11/05','0133','0152','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('115079','IL','LOGAN','LINCOLN',4.015138888000000e+001,-8.933805600000000e+001,'05/01','10/27','05/16','05/01','04/20','10/15','10/27','11/10','0136','0157','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('115326','IL','MCHENRY','MARENGO',4.226361111000000e+001,-8.860777800000000e+001,'05/21','10/14','06/01','05/21','05/06','10/10','10/14','11/01','0111','0131','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('115430','IL','COLES','MATTOON',3.947250000000000e+001,-8.835444400000000e+001,'05/02','10/30','05/10','05/02','04/17','10/18','10/30','11/20','0143','0162','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('115712','IL','WOODFORD','MINONK',4.091250000000000e+001,-8.903416700000000e+001,'05/15','10/22','05/23','05/15','04/27','10/11','10/22','11/10','0127','0142','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('115751','IL','ROCK ISLAND','MOLINE WSO AP',4.146527777000000e+001,-9.052333299999999e+001,'05/09','10/21','05/23','05/09','04/24','10/13','10/21','11/08','0128','0146','0172')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('115768','IL','WARREN','MONMOUTH',4.094416666000000e+001,-9.063805600000001e+001,'05/02','10/29','05/20','05/02','04/21','10/14','10/29','11/11','0131','0155','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('115833','IL','WHITESIDE','MORRISON',4.180388888000000e+001,-8.997444400000001e+001,'05/12','10/19','05/25','05/12','04/26','10/11','10/19','11/04','0121','0142','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('115888','IL','WABASH','MT CARMEL',3.841055555000000e+001,-8.775777800000000e+001,'04/19','11/16','05/09','04/19','04/12','11/03','11/16','12/05','0142','0177','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('115901','IL','CARROLL','MT CARROLL',4.209805555000000e+001,-8.998416700000000e+001,'05/28','10/10','06/08','05/28','05/16','09/30','10/10','10/23','0094','0113','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('115943','IL','JEFFERSON','MT VERNON 3 NE',3.834833333000000e+001,-8.885333300000001e+001,'04/29','10/27','05/13','04/29','04/18','10/18','10/27','11/13','0141','0162','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('116011','IL','WASHINGTON','NASHVILLE 1 E',3.834305555000000e+001,-8.935861100000000e+001,'04/22','11/10','05/04','04/22','04/14','10/28','11/10','11/24','0150','0176','0202')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('116446','IL','RICHLAND','OLNEY 2S',3.870027777000000e+001,-8.808166700000000e+001,'05/04','10/24','05/16','05/04','04/18','10/16','10/24','11/12','0138','0155','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('116526','IL','LA SALLE','OTTAWA 5SW',4.132833333000000e+001,-8.891055600000000e+001,'05/10','10/30','05/20','05/10','04/21','10/15','10/30','11/15','0135','0153','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('116558','IL','CRAWFORD','PALESTINE',3.900277777000000e+001,-8.762250000000000e+001,'04/28','11/08','05/22','04/28','04/16','10/20','11/08','11/13','0130','0158','0188')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('116579','IL','SHELBY','PANA 3E',3.937222222000000e+001,-8.902416700000001e+001,'04/29','11/04','05/12','04/29','04/17','10/20','11/04','11/18','0141','0158','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('116610','IL','EDGAR','PARIS STP',3.961861111000000e+001,-8.766722200000000e+001,'05/02','11/01','05/16','05/02','04/20','10/17','11/01','11/17','0139','0161','0183')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('116616','IL','COOK','PARK FOREST',4.149472222000000e+001,-8.768027800000000e+001,'05/13','10/29','05/24','05/13','04/26','10/16','10/29','11/15','0131','0145','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('116661','IL','LEE','PAW PAW 2 NW',4.171222222000000e+001,-8.899888900000001e+001,'05/14','10/23','05/29','05/14','04/30','10/11','10/23','11/06','0123','0144','0165')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('116711','IL','PEORIA','PEORIA INTERNATIONAL AP',4.066750000000000e+001,-8.968388899999999e+001,'05/03','10/29','05/21','05/03','04/16','10/15','10/29','11/12','0134','0159','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('116753','IL','LA SALLE','PERU',4.135027777000000e+001,-8.910722199999999e+001,'05/14','10/21','05/22','05/14','04/28','10/12','10/21','11/09','0124','0144','0165')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('116819','IL','FORD','PIPER CITY',4.075694444000000e+001,-8.818277800000000e+001,'05/10','10/24','05/21','05/10','05/01','10/12','10/24','11/13','0125','0142','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('116910','IL','LIVINGSTON','PONTIAC',4.088527777000000e+001,-8.863888900000001e+001,'05/05','11/02','05/15','05/05','04/21','10/16','11/02','11/15','0141','0157','0181')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('117004','IL','PEORIA','PRINCEVILLE 2W',4.093138888000000e+001,-8.977972200000001e+001,'05/14','10/23','05/29','05/14','04/30','10/10','10/23','11/01','0111','0136','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('117072','IL','ADAMS','QUINCY RGNL AP',3.993694444000000e+001,-9.119194400000001e+001,'04/24','11/06','05/07','04/24','04/15','10/20','11/06','11/19','0145','0170','0191')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('117077','IL','ADAMS','QUINCY DAM 21',3.990583333000000e+001,-9.142805600000000e+001,'04/21','11/08','05/04','04/21','04/15','10/25','11/08','11/20','0148','0174','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('117150','IL','CHAMPAIGN','RANTOUL',4.031305555000000e+001,-8.815944399999999e+001,'05/06','10/26','05/17','05/06','04/25','10/16','10/26','11/08','0135','0154','0173')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('117382','IL','WINNEBAGO','ROCKFORD AP',4.219277777000000e+001,-8.909305600000000e+001,'05/14','10/21','05/26','05/14','04/27','10/10','10/21','11/04','0121','0136','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('117487','IL','HARDIN','ROSICLARE 5NW',3.747472222000000e+001,-8.841222200000000e+001,'05/05','11/04','05/10','05/05','04/20','10/22','11/04','11/17','0140','0156','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('117551','IL','SCHUYLER','RUSHVILLE 4NE',4.013472222000000e+001,-9.047916700000000e+001,'04/25','10/31','05/19','04/25','04/17','10/20','10/31','11/12','0132','0164','0188')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('117636','IL','MARION','SALEM',3.864527777000000e+001,-8.894611100000000e+001,'04/25','11/03','05/11','04/25','04/17','10/22','11/03','11/19','0144','0169','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('118179','IL','SANGAMON','SPRINGFIELD LINCOLN AP',3.984472222000000e+001,-8.968388899999999e+001,'04/25','10/25','05/14','04/25','04/15','10/14','10/25','11/13','0141','0167','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('118293','IL','JO DAVIESS','STOCKTON 3 NNE',4.240055555000000e+001,-8.999583300000001e+001,'05/12','10/16','05/24','05/12','05/02','10/11','10/16','11/01','0117','0136','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('118684','IL','DOUGLAS','TUSCOLA',3.979500000000000e+001,-8.829000000000001e+001,'05/05','10/27','05/16','05/05','04/17','10/16','10/27','11/11','0137','0153','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('118740','IL','CHAMPAIGN','URBANA',4.008388888000000e+001,-8.824027800000000e+001,'04/30','10/30','05/12','04/30','04/17','10/22','10/30','11/16','0142','0162','0188')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('118916','IL','BUREAU','WALNUT',4.155194444000000e+001,-8.959888900000000e+001,'05/12','10/21','05/19','05/12','04/27','10/11','10/21','11/04','0127','0143','0167')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('119002','IL','MONROE','WATERLOO',3.836638888000000e+001,-9.016194400000001e+001,'04/23','11/06','05/06','04/23','04/15','10/29','11/06','11/24','0151','0173','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('119021','IL','IROQUOIS','WATSEKA 2 NW',4.079277777000000e+001,-8.775555600000000e+001,'05/14','10/19','05/28','05/14','05/03','10/12','10/19','11/06','0120','0142','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('119241','IL','GREENE','WHITE HALL 1 E',3.944111111000000e+001,-9.037888900000000e+001,'04/24','10/28','05/10','04/24','04/19','10/19','10/28','11/14','0141','0167','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('119354','IL','SHELBY','WINDSOR',3.944583333000000e+001,-8.859611099999999e+001,'05/04','11/05','05/11','05/04','04/16','10/19','11/05','11/14','0143','0159','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('120177','IN','MADISON','ANDERSON SEWAGE PLT',4.011166666000000e+001,-8.571638900000001e+001,'05/12','11/02','05/16','05/12','04/24','10/17','11/02','11/14','0138','0151','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('120200','IN','STEUBEN','ANGOLA',4.163972222000000e+001,-8.498972200000000e+001,'05/22','10/20','06/07','05/22','05/04','10/11','10/20','11/05','0105','0132','0156')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('120676','IN','ADAMS','BERNE WWTP',4.066833333000000e+001,-8.493055600000000e+001,'05/08','11/05','05/17','05/08','04/25','10/20','11/05','11/14','0135','0153','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('120784','IN','MONROE','BLOOMINGTON IN UNIV',3.917416666000000e+001,-8.652138900000000e+001,'04/27','11/07','05/10','04/27','04/16','10/26','11/07','11/19','0149','0173','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('120830','IN','WELLS','BLUFFTON 1 N',4.074750000000000e+001,-8.517388900000000e+001,'05/09','10/26','05/21','05/09','04/30','10/12','10/26','11/11','0127','0146','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('121030','IN','FRANKLIN','BROOKVILLE',3.942388888000000e+001,-8.501277800000000e+001,'05/12','10/20','05/23','05/12','04/27','10/12','10/20','11/08','0128','0146','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('121739','IN','WHITLEY','COLUMBIA CITY',4.114527777000000e+001,-8.548972200000000e+001,'05/11','10/22','05/27','05/11','05/02','10/12','10/22','11/09','0121','0145','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('121747','IN','BARTHOLOMEW','COLUMBUS',3.916611111000000e+001,-8.592277799999999e+001,'05/02','11/01','05/11','05/02','04/18','10/19','11/01','11/16','0144','0163','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('122309','IN','DUBOIS','DUBOIS S IN FORAGE FM',3.845583333000000e+001,-8.669833300000001e+001,'05/08','10/31','05/16','05/08','04/19','10/17','10/31','11/15','0137','0156','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('122638','IN','MADISON','ELWOOD',4.028722222000000e+001,-8.584527799999999e+001,'05/12','10/22','05/22','05/12','04/29','10/11','10/22','11/08','0127','0146','0167')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('122731','IN','VANDERBURGH','EVANSVILLE MUSEUM',3.796472222000000e+001,-8.757833300000000e+001,'04/21','11/23','05/04','04/21','04/13','11/12','11/23','12/03','0156','0181','0199')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('122738','IN','VANDERBURGH','EVANSVILLE REGIONAL AP',3.804416666000000e+001,-8.752055600000000e+001,'04/22','11/09','05/05','04/22','04/14','10/22','11/09','11/19','0155','0178','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('122825','IN','RANDOLPH','FARMLAND 5 NNW',4.025388888000000e+001,-8.514833299999999e+001,'05/14','10/18','05/26','05/14','05/05','10/08','10/18','11/02','0122','0141','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('123037','IN','ALLEN','FORT WAYNE AP',4.097055555000000e+001,-8.520638900000000e+001,'05/09','10/28','05/15','05/09','04/25','10/15','10/28','11/10','0138','0149','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('123082','IN','CLINTON','FRANKFORT DISPOSAL PLT',4.029861111000000e+001,-8.650666699999999e+001,'05/13','10/24','05/26','05/13','04/29','10/13','10/24','11/06','0127','0146','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('123418','IN','ELKHART','GOSHEN 3SW',4.155750000000000e+001,-8.588249999999999e+001,'05/13','10/29','05/24','05/13','04/27','10/16','10/29','11/13','0125','0149','0171')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('123513','IN','PUTNAM','GREENCASTLE 1 W',3.964388888000000e+001,-8.687666700000000e+001,'05/05','11/05','05/14','05/05','04/17','10/20','11/05','11/16','0142','0159','0188')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('123527','IN','HANCOCK','GREENFIELD',3.978583333000000e+001,-8.576111100000000e+001,'05/07','10/30','05/15','05/07','04/21','10/18','10/30','11/13','0140','0156','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('123547','IN','DECATUR','GREENSBURG',3.934750000000000e+001,-8.548916700000000e+001,'05/06','11/01','05/15','05/06','04/23','10/17','11/01','11/14','0137','0153','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('123777','IN','BLACKFORD','HARTFORD CITY 4 ESE',4.043555555000000e+001,-8.528916700000001e+001,'05/11','10/26','05/19','05/11','04/29','10/15','10/26','11/08','0132','0147','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('124259','IN','MARION','INDIANAPOLIS INTL AP',3.973166666000000e+001,-8.627888900000001e+001,'05/04','10/31','05/12','05/04','04/20','10/19','10/31','11/15','0142','0160','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('124272','IN','MARION','INDIANAPOLIS SE SIDE',3.971638888000000e+001,-8.606777800000000e+001,'05/01','11/04','05/18','05/01','04/20','10/20','11/04','11/18','0135','0159','0188')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('124662','IN','HOWARD','KOKOMO 3 WSW',4.045833333000000e+001,-8.617583300000000e+001,'05/11','10/22','05/25','05/11','04/30','10/10','10/22','11/07','0122','0145','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('124715','IN','TIPPECANOE','LAFAYETTE 8 S',4.029638888000000e+001,-8.690277800000000e+001,'05/14','10/18','05/27','05/14','05/02','10/09','10/18','11/04','0121','0140','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('124730','IN','LAGRANGE','LAGRANGE 1 S',4.162916666000000e+001,-8.541416700000001e+001,'05/22','10/22','06/01','05/22','05/09','10/10','10/22','11/10','0116','0133','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('124837','IN','LAPORTE','LAPORTE',4.161166666000000e+001,-8.672972200000000e+001,'05/06','11/06','05/17','05/06','04/17','10/26','11/06','11/21','0143','0162','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('125174','IN','LAKE','LOWELL',4.126472222000000e+001,-8.741777800000000e+001,'05/18','10/20','05/31','05/18','05/01','10/09','10/20','11/05','0118','0140','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('125237','IN','JEFFERSON','MADISON SEWAGE PLT',3.873694444000000e+001,-8.539416700000000e+001,'05/02','11/11','05/14','05/02','04/14','10/26','11/11','11/23','0147','0173','0197')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('125337','IN','GRANT','MARION 2 N',4.058000000000000e+001,-8.565861099999999e+001,'05/10','10/26','05/21','05/10','04/28','10/16','10/26','11/14','0131','0151','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('125407','IN','MORGAN','MARTINSVILLE 2 SW',3.940388888000000e+001,-8.645305600000000e+001,'05/12','10/19','05/28','05/12','04/26','10/11','10/19','11/06','0121','0143','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('126001','IN','POSEY','MT VERNON',3.792861111000000e+001,-8.789555600000000e+001,'04/17','11/12','04/28','04/17','04/11','11/01','11/12','11/24','0164','0189','0205')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('126164','IN','HENRY','NEW CASTLE 3 SW',3.989416666000000e+001,-8.539527800000001e+001,'05/10','10/27','05/18','05/10','04/27','10/12','10/27','11/08','0134','0150','0173')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('126435','IN','JENNINGS','NORTH VERNON 2 ESE',3.900166666000000e+001,-8.559972200000000e+001,'05/10','10/29','05/19','05/10','04/21','10/12','10/29','11/15','0134','0155','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('126580','IN','LAWRENCE','OOLITIC PURDUE EX FRM',3.888944444000000e+001,-8.655194400000001e+001,'05/11','10/21','05/19','05/11','04/23','10/12','10/21','11/11','0134','0150','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('126705','IN','ORANGE','PAOLI',3.855555555000000e+001,-8.648583300000000e+001,'05/13','10/23','05/23','05/13','04/28','10/10','10/23','11/07','0126','0145','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('127069','IN','JAY','PORTLAND 1 SW',4.041750000000000e+001,-8.499250000000001e+001,'05/12','10/20','05/22','05/12','04/30','10/12','10/20','11/07','0128','0143','0167')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('127125','IN','GIBSON','PRINCETON 1 W',3.835666666000000e+001,-8.759055600000001e+001,'04/24','11/09','05/12','04/24','04/14','10/20','11/09','11/19','0149','0173','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('127298','IN','JASPER','RENSSELAER',4.093555555000000e+001,-8.715638900000000e+001,'05/11','10/26','05/21','05/11','04/25','10/12','10/26','11/13','0133','0146','0177')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('127370','IN','WAYNE','RICHMOND WTR WKS',3.985444444000000e+001,-8.487777800000001e+001,'05/12','10/24','05/20','05/12','04/30','10/12','10/24','11/09','0131','0147','0167')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('127482','IN','FULTON','ROCHESTER',4.106638888000000e+001,-8.620972200000000e+001,'05/10','10/29','05/25','05/10','04/28','10/14','10/29','11/09','0125','0145','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('127522','IN','PARKE','ROCKVILLE',3.975944444000000e+001,-8.722694400000000e+001,'05/08','10/27','05/20','05/08','04/17','10/16','10/27','11/12','0137','0154','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('127646','IN','RUSH','RUSHVILLE',3.960416666000000e+001,-8.545277800000000e+001,'05/07','10/26','05/17','05/07','04/26','10/13','10/26','11/11','0136','0153','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('127724','IN','SPENCER','SAINT MEINRAD',3.816416666000000e+001,-8.680944400000000e+001,'05/01','10/31','05/15','05/01','04/19','10/20','10/31','11/11','0141','0165','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('127755','IN','WASHINGTON','SALEM',3.861583333000000e+001,-8.608555600000000e+001,'05/10','10/21','05/15','05/10','04/24','10/13','10/21','11/12','0140','0151','0177')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('127935','IN','JACKSON','SEYMOUR 2 N',3.898222222000000e+001,-8.589888900000000e+001,'05/03','10/26','05/14','05/03','04/22','10/12','10/26','11/12','0138','0156','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('127999','IN','SHELBY','SHELBYVILLE SEWAGE PLT',3.952833333000000e+001,-8.579138900000000e+001,'05/08','10/26','05/15','05/08','04/23','10/13','10/26','11/13','0141','0153','0177')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('128036','IN','MARTIN','SHOALS 8 S',3.855277777000000e+001,-8.679444400000000e+001,'05/10','10/24','05/18','05/10','04/25','10/14','10/24','11/10','0135','0153','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('128187','IN','ST. JOSEPH','SOUTH BEND AP',4.170722222000000e+001,-8.631638900000000e+001,'05/11','11/03','05/27','05/11','04/28','10/21','11/03','11/18','0129','0153','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('128290','IN','OWEN','SPENCER',3.928361111000000e+001,-8.677027800000001e+001,'05/14','10/21','05/27','05/14','04/30','10/12','10/21','11/07','0125','0143','0167')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('128698','IN','PERRY','TELL CITY',3.795305555000000e+001,-8.677472200000000e+001,'04/23','11/09','05/04','04/23','04/15','10/28','11/09','11/25','0160','0178','0202')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('128723','IN','VIGO','TERRE HAUTE INDIANA ST',3.947083333000000e+001,-8.740805600000000e+001,'05/08','10/31','05/23','05/08','04/18','10/26','10/31','11/14','0131','0152','0183')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('129138','IN','WABASH','WABASH',4.078694444000000e+001,-8.582083299999999e+001,'05/14','10/19','05/28','05/14','05/06','10/11','10/19','11/01','0120','0140','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('129222','IN','LAPORTE','WANATAH 2 WNW',4.144388888000000e+001,-8.692944400000000e+001,'05/17','10/22','06/03','05/17','05/02','10/09','10/22','11/06','0108','0139','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('129240','IN','KOSCIUSKO','WARSAW',4.126333333000000e+001,-8.586777800000000e+001,'05/10','10/26','05/30','05/10','05/01','10/14','10/26','11/10','0121','0147','0166')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('129253','IN','DAVIESS','WASHINGTON 1 W',3.864888888000000e+001,-8.719888899999999e+001,'04/25','11/05','05/12','04/25','04/17','10/24','11/05','11/17','0140','0171','0191')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('129430','IN','TIPPECANOE','WEST LAFAYETTE 6 NW',4.047500000000000e+001,-8.699194400000000e+001,'05/15','10/24','05/27','05/15','04/28','10/09','10/24','11/07','0122','0142','0165')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('129557','IN','BOONE','WHITESTOWN',3.999611111000000e+001,-8.635416700000000e+001,'05/08','10/25','05/26','05/08','04/24','10/14','10/25','11/10','0126','0150','0171')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('129670','IN','PULASKI','WINAMAC 2SSE',4.102666666000000e+001,-8.658666700000001e+001,'05/15','10/25','05/31','05/15','04/29','10/17','10/25','11/08','0125','0147','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('129678','IN','RANDOLPH','WINCHESTER AIRPORT 3 E',4.017138888000000e+001,-8.492083300000000e+001,'05/09','10/27','05/15','05/09','04/25','10/14','10/27','11/13','0134','0153','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('130112','IA','MONROE','ALBIA 3 NNE',4.106555555000000e+001,-9.278666699999999e+001,'05/02','10/26','05/16','05/02','04/18','10/14','10/26','11/06','0134','0150','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('130133','IA','KOSSUTH','ALGONA 3 W',4.306833333000000e+001,-9.430527800000000e+001,'05/13','10/16','05/18','05/13','04/29','10/09','10/16','11/01','0124','0139','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('130157','IA','BUTLER','ALLISON',4.275361111000000e+001,-9.280222200000000e+001,'05/11','10/17','05/20','05/11','04/27','10/09','10/17','10/30','0122','0142','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('130200','IA','BOONE','AMES 8 WSW',4.202083333000000e+001,-9.377416700000001e+001,'05/09','10/20','05/16','05/09','04/20','10/10','10/20','10/28','0133','0143','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('130241','IA','POLK','ANKENY',4.171833333000000e+001,-9.357416700000000e+001,'05/07','10/21','05/18','05/07','04/23','10/08','10/21','11/02','0126','0146','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('130364','IA','CASS','ATLANTIC 1 NE',4.141750000000000e+001,-9.500388900000000e+001,'05/13','10/11','05/31','05/13','05/10','09/28','10/11','10/22','0104','0131','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('130385','IA','AUDUBON','AUDUBON',4.170694444000000e+001,-9.492222200000001e+001,'05/12','10/16','05/23','05/12','05/04','10/04','10/16','11/03','0117','0138','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('130536','IA','RINGGOLD','BEACONSFIELD',4.082361111000000e+001,-9.404750000000000e+001,'05/09','10/25','05/22','05/09','04/27','10/18','10/25','11/10','0122','0145','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('130576','IA','TAYLOR','BEDFORD',4.067416666000000e+001,-9.472444400000001e+001,'05/09','10/20','05/18','05/09','04/24','10/10','10/20','11/01','0126','0147','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('130600','IA','BENTON','BELLE PLAINE',4.188138888000000e+001,-9.227638900000000e+001,'05/10','10/17','05/22','05/10','04/26','10/06','10/17','11/02','0121','0143','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('130608','IA','JACKSON','BELLEVUE L&D 12',4.226111111000000e+001,-9.042305600000000e+001,'05/15','10/17','05/29','05/15','04/28','10/09','10/17','11/01','0118','0138','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('130753','IA','DAVIS','BLOOMFIELD 1 WNW',4.075972222000000e+001,-9.243944400000000e+001,'04/30','10/27','05/12','04/30','04/18','10/18','10/27','11/08','0138','0157','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('130807','IA','BOONE','BOONE',4.204166666000000e+001,-9.389055600000000e+001,'05/13','10/16','05/27','05/13','05/02','10/07','10/16','10/27','0113','0135','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('130923','IA','HANCOCK','BRITT',4.310166666000000e+001,-9.380138900000000e+001,'05/13','10/13','05/22','05/13','05/01','10/04','10/13','10/29','0120','0139','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('131060','IA','DES MOINES','BURLINGTON 2S',4.077472222000000e+001,-9.111638900000000e+001,'04/29','11/04','05/08','04/29','04/17','10/23','11/04','11/14','0149','0167','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('131233','IA','CARROLL','CARROLL',4.206500000000000e+001,-9.484999999999999e+001,'05/15','10/17','05/24','05/15','05/05','10/05','10/17','10/30','0113','0129','0152')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('131257','IA','DUBUQUE','CASCADE',4.229888888000000e+001,-9.099833300000000e+001,'05/18','10/13','05/29','05/18','05/04','10/03','10/13','10/27','0110','0134','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('131277','IA','MONONA','CASTANA EXP FARM',4.206333333000000e+001,-9.583638900000000e+001,'05/12','10/19','05/16','05/12','04/29','10/11','10/19','10/29','0124','0141','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('131314','IA','LINN','CEDAR RAPIDS AP',4.188333333000000e+001,-9.171666700000000e+001,'05/04','10/20','05/16','05/04','04/20','10/09','10/20','11/04','0129','0150','0173')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('131319','IA','LINN','CEDAR RAPIDS NO 1',4.205000000000000e+001,-9.158805600000000e+001,'05/09','10/20','05/21','05/09','04/24','10/11','10/20','11/04','0128','0145','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('131354','IA','APPANOOSE','CENTERVILLE',4.073638888000000e+001,-9.286916700000000e+001,'05/03','10/28','05/11','05/03','04/19','10/15','10/28','11/08','0140','0152','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('131394','IA','LUCAS','CHARITON 1 E',4.101638888000000e+001,-9.327916700000000e+001,'05/17','10/15','05/28','05/17','05/04','10/08','10/15','11/02','0113','0136','0158')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('131402','IA','FLOYD','CHARLES CITY',4.307750000000000e+001,-9.267138900000001e+001,'05/11','10/14','05/26','05/11','04/27','10/04','10/14','10/27','0114','0138','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('131442','IA','CHEROKEE','CHEROKEE',4.275722222000000e+001,-9.553777800000000e+001,'05/17','10/12','06/01','05/17','05/11','09/29','10/12','10/23','0106','0130','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('131533','IA','PAGE','CLARINDA',4.072444444000000e+001,-9.501916700000000e+001,'05/06','10/23','05/17','05/06','04/25','10/09','10/23','11/06','0127','0147','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('131541','IA','WRIGHT','CLARION',4.272000000000000e+001,-9.373361100000000e+001,'05/16','10/11','05/25','05/16','05/03','10/02','10/11','10/23','0112','0128','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('131635','IA','CLINTON','CLINTON #1',4.179472222000000e+001,-9.026388900000001e+001,'05/08','10/19','05/21','05/08','04/23','10/11','10/19','11/06','0127','0146','0167')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('131833','IA','ADAMS','CORNING',4.098861111000000e+001,-9.474916700000000e+001,'05/10','10/22','05/22','05/10','04/29','10/10','10/22','10/29','0119','0140','0158')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('131954','IA','HOWARD','CRESCO 1 NE',4.338944444000000e+001,-9.209388900000000e+001,'05/19','10/15','06/04','05/19','05/08','10/04','10/15','10/21','0104','0128','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('131962','IA','UNION','CRESTON 2 SW',4.103722222000000e+001,-9.439416700000000e+001,'05/06','10/21','05/17','05/06','04/30','10/14','10/21','11/06','0129','0146','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('132110','IA','WINNESHIEK','DECORAH',4.330416666000000e+001,-9.179527800000000e+001,'05/20','10/15','05/30','05/20','05/07','10/03','10/15','10/28','0115','0131','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('132171','IA','CRAWFORD','DENISON',4.203638888000000e+001,-9.532888900000000e+001,'05/10','10/23','05/15','05/10','04/29','10/13','10/23','11/05','0132','0141','0167')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('132203','IA','POLK','DES MOINES AP',4.153388888000000e+001,-9.365305600000001e+001,'05/02','10/27','05/13','05/02','04/18','10/19','10/27','11/11','0138','0158','0183')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('132364','IA','DUBUQUE','DUBUQUE L&D 11',4.254000000000000e+001,-9.064611100000001e+001,'04/30','11/06','05/10','04/30','04/14','10/21','11/06','11/12','0144','0167','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('132367','IA','DUBUQUE','DUBUQUE WSO AP',4.239777777000000e+001,-9.070361100000000e+001,'05/09','10/22','05/25','05/09','04/29','10/15','10/22','11/02','0121','0144','0165')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('132573','IA','HARDIN','ELDORA',4.236194444000000e+001,-9.309888900000000e+001,'05/08','10/19','05/15','05/08','04/23','10/09','10/19','11/02','0132','0144','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('132603','IA','CLAYTON','ELKADER 6 SSW',4.277527777000000e+001,-9.145361100000000e+001,'05/25','10/08','06/11','05/25','05/17','09/27','10/08','10/17','0094','0115','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('132689','IA','PALO ALTO','EMMETSBURG',4.310250000000000e+001,-9.468333300000001e+001,'05/11','10/18','05/17','05/11','04/20','10/08','10/18','10/30','0127','0143','0166')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('132724','IA','EMMET','ESTHERVILLE 4E',4.340361111000000e+001,-9.474722199999999e+001,'05/15','10/11','05/24','05/15','05/04','10/03','10/11','10/25','0116','0135','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('132789','IA','JEFFERSON','FAIRFIELD',4.102111111000000e+001,-9.195527800000001e+001,'05/03','10/26','05/17','05/03','04/20','10/14','10/26','11/07','0137','0156','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('132864','IA','FAYETTE','FAYETTE',4.285027777000000e+001,-9.181583300000000e+001,'05/23','10/09','06/01','05/23','05/12','09/29','10/09','10/17','0105','0122','0143')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('132977','IA','WINNEBAGO','FOREST CITY 2 NNE',4.328444444000000e+001,-9.363055600000000e+001,'05/11','10/13','05/19','05/11','04/25','10/06','10/13','10/30','0123','0142','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('132999','IA','WEBSTER','FT DODGE 5NNW',4.258361111000000e+001,-9.420055600000001e+001,'05/13','10/21','05/17','05/13','05/01','10/05','10/21','10/30','0123','0137','0159')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('133007','IA','LEE','FT MADISON',4.062111111000000e+001,-9.132611100000000e+001,'04/30','11/06','05/11','04/30','04/14','10/21','11/06','11/18','0142','0164','0190')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('133438','IA','ADAIR','GREENFIELD',4.129805555000000e+001,-9.445611100000001e+001,'05/08','10/25','05/13','05/08','04/25','10/14','10/25','11/03','0134','0146','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('133473','IA','POWESHIEK','GRINNELL 3 SW',4.172027777000000e+001,-9.274888900000001e+001,'05/20','10/09','06/01','05/20','05/10','10/02','10/09','10/20','0105','0124','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('133487','IA','GRUNDY','GRUNDY CTR',4.236472222000000e+001,-9.275944400000000e+001,'05/12','10/13','05/22','05/12','05/01','10/03','10/13','10/25','0119','0142','0158')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('133509','IA','GUTHRIE','GUTHRIE CTR',4.166861111000000e+001,-9.449722199999999e+001,'05/13','10/17','05/24','05/13','05/02','09/29','10/17','10/28','0112','0135','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('133517','IA','CLAYTON','GUTTENBERG L&D 10',4.278583333000000e+001,-9.109583300000000e+001,'05/03','10/25','05/17','05/03','04/23','10/12','10/25','11/10','0133','0154','0172')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('133584','IA','FRANKLIN','HAMPTON',4.275611111000000e+001,-9.320111100000000e+001,'05/10','10/15','05/20','05/10','04/26','10/08','10/15','10/31','0122','0143','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('133632','IA','SHELBY','HARLAN 1N',4.167833333000000e+001,-9.532472199999999e+001,'05/12','10/21','05/19','05/12','04/30','10/08','10/21','10/30','0124','0142','0166')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('133718','IA','SIOUX','HAWARDEN',4.300305555000000e+001,-9.648500000000000e+001,'05/15','10/11','05/27','05/15','05/08','10/02','10/11','10/24','0109','0126','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('134063','IA','WARREN','INDIANOLA 2W',4.136555555000000e+001,-9.364805600000000e+001,'05/09','10/20','05/24','05/09','04/28','10/07','10/20','11/02','0118','0138','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('134101','IA','JOHNSON','IOWA CITY',4.160916666000000e+001,-9.150500000000000e+001,'04/27','10/29','05/12','04/27','04/17','10/19','10/29','11/14','0141','0160','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('134142','IA','HARDIN','IOWA FALLS',4.251888888000000e+001,-9.325361100000001e+001,'05/12','10/15','05/19','05/12','04/25','10/09','10/15','10/30','0122','0135','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('134228','IA','GREENE','JEFFERSON',4.203472222000000e+001,-9.441138900000000e+001,'05/11','10/20','05/19','05/11','04/25','10/09','10/20','10/31','0126','0141','0166')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('134381','IA','LEE','KEOKUK LOCK DAM 19',4.039666666000000e+001,-9.137500000000000e+001,'04/17','11/09','05/03','04/17','04/12','10/25','11/09','11/19','0151','0181','0203')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('134389','IA','VAN BUREN','KEOSAUQUA',4.073083333000000e+001,-9.196083299999999e+001,'05/04','10/22','05/20','05/04','04/24','10/14','10/22','11/04','0127','0145','0167')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('134502','IA','MARION','KNOXVILLE',4.132472222000000e+001,-9.310083299999999e+001,'05/05','10/27','05/10','05/05','04/18','10/16','10/27','11/09','0143','0157','0181')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('134561','IA','DICKINSON','LAKE PARK',4.344833333000000e+001,-9.532472199999999e+001,'05/15','10/17','05/19','05/15','05/02','10/06','10/17','10/29','0122','0137','0158')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('134585','IA','DECATUR','LAMONI',4.062333333000000e+001,-9.395083300000000e+001,'04/27','10/29','05/09','04/27','04/17','10/18','10/29','11/14','0142','0161','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('134705','IA','SCOTT','LE CLAIRE L&D 14',4.157472222000000e+001,-9.040055600000000e+001,'04/27','11/04','05/09','04/27','04/16','10/22','11/04','11/16','0144','0167','0191')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('134735','IA','PLYMOUTH','LE MARS',4.278166666000000e+001,-9.614583300000000e+001,'05/13','10/15','05/23','05/13','05/06','10/05','10/15','10/26','0116','0139','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('134758','IA','DECATUR','LEON 6 ESE',4.072444444000000e+001,-9.364527800000001e+001,'05/15','10/19','05/31','05/15','05/02','10/10','10/19','11/04','0107','0131','0152')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('134894','IA','HARRISON','LOGAN',4.163805555000000e+001,-9.578833299999999e+001,'05/11','10/20','05/20','05/11','04/28','10/05','10/20','10/27','0123','0141','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('135123','IA','MONONA','MAPLETON NO.2',4.216194444000000e+001,-9.578361099999999e+001,'05/14','10/16','05/20','05/14','05/02','10/02','10/16','10/26','0119','0134','0156')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('135131','IA','JACKSON','MAQUOKETA 4 W',4.204944444000000e+001,-9.074888900000001e+001,'05/17','10/15','05/26','05/17','05/03','10/06','10/15','10/31','0115','0134','0158')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('135198','IA','MARSHALL','MARSHALLTOWN',4.206472222000000e+001,-9.292444399999999e+001,'05/09','10/17','05/19','05/09','04/26','10/05','10/17','10/26','0121','0138','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('135230','IA','CERRO GORDO','MASON CITY',4.316305555000000e+001,-9.319527800000000e+001,'05/15','10/15','05/29','05/15','05/07','10/04','10/15','10/26','0109','0134','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('135235','IA','CERRO GORDO','MASON CITY MUNI AP',4.315444444000000e+001,-9.332694400000000e+001,'05/13','10/11','05/25','05/13','05/04','10/05','10/11','10/24','0116','0136','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('135493','IA','DICKINSON','MILFORD 4 NW',4.338277777000000e+001,-9.518416700000000e+001,'05/13','10/15','05/24','05/13','05/07','10/05','10/15','10/24','0115','0136','0152')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('135769','IA','RINGGOLD','MT AYR',4.070527777000000e+001,-9.424277800000000e+001,'05/07','10/24','05/17','05/07','04/24','10/11','10/24','11/06','0129','0146','0165')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('135796','IA','HENRY','MT PLEASANT 1 SSW',4.094861111000000e+001,-9.156472200000000e+001,'05/05','10/24','05/19','05/05','04/19','10/16','10/24','11/11','0135','0152','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('135837','IA','MUSCATINE','MUSCATINE',4.140750000000000e+001,-9.107250000000001e+001,'05/06','10/26','05/16','05/06','04/23','10/13','10/26','11/07','0130','0147','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('135952','IA','CHICKASAW','NEW HAMPTON',4.304527777000000e+001,-9.231222200000001e+001,'05/11','10/15','05/23','05/11','04/25','10/09','10/15','10/29','0122','0142','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('135992','IA','JASPER','NEWTON',4.171166666000000e+001,-9.302972200000001e+001,'05/02','10/26','05/17','05/02','04/18','10/11','10/26','11/06','0121','0154','0177')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('136103','IA','WORTH','NORTHWOOD',4.343861111000000e+001,-9.322527800000000e+001,'05/13','10/16','05/20','05/13','05/01','10/06','10/16','10/31','0121','0140','0159')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('136151','IA','POTTAWATTAMIE','OAKLAND',4.130444444000000e+001,-9.538444400000000e+001,'05/11','10/19','05/31','05/11','05/02','10/04','10/19','10/27','0109','0129','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('136305','IA','MITCHELL','OSAGE',4.327944444000000e+001,-9.281055600000001e+001,'05/11','10/18','05/18','05/11','04/27','10/07','10/18','11/03','0125','0144','0167')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('136316','IA','CLARKE','OSCEOLA',4.101944444000000e+001,-9.375027799999999e+001,'05/08','10/24','05/15','05/08','04/24','10/11','10/24','11/09','0131','0145','0171')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('136327','IA','MAHASKA','OSKALOOSA',4.132138888000000e+001,-9.264666699999999e+001,'05/04','10/20','05/16','05/04','04/22','10/11','10/20','11/05','0134','0149','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('136389','IA','WAPELLO','OTTUMWA INDUSTRIAL AP',4.110777777000000e+001,-9.244666700000001e+001,'04/26','10/30','05/11','04/26','04/18','10/20','10/30','11/13','0141','0166','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('136566','IA','DALLAS','PERRY',4.183944444000000e+001,-9.411055600000000e+001,'05/10','10/16','05/18','05/10','04/27','10/05','10/16','11/01','0123','0141','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('136719','IA','POCAHONTAS','POCAHONTAS',4.272916666000000e+001,-9.466138900000000e+001,'05/14','10/11','05/21','05/14','05/03','10/02','10/11','10/27','0117','0137','0152')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('136800','IA','O''BRIEN','PRIMGHAR',4.308638888000000e+001,-9.562916700000000e+001,'05/10','10/11','05/20','05/10','05/06','10/04','10/11','10/24','0119','0140','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('136910','IA','APPANOOSE','RATHBUN DAM',4.082500000000000e+001,-9.289250000000000e+001,'05/01','10/26','05/13','05/01','04/21','10/21','10/26','11/06','0139','0155','0172')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('136940','IA','MONTGOMERY','RED OAK',4.100361111000000e+001,-9.524194400000000e+001,'05/12','10/17','05/18','05/12','05/02','10/05','10/17','10/27','0119','0134','0156')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('137147','IA','LYON','ROCK RAPIDS',4.343000000000000e+001,-9.616861100000000e+001,'05/17','10/11','05/31','05/17','05/04','10/01','10/11','10/25','0106','0128','0152')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('137161','IA','CALHOUN','ROCKWELL CITY',4.239694444000000e+001,-9.462916700000000e+001,'05/11','10/19','05/16','05/11','04/28','10/07','10/19','10/29','0127','0142','0166')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('137312','IA','SAC','SAC CITY',4.241944444000000e+001,-9.497611100000000e+001,'05/11','10/19','05/22','05/11','04/30','10/05','10/19','10/31','0119','0137','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('137386','IA','O''BRIEN','SANBORN',4.317916666000000e+001,-9.566027800000001e+001,'05/13','10/13','05/22','05/13','05/06','10/06','10/13','10/25','0117','0136','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('137594','IA','O''BRIEN','SHELDON',4.318083333000000e+001,-9.585277800000000e+001,'05/19','10/09','05/30','05/19','05/07','09/30','10/09','10/23','0105','0124','0145')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('137613','IA','PAGE','SHENANDOAH',4.076722222000000e+001,-9.538000000000000e+001,'05/07','10/24','05/15','05/07','04/28','10/10','10/24','11/03','0128','0145','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('137664','IA','OSCEOLA','SIBLEY 3 NE',4.344027777000000e+001,-9.572250000000000e+001,'05/18','10/09','05/27','05/18','05/10','10/04','10/09','10/21','0112','0126','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('137669','IA','FREMONT','SIDNEY',4.074527777000000e+001,-9.564222200000000e+001,'05/01','10/29','05/10','05/01','04/19','10/19','10/29','11/14','0141','0162','0182')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('137678','IA','KEOKUK','SIGOURNEY',4.133277777000000e+001,-9.219750000000001e+001,'05/02','10/29','05/14','05/02','04/21','10/14','10/29','11/10','0138','0155','0176')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('137700','IA','SIOUX','SIOUX CTR 2 SE',4.305583333000000e+001,-9.615250000000000e+001,'05/14','10/11','06/01','05/14','05/04','09/30','10/11','10/25','0105','0131','0153')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('137708','IA','WOODBURY','SIOUX CITY AP',4.239138888000000e+001,-9.637916700000000e+001,'05/10','10/16','05/17','05/10','04/30','10/04','10/16','10/28','0124','0140','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('137726','IA','BUENA VISTA','SIOUX RAPIDS 4 E',4.289305555000000e+001,-9.506527800000001e+001,'05/13','10/11','05/24','05/13','05/04','10/02','10/11','10/24','0114','0135','0152')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('137844','IA','CLAY','SPENCER 1 N',4.316527777000000e+001,-9.514666699999999e+001,'05/14','10/10','05/24','05/14','05/07','09/30','10/10','10/24','0115','0132','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('137979','IA','BUENA VISTA','STORM LAKE 2 E',4.263472222000000e+001,-9.516944400000000e+001,'05/14','10/21','05/19','05/14','04/30','10/09','10/21','10/30','0126','0139','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('138026','IA','KOSSUTH','SWEA CITY 4W',4.340222222000000e+001,-9.438305600000000e+001,'05/14','10/13','05/18','05/14','04/30','10/04','10/13','10/26','0122','0134','0158')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('138296','IA','TAMA','TOLEDO 3N',4.203555555000000e+001,-9.258055600000000e+001,'05/13','10/16','05/26','05/13','05/03','10/07','10/16','11/01','0116','0137','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('138339','IA','BREMER','TRIPOLI',4.281250000000000e+001,-9.225749999999999e+001,'05/12','10/15','05/22','05/12','04/28','10/06','10/15','10/29','0122','0139','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('138568','IA','BENTON','VINTON',4.217027777000000e+001,-9.200777800000000e+001,'05/10','10/15','05/21','05/10','04/24','10/07','10/15','10/27','0119','0142','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('138688','IA','WASHINGTON','WASHINGTON',4.128277777000000e+001,-9.170666700000000e+001,'04/27','10/27','05/13','04/27','04/18','10/15','10/27','11/11','0137','0158','0177')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('138706','IA','BLACK HAWK','WATERLOO MUNICIPAL AP',4.255444444000000e+001,-9.240111100000000e+001,'05/14','10/12','05/23','05/14','05/01','10/02','10/12','10/25','0114','0134','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('138755','IA','ALLAMAKEE','WAUKON',4.327416666000000e+001,-9.147111099999999e+001,'05/12','10/18','05/20','05/12','05/02','10/09','10/18','11/01','0127','0141','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('138806','IA','HAMILTON','WEBSTER CITY',4.246861111000000e+001,-9.379722200000001e+001,'05/15','10/11','05/29','05/15','05/05','10/03','10/11','10/26','0109','0135','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('139067','IA','IOWA','WILLIAMSBURG 3SE',4.164027777000000e+001,-9.197833300000001e+001,'05/13','10/18','05/22','05/13','04/24','10/09','10/18','11/01','0121','0143','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('139132','IA','MADISON','WINTERSET 1N',4.135611111000000e+001,-9.401277800000000e+001,'05/12','10/16','05/23','05/12','04/30','10/06','10/16','10/31','0122','0139','0159')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('140010','KS','DICKINSON','ABILENE',3.892666666000000e+001,-9.721277800000000e+001,'05/02','11/02','05/14','05/02','04/20','10/19','11/02','11/17','0132','0155','0181')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('140264','KS','HARPER','ANTHONY',3.715500000000000e+001,-9.802833300000000e+001,'04/19','11/13','04/30','04/19','04/09','10/30','11/13','11/26','0160','0183','0205')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('140365','KS','CLARK','ASHLAND',3.719416666000000e+001,-9.976333300000000e+001,'05/05','10/25','05/13','05/05','04/26','10/16','10/25','11/06','0137','0148','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('140405','KS','ATCHISON','ATCHISON',3.957555555000000e+001,-9.511083300000000e+001,'04/22','11/07','05/01','04/22','04/14','10/25','11/07','11/17','0151','0176','0190')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('140439','KS','RAWLINS','ATWOOD',3.979972222000000e+001,-1.010422220000000e+002,'05/23','10/10','06/01','05/23','05/12','10/04','10/10','10/25','0110','0126','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('140682','KS','REPUBLIC','BELLEVILLE',3.981833333000000e+001,-9.763750000000000e+001,'05/04','10/27','05/14','05/04','04/21','10/14','10/27','11/06','0128','0156','0182')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('140693','KS','MITCHELL','BELOIT',3.945750000000000e+001,-9.811250000000000e+001,'05/03','10/29','05/15','05/03','04/19','10/16','10/29','11/08','0134','0158','0182')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('140865','KS','RUSH','BISON 3NW',3.856361111000000e+001,-9.923500000000000e+001,'05/07','10/28','05/20','05/07','04/23','10/16','10/28','11/08','0127','0148','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('141029','KS','SHERMAN','BREWSTER 4W',3.936861111000000e+001,-1.014466670000000e+002,'05/21','10/17','05/29','05/21','05/11','10/06','10/17','10/28','0113','0131','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('141351','KS','BUTLER','CASSODAY 2SW',3.803250000000000e+001,-9.667972200000000e+001,'05/03','10/28','05/12','05/03','04/24','10/20','10/28','11/08','0139','0155','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('141383','KS','TREGO','CEDAR BLUFF DAM',3.879777777000000e+001,-9.972305600000000e+001,'05/11','10/26','05/17','05/11','04/24','10/13','10/26','11/05','0131','0145','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('141522','KS','GRAY','CIMARRON',3.781305555000000e+001,-1.003455560000000e+002,'05/10','10/26','05/18','05/10','04/27','10/14','10/26','11/07','0130','0142','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('141559','KS','CLAY','CLAY CTR',3.937388888000000e+001,-9.712750000000000e+001,'05/02','10/30','05/16','05/02','04/15','10/19','10/30','11/12','0135','0161','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('141699','KS','THOMAS','COLBY 1SW',3.939250000000000e+001,-1.010688890000000e+002,'05/16','10/19','05/29','05/16','05/12','10/07','10/19','10/29','0114','0133','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('141704','KS','COMANCHE','COLDWATER',3.727055555000000e+001,-9.932722200000001e+001,'04/26','11/06','05/10','04/26','04/18','10/26','11/06','11/14','0146','0165','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('141740','KS','CHEROKEE','COLUMBUS',3.717638888000000e+001,-9.483972200000000e+001,'04/22','11/09','05/05','04/22','04/12','10/27','11/09','11/27','0150','0177','0202')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('141767','KS','CLOUD','CONCORDIA ASOS',3.955138888000000e+001,-9.765083300000001e+001,'05/04','11/01','05/12','05/04','04/17','10/21','11/01','11/14','0139','0159','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('141858','KS','CHASE','COTTONWOOD FALLS',3.837027777000000e+001,-9.654833300000000e+001,'04/28','10/29','05/12','04/28','04/19','10/15','10/29','11/11','0137','0160','0183')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('141867','KS','MORRIS','COUNCIL GROVE LAKE',3.867583333000000e+001,-9.650972200000000e+001,'05/01','10/29','05/11','05/01','04/15','10/19','10/29','11/10','0139','0157','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('142164','KS','FORD','DODGE CITY RGNL AP',3.776861111000000e+001,-9.996777800000000e+001,'05/05','11/02','05/14','05/05','04/20','10/23','11/02','11/10','0138','0161','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('142401','KS','BUTLER','EL DORADO',3.781833333000000e+001,-9.684444400000000e+001,'04/28','11/05','05/10','04/28','04/13','10/22','11/05','11/17','0143','0164','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('142432','KS','MORTON','ELKHART',3.700583333000000e+001,-1.018866670000000e+002,'05/07','11/02','05/13','05/07','04/23','10/21','11/02','11/13','0142','0157','0177')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('142622','KS','GREENWOOD','EUREKA 1E',3.782527777000000e+001,-9.626444400000000e+001,'04/24','11/03','05/10','04/24','04/15','10/22','11/03','11/17','0143','0166','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('142686','KS','GREENWOOD','FALL RIVER LAKE',3.764750000000000e+001,-9.607805600000000e+001,'04/25','11/08','05/05','04/25','04/12','10/27','11/08','11/24','0145','0169','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('142835','KS','BOURBON','FT SCOTT',3.784277777000000e+001,-9.470861100000001e+001,'04/21','11/08','05/06','04/21','04/12','10/27','11/08','11/24','0148','0180','0200')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('142894','KS','WILSON','FREDONIA',3.752916666000000e+001,-9.581444400000000e+001,'04/26','11/05','05/10','04/26','04/19','10/19','11/05','11/16','0145','0167','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('142980','KS','FINNEY','GARDEN CITY EXP STN',3.799305555000000e+001,-1.008122220000000e+002,'05/12','10/24','05/19','05/12','04/24','10/13','10/24','11/05','0127','0147','0167')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('143008','KS','ANDERSON','GARNETT 1 E',3.828000000000000e+001,-9.521777800000000e+001,'04/28','11/04','05/06','04/28','04/16','10/24','11/04','11/15','0145','0162','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('143074','KS','CRAWFORD','GIRARD',3.750805555000000e+001,-9.483916700000000e+001,'04/21','11/15','04/28','04/21','04/11','10/31','11/15','11/28','0159','0182','0203')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('143100','KS','MITCHELL','GLEN ELDER LAKE',3.950388888000000e+001,-9.831500000000000e+001,'05/08','10/28','05/16','05/08','04/27','10/16','10/28','11/13','0132','0156','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('143153','KS','SHERMAN','GOODLAND RENNER FLD',3.936722222000000e+001,-1.016933330000000e+002,'05/18','10/17','05/23','05/18','05/06','10/11','10/17','10/29','0120','0130','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('143218','KS','BARTON','GREAT BEND',3.837583333000000e+001,-9.878027800000000e+001,'04/26','11/04','05/10','04/26','04/13','10/26','11/04','11/13','0144','0166','0194')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('143239','KS','KIOWA','GREENSBURG',3.760250000000000e+001,-9.930222200000000e+001,'04/28','11/05','05/10','04/28','04/20','10/22','11/05','11/14','0143','0162','0182')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('143527','KS','ELLIS','HAYS 1 S',3.885861111000000e+001,-9.933583299999999e+001,'05/10','10/25','05/21','05/10','04/29','10/13','10/25','11/02','0126','0144','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('143554','KS','LANE','HEALY',3.860027777000000e+001,-1.006197220000000e+002,'05/15','10/24','05/23','05/15','05/02','10/13','10/24','11/01','0124','0138','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('143594','KS','DICKINSON','HERINGTON',3.866555555000000e+001,-9.694944400000000e+001,'05/10','10/26','05/17','05/10','04/23','10/15','10/26','11/07','0130','0147','0176')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('143759','KS','JACKSON','HOLTON',3.945777777000000e+001,-9.575500000000000e+001,'05/05','10/25','05/16','05/05','04/20','10/16','10/25','11/13','0132','0149','0177')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('143810','KS','BROWN','HORTON',3.966777777000000e+001,-9.552000000000000e+001,'05/05','10/24','05/11','05/05','04/22','10/17','10/24','11/10','0134','0151','0176')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('143822','KS','ELK','HOWARD 1W',3.746027777000000e+001,-9.628694400000001e+001,'04/25','11/02','05/11','04/25','04/20','10/21','11/02','11/13','0138','0163','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('143837','KS','SHERIDAN','HOXIE',3.935333333000000e+001,-1.004397220000000e+002,'05/16','10/22','05/24','05/16','05/05','10/11','10/22','10/31','0124','0133','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('143847','KS','STAFFORD','HUDSON',3.810416666000000e+001,-9.865916700000000e+001,'04/22','11/10','05/06','04/22','04/15','10/26','11/10','11/19','0150','0169','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('143855','KS','STEVENS','HUGOTON',3.716444444000000e+001,-1.013397220000000e+002,'05/03','11/03','05/14','05/03','04/18','10/22','11/03','11/15','0139','0160','0188')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('143930','KS','RENO','HUTCHINSON 10 SW',3.793111111000000e+001,-9.802972200000001e+001,'04/30','11/01','05/12','04/30','04/16','10/23','11/01','11/14','0143','0156','0191')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('143954','KS','MONTGOMERY','INDEPENDENCE',3.723638888000000e+001,-9.570027800000000e+001,'04/22','11/09','05/02','04/22','04/09','11/01','11/09','11/28','0152','0176','0204')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('143984','KS','ALLEN','IOLA 1 W',3.792333333000000e+001,-9.542416700000000e+001,'04/20','11/10','05/05','04/20','04/14','10/25','11/10','11/22','0151','0177','0194')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('144104','KS','COFFEY','JOHN REDMOND LAKE',3.825472222000000e+001,-9.575000000000000e+001,'04/25','11/06','05/09','04/25','04/14','10/22','11/06','11/16','0145','0167','0191')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('144178','KS','ELLSWORTH','KANOPOLIS LAKE',3.860777777000000e+001,-9.795972200000000e+001,'05/01','10/31','05/13','05/01','04/20','10/18','10/31','11/10','0133','0160','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('144313','KS','KINGMAN','KINGMAN',3.763611111000000e+001,-9.811361100000001e+001,'04/24','11/03','05/10','04/24','04/13','10/23','11/03','11/17','0145','0166','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('144357','KS','PHILLIPS','KIRWIN DAM',3.966194444000000e+001,-9.912277800000000e+001,'05/13','10/17','05/21','05/13','04/27','10/04','10/17','10/31','0120','0138','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('144464','KS','KEARNY','LAKIN',3.794111111000000e+001,-1.012491670000000e+002,'05/07','10/28','05/16','05/07','04/21','10/19','10/28','11/06','0130','0147','0173')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('144559','KS','DOUGLAS','LAWRENCE',3.895833333000000e+001,-9.525138900000000e+001,'04/21','11/11','05/03','04/21','04/12','10/31','11/11','11/23','0154','0186','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('144665','KS','WICHITA','LEOTI',3.847944444000000e+001,-1.013658330000000e+002,'05/20','10/21','05/24','05/20','05/03','10/12','10/21','10/30','0122','0132','0159')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('144695','KS','SEWARD','LIBERAL',3.702222222000000e+001,-1.009294440000000e+002,'04/29','11/06','05/09','04/29','04/16','10/29','11/06','11/13','0147','0169','0191')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('144712','KS','LINCOLN','LINCOLN 1 SE',3.902944444000000e+001,-9.813000000000000e+001,'05/11','10/22','05/19','05/11','05/04','10/10','10/22','11/02','0123','0137','0156')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('144972','KS','RILEY','MANHATTAN',3.919722222000000e+001,-9.658138900000000e+001,'05/05','10/29','05/15','05/05','04/22','10/15','10/29','11/10','0137','0154','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('144982','KS','JEWELL','MANKATO',3.978888888000000e+001,-9.820388900000000e+001,'05/11','10/25','05/19','05/11','05/03','10/11','10/25','11/07','0126','0143','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('145039','KS','MARION','MARION RSVR',3.837777777000000e+001,-9.707527800000000e+001,'04/26','11/03','05/13','04/26','04/15','10/21','11/03','11/16','0138','0164','0188')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('145063','KS','MARSHALL','MARYSVILLE',3.983833333000000e+001,-9.663638899999999e+001,'05/09','10/21','05/18','05/09','04/29','10/08','10/21','11/03','0127','0148','0171')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('145127','KS','RAWLINS','MC DONALD',3.978444444000000e+001,-1.013686110000000e+002,'05/15','10/23','05/23','05/15','05/05','10/12','10/23','11/01','0122','0137','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('145152','KS','MCPHERSON','MCPHERSON',3.837722222000000e+001,-9.760972200000001e+001,'04/29','11/03','05/12','04/29','04/13','10/19','11/03','11/12','0143','0165','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('145171','KS','MEADE','MEADE',3.728500000000000e+001,-1.003450000000000e+002,'05/05','10/31','05/11','05/05','04/17','10/21','10/31','11/11','0139','0158','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('145306','KS','GEARY','MILFORD LAKE',3.907444444000000e+001,-9.689833299999999e+001,'05/01','11/02','05/12','05/01','04/15','10/21','11/02','11/11','0138','0158','0188')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('145363','KS','OTTAWA','MINNEAPOLIS',3.912472222000000e+001,-9.770472200000000e+001,'05/02','11/01','05/14','05/02','04/18','10/17','11/01','11/09','0135','0160','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('145536','KS','LABETTE','MOUND VALLEY 3 WSW',3.718722222000000e+001,-9.545083300000000e+001,'04/28','11/03','05/11','04/28','04/19','10/20','11/03','11/16','0143','0159','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('145692','KS','NESS','NESS CITY',3.844777777000000e+001,-9.991000000000000e+001,'05/09','10/25','05/20','05/09','04/28','10/10','10/25','11/05','0127','0147','0171')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('145744','KS','HARVEY','NEWTON',3.803444444000000e+001,-9.734305600000000e+001,'04/29','11/05','05/07','04/29','04/15','10/22','11/05','11/18','0141','0164','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('145852','KS','NORTON','NORTON DAM',3.981138888000000e+001,-9.993861100000000e+001,'05/19','10/19','05/24','05/19','05/01','10/09','10/19','10/30','0123','0134','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('145856','KS','NORTON','NORTON 9SSE',3.974111111000000e+001,-9.983611100000000e+001,'05/13','10/27','05/16','05/13','05/02','10/14','10/27','11/03','0126','0142','0165')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('145870','KS','KINGMAN','NORWICH',3.745500000000000e+001,-9.784861100000001e+001,'04/18','11/17','05/03','04/18','04/11','11/04','11/17','11/26','0160','0185','0203')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('145888','KS','LOGAN','OAKLEY 4W',3.911305555000000e+001,-1.009447220000000e+002,'05/15','10/25','05/23','05/15','05/03','10/12','10/25','11/03','0124','0145','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('145906','KS','DECATUR','OBERLIN',3.981833333000000e+001,-1.005330560000000e+002,'05/16','10/16','05/28','05/16','05/10','10/07','10/16','10/27','0115','0130','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('146128','KS','FRANKLIN','OTTAWA',3.861333333000000e+001,-9.528083300000000e+001,'04/25','11/04','05/10','04/25','04/16','10/21','11/04','11/19','0143','0164','0188')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('146242','KS','LABETTE','PARSONS 2 NW',3.736777777000000e+001,-9.528916700000001e+001,'04/22','11/08','05/03','04/22','04/13','10/30','11/08','11/20','0150','0168','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('146333','KS','JEFFERSON','PERRY LAKE',3.911722222000000e+001,-9.540972200000000e+001,'04/28','10/30','05/10','04/28','04/14','10/18','10/30','11/16','0143','0160','0188')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('146435','KS','ROOKS','PLAINVILLE 4WNW',3.924500000000000e+001,-9.938083300000000e+001,'05/11','10/28','05/19','05/11','04/27','10/18','10/28','11/08','0125','0149','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('146498','KS','OSAGE','POMONA LAKE',3.864500000000000e+001,-9.556611100000001e+001,'04/22','11/05','05/05','04/22','04/13','10/27','11/05','11/18','0150','0175','0194')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('146549','KS','PRATT','PRATT',3.764555555000000e+001,-9.872805600000000e+001,'05/03','10/29','05/13','05/03','04/23','10/22','10/29','11/12','0135','0155','0177')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('146637','KS','GOVE','QUINTER',3.906638888000000e+001,-1.002394440000000e+002,'05/09','10/28','05/17','05/09','04/22','10/16','10/28','11/07','0131','0145','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('147093','KS','CHEYENNE','SAINT FRANCIS',3.976750000000000e+001,-1.018066670000000e+002,'05/15','10/21','05/22','05/15','05/04','10/09','10/21','10/30','0123','0136','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('318292','NC','IREDELL','STATESVILLE 2 NNE',3.581000000000000e+001,-8.088083300000000e+001,'05/09','11/01','05/17','05/09','04/24','10/19','11/01','11/15','0139','0152','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('318492','NC','GRAHAM','TAPOCO',3.544777777000000e+001,-8.393888900000000e+001,'05/02','11/14','05/14','05/02','04/23','10/22','11/14','11/25','0146','0170','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('318500','NC','EDGECOMBE','TARBORO 1 S',3.588472222000000e+001,-7.753861100000000e+001,'04/19','11/12','05/03','04/19','04/10','11/03','11/12','12/01','0164','0182','0206')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('318694','NC','ASHE','TRANSOU',3.639194444000000e+001,-8.130388900000000e+001,'06/02','10/13','06/15','06/02','05/19','10/03','10/13','10/18','0086','0112','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('318744','NC','POLK','TRYON',3.520583333000000e+001,-8.225166700000000e+001,'04/23','11/12','05/06','04/23','04/04','11/02','11/12','11/29','0162','0185','0212')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('318964','NC','ANSON','WADESBORO',3.496027777000000e+001,-8.007722200000001e+001,'04/12','11/25','04/24','04/12','03/30','11/10','11/25','12/12','0178','0198','0236')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('319123','NC','HAYWOOD','WATERVILLE 2',3.577416666000000e+001,-8.309805600000000e+001,'04/30','11/13','05/13','04/30','04/10','10/27','11/13','11/27','0151','0173','0211')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('319147','NC','HAYWOOD','WAYNESVILLE 1 E',3.548666666000000e+001,-8.296833300000000e+001,'05/19','10/18','06/06','05/19','05/07','10/12','10/18','10/31','0108','0131','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('319357','NC','COLUMBUS','WHITEVILLE 7 NW',3.440944444000000e+001,-7.879138900000000e+001,'04/17','11/18','05/01','04/17','04/06','11/04','11/18','12/02','0170','0190','0217')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('319423','NC','PENDER','WILLARD 4 SW',3.466055555000000e+001,-7.804527800000000e+001,'04/18','11/22','04/30','04/18','04/07','11/09','11/22','12/07','0165','0189','0211')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('319440','NC','MARTIN','WILLIAMSTON 1 E',3.585277777000000e+001,-7.703055600000000e+001,'04/15','11/22','04/26','04/15','04/01','11/08','11/22','12/12','0175','0192','0230')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('319457','NC','NEW HANOVER','WILMINGTON INTL AP',3.426750000000000e+001,-7.789972200000000e+001,'04/08','12/06','04/15','04/08','03/19','11/21','12/06','12/25','0191','0217','0250')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('319467','NC','NEW HANOVER','WILMINGTON 7 N',3.432083333000000e+001,-7.792055600000001e+001,'04/19','11/23','04/28','04/19','04/04','11/05','11/23','12/04','0175','0191','0222')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('319476','NC','WILSON','WILSON 3 SW',3.569388888000000e+001,-7.794555600000000e+001,'04/18','11/22','05/01','04/18','04/04','11/08','11/22','12/07','0166','0185','0213')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('319555','NC','WILKES','W KERR SCOTT RSVR',3.613083333000000e+001,-8.122750000000001e+001,'05/07','11/03','05/17','05/07','04/20','10/18','11/03','11/19','0140','0158','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('319675','NC','YADKIN','YADKINVILLE 6 E',3.613055555000000e+001,-8.054805600000000e+001,'05/07','10/31','05/15','05/07','04/21','10/23','10/31','11/13','0141','0163','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('320209','ND','SLOPE','AMIDON',4.648194444000000e+001,-1.033222220000000e+002,'05/31','10/04','06/13','05/31','05/18','09/26','10/04','10/17','0084','0111','0128')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('320382','ND','MCINTOSH','ASHLEY',4.604055555000000e+001,-9.937416700000000e+001,'05/25','10/01','06/22','05/25','05/19','09/26','10/01','10/10','0072','0111','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('320590','ND','GOLDEN VALLEY','BEACH',4.692833333000000e+001,-1.040158330000000e+002,'06/03','10/02','06/15','06/03','05/19','09/22','10/02','10/13','0081','0102','0124')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('320626','ND','ROLETTE','BELCOURT KEYA RADIO',4.884111111000000e+001,-9.975083300000000e+001,'06/16','09/26','07/10','06/16','05/27','09/16','09/26','10/05','0039','0074','0112')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('320819','ND','BURLEIGH','BISMARCK MUNI AP',4.678250000000000e+001,-1.007572220000000e+002,'05/28','10/03','06/19','05/28','05/18','09/23','10/03','10/14','0078','0110','0126')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('320941','ND','BOTTINEAU','BOTTINEAU',4.882166666000000e+001,-1.004525000000000e+002,'05/29','10/01','06/13','05/29','05/17','09/24','10/01','10/09','0086','0112','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('320995','ND','BOWMAN','BOWMAN',4.618250000000000e+001,-1.034061110000000e+002,'05/30','09/28','06/14','05/30','05/16','09/25','09/28','10/13','0084','0108','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('321225','ND','MCLEAN','BUTTE 5SE',4.779472222000000e+001,-1.005847220000000e+002,'05/21','10/06','06/02','05/21','05/18','09/26','10/06','10/19','0098','0118','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('321362','ND','FOSTER','CARRINGTON 4 N',4.750888888000000e+001,-9.912111100000000e+001,'05/26','09/29','06/17','05/26','05/17','09/23','09/29','10/11','0077','0109','0125')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('321435','ND','PEMBINA','CAVALIER 7NW',4.886277777000000e+001,-9.770138900000001e+001,'05/30','10/05','06/08','05/30','05/18','09/24','10/05','10/18','0090','0109','0130')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('321456','ND','OLIVER','CENTER 4SE',4.706444444000000e+001,-1.012119440000000e+002,'06/04','09/30','06/16','06/04','05/23','09/26','09/30','10/14','0074','0099','0119')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('321686','ND','STEELE','COLGATE',4.724277777000000e+001,-9.765611100000000e+001,'05/30','10/04','06/08','05/30','05/18','09/26','10/04','10/14','0081','0105','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('321766','ND','GRIGGS','COOPERSTOWN',4.740500000000000e+001,-9.803805600000000e+001,'05/24','10/03','06/08','05/24','05/15','09/24','10/03','10/12','0089','0113','0131')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('321871','ND','DIVIDE','CROSBY',4.890750000000000e+001,-1.032944440000000e+002,'05/27','10/04','06/09','05/27','05/19','09/23','10/04','10/13','0082','0109','0126')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('322158','ND','RAMSEY','DEVILS LAKE KDLR',4.810694444000000e+001,-9.886805600000000e+001,'05/20','10/08','06/03','05/20','05/15','10/01','10/08','10/20','0100','0122','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('322183','ND','STARK','THEODORE ROOSEVELT AP',4.679944444000000e+001,-1.027972220000000e+002,'05/28','10/04','06/11','05/28','05/17','09/26','10/04','10/17','0090','0109','0131')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('322188','ND','STARK','DICKINSON EXP STN',4.689111111000000e+001,-1.028111110000000e+002,'06/07','09/27','07/01','06/07','05/28','09/17','09/27','10/04','0058','0091','0113')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('322304','ND','MCHENRY','DRAKE 9 NE',4.804750000000000e+001,-1.003100000000000e+002,'05/23','10/04','06/03','05/23','05/20','09/25','10/04','10/14','0094','0112','0124')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('322365','ND','DUNN','DUNN CENTER 1E',4.734638888000000e+001,-1.025866670000000e+002,'05/28','10/05','06/10','05/28','05/19','09/25','10/05','10/18','0089','0109','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('322482','ND','LAMOURE','EDGELEY 3WNW',4.636944444000000e+001,-9.876611100000000e+001,'05/21','10/04','05/31','05/21','05/15','09/28','10/04','10/22','0105','0121','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('322525','ND','RAMSEY','EDMORE 1NW',4.842666666000000e+001,-9.847000000000000e+001,'06/04','10/01','06/30','06/04','05/23','09/21','10/01','10/06','0053','0093','0117')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('322605','ND','DICKEY','ELLENDALE',4.601083333000000e+001,-9.852611100000000e+001,'05/21','10/03','06/03','05/21','05/17','09/30','10/03','10/17','0095','0118','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('322695','ND','RANSOM','ENDERLIN 2W',4.661666666000000e+001,-9.763833300000000e+001,'05/20','10/04','06/04','05/20','05/14','09/25','10/04','10/18','0096','0121','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('322809','ND','BILLINGS','FAIRFIELD',4.719055555000000e+001,-1.032247220000000e+002,'05/28','10/06','06/13','05/28','05/18','09/25','10/06','10/18','0088','0109','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('322859','ND','CASS','FARGO HECTOR INTL AP',4.692527777000000e+001,-9.681111100000000e+001,'05/21','10/07','05/29','05/21','05/16','09/28','10/07','10/20','0103','0121','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('322949','ND','WELLS','FESSENDEN',4.764555555000000e+001,-9.962194400000000e+001,'05/22','10/08','06/02','05/22','05/15','09/28','10/08','10/17','0095','0117','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('323117','ND','SARGENT','FORMAN 5 SSE',4.603333333000000e+001,-9.759500000000000e+001,'05/23','10/05','06/02','05/23','05/15','09/27','10/05','10/16','0097','0115','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('323196','ND','DIVIDE','FORTUNA 1 W',4.890805555000000e+001,-1.038055560000000e+002,'05/28','09/29','06/13','05/28','05/19','09/19','09/29','10/10','0078','0102','0122')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('323217','ND','WARD','FOXHOLM 7 N',4.845833333000000e+001,-1.015697220000000e+002,'05/30','10/04','06/15','05/30','05/19','09/23','10/04','10/14','0071','0101','0117')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('323287','ND','DICKEY','FULLERTON 1 ESE',4.615805555000000e+001,-9.840000000000001e+001,'05/24','10/05','06/06','05/24','05/17','09/26','10/05','10/15','0088','0108','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('323376','ND','MCLEAN','GARRISON',4.765388888000000e+001,-1.014197220000000e+002,'05/29','09/30','06/15','05/29','05/23','09/24','09/30','10/11','0081','0107','0121')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('323616','ND','GRAND FORKS','GRAND FORKS INTL AP',4.794277777000000e+001,-9.718388899999999e+001,'05/30','10/06','06/12','05/30','05/15','09/27','10/06','10/20','0081','0106','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('323621','ND','GRAND FORKS','GRAND FORKS UNIV NWS',4.792166666000000e+001,-9.709805600000000e+001,'05/22','10/07','06/03','05/22','05/14','09/26','10/07','10/20','0098','0123','0139')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('323963','ND','TOWNER','HANSBORO 4 NNE',4.899888888000000e+001,-9.934638900000000e+001,'06/02','09/27','06/22','06/02','05/22','09/17','09/27','10/11','0067','0097','0120')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('324102','ND','MORTON','HEBRON',4.690750000000000e+001,-1.020383330000000e+002,'06/01','10/03','06/18','06/01','05/24','09/24','10/03','10/09','0070','0103','0120')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('324203','ND','TRAILL','HILLSBORO 3 N',4.743888888000000e+001,-9.706638900000000e+001,'05/19','10/08','05/28','05/19','05/13','10/01','10/08','10/21','0104','0126','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('324413','ND','STUTSMAN','JAMESTOWN MUNI AP',4.692583333000000e+001,-9.866916700000000e+001,'05/21','10/09','06/05','05/21','05/13','09/30','10/09','10/18','0097','0119','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('324418','ND','STUTSMAN','JAMESTOWN STATE HOSP',4.688444444000000e+001,-9.868500000000000e+001,'05/23','10/06','05/30','05/23','05/12','09/24','10/06','10/18','0102','0118','0139')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('324571','ND','MCKENZIE','KEENE 3S',4.789666666000000e+001,-1.029208330000000e+002,'06/07','09/29','06/18','06/07','05/22','09/19','09/29','10/09','0075','0091','0116')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('324646','ND','WARD','KENMARE 1 WSW',4.866916666000000e+001,-1.020975000000000e+002,'05/29','10/02','06/27','05/29','05/20','09/19','10/02','10/12','0061','0099','0113')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('324937','ND','LAMOURE','LA MOURE',4.635472222000000e+001,-9.829277800000000e+001,'05/31','10/04','06/10','05/31','05/19','09/25','10/04','10/09','0083','0102','0121')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('324958','ND','CAVALIER','LANGDON EXP FARM',4.876222222000000e+001,-9.834472200000000e+001,'06/03','09/30','06/20','06/03','05/20','09/24','09/30','10/12','0068','0099','0124')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('325220','ND','RANSOM','LISBON',4.643861111000000e+001,-9.768555600000001e+001,'05/23','10/04','06/10','05/23','05/16','09/25','10/04','10/12','0089','0115','0131')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('325479','ND','MORTON','MANDAN EXP STN',4.681277777000000e+001,-1.009097220000000e+002,'05/26','10/04','06/09','05/26','05/18','09/25','10/04','10/15','0090','0115','0128')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('325638','ND','MCLEAN','MAX',4.782138888000000e+001,-1.012922220000000e+002,'05/25','10/04','06/09','05/25','05/17','09/27','10/04','10/15','0088','0114','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('325710','ND','SHERIDAN','MC CLUSKY',4.748250000000000e+001,-1.004444440000000e+002,'05/22','10/07','05/30','05/22','05/13','09/28','10/07','10/16','0104','0120','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('325730','ND','FOSTER','MC HENRY 3W',4.758083333000000e+001,-9.864222200000000e+001,'05/23','10/02','06/08','05/23','05/16','09/28','10/02','10/14','0086','0112','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('325754','ND','RICHLAND','MC LEOD 3 E',4.640250000000000e+001,-9.723805600000000e+001,'05/23','10/05','06/07','05/23','05/16','09/25','10/05','10/13','0093','0117','0130')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('325813','ND','BILLINGS','MEDORA',4.691611111000000e+001,-1.035263890000000e+002,'06/08','09/26','06/22','06/08','05/23','09/19','09/26','10/07','0069','0099','0116')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('325988','ND','WARD','MINOT INTL AP',4.825527777000000e+001,-1.012733330000000e+002,'05/22','10/11','05/30','05/22','05/13','09/29','10/11','10/24','0105','0120','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('325993','ND','WARD','MINOT EXP STN',4.818027777000000e+001,-1.012963890000000e+002,'05/25','10/08','06/05','05/25','05/16','09/27','10/08','10/17','0092','0110','0132')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('326015','ND','BURLEIGH','MOFFIT 3 SE',4.667055555000000e+001,-1.002294440000000e+002,'06/03','10/03','06/27','06/03','05/21','09/27','10/03','10/09','0067','0101','0120')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('326025','ND','RENVILLE','MOHALL',4.876027777000000e+001,-1.015088890000000e+002,'05/27','10/02','06/09','05/27','05/20','09/22','10/02','10/17','0087','0104','0119')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('326255','ND','LOGAN','NAPOLEON',4.650666666000000e+001,-9.976916700000000e+001,'05/31','10/05','06/06','05/31','05/18','09/27','10/05','10/10','0091','0111','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('326315','ND','HETTINGER','NEW ENGLAND',4.654138888000000e+001,-1.028691670000000e+002,'05/31','09/30','06/12','05/31','05/20','09/22','09/30','10/13','0090','0106','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('326365','ND','MORTON','NEW SALEM 5NW',4.689250000000000e+001,-1.014897220000000e+002,'06/05','10/05','06/23','06/05','05/24','09/26','10/05','10/10','0066','0100','0117')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('326620','ND','DICKEY','OAKES',4.614583333000000e+001,-9.809194400000000e+001,'05/22','10/06','05/30','05/22','05/17','09/24','10/06','10/17','0101','0116','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('326947','ND','PEMBINA','PEMBINA',4.897111111000000e+001,-9.724166700000001e+001,'06/05','09/29','06/26','06/05','05/23','09/18','09/29','10/10','0063','0096','0121')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('327027','ND','NELSON','PETERSBURG 2 N',4.803555555000000e+001,-9.801000000000001e+001,'06/02','09/30','06/10','06/02','05/17','09/22','09/30','10/10','0082','0101','0124')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('327311','ND','GRANT','PRETTY ROCK',4.617583333000000e+001,-1.018561110000000e+002,'06/02','09/29','06/20','06/02','05/23','09/21','09/29','10/09','0076','0102','0119')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('327530','ND','STARK','RICHARDTON ABBEY',4.688861111000000e+001,-1.023191670000000e+002,'05/22','10/11','06/01','05/22','05/14','09/27','10/11','10/19','0106','0119','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('327585','ND','MCLEAN','RIVERDALE',4.749805555000000e+001,-1.013750000000000e+002,'05/22','10/07','05/31','05/22','05/13','09/27','10/07','10/14','0101','0116','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('327704','ND','PIERCE','RUGBY',4.835416666000000e+001,-9.999250000000001e+001,'05/30','10/04','06/07','05/30','05/20','09/28','10/04','10/18','0081','0108','0128')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('328276','ND','MOUNTRAIL','STANLEY 3 NNW',4.845638888000000e+001,-1.025947220000000e+002,'05/31','09/30','06/13','05/31','05/18','09/22','09/30','10/10','0081','0097','0123')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('328366','ND','KIDDER','STEELE 3N',4.689166666000000e+001,-9.993250000000001e+001,'05/27','10/05','06/08','05/27','05/12','09/30','10/05','10/13','0082','0113','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('328737','ND','WILLIAMS','TIOGA 1E',4.839888888000000e+001,-1.029180560000000e+002,'06/09','09/26','07/04','06/09','05/26','09/19','09/26','10/05','0060','0088','0109')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('328792','ND','MCHENRY','TOWNER 2 NE',4.837055555000000e+001,-1.003908330000000e+002,'06/04','10/02','06/23','06/04','05/22','09/21','10/02','10/11','0063','0095','0116')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('328840','ND','MCLEAN','TURTLE LAKE',4.752138888000000e+001,-1.008883330000000e+002,'05/27','10/03','06/07','05/27','05/20','09/26','10/03','10/12','0091','0107','0125')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('328872','ND','MCLEAN','UNDERWOOD',4.745500000000000e+001,-1.011461110000000e+002,'05/25','10/06','06/05','05/25','05/14','09/29','10/06','10/16','0095','0117','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('328913','ND','MCHENRY','UPHAM 3 N',4.861472222000000e+001,-1.007263890000000e+002,'05/31','09/25','06/27','05/31','05/23','09/19','09/25','10/03','0059','0094','0117')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('328937','ND','BARNES','VALLEY CITY 3 NNW',4.695583333000000e+001,-9.802027800000001e+001,'05/24','10/02','06/05','05/24','05/17','09/24','10/02','10/12','0092','0113','0130')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('328990','ND','MCHENRY','VELVA 3NE',4.807972222000000e+001,-1.008750000000000e+002,'05/29','10/05','06/10','05/29','05/19','09/24','10/05','10/12','0083','0105','0128')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('329233','ND','MCKENZIE','WATFORD CITY',4.780388888000000e+001,-1.032891670000000e+002,'06/01','09/26','06/18','06/01','05/19','09/22','09/26','10/08','0076','0102','0122')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('329246','ND','MCKENZIE','WATFORD CITY 14S',4.760000000000000e+001,-1.032597220000000e+002,'05/31','09/25','06/17','05/31','05/22','09/18','09/25','10/06','0072','0097','0118')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('329333','ND','BOTTINEAU','WESTHOPE',4.890972222000000e+001,-1.010191670000000e+002,'05/29','10/01','06/20','05/29','05/21','09/23','10/01','10/07','0070','0104','0120')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('329400','ND','DIVIDE','WILDROSE 3NW',4.866305555000000e+001,-1.032130560000000e+002,'05/27','09/30','06/09','05/27','05/19','09/21','09/30','10/08','0084','0106','0125')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('329425','ND','WILLIAMS','WILLISTON SLOULIN FLD',4.817388888000000e+001,-1.036366670000000e+002,'05/30','10/04','06/14','05/30','05/19','09/21','10/04','10/12','0088','0107','0125')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('329430','ND','WILLIAMS','WILLISTON EXP FARM',4.813750000000000e+001,-1.037372220000000e+002,'05/24','10/04','06/03','05/24','05/16','09/24','10/04','10/17','0100','0112','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('329445','ND','BOTTINEAU','WILLOW CITY',4.860611111000000e+001,-1.002911110000000e+002,'06/02','09/30','06/18','06/02','05/20','09/22','09/30','10/08','0062','0096','0122')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('329515','ND','MCINTOSH','WISHEK',4.626083333000000e+001,-9.956000000000000e+001,'06/12','10/04','06/25','06/12','05/27','09/29','10/04','10/10','0058','0090','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('330058','OH','SUMMIT','AKRON CANTON WSO AP',4.091666666000000e+001,-8.143333300000001e+001,'05/15','11/03','05/26','05/15','04/28','10/20','11/03','11/15','0134','0153','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('330256','OH','ASHLAND','ASHLAND 2 SW',4.083333333000000e+001,-8.234999999999999e+001,'05/19','10/22','06/02','05/19','05/07','10/08','10/22','11/05','0113','0137','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('330279','OH','ATHENS','ATHENS 1 N',3.934277777000000e+001,-8.209638900000000e+001,'05/21','10/20','06/05','05/21','05/06','10/10','10/20','11/01','0107','0128','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('330563','OH','LOGAN','BELLEFONTAINE',4.035333333000000e+001,-8.377472200000000e+001,'05/15','10/25','05/20','05/15','04/28','10/12','10/25','11/12','0129','0144','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('330862','OH','WOOD','BOWLING GREEN WWTP',4.138305555000000e+001,-8.361111099999999e+001,'05/10','10/28','05/23','05/10','04/27','10/15','10/28','11/11','0128','0148','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('331072','OH','CRAWFORD','BUCYRUS',4.081277777000000e+001,-8.296944400000000e+001,'05/12','10/26','05/21','05/12','04/26','10/13','10/26','11/13','0129','0152','0171')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('331152','OH','HARRISON','CADIZ',4.026861111000000e+001,-8.099805600000001e+001,'05/09','11/01','05/23','05/09','04/29','10/19','11/01','11/16','0131','0154','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('331197','OH','GUERNSEY','CAMBRIDGE',4.001666666000000e+001,-8.158333300000000e+001,'05/22','10/23','05/29','05/22','04/27','10/13','10/23','11/10','0123','0140','0171')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('331390','OH','MERCER','CELINA 3 NE',4.056944444000000e+001,-8.453638900000000e+001,'05/10','10/28','05/18','05/10','04/24','10/15','10/28','11/13','0131','0149','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('331404','OH','KNOX','CENTERBURG 2 SE',4.030000000000000e+001,-8.265000000000001e+001,'05/17','10/22','05/23','05/17','04/30','10/09','10/22','11/09','0126','0142','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('331458','OH','GEAUGA','CHARDON',4.158333333000000e+001,-8.118333300000001e+001,'05/28','10/23','06/16','05/28','05/11','10/08','10/23','11/13','0102','0127','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('331515','OH','HAMILTON','CHEVIOT',3.915472222000000e+001,-8.462333300000000e+001,'05/03','10/29','05/15','05/03','04/22','10/17','10/29','11/13','0143','0161','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('331536','OH','CLERMONT','CHILO MELDAHL L&D',3.879833333000000e+001,-8.417305600000000e+001,'05/02','11/11','05/17','05/02','04/19','10/28','11/11','11/23','0141','0168','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('331541','OH','MEDINA','CHIPPEWA LAKE',4.105166666000000e+001,-8.193611100000000e+001,'05/19','10/25','06/04','05/19','05/13','10/07','10/25','11/13','0108','0139','0153')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('331592','OH','PICKAWAY','CIRCLEVILLE',3.961055555000000e+001,-8.295472200000000e+001,'05/06','11/04','05/19','05/06','04/21','10/16','11/04','11/18','0134','0155','0182')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('331657','OH','CUYAHOGA','CLEVELAND WSFO AP',4.140500000000000e+001,-8.185277800000000e+001,'05/16','11/07','05/27','05/16','04/30','10/20','11/07','11/17','0128','0156','0183')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('331783','OH','FRANKLIN','COLUMBUS VLY CROSSING',3.990472222000000e+001,-8.292000000000000e+001,'05/09','10/27','05/13','05/09','04/23','10/15','10/27','11/14','0138','0151','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('331786','OH','FRANKLIN','COLUMBUS WSO AP',3.999138888000000e+001,-8.288083300000000e+001,'05/09','11/03','05/23','05/09','04/24','10/17','11/03','11/16','0130','0157','0182')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('331890','OH','COSHOCTON','COSHOCTON WPC PLT',4.024027777000000e+001,-8.187111100000000e+001,'05/18','10/25','05/27','05/18','05/03','10/11','10/25','11/07','0121','0139','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('331905','OH','COSHOCTON','COSHOCTON AG RSCH STN',4.037083333000000e+001,-8.179083300000001e+001,'05/04','11/02','05/17','05/04','04/23','10/19','11/02','11/18','0137','0160','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('332044','OH','KNOX','DANVILLE 2 W',4.043972222000000e+001,-8.230388900000000e+001,'05/27','10/09','06/13','05/27','05/18','09/30','10/09','10/25','0091','0119','0143')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('332067','OH','MONTGOMERY','DAYTON MCD',3.976333333000000e+001,-8.419111100000001e+001,'04/22','11/13','05/06','04/22','04/17','11/04','11/13','11/21','0153','0183','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('332075','OH','MONTGOMERY','DAYTON WSO AP',3.990611111000000e+001,-8.421861100000000e+001,'05/06','11/04','05/14','05/06','04/22','10/19','11/04','11/15','0139','0155','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('332098','OH','DEFIANCE','DEFIANCE',4.127777777000000e+001,-8.438527800000000e+001,'05/11','11/03','05/19','05/11','04/27','10/18','11/03','11/14','0133','0148','0172')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('332251','OH','ASHTABULA','DORSET',4.168333333000000e+001,-8.066666700000000e+001,'06/08','10/20','06/17','06/08','05/14','10/07','10/20','11/06','0090','0109','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('332485','OH','PREBLE','EATON',3.973472222000000e+001,-8.463361100000000e+001,'05/15','10/26','05/25','05/15','05/01','10/11','10/26','11/08','0125','0141','0159')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('332599','OH','LORAIN','ELYRIA 3 E',4.138333333000000e+001,-8.205000000000000e+001,'05/12','11/03','05/27','05/12','04/29','10/18','11/03','11/15','0129','0155','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('332786','OH','HANCOCK','FINDLAY FAA AP',4.101361111000000e+001,-8.366861100000000e+001,'05/07','10/28','05/16','05/07','04/22','10/17','10/28','11/12','0137','0153','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('332791','OH','HANCOCK','FINDLAY WPCC',4.104611111000000e+001,-8.366222200000000e+001,'05/11','11/03','05/15','05/11','04/26','10/17','11/03','11/14','0137','0148','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('332928','OH','WARREN','FRANKLIN',3.955361111000000e+001,-8.431888900000000e+001,'05/09','10/23','05/16','05/09','04/23','10/12','10/23','11/08','0134','0151','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('332956','OH','KNOX','FREDERICKTOWN 4 S',4.041666666000000e+001,-8.253333300000000e+001,'05/17','10/13','06/01','05/17','05/05','10/02','10/13','10/29','0107','0128','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('332974','OH','SANDUSKY','FREMONT',4.133333333000000e+001,-8.311666700000001e+001,'05/09','10/29','05/17','05/09','04/20','10/15','10/29','11/12','0135','0153','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('333029','OH','GALLIA','GALLIPOLIS',3.882027777000000e+001,-8.218222200000000e+001,'05/12','11/03','05/22','05/12','04/30','10/22','11/03','11/15','0131','0149','0171')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('333375','OH','DARKE','GREENVILLE WTP',4.010000000000000e+001,-8.465000000000001e+001,'05/11','10/22','05/21','05/11','05/01','10/09','10/22','11/01','0122','0144','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('333758','OH','HIGHLAND','HILLSBORO',3.923333333000000e+001,-8.360916700000000e+001,'05/01','11/09','05/14','05/01','04/20','10/27','11/09','11/21','0141','0164','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('333780','OH','PORTAGE','HIRAM',4.130000000000000e+001,-8.115000000000001e+001,'05/10','11/03','05/27','05/10','05/01','10/17','11/03','11/12','0130','0153','0182')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('333874','OH','WOOD','HOYTVILLE 2 NE',4.121666666000000e+001,-8.376666700000000e+001,'05/13','10/20','05/27','05/13','05/02','10/09','10/20','11/08','0120','0142','0158')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('334004','OH','JACKSON','JACKSON 3 NW',3.908000000000000e+001,-8.270777800000001e+001,'05/21','10/25','05/28','05/21','05/05','10/16','10/25','11/07','0119','0138','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('334189','OH','HARDIN','KENTON',4.064888888000000e+001,-8.360611100000000e+001,'05/12','10/30','05/24','05/12','04/29','10/17','10/30','11/15','0127','0144','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('334551','OH','ALLEN','LIMA WWTP',4.072472222000000e+001,-8.412944400000001e+001,'05/11','11/01','05/19','05/11','04/28','10/18','11/01','11/17','0134','0151','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('334865','OH','RICHLAND','MANSFIELD WSO AP',4.082027777000000e+001,-8.251777800000001e+001,'05/09','11/03','05/20','05/09','04/28','10/14','11/03','11/12','0133','0152','0176')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('334874','OH','RICHLAND','MANSFIELD 5 W',4.076666666000000e+001,-8.261666700000001e+001,'05/22','10/17','06/05','05/22','05/14','10/09','10/17','11/06','0111','0129','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('334927','OH','WASHINGTON','MARIETTA WWTP',3.940888888000000e+001,-8.143277800000000e+001,'05/10','11/04','05/16','05/10','04/21','10/22','11/04','11/15','0140','0155','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('334942','OH','MARION','MARION 2 N',4.061666666000000e+001,-8.313333299999999e+001,'05/11','10/24','05/24','05/11','04/27','10/15','10/24','11/10','0124','0146','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('334979','OH','UNION','MARYSVILLE',4.024111111000000e+001,-8.336694400000000e+001,'05/06','11/03','05/21','05/06','04/23','10/17','11/03','11/15','0131','0149','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('335041','OH','MORGAN','MC CONNELLSVILLE LK 7',3.965222222000000e+001,-8.185611100000000e+001,'05/20','10/28','05/29','05/20','05/06','10/15','10/28','11/12','0122','0144','0165')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('335297','OH','HOLMES','MILLERSBURG',4.055000000000000e+001,-8.191666700000000e+001,'05/23','10/20','05/31','05/23','05/05','10/06','10/20','11/04','0117','0134','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('335315','OH','COLUMBIANA','MILLPORT 4 NE',4.076916666000000e+001,-8.085611100000000e+001,'06/01','10/06','06/16','06/01','05/18','09/30','10/06','10/25','0087','0115','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('335438','OH','WILLIAMS','MONTPELIER',4.158861111000000e+001,-8.458499999999999e+001,'05/15','10/21','05/29','05/15','05/03','10/10','10/21','11/04','0120','0138','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('335747','OH','LICKING','NEWARK WATER WKS',4.008750000000000e+001,-8.241277800000000e+001,'05/18','10/26','05/26','05/18','04/26','10/10','10/26','11/10','0122','0143','0172')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('335857','OH','PERRY','NEW LEXINGTON 2 NW',3.973333333000000e+001,-8.221555600000001e+001,'05/20','10/18','05/30','05/20','05/04','10/10','10/18','11/06','0117','0135','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('336118','OH','HURON','NORWALK WWTP',4.126666666000000e+001,-8.261666700000001e+001,'05/10','11/04','05/26','05/10','05/01','10/16','11/04','11/16','0125','0151','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('336196','OH','LORAIN','OBERLIN',4.126666666000000e+001,-8.221666700000000e+001,'05/22','10/31','06/04','05/22','05/09','10/12','10/31','11/12','0108','0130','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('336389','OH','LAKE','PAINESVILLE 4 NW',4.175000000000000e+001,-8.130000000000000e+001,'05/02','11/13','05/16','05/02','04/20','11/05','11/13','11/28','0149','0169','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('336405','OH','PUTNAM','PANDORA',4.094611111000000e+001,-8.396138900000000e+001,'05/12','10/26','05/17','05/12','04/27','10/16','10/26','11/09','0133','0145','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('336465','OH','PAULDING','PAULDING',4.112444444000000e+001,-8.459222200000001e+001,'05/14','10/23','05/25','05/14','05/03','10/11','10/23','11/04','0122','0139','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('336600','OH','MUSKINGUM','PHILO 3 SW',3.983861111000000e+001,-8.191666700000000e+001,'05/16','10/27','06/02','05/16','05/04','10/11','10/27','11/08','0117','0138','0156')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('336781','OH','SCIOTO','PORTSMOUTH-SCIOTOVILLE',3.875694444000000e+001,-8.288722199999999e+001,'04/28','11/04','05/15','04/28','04/20','10/24','11/04','11/19','0132','0157','0181')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('337447','OH','ERIE','SANDUSKY',4.145000000000000e+001,-8.271666700000000e+001,'04/28','11/14','05/08','04/28','04/15','10/30','11/14','11/24','0157','0176','0200')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('337935','OH','CLARK','SPRINGFIELD NEW WATER WKS',3.996666666000000e+001,-8.381666700000000e+001,'05/13','10/20','05/26','05/13','04/30','10/11','10/20','11/10','0122','0145','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('338025','OH','JEFFERSON','STEUBENVILLE',4.037638888000000e+001,-8.062833300000000e+001,'05/09','11/06','05/24','05/09','04/25','10/22','11/06','11/17','0134','0161','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('338313','OH','SENECA','TIFFIN',4.111666666000000e+001,-8.316666700000000e+001,'05/08','10/31','05/17','05/08','04/26','10/16','10/31','11/12','0135','0152','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('338357','OH','LUCAS','TOLEDO EXPRESS WSO AP',4.158861111000000e+001,-8.380138900000000e+001,'05/18','10/22','05/29','05/18','05/03','10/09','10/22','11/08','0119','0136','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('338534','OH','WYANDOT','UPPER SANDUSKY',4.083333333000000e+001,-8.328333300000000e+001,'05/13','10/27','05/19','05/13','04/28','10/14','10/27','11/12','0132','0146','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('338552','OH','CHAMPAIGN','URBANA WWTP',4.009861111000000e+001,-8.378222200000000e+001,'05/09','10/28','05/25','05/09','04/23','10/12','10/28','11/12','0128','0147','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('338609','OH','VAN WERT','VAN WERT 1 S',4.084944444000000e+001,-8.458083300000000e+001,'05/09','10/30','05/17','05/09','04/25','10/17','10/30','11/14','0135','0149','0173')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('338769','OH','TRUMBULL','WARREN 3 S',4.120000000000000e+001,-8.081666700000000e+001,'06/01','10/17','06/14','06/01','05/17','10/05','10/17','11/01','0097','0120','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('338794','OH','FAYETTE','WASHINGTON COURT HOUSE',3.954666666000000e+001,-8.341527800000000e+001,'05/04','11/03','05/13','05/04','04/20','10/18','11/03','11/17','0142','0159','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('338822','OH','FULTON','WAUSEON WTP',4.151833333000000e+001,-8.414527800000001e+001,'05/13','10/21','05/21','05/13','05/02','10/13','10/21','11/07','0131','0141','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('338830','OH','PIKE','WAVERLY',3.911138888000000e+001,-8.297972200000000e+001,'05/18','10/22','05/26','05/18','05/02','10/12','10/22','11/09','0124','0140','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('338951','OH','FRANKLIN','WESTERVILLE',4.012638888000000e+001,-8.294333300000000e+001,'05/13','10/23','05/31','05/13','05/01','10/12','10/23','11/10','0118','0143','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('339219','OH','CLINTON','WILMINGTON 3 N',3.948333333000000e+001,-8.384999999999999e+001,'05/10','10/27','05/13','05/10','04/25','10/12','10/27','11/11','0135','0149','0171')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('339312','OH','WAYNE','WOOSTER EXP STN',4.078333333000000e+001,-8.191666700000000e+001,'05/19','10/19','05/30','05/19','04/30','10/08','10/19','11/06','0116','0140','0165')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('339361','OH','GREENE','XENIA 6 SSE',3.961666666000000e+001,-8.390000000000001e+001,'05/09','10/27','05/19','05/09','04/26','10/09','10/27','11/09','0127','0147','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('339406','OH','TRUMBULL','YOUNGSTOWN WSO AP',4.125444444000000e+001,-8.067388900000000e+001,'05/22','10/31','06/09','05/22','05/02','10/08','10/31','11/07','0108','0135','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('340184','OK','KIOWA','ALTUS DAM',3.488472222000000e+001,-9.929638900000001e+001,'04/13','11/21','04/23','04/13','04/10','11/09','11/21','11/29','0170','0194','0208')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('340193','OK','WOODS','ALVA 1W',3.680138888000000e+001,-9.868777799999999e+001,'04/19','11/13','05/01','04/19','04/11','11/02','11/13','11/25','0154','0183','0202')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('340224','OK','CADDO','ANADARKO 3 E',3.506194444000000e+001,-9.819888899999999e+001,'04/20','11/10','05/03','04/20','04/13','10/27','11/10','11/24','0154','0175','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('340256','OK','PUSHMATAHA','ANTLERS',3.422083333000000e+001,-9.561500000000000e+001,'04/17','11/16','04/24','04/17','04/08','11/04','11/16','12/30','0170','0190','0211')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('340292','OK','CARTER','ARDMORE',3.417722222000000e+001,-9.716166699999999e+001,'04/12','12/03','04/17','04/12','03/29','11/21','12/03','12/15','0195','0211','0238')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('340332','OK','ELLIS','ARNETT 3NE',3.616694444000000e+001,-9.972138900000000e+001,'04/23','11/09','05/06','04/23','04/13','10/25','11/09','11/20','0151','0176','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('340548','OK','OSAGE','BARTLESVILLE MUNICIPAL AP',3.676833333000000e+001,-9.602611100000000e+001,'04/19','11/10','05/02','04/19','04/11','10/22','11/10','11/19','0151','0176','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('340593','OK','BEAVER','BEAVER',3.681250000000000e+001,-1.005308330000000e+002,'05/05','10/29','05/14','05/05','04/27','10/20','10/29','11/11','0138','0156','0173')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('340755','OK','NOBLE','BILLINGS',3.652972222000000e+001,-9.744722200000000e+001,'04/22','11/14','05/03','04/22','04/13','11/01','11/14','11/27','0158','0181','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('340830','OK','MCCLAIN','BLANCHARD 2 SSW',3.511833333000000e+001,-9.767000000000000e+001,'04/17','11/22','05/01','04/17','04/04','11/08','11/22','11/30','0167','0193','0220')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('340908','OK','CIMARRON','BOISE CITY 2 E',3.672361111000000e+001,-1.024805560000000e+002,'05/13','10/26','05/19','05/13','04/29','10/18','10/26','11/08','0130','0144','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('341144','OK','CREEK','BRISTOW',3.582916666000000e+001,-9.639166700000000e+001,'04/15','11/10','05/02','04/15','04/11','10/26','11/10','11/25','0157','0183','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('341243','OK','HARPER','BUFFALO 2 SSW',3.680027777000000e+001,-9.964000000000000e+001,'04/26','10/30','05/13','04/26','04/14','10/22','10/30','11/12','0142','0167','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('341684','OK','LINCOLN','CHANDLER',3.570611111000000e+001,-9.688000000000000e+001,'04/15','11/19','04/25','04/15','04/05','11/04','11/19','12/02','0176','0196','0215')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('341706','OK','COMANCHE','CHATTANOOGA',3.442250000000000e+001,-9.864972200000000e+001,'04/16','11/21','04/28','04/16','04/08','11/07','11/21','11/30','0166','0193','0210')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('341724','OK','ALFALFA','CHEROKEE 4W',3.676722222000000e+001,-9.842444399999999e+001,'04/20','11/12','05/04','04/20','04/10','10/31','11/12','11/26','0153','0182','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('341750','OK','GRADY','CHICKASHA EXP STATION',3.504888888000000e+001,-9.791583300000001e+001,'04/17','11/12','04/27','04/17','04/09','11/03','11/12','11/30','0165','0189','0209')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('341828','OK','ROGERS','CLAREMORE 2 ENE',3.632250000000000e+001,-9.558083300000000e+001,'04/17','11/12','05/01','04/17','04/11','10/30','11/12','12/02','0158','0187','0205')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('342318','OK','PAYNE','CUSHING',3.598027777000000e+001,-9.677583300000001e+001,'04/13','11/24','04/18','04/13','03/30','11/11','11/24','12/06','0180','0197','0222')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('342660','OK','STEPHENS','DUNCAN',3.450111111000000e+001,-9.795916699999999e+001,'04/12','11/25','04/16','04/12','04/02','11/13','11/25','12/08','0190','0204','0224')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('342678','OK','BRYAN','DURANT',3.400000000000000e+001,-9.636861100000000e+001,'04/14','11/25','04/23','04/14','04/07','11/11','11/25','12/10','0177','0195','0211')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('342912','OK','GARFIELD','ENID',3.641944444000000e+001,-9.787472200000001e+001,'04/17','11/16','04/26','04/17','04/13','11/05','11/16','11/28','0172','0195','0209')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('342944','OK','BECKHAM','ERICK',3.521638888000000e+001,-9.986277800000001e+001,'04/20','11/12','05/06','04/20','04/12','10/26','11/12','11/23','0150','0175','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('343304','OK','WOODWARD','FORT SUPPLY 3SE',3.654416666000000e+001,-9.953500000000000e+001,'04/24','11/03','05/13','04/24','04/14','10/23','11/03','11/16','0143','0170','0195')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('343358','OK','WOODS','FREEDOM',3.676472222000000e+001,-9.911277800000001e+001,'04/26','10/30','05/10','04/26','04/21','10/19','10/30','11/14','0145','0160','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('343407','OK','ELLIS','GAGE AP',3.629666666000000e+001,-9.976888900000000e+001,'04/28','11/01','05/12','04/28','04/15','10/23','11/01','11/15','0137','0155','0190')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('343489','OK','BEAVER','GATE',3.685000000000000e+001,-1.000569440000000e+002,'04/27','11/08','05/09','04/27','04/12','10/31','11/08','11/18','0152','0173','0197')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('343497','OK','BLAINE','GEARY',3.563055555000000e+001,-9.832166700000001e+001,'04/13','11/26','04/28','04/13','04/10','11/14','11/26','12/02','0163','0191','0214')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('343628','OK','TEXAS','GOODWELL RSCH STN',3.659138888000000e+001,-1.016180560000000e+002,'05/10','10/31','05/15','05/10','04/27','10/20','10/31','11/11','0137','0153','0177')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('343740','OK','ALFALFA','GREAT SALT PLAINS DAM',3.674250000000000e+001,-9.813305600000000e+001,'04/14','11/15','04/25','04/14','04/11','11/05','11/15','11/29','0169','0197','0205')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('343821','OK','LOGAN','GUTHRIE 5S',3.581611111000000e+001,-9.739500000000000e+001,'04/18','11/14','05/03','04/18','04/12','11/05','11/14','11/28','0156','0184','0203')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('344001','OK','CARTER','HEALDTON 3 E',3.423333333000000e+001,-9.742027800000000e+001,'04/21','11/14','05/05','04/21','04/11','11/05','11/14','11/29','0162','0186','0207')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('344019','OK','ALFALFA','HELENA 1 SSE',3.653805555000000e+001,-9.826611100000000e+001,'04/19','11/12','05/02','04/19','04/14','10/31','11/12','11/27','0160','0183','0195')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('344055','OK','KINGFISHER','HENNESSEY 4 ESE',3.609416666000000e+001,-9.783499999999999e+001,'04/18','11/16','05/02','04/18','04/11','11/06','11/16','11/28','0163','0187','0203')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('344204','OK','KIOWA','HOBART MUNICIPAL  AIRPORT',3.498944444000000e+001,-9.905250000000000e+001,'04/17','11/23','04/28','04/17','04/10','11/09','11/23','12/02','0164','0187','0212')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('344235','OK','HUGHES','HOLDENVILLE 2SSE',3.505666666000000e+001,-9.638611100000000e+001,'04/15','11/21','04/24','04/15','04/06','11/09','11/21','12/02','0168','0194','0213')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('344451','OK','MCCURTAIN','IDABEL',3.393361111000000e+001,-9.482777800000000e+001,'04/16','11/22','04/21','04/16','04/06','11/10','11/22','11/30','0174','0197','0215')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('344573','OK','GRANT','JEFFERSON',3.672222222000000e+001,-9.779027800000000e+001,'04/24','11/08','05/07','04/24','04/12','10/27','11/08','11/25','0152','0166','0195')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('344672','OK','DELAWARE','KANSAS 2 NE',3.621333333000000e+001,-9.477249999999999e+001,'04/18','11/12','04/30','04/18','04/10','11/02','11/12','11/29','0158','0189','0207')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('344861','OK','KINGFISHER','KINGFISHER',3.585833333000000e+001,-9.792944400000000e+001,'04/19','11/15','05/04','04/19','04/13','11/02','11/15','11/26','0161','0183','0202')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('345063','OK','COMANCHE','LAWTON',3.460972222000000e+001,-9.845722200000000e+001,'04/11','11/25','04/19','04/11','03/31','11/10','11/25','12/02','0184','0204','0225')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('345468','OK','MARSHALL','MADILL',3.409194444000000e+001,-9.677083300000000e+001,'04/08','11/28','04/18','04/08','03/29','11/14','11/28','12/09','0189','0207','0226')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('345509','OK','GREER','MANGUM',3.489111111000000e+001,-9.950166700000000e+001,'04/14','11/21','04/28','04/14','04/11','11/04','11/21','11/27','0165','0189','0206')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('345522','OK','PAWNEE','MANNFORD 6 NW',3.617472222000000e+001,-9.644333300000000e+001,'04/15','11/10','05/06','04/15','04/10','10/23','11/10','11/22','0152','0179','0200')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('345563','OK','LOVE','MARIETTA 5SW',3.387611111000000e+001,-9.716416700000001e+001,'04/12','11/23','04/17','04/12','03/31','11/14','11/23','12/06','0187','0205','0222')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('345664','OK','PITTSBURG','MCALESTER REGIONAL AIRPORT',3.488222222000000e+001,-9.578305600000000e+001,'04/15','11/21','04/26','04/15','04/06','11/13','11/21','12/09','0171','0189','0208')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('345779','OK','LINCOLN','MEEKER 5 W',3.550500000000000e+001,-9.697722200000000e+001,'04/16','11/10','04/30','04/16','04/10','11/05','11/10','11/29','0157','0189','0208')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('345855','OK','OTTAWA','MIAMI',3.688333333000000e+001,-9.488333299999999e+001,'04/23','11/10','05/04','04/23','04/11','10/23','11/10','11/26','0148','0173','0200')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('346130','OK','MUSKOGEE','MUSKOGEE',3.577805555000000e+001,-9.533388900000000e+001,'04/13','11/17','04/27','04/13','04/03','11/07','11/17','12/05','0169','0195','0218')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('346139','OK','WOODWARD','MUTUAL',3.622833333000000e+001,-9.917000000000000e+001,'04/25','11/10','05/07','04/25','04/13','10/26','11/10','11/22','0150','0175','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('346278','OK','KAY','NEWKIRK 1NW',3.689138888000000e+001,-9.705861100000000e+001,'04/22','11/12','05/08','04/22','04/08','11/02','11/12','11/27','0154','0180','0209')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('346386','OK','CLEVELAND','NORMAN 3SSE',3.518111111000000e+001,-9.743777799999999e+001,'04/15','11/19','04/29','04/15','04/06','11/04','11/19','12/01','0167','0191','0210')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('346638','OK','OKFUSKEE','OKEMAH',3.542527777000000e+001,-9.630333300000000e+001,'04/11','11/26','04/16','04/11','04/06','11/15','11/26','12/07','0186','0204','0221')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('346661','OK','OKLAHOMA','OKLAHOMA CITY WILL ROGERS AP',3.538888888000000e+001,-9.760055600000000e+001,'04/13','11/19','04/21','04/13','04/05','11/09','11/19','12/03','0179','0193','0215')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('346670','OK','OKMULGEE','OKMULGEE WTR WKS',3.562388888000000e+001,-9.602500000000001e+001,'04/17','11/12','04/28','04/17','04/13','10/29','11/12','11/24','0154','0183','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('346935','OK','OSAGE','PAWHUSKA',3.666916666000000e+001,-9.634722200000000e+001,'04/16','11/07','05/10','04/16','04/11','10/25','11/07','11/17','0150','0183','0202')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('347012','OK','NOBLE','PERRY',3.628861111000000e+001,-9.728972200000000e+001,'04/15','11/15','04/29','04/15','04/10','11/06','11/15','11/26','0163','0186','0209')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('347201','OK','KAY','PONCA CITY MUNI AP',3.673666666000000e+001,-9.710194400000000e+001,'04/16','11/14','05/05','04/16','04/10','11/05','11/14','11/30','0158','0184','0202')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('347390','OK','PAWNEE','RALSTON',3.650444444000000e+001,-9.674388900000000e+001,'04/15','11/08','05/13','04/15','04/14','10/22','11/08','11/17','0147','0179','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('347862','OK','SEQUOYAH','SALLISAW 2 NW',3.545722222000000e+001,-9.480472200000000e+001,'04/15','11/25','04/29','04/15','04/09','11/02','11/25','12/02','0161','0190','0208')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('348042','OK','SEMINOLE','SEMINOLE',3.523166666000000e+001,-9.665305600000001e+001,'04/11','11/21','04/23','04/11','04/03','11/08','11/21','12/06','0176','0203','0217')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('348380','OK','MAYES','SPAVINAW',3.638944444000000e+001,-9.505972199999999e+001,'04/14','11/24','04/24','04/14','04/06','11/05','11/24','12/03','0169','0194','0213')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('348501','OK','PAYNE','STILLWATER 2 W',3.611750000000000e+001,-9.709500000000000e+001,'04/21','11/11','04/30','04/21','04/11','10/31','11/11','11/28','0158','0182','0205')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('348677','OK','CHEROKEE','TAHLEQUAH',3.593694444000000e+001,-9.496444400000000e+001,'04/20','11/12','05/07','04/20','04/13','10/29','11/12','11/24','0149','0180','0199')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('348708','OK','DEWEY','TALOGA',3.603805555000000e+001,-9.895916699999999e+001,'04/29','10/30','05/09','04/29','04/18','10/20','10/30','11/17','0146','0165','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('348992','OK','TULSA','TULSA INTL AP',3.619944444000000e+001,-9.588722199999999e+001,'04/08','11/22','04/19','04/08','04/02','11/09','11/22','12/05','0180','0206','0221')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('349023','OK','PUSHMATAHA','TUSKAHOMA',3.461472222000000e+001,-9.528027800000000e+001,'04/21','11/09','05/03','04/21','04/12','10/25','11/09','11/26','0152','0177','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('349203','OK','CRAIG','VINITA 2 N',3.654694444000000e+001,-9.513222200000000e+001,'04/21','11/08','05/05','04/21','04/12','10/26','11/08','11/24','0150','0178','0195')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('349278','OK','COTTON','WALTERS',3.436027777000000e+001,-9.830055600000000e+001,'04/14','11/20','04/26','04/14','04/06','11/09','11/20','12/01','0170','0194','0215')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('349364','OK','BLAINE','WATONGA',3.585777777000000e+001,-9.841388900000000e+001,'04/17','11/14','05/05','04/17','04/12','10/30','11/14','11/26','0158','0187','0206')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('349404','OK','WOODS','WAYNOKA',3.657583333000000e+001,-9.887972200000000e+001,'04/27','11/05','05/07','04/27','04/16','10/23','11/05','11/16','0145','0165','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('349422','OK','CUSTER','WEATHERFORD',3.552000000000000e+001,-9.869861100000000e+001,'04/16','11/20','04/26','04/16','04/10','11/05','11/20','11/29','0167','0188','0207')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('349629','OK','COMANCHE','WICHITA MTN WR',3.473250000000000e+001,-9.871250000000001e+001,'04/19','11/09','05/03','04/19','04/17','10/29','11/09','11/28','0157','0189','0202')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('350036','OR','LAKE','ADEL',4.217611111000000e+001,-1.198961110000000e+002,'06/27','10/05','07/07','06/27','06/05','09/27','10/05','10/25','0048','0067','0097')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('350118','OR','LAKE','ALKALI LAKE',4.296944444000000e+001,-1.199933330000000e+002,'07/07','09/30','07/24','07/07','06/11','09/10','09/30','10/12','0030','0054','0092')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('350197','OR','JEFFERSON','ANTELOPE 6 SSW',4.481972222000000e+001,-1.207533330000000e+002,'06/16','10/14','07/13','06/16','05/31','10/01','10/14','11/01','0048','0089','0126')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('350265','OR','GILLIAM','ARLINGTON',4.572111111000000e+001,-1.202063890000000e+002,'05/06','10/31','05/17','05/06','04/20','10/25','10/31','11/21','0125','0157','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('350304','OR','JACKSON','ASHLAND',4.221277777000000e+001,-1.227144440000000e+002,'05/24','10/27','06/17','05/24','05/07','10/12','10/27','11/20','0090','0128','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('350328','OR','CLATSOP','ASTORIA AP PORT OF',4.615694444000000e+001,-1.238825000000000e+002,'04/30','12/08','05/18','04/30','03/19','10/28','12/08','01/19','0138','0180','0250')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('350356','OR','GRANT','AUSTIN 3 S',4.457472222000000e+001,-1.184913890000000e+002,'07/28','09/03','08/02','07/28','07/13','08/11','09/03','09/15','0001','0014','0044')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('350412','OR','BAKER','BAKER CITY AP',4.484277777000000e+001,-1.178086110000000e+002,'06/27','09/25','07/13','06/27','05/28','09/17','09/25','10/11','0043','0075','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('350471','OR','COOS','BANDON 2 NNE',4.314972222000000e+001,-1.244019440000000e+002,'05/07','12/19','05/28','05/07','03/18','11/14','12/19','00/00','0121','0170','0261')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('350501','OR','CROOK','BARNES STN',4.394555555000000e+001,-1.202169440000000e+002,'07/17','09/20','07/27','07/17','06/29','09/04','09/20','10/05','0018','0037','0070')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('350652','OR','LINN','BELKNAP SPRINGS 8 N',4.428666666000000e+001,-1.220386110000000e+002,'06/02','10/31','06/25','06/02','05/03','10/10','10/31','11/26','0077','0127','0173')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('350694','OR','DESCHUTES','BEND',4.405666666000000e+001,-1.212850000000000e+002,'07/14','09/24','07/25','07/14','06/23','09/09','09/24','10/05','0018','0046','0081')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('350858','OR','MORROW','BOARDMAN',4.584722222000000e+001,-1.196933330000000e+002,'04/30','10/25','05/17','04/30','04/19','10/16','10/25','11/09','0128','0158','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('350897','OR','MULTNOMAH','BONNEVILLE DAM',4.563611111000000e+001,-1.219519440000000e+002,'04/17','12/21','05/07','04/17','03/10','12/06','12/21','01/26','0179','0215','0278')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('351067','OR','DESCHUTES','BROTHERS',4.380944444000000e+001,-1.206000000000000e+002,'07/29','09/04','08/02','07/29','07/24','08/25','09/04','09/22','0001','0008','0023')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('351433','OR','LINN','CASCADIA',4.439138888000000e+001,-1.224811110000000e+002,'06/05','10/23','06/17','06/05','04/23','10/12','10/23','12/05','0088','0116','0190')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('351448','OR','JOSEPHINE','CAVE JUNCTION 1 WNW',4.215972222000000e+001,-1.236422220000000e+002,'05/27','11/01','06/20','05/27','05/01','10/13','11/01','12/16','0083','0130','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('351546','OR','KLAMATH','CHEMULT',4.322916666000000e+001,-1.217894440000000e+002,'08/03','08/21','08/04','08/03','07/28','08/09','08/21','09/10','0000','0001','0017')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('351643','OR','COLUMBIA','CLATSKANIE',4.610805555000000e+001,-1.232058330000000e+002,'05/04','11/20','05/28','05/04','04/04','10/31','11/20','12/17','0132','0159','0216')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('351682','OR','TILLAMOOK','CLOVERDALE',4.520500000000000e+001,-1.238925000000000e+002,'05/03','12/13','06/08','05/03','03/25','11/05','12/13','01/22','0126','0183','0247')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('351765','OR','GILLIAM','CONDON',4.523250000000000e+001,-1.201816670000000e+002,'06/10','10/15','07/13','06/10','05/29','09/29','10/15','10/28','0054','0108','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('351836','OR','COOS','COQUILLE CITY',4.318722222000000e+001,-1.242025000000000e+002,'05/04','12/04','06/09','05/04','03/05','11/01','12/04','12/31','0112','0173','0259')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('351862','OR','BENTON','CORVALLIS STATE UNIV',4.463416666000000e+001,-1.231900000000000e+002,'05/11','11/20','06/03','05/11','04/05','10/24','11/20','12/23','0124','0157','0215')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('351877','OR','BENTON','CORVALLIS WATER BUREAU',4.450777777000000e+001,-1.234575000000000e+002,'05/12','11/18','06/01','05/12','03/29','11/01','11/18','12/16','0120','0160','0226')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('351897','OR','LANE','COTTAGE GROVE 2E',4.379166666000000e+001,-1.230275000000000e+002,'06/13','10/31','07/06','06/13','05/15','10/08','10/31','12/18','0050','0100','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('351902','OR','LANE','COTTAGE GROVE DAM',4.371777777000000e+001,-1.230577780000000e+002,'05/06','11/21','05/29','05/06','03/30','10/29','11/21','12/20','0122','0174','0225')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('351926','OR','UNION','COVE 1 E',4.529638888000000e+001,-1.177902780000000e+002,'06/18','09/30','07/16','06/18','05/26','09/18','09/30','10/14','0048','0087','0117')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('351946','OR','KLAMATH','CRATER LAKE NPS HQ',4.289666666000000e+001,-1.221327780000000e+002,'07/25','09/07','07/31','07/25','07/16','08/23','09/07','10/06','0002','0012','0049')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('352112','OR','POLK','DALLAS 2 NE',4.494638888000000e+001,-1.232908330000000e+002,'05/21','11/12','06/06','05/21','04/19','10/18','11/12','12/12','0103','0144','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('352135','OR','MALHEUR','DANNER',4.294472222000000e+001,-1.173388890000000e+002,'07/06','09/23','07/18','07/06','06/14','09/12','09/23','10/03','0028','0058','0092')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('352292','OR','MARION','DETROIT DAM',4.472416666000000e+001,-1.222547220000000e+002,'04/16','12/15','05/23','04/16','03/05','11/24','12/15','00/00','0151','0212','0268')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('352374','OR','LANE','DORENA',4.378194444000000e+001,-1.229627780000000e+002,'05/14','11/16','06/14','05/14','04/22','10/22','11/16','12/13','0105','0149','0199')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('352406','OR','DOUGLAS','DRAIN',4.366555555000000e+001,-1.233275000000000e+002,'05/09','11/22','06/01','05/09','04/04','10/29','11/22','01/21','0117','0160','0230')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('352415','OR','HARNEY','DREWSEY',4.380805555000000e+001,-1.183775000000000e+002,'07/08','09/17','07/22','07/08','06/13','09/06','09/17','09/29','0025','0051','0090')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('352440','OR','WASCO','DUFUR',4.545388888000000e+001,-1.211302780000000e+002,'06/15','10/16','07/06','06/15','05/24','10/02','10/16','10/29','0061','0107','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('352678','OR','WALLOWA','ENTERPRISE 20 NNE',4.570833333000000e+001,-1.171527780000000e+002,'07/17','09/14','07/31','07/17','06/28','08/28','09/14','09/23','0010','0036','0070')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('352693','OR','CLACKAMAS','ESTACADA 2 SE',4.526888888000000e+001,-1.223186110000000e+002,'05/02','12/06','05/27','05/02','03/18','11/01','12/06','01/01','0137','0182','0245')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('352709','OR','LANE','EUGENE-MAHLON SWEET FLD',4.412777777000000e+001,-1.232205560000000e+002,'05/24','11/08','06/11','05/24','04/06','10/21','11/08','12/27','0114','0144','0211')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('352867','OR','LANE','FERN RIDGE-VENETA',4.404944444000000e+001,-1.233702780000000e+002,'05/09','11/23','05/29','05/09','03/12','11/10','11/23','12/31','0133','0168','0253')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('352997','OR','WASHINGTON','FOREST GROVE',4.552472222000000e+001,-1.231027780000000e+002,'05/16','11/10','06/01','05/16','04/07','10/19','11/10','12/13','0121','0154','0213')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('353038','OR','WHEELER','FOSSIL',4.499833333000000e+001,-1.202175000000000e+002,'07/08','10/02','07/27','07/08','06/22','09/18','10/02','10/24','0019','0058','0091')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('353047','OR','LINN','FOSTER DAM',4.441388888000000e+001,-1.226727780000000e+002,'04/25','11/20','06/03','04/25','03/12','10/29','11/20','12/19','0114','0173','0240')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('353356','OR','CURRY','GOLD BEACH RS',4.240361111000000e+001,-1.244241670000000e+002,'04/21','00/00','05/20','04/21','02/27','12/15','00/00','00/00','0176','0231','0315')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('353402','OR','CLACKAMAS','GOVERNMENT CAMP',4.530138888000000e+001,-1.217416670000000e+002,'06/27','10/12','07/20','06/27','05/26','09/21','10/12','11/05','0034','0082','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('353445','OR','JOSEPHINE','GRANTS PASS',4.242444444000000e+001,-1.233236110000000e+002,'05/17','11/13','06/10','05/17','04/27','10/19','11/13','12/20','0099','0130','0176')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('353542','OR','JEFFERSON','GRIZZLY',4.451750000000000e+001,-1.209388890000000e+002,'07/28','09/11','08/02','07/28','07/07','08/27','09/11','10/06','0002','0021','0060')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('353604','OR','BAKER','HALFWAY',4.487361111000000e+001,-1.171094440000000e+002,'06/29','09/27','07/13','06/29','06/03','09/16','09/27','10/11','0040','0068','0111')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('353692','OR','LAKE','HART MTN REFUGE',4.254833333000000e+001,-1.196555560000000e+002,'07/23','09/08','07/29','07/23','07/09','08/25','09/08','09/28','0008','0021','0051')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('353770','OR','CLACKAMAS','HEADWORKS PORTLAND WTR',4.544861111000000e+001,-1.221547220000000e+002,'05/02','12/12','05/17','05/02','03/14','11/14','12/12','01/11','0147','0182','0260')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('353827','OR','MORROW','HEPPNER',4.536527777000000e+001,-1.195638890000000e+002,'05/17','10/24','06/15','05/17','05/03','10/10','10/24','11/09','0095','0132','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('353995','OR','LANE','HONEYMAN SP',4.392805555000000e+001,-1.241069440000000e+002,'05/04','12/19','05/23','05/04','03/09','11/22','12/19','02/05','0147','0186','0268')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('354003','OR','HOOD RIVER','HOOD RIVER EXP STN',4.568472222000000e+001,-1.215175000000000e+002,'05/18','10/25','06/07','05/18','04/17','10/08','10/25','11/12','0104','0137','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('354060','OR','JACKSON','HOWARD PRAIRIE DAM',4.222916666000000e+001,-1.223813890000000e+002,'07/07','10/04','07/24','07/07','06/06','09/15','10/04','10/25','0020','0062','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('354098','OR','BAKER','HUNTINGTON',4.435638888000000e+001,-1.172550000000000e+002,'05/19','10/21','06/10','05/19','05/01','10/11','10/21','11/06','0111','0136','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('354126','OR','DOUGLAS','IDLEYLD PARK 4 NE',4.337083333000000e+001,-1.229652780000000e+002,'06/08','10/26','06/29','06/08','04/27','10/06','10/26','12/05','0069','0108','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('354291','OR','GRANT','JOHN DAY',4.442333333000000e+001,-1.189594440000000e+002,'06/13','10/07','07/04','06/13','05/22','09/21','10/07','10/23','0057','0092','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('354622','OR','UNION','LA GRANDE',4.531666666000000e+001,-1.180747220000000e+002,'06/18','10/08','06/30','06/18','05/18','10/01','10/08','10/23','0065','0096','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('354670','OR','LAKE','LAKEVIEW 2 NNW',4.224138888000000e+001,-1.203677780000000e+002,'07/03','10/06','07/18','07/03','06/11','09/19','10/06','10/19','0034','0068','0105')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('354811','OR','LANE','LEABURG 1 SW',4.410138888000000e+001,-1.226886110000000e+002,'05/02','11/30','06/01','05/02','03/25','11/01','11/30','12/27','0125','0178','0242')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('355020','OR','GRANT','LONG CREEK',4.471361111000000e+001,-1.191016670000000e+002,'07/08','09/24','07/24','07/08','06/14','09/10','09/24','10/10','0021','0060','0096')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('355050','OR','LANE','LOOKOUT POINT DAM',4.391444444000000e+001,-1.227600000000000e+002,'04/21','12/10','05/21','04/21','03/03','11/27','12/10','01/13','0153','0201','0268')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('355055','OR','JACKSON','LOST CREEK DAM',4.267222222000000e+001,-1.226750000000000e+002,'05/30','10/27','06/19','05/30','05/04','10/10','10/27','11/25','0082','0121','0166')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('355139','OR','JEFFERSON','MADRAS',4.461666666000000e+001,-1.210011110000000e+002,'06/25','09/30','07/15','06/25','06/02','09/17','09/30','10/14','0044','0075','0112')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('355142','OR','JEFFERSON','MADRAS 2 N',4.466333333000000e+001,-1.211461110000000e+002,'06/12','10/16','07/02','06/12','05/21','10/02','10/16','10/28','0066','0098','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('355160','OR','MALHEUR','MALHEUR BRANCH EXP STN',4.397944444000000e+001,-1.170247220000000e+002,'05/17','10/18','06/16','05/17','05/01','10/05','10/18','10/29','0097','0131','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('355162','OR','HARNEY','MALHEUR REFUGE HQ',4.326500000000000e+001,-1.188447220000000e+002,'06/28','09/26','07/18','06/28','06/10','09/18','09/26','10/09','0031','0060','0095')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('355221','OR','LINN','MARION FRKS FISH HATCH',4.461250000000000e+001,-1.219486110000000e+002,'06/18','10/12','07/06','06/18','05/13','09/19','10/12','11/02','0051','0086','0152')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('355362','OR','LANE','MCKENZIE BRG RS',4.417916666000000e+001,-1.221163890000000e+002,'06/10','10/24','07/04','06/10','05/14','10/02','10/24','11/22','0057','0097','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('355384','OR','YAMHILL','MC MINNVILLE',4.522138888000000e+001,-1.231622220000000e+002,'05/23','11/17','06/21','05/23','04/28','10/23','11/17','12/18','0100','0138','0188')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('355429','OR','JACKSON','MEDFORD INTL AP',4.238111111000000e+001,-1.228722220000000e+002,'05/17','11/05','06/01','05/17','04/21','10/17','11/05','12/03','0121','0147','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('355593','OR','UMATILLA','MILTON FREEWATER',4.594277777000000e+001,-1.184088890000000e+002,'04/22','11/02','05/10','04/22','04/08','10/19','11/02','11/22','0134','0165','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('355711','OR','GRANT','MONUMENT 2',4.481861111000000e+001,-1.194200000000000e+002,'06/11','10/04','06/28','06/11','05/14','09/23','10/04','10/22','0067','0098','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('355734','OR','SHERMAN','MORO',4.548250000000000e+001,-1.207236110000000e+002,'05/28','10/22','06/25','05/28','05/14','10/08','10/22','11/03','0077','0120','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('356032','OR','LINCOLN','NEWPORT',4.464305555000000e+001,-1.240555560000000e+002,'05/05','01/18','06/06','05/05','03/20','11/22','01/18','00/00','0132','0178','0251')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('356179','OR','MALHEUR','NYSSA',4.387638888000000e+001,-1.169902780000000e+002,'05/11','10/26','06/07','05/11','04/23','10/15','10/26','11/08','0107','0142','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('356213','OR','LANE','OAKRIDGE FISH HATCHERY',4.374277777000000e+001,-1.224433330000000e+002,'05/15','10/30','06/16','05/15','04/21','10/18','10/30','12/14','0092','0147','0199')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('356302','OR','HARNEY','O O RCH',4.327833333000000e+001,-1.193111110000000e+002,'06/30','09/22','07/17','06/30','06/10','09/08','09/22','10/07','0033','0060','0099')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('356334','OR','CLACKAMAS','OREGON CITY',4.535583333000000e+001,-1.226047220000000e+002,'04/22','12/10','05/14','04/22','03/15','11/07','12/10','01/01','0151','0197','0259')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('356366','OR','LINCOLN','OTIS 2 NE',4.503333333000000e+001,-1.239238890000000e+002,'05/06','12/06','05/31','05/06','03/12','11/09','12/06','00/00','0124','0179','0263')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('356405','OR','MALHEUR','OWYHEE DAM',4.365000000000000e+001,-1.172466670000000e+002,'05/12','10/25','06/13','05/12','04/27','10/16','10/25','11/04','0095','0139','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('356426','OR','LAKE','PAISLEY',4.269222222000000e+001,-1.205402780000000e+002,'07/05','09/27','07/21','07/05','06/07','09/15','09/27','10/11','0031','0056','0104')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('356532','OR','JEFFERSON','PELTON DAM',4.472750000000000e+001,-1.212505560000000e+002,'06/05','10/16','06/26','06/05','05/15','10/01','10/16','10/30','0072','0106','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('356540','OR','UMATILLA','PENDLETON BR EXP STN',4.572055555000000e+001,-1.186263890000000e+002,'06/04','10/08','06/28','06/04','05/16','09/25','10/08','10/22','0067','0105','0139')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('356541','OR','UMATILLA','PENDLETON DWTN',4.567027777000000e+001,-1.187963890000000e+002,'05/06','10/11','06/01','05/06','04/16','10/03','10/11','10/25','0096','0126','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('356546','OR','UMATILLA','PENDLETON E OR RGNL AP',4.569833333000000e+001,-1.188547220000000e+002,'05/02','11/01','05/22','05/02','04/11','10/20','11/01','11/27','0134','0161','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('356634','OR','UMATILLA','PILOT ROCK 1 SE',4.547555555000000e+001,-1.188252780000000e+002,'05/30','10/17','06/27','05/30','05/06','10/03','10/17','10/28','0079','0119','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('356751','OR','MULTNOMAH','PORTLAND INTL AP',4.559083333000000e+001,-1.226002780000000e+002,'04/15','12/06','05/01','04/15','03/16','11/13','12/06','12/26','0171','0206','0243')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('356784','OR','CURRY','PORT ORFORD NO 2',4.275194444000000e+001,-1.245011110000000e+002,'05/02','12/26','05/30','05/02','03/10','11/25','12/26','00/00','0145','0207','0275')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('356820','OR','COOS','POWERS',4.288861111000000e+001,-1.240688890000000e+002,'05/03','11/24','06/01','05/03','03/18','10/29','11/24','12/28','0121','0172','0241')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('356853','OR','HARNEY','P-RANCH SOUTH PLACE',4.280805555000000e+001,-1.188777780000000e+002,'07/06','09/16','07/21','07/06','06/03','09/03','09/16','09/26','0022','0053','0095')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('356883','OR','CROOK','PRINEVILLE',4.430222222000000e+001,-1.208080560000000e+002,'07/18','09/14','07/27','07/18','06/15','08/27','09/14','09/30','0012','0038','0085')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('356907','OR','JACKSON','PROSPECT 2 SW',4.273416666000000e+001,-1.225163890000000e+002,'06/19','10/13','07/16','06/19','05/26','09/25','10/13','11/07','0039','0088','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('357062','OR','DESCHUTES','REDMOND AP',4.425583333000000e+001,-1.211391670000000e+002,'07/07','09/28','07/26','07/07','06/20','09/07','09/28','10/14','0024','0057','0091')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('357160','OR','BAKER','RICHLAND',4.476555555000000e+001,-1.171597220000000e+002,'06/13','10/09','06/29','06/13','05/26','09/27','10/09','10/23','0072','0103','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('357169','OR','DOUGLAS','RIDDLE',4.295055555000000e+001,-1.233572220000000e+002,'05/06','12/02','05/26','05/06','03/31','10/27','12/02','01/25','0128','0164','0237')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('357208','OR','MALHEUR','RIVERSIDE 7 SSW',4.345083333000000e+001,-1.182244440000000e+002,'07/02','10/05','07/17','07/02','06/03','09/17','10/05','10/13','0034','0063','0099')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('357277','OR','MALHEUR','ROCKVILLE 5 N',4.336361111000000e+001,-1.171141670000000e+002,'07/08','09/21','07/21','07/08','06/24','09/11','09/21','09/29','0022','0052','0080')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('357310','OR','MALHEUR','ROME 2 NW',4.285916666000000e+001,-1.176569440000000e+002,'06/23','09/29','07/09','06/23','06/08','09/18','09/29','10/06','0047','0074','0105')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('357331','OR','DOUGLAS','ROSEBURG KQEN',4.321305555000000e+001,-1.233658330000000e+002,'05/02','12/12','05/24','05/02','03/23','11/10','12/12','02/13','0143','0183','0240')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('357391','OR','JACKSON','RUCH',4.222305555000000e+001,-1.230472220000000e+002,'06/05','10/20','06/26','06/05','05/21','10/05','10/20','11/18','0072','0113','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('357500','OR','MARION','SALEM AP MCNARY FLD',4.490500000000000e+001,-1.230011110000000e+002,'05/19','11/05','06/12','05/19','05/01','10/21','11/05','12/07','0109','0143','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('357554','OR','LINN','SANTIAM JUNCTION',4.443555555000000e+001,-1.219433330000000e+002,'06/27','10/29','07/20','06/27','06/13','10/17','10/29','11/07','0019','0054','0103')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('357631','OR','CLACKAMAS','SCOTTS MILLS 9 SE',4.494694444000000e+001,-1.225247220000000e+002,'06/01','11/10','06/22','06/01','05/07','10/19','11/10','12/15','0089','0132','0181')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('357641','OR','CLATSOP','SEASIDE',4.598694444000000e+001,-1.239236110000000e+002,'04/29','12/06','05/27','04/29','03/23','11/03','12/06','01/02','0129','0172','0242')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('357675','OR','GRANT','SENECA',4.413833333000000e+001,-1.189750000000000e+002,'08/01','08/18','08/04','08/01','07/25','08/07','08/18','09/06','0000','0000','0021')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('357698','OR','JOSEPHINE','SEXTON SUMMIT',4.260027777000000e+001,-1.233641670000000e+002,'06/12','11/25','06/27','06/12','05/17','11/01','11/25','12/18','0087','0122','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('357809','OR','MARION','SILVER CREEK FALLS',4.487277777000000e+001,-1.226486110000000e+002,'06/04','10/28','06/29','06/04','05/09','10/08','10/28','12/02','0071','0122','0159')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('357817','OR','LAKE','SILVER LAKE RS',4.312444444000000e+001,-1.210619440000000e+002,'07/21','09/16','07/30','07/21','07/10','09/01','09/16','10/02','0006','0025','0055')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('357823','OR','MARION','SILVERTON',4.500583333000000e+001,-1.227738890000000e+002,'04/29','11/25','05/13','04/29','03/25','11/02','11/25','12/12','0145','0184','0229')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('357857','OR','DESCHUTES','SISTERS',4.428416666000000e+001,-1.215486110000000e+002,'07/31','09/02','08/02','07/31','07/18','08/22','09/02','09/20','0000','0013','0041')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('358029','OR','HARNEY','SQUAW BUTTE-NORTHERN GREAT BAS',4.348694444000000e+001,-1.197211110000000e+002,'07/07','10/05','07/23','07/07','06/15','09/20','10/05','10/30','0027','0068','0107')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('358095','OR','MARION','STAYTON',4.478916666000000e+001,-1.228141670000000e+002,'05/04','11/24','05/30','05/04','04/10','10/30','11/24','12/20','0124','0165','0214')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('358173','OR','LAKE','SUMMER LAKE 1 S',4.295916666000000e+001,-1.207897220000000e+002,'06/14','10/08','07/07','06/14','05/21','09/28','10/08','10/24','0060','0090','0128')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('358407','OR','WASCO','THE DALLES',4.560694444000000e+001,-1.212047220000000e+002,'04/28','11/19','05/15','04/28','04/08','11/01','11/19','12/15','0137','0163','0195')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('358420','OR','LAKE','THE POPLARS',4.326444444000000e+001,-1.209447220000000e+002,'07/17','09/19','07/25','07/17','07/09','08/31','09/19','09/27','0012','0031','0061')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('358466','OR','CLACKAMAS','THREE LYNX',4.512194444000000e+001,-1.220700000000000e+002,'05/08','11/14','06/03','05/08','03/26','10/26','11/14','01/02','0126','0162','0239')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('358536','OR','DOUGLAS','TOKETEE FALLS',4.327500000000000e+001,-1.224497220000000e+002,'05/27','10/22','06/29','05/27','05/04','10/07','10/22','11/30','0069','0122','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('358634','OR','MULTNOMAH','TROUTDALE',4.555333333000000e+001,-1.223886110000000e+002,'04/21','12/13','05/10','04/21','03/20','11/10','12/13','01/11','0152','0187','0237')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('358726','OR','UMATILLA','UKIAH',4.513277777000000e+001,-1.189338890000000e+002,'07/30','09/03','08/06','07/30','07/08','08/13','09/03','09/19','0000','0014','0049')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('358797','OR','MALHEUR','VALE',4.398138888000000e+001,-1.172438890000000e+002,'06/05','10/14','06/28','06/05','05/13','10/01','10/14','10/23','0074','0107','0142')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('358884','OR','COLUMBIA','VERNONIA NO 2',4.586527777000000e+001,-1.231902780000000e+002,'05/31','10/18','06/30','05/31','04/27','09/30','10/18','11/14','0059','0107','0166')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('358997','OR','WALLOWA','WALLOWA',4.557222222000000e+001,-1.175313890000000e+002,'07/04','09/21','07/23','07/04','06/11','09/03','09/21','09/30','0031','0056','0095')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('359176','OR','MALHEUR','WESTFALL',4.399027777000000e+001,-1.177183330000000e+002,'06/10','10/13','06/28','06/10','05/14','10/03','10/13','10/27','0078','0104','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('359316','OR','DESCHUTES','WICKIUP DAM',4.368250000000000e+001,-1.216875000000000e+002,'07/15','09/22','07/26','07/15','06/23','09/07','09/22','10/10','0018','0051','0081')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('360106','PA','LEHIGH','ALLENTOWN AP',4.065083333000000e+001,-7.544916700000000e+001,'05/04','11/03','05/14','05/04','04/17','10/21','11/03','11/19','0139','0154','0191')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('360140','PA','BLAIR','ALTOONA 3 W',4.049500000000000e+001,-7.846666700000000e+001,'05/17','10/25','06/05','05/17','04/27','10/14','10/25','11/10','0103','0142','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('360560','PA','CARBON','BELTZVILLE DAM',4.086194444000000e+001,-7.564277800000001e+001,'05/15','10/18','06/03','05/15','05/07','10/08','10/18','11/01','0103','0135','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('360865','PA','MCKEAN','BRADFORD RGNL AP',4.180305555000000e+001,-7.864027800000000e+001,'06/19','10/07','07/07','06/19','06/03','09/24','10/07','10/24','0045','0081','0113')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('360868','PA','MCKEAN','BRADFORD 4SW RES 5',4.189750000000000e+001,-7.871444400000000e+001,'06/13','10/07','06/28','06/13','05/26','09/28','10/07','10/28','0063','0095','0119')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('361139','PA','BUTLER','BUTLER 2 SW',4.085000000000000e+001,-7.991666700000000e+001,'05/28','10/24','06/13','05/28','05/10','10/05','10/24','11/06','0100','0125','0159')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('361354','PA','FRANKLIN','CHAMBERSBURG 1 ESE',3.993527777000000e+001,-7.763944400000000e+001,'05/12','11/01','05/21','05/12','04/23','10/14','11/01','11/10','0130','0149','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('361485','PA','CLARION','CLARION 3 SW',4.119222222000000e+001,-7.943611100000000e+001,'06/04','10/19','06/14','06/04','05/24','10/05','10/19','11/03','0096','0111','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('361705','PA','SOMERSET','CONFLUENCE 1 SW DAM',3.979944444000000e+001,-7.936638900000000e+001,'05/26','10/20','06/11','05/26','05/11','10/12','10/20','10/31','0105','0126','0153')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('362183','PA','WESTMORELAND','DONEGAL 2 NW',4.013333333000000e+001,-7.940000000000001e+001,'05/29','10/25','06/18','05/29','05/11','10/08','10/25','11/06','0087','0126','0156')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('362190','PA','WASHINGTON','DONORA 1 SW',4.016361111000000e+001,-7.986944400000000e+001,'05/14','11/03','05/29','05/14','05/02','10/21','11/03','11/16','0128','0153','0172')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('362470','PA','CAMBRIA','EBENSBURG SEWAGE PLT',4.046805555000000e+001,-7.872888900000000e+001,'06/12','10/04','06/29','06/12','05/24','09/26','10/04','10/26','0067','0099','0131')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('362682','PA','ERIE','ERIE WSO AP',4.208000000000000e+001,-8.018250000000001e+001,'05/16','11/11','05/30','05/16','04/26','10/26','11/11','11/25','0134','0155','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('362721','PA','BEDFORD','EVERETT',4.001361111000000e+001,-7.836527800000000e+001,'05/22','10/23','06/03','05/22','05/10','10/11','10/23','11/03','0104','0128','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('362942','PA','ARMSTRONG','FORD CITY 4 S DAM',4.071666666000000e+001,-7.950000000000000e+001,'05/18','10/25','06/08','05/18','05/10','10/11','10/25','11/06','0111','0139','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('363018','PA','LUZERNE','FRANCIS E WALTER DAM',4.111833333000000e+001,-7.572777800000000e+001,'06/11','10/05','06/24','06/11','05/22','09/22','10/05','10/20','0066','0098','0131')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('363028','PA','VENANGO','FRANKLIN',4.140027777000000e+001,-7.983027800000001e+001,'05/18','10/29','06/14','05/18','05/06','10/15','10/29','11/11','0110','0149','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('363437','PA','MONTGOMERY','GRATERFORD 1 E',4.023055555000000e+001,-7.543527800000000e+001,'05/24','10/31','06/01','05/24','05/10','10/18','10/31','11/18','0103','0119','0145')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('363758','PA','PIKE','HAWLEY 1 E',4.147638888000000e+001,-7.516527800000000e+001,'05/24','10/14','06/10','05/24','05/10','10/01','10/14','10/28','0100','0129','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('364214','PA','INDIANA','INDIANA 3 SE',4.059694444000000e+001,-7.911833300000001e+001,'05/26','10/26','06/13','05/26','05/07','10/10','10/26','11/06','0102','0133','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('364325','PA','CRAWFORD','JAMESTOWN 2 NW',4.150000000000000e+001,-8.046666700000000e+001,'05/29','10/21','06/14','05/29','05/13','10/07','10/21','11/05','0105','0124','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('364432','PA','MCKEAN','KANE 1NNE',4.167666666000000e+001,-7.880361100000000e+001,'06/20','09/28','07/08','06/20','06/06','09/18','09/28','10/12','0042','0077','0111')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('364763','PA','LANCASTER','LANCASTER 2NE FLTR PLT',4.005000000000000e+001,-7.627416700000001e+001,'05/01','11/04','05/17','05/01','04/17','10/18','11/04','11/19','0135','0166','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('364778','PA','LANCASTER','LANDISVILLE 2 NW',4.011666666000000e+001,-7.643333300000001e+001,'05/10','10/25','05/21','05/10','04/27','10/10','10/25','11/04','0122','0144','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('364836','PA','WESTMORELAND','LAUREL MTN',4.020027777000000e+001,-7.918833300000000e+001,'05/20','10/24','06/08','05/20','05/12','10/13','10/24','11/06','0108','0134','0156')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('364896','PA','LEBANON','LEBANON 2 W',4.033333333000000e+001,-7.646666700000000e+001,'05/11','10/28','05/20','05/11','04/26','10/14','10/28','11/11','0128','0151','0173')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('364992','PA','MIFFLIN','LEWISTOWN',4.058638888000000e+001,-7.756916699999999e+001,'05/11','10/29','05/20','05/11','04/28','10/22','10/29','11/11','0124','0148','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('365050','PA','CRAWFORD','LINESVILLE 1 S',4.165000000000000e+001,-8.043333300000001e+001,'05/22','10/30','06/08','05/22','05/08','10/16','10/30','11/14','0108','0137','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('365390','PA','DELAWARE','MARCUS HOOK',3.982527777000000e+001,-7.542833300000000e+001,'04/14','12/02','04/20','04/14','04/01','11/21','12/02','12/14','0191','0202','0237')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('365470','PA','PIKE','MATAMORAS',4.139138888000000e+001,-7.471722200000001e+001,'05/18','10/22','05/28','05/18','05/02','10/10','10/22','11/07','0118','0141','0159')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('365573','PA','ALLEGHENY','MCKEESPORT',4.033916666000000e+001,-7.986027799999999e+001,'05/16','11/02','05/31','05/16','05/06','10/15','11/02','11/14','0116','0140','0165')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('365651','PA','MERCER','MERCER',4.122472222000000e+001,-8.023500000000000e+001,'06/02','10/18','06/15','06/02','05/17','10/06','10/18','11/01','0085','0111','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('365902','PA','BEAVER','MONTGOMERY L&D',4.065000000000000e+001,-8.038333299999999e+001,'05/14','11/05','05/28','05/14','05/06','10/21','11/05','11/15','0124','0151','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('365915','PA','SUSQUEHANNA','MONTROSE',4.185111111000000e+001,-7.585833300000000e+001,'05/31','10/14','06/12','05/31','05/11','10/01','10/14','10/28','0097','0114','0145')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('366194','PA','BUCKS','NESHAMINY FALLS',4.013583333000000e+001,-7.495500000000000e+001,'05/03','11/05','05/22','05/03','04/24','10/22','11/05','11/19','0127','0154','0176')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('366233','PA','LAWRENCE','NEW CASTLE 1 N',4.101722222000000e+001,-8.036194399999999e+001,'05/29','10/27','06/12','05/29','05/10','10/13','10/27','11/06','0103','0123','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('366370','PA','MONTGOMERY','NORRISTOWN',4.011972222000000e+001,-7.535833300000000e+001,'04/26','11/13','05/12','04/26','04/21','11/02','11/13','11/26','0141','0169','0190')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('366889','PA','PHILADELPHIA','PHILADELPHIA INTL AP',3.986833333000000e+001,-7.523111100000000e+001,'04/19','11/18','04/27','04/19','04/09','11/09','11/18','12/05','0172','0188','0218')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('366927','PA','CHESTER','PHOENIXVILLE 1 E',4.012000000000000e+001,-7.550111100000000e+001,'05/10','11/02','05/25','05/10','04/22','10/22','11/02','11/14','0116','0145','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('366993','PA','ALLEGHENY','PITTSBURGH ASOS',4.048472222000000e+001,-8.021444400000000e+001,'05/10','10/31','05/30','05/10','04/26','10/19','10/31','11/12','0126','0152','0182')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('367029','PA','WAYNE','PLEASANT MT 1 W',4.173944444000000e+001,-7.544638900000000e+001,'06/03','10/06','06/16','06/03','05/15','09/25','10/06','10/23','0081','0107','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('367229','PA','ARMSTRONG','PUTNEYVILLE 2 SE DAM',4.092500000000000e+001,-7.928250000000000e+001,'06/04','10/21','06/17','06/04','05/12','10/05','10/21','11/01','0089','0119','0152')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('367409','PA','CLINTON','RENOVO',4.132972222000000e+001,-7.773805600000000e+001,'05/25','10/24','06/05','05/25','05/14','10/15','10/24','11/09','0102','0134','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('367477','PA','ELK','RIDGWAY',4.141972222000000e+001,-7.874916700000000e+001,'06/09','10/12','06/22','06/09','05/23','10/01','10/12','10/31','0081','0107','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('367782','PA','WESTMORELAND','SALINA 3 W',4.051000000000000e+001,-7.954583300000000e+001,'05/31','10/21','06/14','05/31','05/12','10/06','10/21','11/04','0094','0116','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('367931','PA','SNYDER','SELINSGROVE 2 S',4.078305555000000e+001,-7.686166700000000e+001,'05/14','10/30','05/24','05/14','04/26','10/18','10/30','11/11','0120','0150','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('368073','PA','CUMBERLAND','SHIPPENSBURG',4.005000000000000e+001,-7.751666700000000e+001,'05/01','11/03','05/15','05/01','04/22','10/21','11/03','11/13','0140','0160','0183')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('368184','PA','BUTLER','SLIPPERY ROCK 1 SSW',4.105000000000000e+001,-8.006666700000000e+001,'06/09','10/15','06/19','06/09','05/13','10/02','10/15','11/03','0083','0112','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('368449','PA','CENTRE','STATE COLLEGE',4.079333333000000e+001,-7.786722200000000e+001,'05/11','10/30','05/24','05/11','04/25','10/18','10/30','11/11','0120','0151','0177')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('368469','PA','CAMERON','STEVENSON DAM',4.140388888000000e+001,-7.801833300000000e+001,'05/21','10/24','06/07','05/21','05/12','10/13','10/24','11/05','0112','0140','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('368596','PA','MONROE','STROUDSBURG',4.101250000000000e+001,-7.519055600000000e+001,'05/18','10/21','06/06','05/18','05/04','10/02','10/21','11/01','0106','0135','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('368873','PA','FOREST','TIONESTA 2 SE LAKE',4.148333333000000e+001,-7.943333300000001e+001,'06/03','10/26','06/14','06/03','05/15','10/09','10/26','11/07','0099','0119','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('368888','PA','CRAWFORD','TITUSVILLE WTR WKS',4.163333333000000e+001,-7.970000000000000e+001,'06/07','10/14','06/19','06/07','05/18','10/01','10/14','10/27','0085','0109','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('368893','PA','MONROE','TOBYHANNA POCONO MTN AP',4.113861111000000e+001,-7.522250000000000e+001,'06/08','10/08','06/23','06/08','05/14','09/28','10/08','10/27','0070','0103','0142')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('368905','PA','BRADFORD','TOWANDA 1 S',4.175111111000000e+001,-7.644305600000000e+001,'05/17','10/25','06/03','05/17','05/05','10/05','10/25','11/04','0108','0141','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('369050','PA','FAYETTE','UNIONTOWN 1 NE',3.991500000000000e+001,-7.971916700000000e+001,'05/20','10/20','06/06','05/20','05/06','10/09','10/20','11/01','0112','0134','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('369298','PA','WARREN','WARREN',4.184666666000000e+001,-7.914944400000000e+001,'05/27','10/27','06/13','05/27','05/10','10/09','10/27','11/11','0101','0130','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('369367','PA','GREENE','WAYNESBURG 1 E',3.990000000000000e+001,-8.016666700000000e+001,'05/21','10/20','06/09','05/21','05/06','10/10','10/20','11/02','0105','0137','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('369408','PA','TIOGA','WELLSBORO 4 SW',4.170027777000000e+001,-7.738944400000000e+001,'05/27','10/16','06/12','05/27','05/17','10/05','10/16','10/25','0091','0120','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('369464','PA','CHESTER','WEST CHESTER 2 NW',3.997083333000000e+001,-7.563500000000001e+001,'05/10','11/03','05/26','05/10','04/25','10/26','11/03','11/19','0129','0152','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('369705','PA','LUZERNE','WILKES-BARRE INTL AP',4.133361111000000e+001,-7.572694400000000e+001,'05/10','11/01','05/27','05/10','04/26','10/12','11/01','11/12','0122','0153','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('369728','PA','LYCOMING','WILLIAMSPORT RGNL AP',4.124333333000000e+001,-7.692166700000000e+001,'05/13','10/28','05/24','05/13','04/26','10/18','10/28','11/11','0125','0149','0181')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('369933','PA','YORK','YORK 3 SSW PUMP STN',3.991666666000000e+001,-7.675000000000000e+001,'05/14','10/25','05/31','05/14','04/25','10/12','10/25','11/07','0116','0147','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('374266','RI','WASHINGTON','KINGSTON',4.149055555000000e+001,-7.154138900000000e+001,'05/21','10/14','06/07','05/21','05/07','10/04','10/14','10/31','0101','0134','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('376698','RI','KENT','PROVIDENCE',4.172194444000000e+001,-7.143250000000001e+001,'04/29','11/06','05/15','04/29','04/14','10/22','11/06','11/21','0144','0167','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('380165','SC','ANDERSON','ANDERSON',3.452833333000000e+001,-8.266055600000000e+001,'04/21','11/15','05/04','04/21','04/07','11/02','11/15','12/03','0164','0190','0216')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('380170','SC','ANDERSON','ANDERSON FAA AP',3.449777777000000e+001,-8.270972200000000e+001,'04/17','11/22','04/30','04/17','04/03','11/09','11/22','12/05','0172','0192','0223')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('380184','SC','GEORGETOWN','ANDREWS',3.344083333000000e+001,-7.956722200000000e+001,'04/16','11/28','04/22','04/16','03/23','11/19','11/28','12/18','0187','0205','0243')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('380448','SC','BAMBERG','BAMBERG',3.330000000000000e+001,-8.103055600000000e+001,'04/08','11/25','04/21','04/08','03/24','11/14','11/25','12/14','0184','0209','0243')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('380736','SC','LEE','BISHOPVILLE 1ENE',3.421694444000000e+001,-8.023916700000000e+001,'04/20','11/19','04/28','04/20','04/06','11/05','11/19','12/04','0171','0188','0216')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('381093','SC','GEORGETOWN','BROOKGREEN GARDENS',3.351833333000000e+001,-7.909222200000001e+001,'04/17','12/01','04/27','04/17','04/03','11/15','12/01','12/08','0176','0201','0231')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('381256','SC','GREENVILLE','CAESARS HEAD',3.510722222000000e+001,-8.262555600000000e+001,'04/28','11/12','05/13','04/28','04/17','10/29','11/12','11/30','0149','0175','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('381277','SC','ABBEVILLE','CALHOUN FALLS',3.409055555000000e+001,-8.258833300000001e+001,'04/16','11/23','04/29','04/16','03/28','11/09','11/23','12/06','0174','0199','0237')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('381544','SC','CHARLESTON','CHARLESTON INTL. AIRPORT',3.289861111000000e+001,-8.004027800000000e+001,'04/03','12/14','04/12','04/03','03/14','11/30','12/14','01/16','0203','0228','0261')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('381549','SC','CHARLESTON','CHARLESTON CITY',3.278000000000000e+001,-7.993194400000000e+001,'03/08','01/15','03/28','03/08','02/23','12/28','01/15','00/00','0243','0282','0308')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('381588','SC','CHESTERFIELD','CHERAW',3.473194444000000e+001,-7.988333299999999e+001,'04/15','11/21','04/30','04/15','04/01','11/05','11/21','12/05','0169','0192','0225')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('381633','SC','CHESTER','CHESTER 1 SE',3.468472222000000e+001,-8.119583299999999e+001,'04/26','11/18','05/07','04/26','04/13','11/03','11/18','11/30','0157','0174','0200')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('381726','SC','MCCORMICK','CLARKS HILL 1 W',3.366305555000000e+001,-8.218972200000000e+001,'04/18','11/19','05/03','04/18','04/05','11/05','11/19','12/10','0167','0191','0223')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('381770','SC','PICKENS','CLEMSON UNIV',3.466027777000000e+001,-8.282361100000000e+001,'04/21','11/21','05/04','04/21','04/09','11/04','11/21','12/01','0166','0184','0212')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('381939','SC','LEXINGTON','COLUMBIA METRO AP',3.394194444000000e+001,-8.111805600000000e+001,'04/20','11/21','05/01','04/20','03/31','11/04','11/21','12/04','0169','0192','0226')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('381944','SC','RICHLAND','COLUMBIA UNIV OF SC',3.398305555000000e+001,-8.101666700000000e+001,'04/07','11/29','04/15','04/07','03/12','11/20','11/29','12/29','0190','0216','0255')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('381997','SC','HORRY','CONWAY',3.383138888000000e+001,-7.905583300000001e+001,'04/07','12/06','04/16','04/07','03/18','11/23','12/06','01/02','0194','0218','0257')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('382260','SC','DARLINGTON','DARLINGTON',3.430111111000000e+001,-7.987666700000000e+001,'04/13','11/22','04/26','04/13','04/02','11/09','11/22','12/05','0168','0193','0223')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('382386','SC','DILLON','DILLON',3.440916666000000e+001,-7.935638899999999e+001,'04/17','11/20','05/01','04/17','04/07','11/10','11/20','12/03','0164','0187','0213')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('382730','SC','COLLETON','EDISTO BEACH STATE PARK',3.250500000000000e+001,-8.029472199999999e+001,'04/03','01/03','04/13','04/03','03/09','12/04','01/03','01/26','0207','0233','0267')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('383106','SC','FLORENCE','FLORENCE RGNL AP',3.418527777000000e+001,-7.972388900000000e+001,'04/10','11/25','04/23','04/10','03/27','11/13','11/25','12/13','0180','0214','0242')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('383111','SC','DARLINGTON','FLORENCE 8 NE',3.429333333000000e+001,-7.974000000000000e+001,'04/12','11/23','04/22','04/12','04/02','11/05','11/23','12/02','0181','0202','0226')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('383747','SC','SPARTANBURG','GRNVL SPART INTL AP',3.488472222000000e+001,-8.222388900000000e+001,'04/24','11/22','05/06','04/24','04/07','11/05','11/22','12/05','0163','0185','0213')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('384607','SC','EDGEFIELD','JOHNSTON 4 SW',3.377750000000000e+001,-8.184666700000000e+001,'04/16','11/21','04/26','04/16','04/05','11/06','11/21','12/06','0173','0192','0222')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('384886','SC','FLORENCE','LAKE CITY 2 SE',3.386416666000000e+001,-7.972972200000000e+001,'04/15','11/24','04/27','04/15','03/29','11/11','11/24','12/13','0175','0202','0232')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('385017','SC','LAURENS','LAURENS',3.449888888000000e+001,-8.202194400000001e+001,'04/26','11/11','05/07','04/26','04/15','10/30','11/11','11/23','0155','0175','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('385200','SC','NEWBERRY','LITTLE MTN',3.419416666000000e+001,-8.141500000000001e+001,'04/18','11/27','04/22','04/18','04/01','11/07','11/27','12/06','0183','0197','0227')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('385278','SC','OCONEE','LONG CREEK',3.479750000000000e+001,-8.326750000000000e+001,'04/30','11/16','05/19','04/30','04/15','10/26','11/16','11/26','0143','0166','0194')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('385633','SC','MARLBORO','MCCOLL 3 NNW',3.470555555000000e+001,-7.956833300000000e+001,'04/14','11/19','04/25','04/14','04/06','11/09','11/19','12/02','0176','0192','0216')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('386209','SC','NEWBERRY','NEWBERRY',3.429777777000000e+001,-8.162361100000000e+001,'04/20','11/19','05/04','04/20','04/08','11/03','11/19','11/30','0167','0190','0213')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('386293','SC','CHEROKEE','NINETY NINE ISLANDS',3.503166666000000e+001,-8.149277800000000e+001,'05/10','11/02','05/17','05/10','04/23','10/19','11/02','11/15','0141','0158','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('386527','SC','ORANGEBURG','ORANGEBURG 2',3.348861111000000e+001,-8.087333300000000e+001,'04/12','11/30','04/21','04/12','03/27','11/14','11/30','12/16','0178','0203','0238')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('386688','SC','FAIRFIELD','PARR',3.429305555000000e+001,-8.131805600000000e+001,'04/26','11/19','05/09','04/26','04/16','11/03','11/19','12/05','0155','0178','0203')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('386775','SC','LEXINGTON','PELION 4 NW',3.380166666000000e+001,-8.127444400000000e+001,'04/25','11/10','05/02','04/25','04/11','10/28','11/10','11/30','0165','0174','0204')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('386831','SC','PICKENS','PICKENS',3.488138888000000e+001,-8.271888900000000e+001,'04/22','11/25','05/05','04/22','04/12','11/04','11/25','11/30','0162','0190','0215')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('387631','SC','SALUDA','SALUDA',3.399777777000000e+001,-8.177472200000000e+001,'04/25','11/13','05/04','04/25','04/10','11/02','11/13','11/30','0160','0174','0208')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('387666','SC','RICHLAND','SANDHILL RSCH ELGIN',3.414194444000000e+001,-8.087000000000001e+001,'04/14','11/28','04/21','04/14','04/08','11/15','11/28','12/12','0187','0199','0228')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('387722','SC','UNION','SANTUCK',3.463500000000000e+001,-8.152055600000000e+001,'04/22','11/20','04/28','04/22','04/06','11/02','11/20','12/02','0169','0188','0217')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('388405','SC','CHARLESTON','SULLIVANS ISLAND',3.276000000000000e+001,-7.984888900000000e+001,'03/24','12/30','04/10','03/24','03/19','12/13','12/30','02/03','0218','0246','0269')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('388426','SC','DORCHESTER','SUMMERVILLE 4W',3.303666666000000e+001,-8.023250000000000e+001,'04/16','12/04','04/29','04/16','03/30','11/17','12/04','12/30','0170','0198','0233')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('388440','SC','SUMTER','SUMTER',3.393638888000000e+001,-8.035694400000000e+001,'04/11','11/26','04/22','04/11','04/02','11/10','11/26','12/04','0178','0202','0221')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('388786','SC','UNION','UNION 8 S',3.460527777000000e+001,-8.166277800000000e+001,'04/27','11/15','05/12','04/27','04/13','10/28','11/15','11/24','0150','0177','0199')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('388887','SC','OCONEE','WALHALLA',3.474833333000000e+001,-8.308416699999999e+001,'05/03','11/04','05/20','05/03','04/20','10/22','11/04','11/23','0140','0166','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('388922','SC','COLLETON','WALTERBORO 1 SW',3.288472222000000e+001,-8.067611100000001e+001,'04/14','11/27','04/26','04/14','03/26','11/08','11/27','12/19','0174','0199','0235')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('389122','SC','ANDERSON','WEST PELZER 2 W',3.465305555000000e+001,-8.248722200000000e+001,'04/24','11/13','05/04','04/24','04/11','11/01','11/13','11/30','0164','0180','0211')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('389327','SC','FAIRFIELD','WINNSBORO',3.437388888000000e+001,-8.109277800000000e+001,'04/20','11/24','05/02','04/20','04/08','11/07','11/24','12/05','0169','0192','0213')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('389350','SC','YORK','WINTHROP UNIV',3.493805555000000e+001,-8.103166700000000e+001,'04/14','11/25','04/22','04/14','04/01','11/14','11/25','12/07','0184','0202','0230')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('389469','SC','BEAUFORT','YEMASSEE',3.268027777000000e+001,-8.084194400000000e+001,'04/18','11/24','04/28','04/18','03/31','11/13','11/24','12/07','0172','0194','0227')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('390020','SD','BROWN','ABERDEEN RGNL AP',4.544333333000000e+001,-9.841305600000000e+001,'05/20','10/02','05/28','05/20','05/14','09/25','10/02','10/19','0104','0119','0143')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('390043','SD','CHARLES MIX','ACADEMY 2NE',4.348916666000000e+001,-9.906305600000000e+001,'05/19','10/11','05/30','05/19','05/10','10/06','10/11','10/25','0104','0125','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('390128','SD','HANSON','ALEXANDRIA',4.365666666000000e+001,-9.778527800000001e+001,'05/15','10/12','05/24','05/15','05/07','10/04','10/12','10/28','0117','0135','0156')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('390236','SD','FALL RIVER','ARDMORE  1 NW',4.303000000000000e+001,-1.036600000000000e+002,'05/31','09/26','06/25','05/31','05/17','09/25','09/26','10/07','0075','0105','0123')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('390559','SD','BUTTE','BELLE FOURCHE',4.467138888000000e+001,-1.038511110000000e+002,'05/23','10/04','06/03','05/23','05/12','09/25','10/04','10/15','0098','0117','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('390701','SD','PERKINS','BISON',4.552861111000000e+001,-1.024650000000000e+002,'05/27','10/06','06/09','05/27','05/18','09/25','10/06','10/20','0096','0114','0131')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('391032','SD','MCCOOK','BRIDGEWATER',4.355250000000000e+001,-9.750166700000000e+001,'05/14','10/13','05/24','05/14','05/07','10/03','10/13','10/26','0117','0137','0152')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('391049','SD','MARSHALL','BRITTON',4.579083333000000e+001,-9.775000000000000e+001,'05/24','10/04','06/04','05/24','05/18','09/25','10/04','10/15','0095','0117','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('391076','SD','BROOKINGS','BROOKINGS 2 NE',4.432527777000000e+001,-9.676861100000001e+001,'05/25','09/30','06/05','05/25','05/14','09/24','09/30','10/15','0096','0111','0132')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('391294','SD','HARDING','CAMP CROOK',4.554888888000000e+001,-1.039744440000000e+002,'06/11','09/26','06/27','06/11','05/20','09/19','09/26','10/04','0064','0087','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('391392','SD','LINCOLN','CANTON',4.330555555000000e+001,-9.659166700000000e+001,'05/15','10/08','05/30','05/15','05/08','09/29','10/08','10/18','0104','0128','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('391539','SD','MELLETTE','CEDAR BUTTE 1NE',4.359583333000000e+001,-1.010094440000000e+002,'05/20','10/14','05/31','05/20','05/10','10/03','10/14','10/29','0111','0129','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('391579','SD','CLAY','CENTERVILLE 6 SE',4.304305555000000e+001,-9.690333300000000e+001,'05/16','10/07','05/26','05/16','05/10','09/29','10/07','10/20','0107','0123','0142')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('391739','SD','CLARK','CLARK',4.488166666000000e+001,-9.773250000000000e+001,'05/17','10/09','05/28','05/17','05/10','10/03','10/09','10/19','0112','0131','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('391777','SD','DEUEL','CLEAR LAKE',4.475916666000000e+001,-9.668722200000001e+001,'05/22','10/10','05/30','05/22','05/12','10/03','10/10','10/21','0107','0126','0145')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('391873','SD','BROWN','COLUMBIA 8 N',4.572500000000000e+001,-9.830000000000000e+001,'05/22','10/04','05/29','05/22','05/14','09/27','10/04','10/18','0105','0117','0142')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('391972','SD','JACKSON','COTTONWOOD 2 E',4.396111111000000e+001,-1.018605560000000e+002,'05/28','09/28','06/21','05/28','05/18','09/23','09/28','10/17','0084','0112','0128')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('392087','SD','CUSTER','CUSTER',4.377444444000000e+001,-1.036119440000000e+002,'06/27','09/27','07/05','06/27','05/30','09/21','09/27','10/05','0051','0071','0107')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('392302','SD','KINGSBURY','DE SMET',4.438666666000000e+001,-9.756055600000001e+001,'05/15','10/10','05/25','05/15','05/09','10/06','10/10','10/24','0116','0135','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('392429','SD','ZIEBACH','DUPREE',4.504805555000000e+001,-1.015991670000000e+002,'05/21','10/03','06/09','05/21','05/17','09/25','10/03','10/19','0095','0118','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('392446','SD','ZIEBACH','DUPREE 15 SSE',4.486583333000000e+001,-1.014672220000000e+002,'05/26','10/09','06/18','05/26','05/16','10/02','10/09','10/17','0086','0109','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('392797','SD','MCPHERSON','EUREKA',4.576444444000000e+001,-9.963527800000000e+001,'05/22','10/02','06/08','05/22','05/17','09/27','10/02','10/20','0089','0117','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('392852','SD','MEADE','FAITH',4.502027777000000e+001,-1.020366670000000e+002,'05/20','10/08','06/03','05/20','05/09','09/29','10/08','10/22','0105','0123','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('392927','SD','FAULK','FAULKTON 1 NW',4.503638888000000e+001,-9.913416700000001e+001,'05/24','10/04','06/14','05/24','05/16','09/28','10/04','10/15','0079','0116','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('392984','SD','MOODY','FLANDREAU',4.405166666000000e+001,-9.659305600000000e+001,'05/18','10/09','06/02','05/18','05/11','09/27','10/09','10/21','0102','0124','0145')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('393029','SD','SANBORN','FORESTBURG 4 NNE',4.406861111000000e+001,-9.808333300000000e+001,'05/18','10/09','05/27','05/18','05/07','09/29','10/09','10/19','0109','0128','0145')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('393069','SD','MEADE','FT MEADE',4.441000000000000e+001,-1.034775000000000e+002,'05/17','10/11','06/05','05/17','05/10','09/30','10/11','10/23','0100','0123','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('393294','SD','POTTER','GETTYSBURG',4.501944444000000e+001,-9.994027800000001e+001,'05/20','10/09','05/28','05/20','05/08','09/29','10/09','10/21','0107','0123','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('393316','SD','ZIEBACH','GLAD VALLEY 2 W',4.541777777000000e+001,-1.018100000000000e+002,'05/23','10/06','06/11','05/23','05/18','09/28','10/06','10/14','0091','0118','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('393452','SD','GREGORY','GREGORY',4.323555555000000e+001,-9.943388899999999e+001,'05/21','10/10','05/31','05/21','05/14','09/26','10/10','10/23','0104','0122','0139')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('393608','SD','HUGHES','HARROLD 12 SSW',4.436277777000000e+001,-9.980333300000000e+001,'06/11','10/07','06/22','06/11','05/16','09/27','10/07','10/15','0074','0092','0126')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('393832','SD','HYDE','HIGHMORE 1 W',4.452222222000000e+001,-9.945500000000000e+001,'05/24','10/05','06/14','05/24','05/15','09/30','10/05','10/21','0087','0116','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('393868','SD','PENNINGTON','HILL CITY',4.393250000000000e+001,-1.035594440000000e+002,'07/05','09/18','07/18','07/05','06/10','09/09','09/18','10/02','0027','0044','0067')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('394007','SD','FALL RIVER','HOT SPRINGS',4.343777777000000e+001,-1.034738890000000e+002,'05/29','10/02','06/13','05/29','05/15','09/25','10/02','10/16','0087','0108','0131')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('394037','SD','MINER','HOWARD',4.401222222000000e+001,-9.752416700000001e+001,'05/15','10/09','05/26','05/15','05/10','10/02','10/09','10/22','0111','0130','0145')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('394127','SD','BEADLE','HURON AP',4.439805555000000e+001,-9.822305600000000e+001,'05/20','10/11','06/02','05/20','05/13','09/30','10/11','10/22','0104','0123','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('394184','SD','JACKSON','INTERIOR 3 NE',4.374833333000000e+001,-1.019413890000000e+002,'05/17','10/16','05/28','05/17','05/06','10/07','10/16','10/27','0113','0133','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('394206','SD','EDMUNDS','IPSWICH',4.544777777000000e+001,-9.903833299999999e+001,'05/26','10/02','06/16','05/26','05/21','09/26','10/02','10/16','0083','0111','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('394516','SD','LYMAN','KENNEBEC',4.390722222000000e+001,-9.986277800000001e+001,'05/21','10/04','06/15','05/21','05/15','09/26','10/04','10/19','0090','0118','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('394596','SD','HAAKON','KIRLEY 6 N',4.461222222000000e+001,-1.013369440000000e+002,'05/18','10/12','05/26','05/18','05/07','09/30','10/12','10/27','0113','0125','0143')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('394834','SD','LAWRENCE','LEAD',4.435333333000000e+001,-1.037713890000000e+002,'06/14','09/30','06/22','06/14','05/19','09/23','09/30','10/19','0078','0095','0126')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('394864','SD','PERKINS','LEMMON',4.593972222000000e+001,-1.021575000000000e+002,'05/25','10/06','06/08','05/25','05/17','09/27','10/06','10/19','0099','0117','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('394983','SD','JACKSON','LONGVALLEY',4.346000000000000e+001,-1.014955560000000e+002,'05/25','10/08','06/07','05/25','05/17','09/28','10/08','10/22','0098','0116','0128')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('395048','SD','HARDING','LUDLOW 3 SSE',4.578500000000000e+001,-1.033719440000000e+002,'06/08','10/02','06/21','06/08','05/25','09/25','10/02','10/11','0075','0099','0117')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('395090','SD','LAKE','MADISON 2SE',4.399055555000000e+001,-9.709250000000000e+001,'05/16','10/09','05/28','05/16','05/08','10/03','10/09','10/23','0110','0130','0152')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('395228','SD','TURNER','MARION',4.342055555000000e+001,-9.725666699999999e+001,'05/17','10/16','05/22','05/17','05/05','10/06','10/16','10/27','0119','0133','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('395281','SD','BENNETT','MARTIN',4.318027777000000e+001,-1.017386110000000e+002,'05/27','10/07','06/11','05/27','05/15','09/27','10/07','10/23','0095','0115','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('395381','SD','CORSON','MC INTOSH 6 SE',4.583833333000000e+001,-1.012766670000000e+002,'05/24','10/09','06/04','05/24','05/12','09/26','10/09','10/16','0098','0119','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('395406','SD','CORSON','MC LAUGHLIN',4.581333333000000e+001,-1.008072220000000e+002,'06/01','10/04','06/07','06/01','05/16','09/25','10/04','10/15','0094','0109','0131')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('395456','SD','SPINK','MELLETTE 4 W',4.515500000000000e+001,-9.858250000000000e+001,'05/25','10/04','06/15','05/25','05/15','09/26','10/04','10/14','0084','0114','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('395481','SD','HUTCHINSON','MENNO',4.323583333000000e+001,-9.757138900000000e+001,'05/15','10/11','05/25','05/15','05/06','09/29','10/11','10/22','0114','0130','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('395544','SD','HAAKON','MILESVILLE 5 NE',4.452083333000000e+001,-1.016191670000000e+002,'05/20','10/13','06/05','05/20','05/12','09/27','10/13','10/24','0104','0124','0139')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('395561','SD','HAND','MILLER',4.451777777000000e+001,-9.898138899999999e+001,'05/17','10/14','05/26','05/17','05/10','10/02','10/14','10/25','0112','0134','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('395620','SD','TODD','MISSION',4.330611111000000e+001,-1.006558330000000e+002,'05/27','10/07','06/16','05/27','05/17','09/26','10/07','10/21','0088','0113','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('395638','SD','TODD','MISSION 14 S',4.311138888000000e+001,-1.006083330000000e+002,'05/19','10/10','06/09','05/19','05/13','10/01','10/10','10/23','0098','0124','0143')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('395691','SD','WALWORTH','MOBRIDGE 2NNW',4.556555555000000e+001,-1.004488890000000e+002,'05/13','10/16','05/29','05/13','05/03','10/05','10/16','10/24','0117','0136','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('395870','SD','PENNINGTON','MT RUSHMORE NATL MEM',4.387694444000000e+001,-1.034577780000000e+002,'06/06','10/04','06/18','06/06','05/23','09/30','10/04','10/24','0089','0107','0128')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('395891','SD','JONES','MURDO',4.388944444000000e+001,-1.007077780000000e+002,'05/20','10/16','05/26','05/20','05/09','10/05','10/16','10/25','0113','0132','0142')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('396054','SD','BUTTE','NEWELL',4.471583333000000e+001,-1.034275000000000e+002,'05/24','10/08','06/09','05/24','05/14','09/28','10/08','10/20','0096','0115','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('396170','SD','STANLEY','OAHE DAM',4.444194444000000e+001,-1.004175000000000e+002,'05/16','10/20','05/24','05/16','05/03','10/10','10/20','10/29','0122','0137','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('396212','SD','FALL RIVER','OELRICHS',4.318777777000000e+001,-1.032372220000000e+002,'05/27','10/07','06/17','05/27','05/13','09/25','10/07','10/16','0088','0110','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('396292','SD','SULLY','ONIDA 4 NW',4.473166666000000e+001,-1.001447220000000e+002,'05/20','10/09','05/31','05/20','05/13','09/27','10/09','10/20','0105','0124','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('396304','SD','FALL RIVER','ORAL',4.340333333000000e+001,-1.032683330000000e+002,'05/27','10/03','06/22','05/27','05/17','09/24','10/03','10/17','0080','0109','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('396427','SD','PENNINGTON','PACTOLA DAM',4.406222222000000e+001,-1.034819440000000e+002,'07/01','09/24','07/15','07/01','06/05','09/17','09/24','10/01','0040','0066','0101')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('396574','SD','CHARLES MIX','PICKSTOWN',4.306888888000000e+001,-9.853250000000000e+001,'05/14','10/21','05/21','05/14','05/02','10/09','10/21','10/31','0122','0140','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('396597','SD','HUGHES','PIERRE RGNL AP',4.438138888000000e+001,-1.002855560000000e+002,'05/16','10/17','05/24','05/16','05/06','10/01','10/17','10/27','0114','0134','0152')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('396712','SD','CAMPBELL','POLLOCK',4.590416666000000e+001,-1.002875000000000e+002,'05/22','10/07','05/29','05/22','05/12','09/30','10/07','10/18','0107','0117','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('396736','SD','SHANNON','PORCUPINE 11 N',4.339500000000000e+001,-1.023894440000000e+002,'06/05','09/30','06/29','06/05','05/20','09/29','09/30','10/12','0064','0101','0121')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('396937','SD','PENNINGTON','RAPID CITY REGIONAL AP',4.404333333000000e+001,-1.030536110000000e+002,'05/25','10/11','06/11','05/25','05/12','09/28','10/11','10/23','0095','0117','0142')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('396947','SD','PENNINGTON','RAPID CITY 4NW',4.411500000000000e+001,-1.032827780000000e+002,'05/24','10/15','06/09','05/24','05/13','10/03','10/15','10/25','0096','0117','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('397052','SD','SPINK','REDFIELD',4.486555555000000e+001,-9.852527800000000e+001,'05/25','10/05','06/14','05/25','05/16','09/24','10/05','10/17','0087','0115','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('397062','SD','HARDING','REDIG 11 NE',4.537666666000000e+001,-1.033675000000000e+002,'05/30','09/30','06/15','05/30','05/20','09/21','09/30','10/12','0082','0105','0122')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('397277','SD','EDMUNDS','ROSCOE',4.545250000000000e+001,-9.933583299999999e+001,'05/20','10/04','06/01','05/20','05/12','09/28','10/04','10/16','0102','0119','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('397545','SD','WALWORTH','SELBY',4.551000000000000e+001,-1.000355560000000e+002,'05/24','10/06','06/03','05/24','05/13','09/29','10/06','10/12','0096','0115','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('397667','SD','MINNEHAHA','SIOUX FALLS AP',4.357777777000000e+001,-9.675388900000000e+001,'05/19','10/11','05/30','05/19','05/09','10/01','10/11','10/20','0106','0126','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('397742','SD','ROBERTS','SISSETON',4.566555555000000e+001,-9.703916700000001e+001,'05/17','10/12','05/29','05/17','05/09','10/01','10/12','10/22','0111','0129','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('397882','SD','LAWRENCE','SPEARFISH',4.451388888000000e+001,-1.038722220000000e+002,'05/21','10/17','06/06','05/21','05/07','10/04','10/17','10/31','0095','0120','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('397992','SD','HYDE','STEPHAN 2 NW',4.426611111000000e+001,-9.944305600000000e+001,'05/24','10/05','06/13','05/24','05/17','09/28','10/05','10/16','0083','0106','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('398116','SD','ROBERTS','SUMMIT 1 W',4.530361111000000e+001,-9.706250000000000e+001,'06/03','10/02','06/14','06/03','05/18','09/26','10/02','10/14','0082','0105','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('398307','SD','DEWEY','TIMBER LAKE',4.542833333000000e+001,-1.010763890000000e+002,'05/22','10/11','06/02','05/22','05/13','09/27','10/11','10/18','0105','0122','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('398472','SD','BON HOMME','TYNDALL',4.299388888000000e+001,-9.786194399999999e+001,'05/12','10/20','05/19','05/12','05/06','10/05','10/20','10/26','0122','0140','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('398622','SD','CLAY','VERMILLION 2 SE',4.276250000000000e+001,-9.691944400000000e+001,'05/16','10/11','05/22','05/16','05/13','10/05','10/11','10/26','0115','0133','0142')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('398911','SD','PENNINGTON','WASTA',4.406944444000000e+001,-1.024477780000000e+002,'05/23','10/05','06/04','05/23','05/15','09/27','10/05','10/20','0101','0118','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('398932','SD','CODINGTON','WATERTOWN RGNL AP',4.490472222000000e+001,-9.714944400000000e+001,'05/26','10/05','06/03','05/26','05/13','10/01','10/05','10/18','0099','0113','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('398980','SD','DAY','WAUBAY NWR',4.542472222000000e+001,-9.732694400000000e+001,'05/21','10/11','05/28','05/21','05/13','10/03','10/11','10/24','0111','0126','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('399004','SD','DAY','WEBSTER',4.533305555000000e+001,-9.752277800000000e+001,'05/19','10/09','06/02','05/19','05/15','10/02','10/09','10/18','0104','0124','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('399070','SD','JERAULD','WESSINGTON SPRINGS',4.407611111000000e+001,-9.857055600000000e+001,'05/11','10/19','05/23','05/11','04/30','10/11','10/19','10/30','0122','0139','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('399232','SD','AURORA','WHITE LAKE',4.372916666000000e+001,-9.871305600000000e+001,'05/22','10/11','05/25','05/22','05/10','09/29','10/11','10/24','0115','0124','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('399367','SD','TRIPP','WINNER',4.336861111000000e+001,-9.984027800000000e+001,'05/19','10/18','05/26','05/19','05/09','10/03','10/18','10/27','0116','0128','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('399442','SD','MELLETTE','WOOD',4.349777777000000e+001,-1.004794440000000e+002,'05/21','10/10','06/02','05/21','05/14','09/28','10/10','10/24','0103','0123','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('399502','SD','YANKTON','YANKTON 2 E',4.287833333000000e+001,-9.736333300000000e+001,'05/11','10/24','05/19','05/11','05/02','10/09','10/24','11/01','0124','0136','0159')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('400081','TN','FENTRESS','ALLARDT',3.638055555000000e+001,-8.487444400000000e+001,'05/06','10/26','05/20','05/06','04/18','10/18','10/26','11/17','0137','0161','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('400284','TN','MCMINN','ATHENS',3.543222222000000e+001,-8.458333300000000e+001,'04/30','11/06','05/16','04/30','04/16','10/23','11/06','11/21','0146','0173','0202')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('400876','TN','HARDEMAN','BOLIVAR WTR WKS',3.526222222000000e+001,-8.898916700000000e+001,'04/17','11/12','04/27','04/17','04/05','10/26','11/12','11/28','0167','0184','0213')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('401094','TN','SULLIVAN','BRISTOL AP',3.647305555000000e+001,-8.240444400000000e+001,'05/03','11/03','05/15','05/03','04/19','10/22','11/03','11/20','0142','0167','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('401145','TN','HAYWOOD','BROWNSVILLE',3.558944444000000e+001,-8.925861100000000e+001,'04/14','11/16','04/21','04/14','03/31','11/04','11/16','11/30','0177','0197','0220')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('401480','TN','SMITH','CARTHAGE',3.624555555000000e+001,-8.594499999999999e+001,'04/25','11/15','05/09','04/25','04/11','10/28','11/15','11/25','0155','0174','0205')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('401561','TN','CLAY','CELINA',3.654083333000000e+001,-8.545944400000001e+001,'05/01','11/06','05/15','05/01','04/19','10/21','11/06','11/19','0146','0165','0190')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('401656','TN','HAMILTON','CHATTANOOGA AP',3.503111111000000e+001,-8.520138900000001e+001,'04/17','11/19','04/28','04/17','04/07','11/02','11/19','12/03','0171','0193','0216')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('401663','TN','CHEATHAM','CHEATHAM L&D',3.632083333000000e+001,-8.722166700000000e+001,'05/05','11/03','05/16','05/05','04/19','10/19','11/03','11/17','0138','0162','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('401790','TN','MONTGOMERY','CLARKSVILLE WWTP',3.654722222000000e+001,-8.733527800000000e+001,'04/27','11/06','05/09','04/27','04/17','10/27','11/06','11/23','0150','0165','0194')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('401808','TN','BRADLEY','CLEVELAND FLTR PLT',3.522027777000000e+001,-8.479805600000000e+001,'04/27','11/04','05/14','04/27','04/17','10/22','11/04','11/20','0147','0174','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('401957','TN','MAURY','COLUMBIA 3 WNW',3.563861111000000e+001,-8.708722200000000e+001,'04/26','11/02','05/08','04/26','04/16','10/20','11/02','11/20','0151','0174','0195')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('402009','TN','PUTNAM','COOKEVILLE',3.610750000000000e+001,-8.550333300000000e+001,'04/30','11/05','05/19','04/30','04/19','10/22','11/05','11/16','0141','0169','0191')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('402108','TN','TIPTON','COVINGTON 3 SW',3.554972222000000e+001,-8.970000000000000e+001,'04/14','11/18','04/24','04/14','03/31','11/05','11/18','12/07','0175','0199','0221')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('402197','TN','CUMBERLAND','CROSSVILLE AP',3.595083333000000e+001,-8.508138900000000e+001,'04/28','11/02','05/19','04/28','04/21','10/18','11/02','11/20','0138','0168','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('402202','TN','CUMBERLAND','CROSSVILLE ED & RESEARCH',3.601472222000000e+001,-8.513111100000000e+001,'05/10','11/02','05/23','05/10','04/23','10/15','11/02','11/08','0131','0148','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('402360','TN','RHEA','DAYTON 2SE',3.547166666000000e+001,-8.499472200000000e+001,'04/22','11/08','05/12','04/22','04/15','10/27','11/08','11/22','0151','0178','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('402489','TN','DICKSON','DICKSON',3.607500000000000e+001,-8.739583300000000e+001,'04/22','11/05','05/11','04/22','04/17','10/28','11/05','11/15','0149','0173','0197')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('402589','TN','STEWART','DOVER 1 W',3.648194444000000e+001,-8.786277800000001e+001,'04/30','11/03','05/09','04/30','04/15','10/25','11/03','11/23','0151','0162','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('402600','TN','WEAKLEY','DRESDEN',3.628361111000000e+001,-8.870638900000000e+001,'04/19','11/08','05/05','04/19','04/14','10/25','11/08','11/22','0155','0180','0204')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('402685','TN','DYER','DYERSBURG III GOLF',3.600027777000000e+001,-8.940944399999999e+001,'04/15','11/25','04/21','04/15','03/30','11/07','11/25','12/04','0173','0190','0219')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('403074','TN','LINCOLN','FAYETTEVILLE WTP',3.515000000000000e+001,-8.654111100000000e+001,'05/01','10/27','05/19','05/01','04/25','10/19','10/27','11/16','0137','0162','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('403280','TN','WILLIAMSON','FRANKLIN SEWAGE PLT',3.594166666000000e+001,-8.686861100000000e+001,'04/30','11/02','05/15','04/30','04/16','10/19','11/02','11/17','0142','0163','0194')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('403420','TN','SEVIER','GATLINBURG 2 SW',3.568777777000000e+001,-8.353694400000001e+001,'05/10','11/02','05/24','05/10','04/22','10/22','11/02','11/13','0135','0154','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('403679','TN','GREENE','GREENEVILLE EXP STN',3.610555555000000e+001,-8.284361100000000e+001,'05/11','10/30','05/20','05/11','05/02','10/16','10/30','11/13','0133','0149','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('404417','TN','CARROLL','HUNTINGDON WTP',3.600277777000000e+001,-8.842527800000001e+001,'04/21','11/07','05/04','04/21','04/11','10/26','11/07','11/25','0158','0178','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('404556','TN','MADISON','JACKSON MCKELLAR- SIPES AP',3.559305555000000e+001,-8.891666700000000e+001,'04/18','11/13','04/24','04/18','04/09','10/30','11/13','11/27','0169','0189','0205')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('404561','TN','MADISON','JACKSON EXP STN',3.562138888000000e+001,-8.884555600000000e+001,'04/19','11/13','05/01','04/19','04/05','10/27','11/13','11/27','0163','0183','0209')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('404858','TN','SULLIVAN','KINGSPORT',3.651944444000000e+001,-8.252750000000000e+001,'04/28','11/07','05/18','04/28','04/14','10/27','11/07','11/24','0145','0177','0199')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('404876','TN','CHEATHAM','KINGSTON SPRINGS',3.610333333000000e+001,-8.711527800000000e+001,'05/02','10/28','05/17','05/02','04/20','10/18','10/28','11/08','0140','0160','0183')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('404946','TN','KNOX','KNOXVILLE EXP STN',3.588194444000000e+001,-8.395722200000000e+001,'04/28','11/06','05/11','04/28','04/15','10/28','11/06','11/18','0150','0172','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('404950','TN','BLOUNT','KNOXVILLE AP',3.581805555000000e+001,-8.398583300000000e+001,'04/22','11/19','05/02','04/22','04/12','10/29','11/19','11/27','0162','0184','0205')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('404987','TN','MACON','LAFAYETTE',3.651916666000000e+001,-8.603000000000000e+001,'04/21','11/11','05/05','04/21','04/13','10/28','11/11','11/24','0157','0180','0200')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('405089','TN','LAWRENCE','LAWRENCEBURG FILT PLT',3.524361111000000e+001,-8.735083299999999e+001,'04/30','11/08','05/16','04/30','04/15','10/21','11/08','11/19','0143','0168','0195')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('405108','TN','WILSON','LEBANON',3.622916666000000e+001,-8.631805600000000e+001,'05/04','11/01','05/20','05/04','04/17','10/20','11/01','11/13','0135','0162','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('405158','TN','LOUDON','LENOIR CITY',3.578750000000000e+001,-8.426222199999999e+001,'04/25','11/12','05/03','04/25','04/10','11/02','11/12','11/27','0165','0177','0213')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('405187','TN','MARSHALL','LEWISBURG EXP STN',3.541388888000000e+001,-8.680861100000000e+001,'04/30','11/02','05/15','04/30','04/20','10/21','11/02','11/14','0137','0165','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('405210','TN','HENDERSON','LEXINGTON',3.564666666000000e+001,-8.839749999999999e+001,'04/23','11/14','05/02','04/23','04/08','11/01','11/14','11/26','0160','0179','0214')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('405278','TN','PERRY','LINDEN WTP',3.560472222000000e+001,-8.784083300000000e+001,'05/02','11/03','05/12','05/02','04/20','10/19','11/03','11/17','0148','0166','0190')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('405332','TN','OVERTON','LIVINGSTON RADIO WLIV',3.637750000000000e+001,-8.533638900000000e+001,'05/06','11/01','05/19','05/06','04/23','10/22','11/01','11/15','0136','0156','0177')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('405681','TN','WEAKLEY','MARTIN U OF T BRANCH E',3.634444444000000e+001,-8.886361100000001e+001,'04/20','11/06','04/29','04/20','04/13','10/23','11/06','11/23','0160','0178','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('405882','TN','WARREN','MC MINNVILLE',3.567222222000000e+001,-8.578111100000000e+001,'04/28','11/06','05/09','04/28','04/13','10/23','11/06','11/23','0151','0173','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('405954','TN','SHELBY','MEMPHIS INTL AP',3.505638888000000e+001,-8.998638900000000e+001,'04/09','11/27','04/14','04/09','03/21','11/17','11/27','12/13','0195','0212','0241')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('406012','TN','GIBSON','MILAN EXP STN',3.593277777000000e+001,-8.872666700000001e+001,'04/21','11/03','05/04','04/21','04/16','10/19','11/03','11/23','0154','0175','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('406162','TN','MARION','MONTEAGLE',3.522444444000000e+001,-8.584166700000000e+001,'04/21','11/11','05/07','04/21','04/15','10/29','11/11','11/26','0156','0179','0206')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('406170','TN','PUTNAM','MONTEREY',3.614833333000000e+001,-8.526500000000000e+001,'05/04','11/21','05/19','05/04','04/17','10/27','11/21','12/19','0141','0166','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('406274','TN','FAYETTE','MOSCOW',3.507111111000000e+001,-8.941166699999999e+001,'04/18','11/12','04/26','04/18','04/05','10/23','11/12','11/30','0164','0181','0202')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('406292','TN','JOHNSON','MTN CITY 2',3.647388888000000e+001,-8.180333300000000e+001,'05/26','10/17','06/09','05/26','05/18','10/06','10/17','10/29','0103','0123','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('406340','TN','MAURY','MT PLEASANT 1N',3.555722222000000e+001,-8.720194400000000e+001,'04/28','11/04','05/13','04/28','04/18','10/22','11/04','11/19','0145','0170','0190')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('406371','TN','RUTHERFORD','MURFREESBORO 5 N',3.592027777000000e+001,-8.637277800000000e+001,'04/24','11/09','05/06','04/24','04/18','10/25','11/09','11/20','0156','0172','0194')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('406402','TN','DAVIDSON','NASHVILLE ASOS',3.611888888000000e+001,-8.668916700000000e+001,'04/21','11/14','04/28','04/21','04/15','11/02','11/14','11/28','0168','0181','0211')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('406534','TN','COCKE','NEWPORT 1 NW',3.598333333000000e+001,-8.320083300000000e+001,'05/02','11/04','05/14','05/02','04/18','10/21','11/04','11/18','0145','0171','0190')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('406619','TN','ANDERSON','NORRIS',3.621305555000000e+001,-8.406027800000000e+001,'05/09','11/04','05/20','05/09','04/21','10/25','11/04','11/21','0141','0158','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('406750','TN','ANDERSON','OAK RIDGE ATDD',3.600277777000000e+001,-8.424861100000000e+001,'04/28','11/06','05/18','04/28','04/16','10/26','11/06','11/19','0144','0172','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('406829','TN','SCOTT','ONEIDA',3.650277777000000e+001,-8.453083300000000e+001,'05/15','10/25','05/25','05/15','04/29','10/14','10/25','11/10','0124','0143','0171')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('406977','TN','HENRY','PARIS 2 SE',3.628722222000000e+001,-8.829583300000000e+001,'04/22','11/11','05/01','04/22','04/14','10/27','11/11','11/24','0162','0180','0206')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('407184','TN','BLEDSOE','PIKEVILLE',3.559805555000000e+001,-8.519361100000000e+001,'05/04','11/01','05/15','05/04','04/20','10/22','11/01','11/15','0144','0164','0182')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('407359','TN','SUMNER','PORTLAND SEWAGE PLT',3.658750000000000e+001,-8.652583300000001e+001,'04/25','11/08','05/04','04/25','04/11','10/23','11/08','11/26','0153','0174','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('407459','TN','GILES','PULASKI WWTP',3.518416666000000e+001,-8.704222200000000e+001,'04/27','11/08','05/02','04/27','04/14','10/24','11/08','11/21','0160','0177','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('407710','TN','LAUDERDALE','RIPLEY',3.571777777000000e+001,-8.949861100000000e+001,'04/14','11/17','04/20','04/14','03/30','11/05','11/17','12/03','0181','0197','0223')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('407834','TN','ROANE','ROCKWOOD 2',3.585277777000000e+001,-8.470500000000000e+001,'05/08','11/02','05/16','05/08','04/16','10/22','11/02','11/15','0142','0158','0195')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('407884','TN','HAWKINS','ROGERSVILLE 1 NE',3.641611111000000e+001,-8.298388900000001e+001,'05/06','11/02','05/17','05/06','04/21','10/21','11/02','11/17','0140','0158','0188')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('408065','TN','OBION','SAMBURG WR',3.645277777000000e+001,-8.930277800000000e+001,'04/21','11/11','05/01','04/21','04/14','10/23','11/11','11/26','0161','0181','0202')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('408108','TN','HARDIN','SAVANNAH 6 SW',3.515250000000000e+001,-8.832138900000000e+001,'04/22','11/12','05/02','04/22','04/12','10/27','11/12','11/22','0165','0179','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('408160','TN','MCNAIRY','SELMER',3.516472222000000e+001,-8.859944400000001e+001,'04/27','11/06','05/11','04/27','04/13','10/21','11/06','11/19','0151','0171','0194')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('408179','TN','SEVIER','SEVIERVILLE',3.592972222000000e+001,-8.359833300000000e+001,'05/12','10/31','05/20','05/12','04/26','10/20','10/31','11/12','0136','0153','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('408246','TN','BEDFORD','SHELBYVILLE WATER DEPT',3.549222222000000e+001,-8.647750000000001e+001,'04/28','11/05','05/08','04/28','04/14','10/21','11/05','11/17','0151','0170','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('408405','TN','DEKALB','SMITHVILLE 2 SE',3.594194444000000e+001,-8.578916700000001e+001,'04/30','11/02','05/19','04/30','04/19','10/19','11/02','11/14','0137','0163','0182')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('408522','TN','WHITE','SPARTA WASTEWATER PLANT',3.590666666000000e+001,-8.547499999999999e+001,'05/03','10/31','05/19','05/03','04/21','10/19','10/31','11/17','0140','0163','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('408562','TN','ROBERTSON','SPRINGFIELD EXP STN',3.647111111000000e+001,-8.684138900000001e+001,'04/28','11/02','05/12','04/28','04/19','10/22','11/02','11/18','0144','0167','0188')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('408868','TN','CLAIBORNE','TAZEWELL',3.646500000000000e+001,-8.356027800000000e+001,'05/18','10/25','05/28','05/18','05/07','10/15','10/25','11/04','0123','0138','0166')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('409155','TN','COFFEE','TULLAHOMA',3.534527777000000e+001,-8.620888900000000e+001,'04/23','11/07','05/03','04/23','04/13','10/26','11/07','11/22','0158','0176','0199')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('409219','TN','OBION','UNION CITY',3.639250000000000e+001,-8.903166700000000e+001,'04/18','11/08','04/30','04/18','04/10','10/23','11/08','11/23','0163','0182','0204')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('409502','TN','WAYNE','WAYNESBORO',3.530416666000000e+001,-8.775916700000001e+001,'05/07','10/26','05/24','05/07','04/23','10/18','10/26','11/12','0130','0155','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('409866','TN','CANNON','WOODBURY 1 WNW',3.583750000000000e+001,-8.608944400000000e+001,'05/04','10/24','05/22','05/04','04/24','10/16','10/24','11/12','0133','0157','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410016','TX','TAYLOR','ABILENE RGNL AP',3.241055555000000e+001,-9.968222200000000e+001,'04/10','11/28','04/19','04/10','04/02','11/18','11/28','12/11','0193','0210','0227')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410120','TX','SHACKELFORD','ALBANY',3.272944444000000e+001,-9.930166700000000e+001,'04/13','11/23','04/25','04/13','04/03','11/13','11/23','12/04','0175','0199','0222')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410174','TX','BREWSTER','ALPINE',3.037638888000000e+001,-1.036600000000000e+002,'04/23','11/22','05/04','04/23','04/13','11/08','11/22','12/04','0160','0182','0206')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410204','TX','BRAZORIA','ALVIN',2.936527777000000e+001,-9.523361100000000e+001,'03/20','01/01','03/29','03/20','03/02','12/15','01/01','00/00','0229','0257','0295')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410211','TX','POTTER','AMARILLO WSO AP',3.513000000000000e+001,-1.014300000000000e+002,'05/01','11/07','05/12','05/01','04/15','10/27','11/07','11/17','0148','0163','0195')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410225','TX','VAL VERDE','AMISTAD DAM',2.946083333000000e+001,-1.010286110000000e+002,'03/12','12/30','03/30','03/12','02/25','12/09','12/30','00/00','0230','0263','0293')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410235','TX','CHAMBERS','ANAHUAC',2.978777777000000e+001,-9.463416700000001e+001,'03/16','01/03','03/25','03/16','03/01','12/13','01/03','00/00','0236','0263','0292')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410257','TX','BRAZORIA','ANGLETON 2 W',2.915722222000000e+001,-9.545916699999999e+001,'03/26','12/29','04/05','03/26','03/12','12/10','12/29','00/00','0220','0252','0278')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410305','TX','ARANSAS','ARANSAS WR',2.830805555000000e+001,-9.680472200000000e+001,'03/07','12/28','03/23','03/07','02/25','12/18','12/28','00/00','0244','0272','0304')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410394','TX','STONEWALL','ASPERMONT',3.315250000000000e+001,-1.002333330000000e+002,'04/12','11/24','04/27','04/12','04/11','11/11','11/24','12/01','0169','0200','0211')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410404','TX','HENDERSON','ATHENS',3.216333333000000e+001,-9.583000000000000e+001,'04/07','12/05','04/16','04/07','03/23','11/22','12/05','12/17','0189','0210','0236')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410428','TX','TRAVIS','AUSTIN-CAMP MABRY',3.032083333000000e+001,-9.776027800000000e+001,'03/15','12/28','03/29','03/15','03/06','12/06','12/28','01/20','0232','0259','0281')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410482','TX','PECOS','BAKERSFIELD',3.088777777000000e+001,-1.023008330000000e+002,'04/11','11/30','04/21','04/11','04/04','11/19','11/30','12/12','0186','0211','0230')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410493','TX','RUNNELS','BALLINGER 2 NW',3.174138888000000e+001,-9.997638900000000e+001,'04/13','11/25','04/22','04/13','04/08','11/13','11/25','12/01','0182','0204','0216')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410498','TX','REEVES','BALMORHEA',3.098444444000000e+001,-1.037402780000000e+002,'04/14','11/25','04/24','04/14','04/07','11/14','11/25','12/03','0180','0202','0216')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410518','TX','ELLIS','BARDWELL DAM',3.226305555000000e+001,-9.663694400000000e+001,'04/04','12/09','04/12','04/04','03/21','11/28','12/09','12/19','0204','0220','0240')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410569','TX','MATAGORDA','BAY CITY WTR WKS',2.897972222000000e+001,-9.597499999999999e+001,'03/17','01/15','03/25','03/17','02/25','12/17','01/15','00/00','0234','0262','0297')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410586','TX','HARRIS','BAYTOWN',2.991416666000000e+001,-9.499083300000000e+001,'03/14','01/01','03/23','03/14','02/28','12/17','01/01','00/00','0239','0261','0287')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410613','TX','JEFFERSON','BEAUMONT RSCH CTR',3.006888888000000e+001,-9.429277800000000e+001,'03/24','12/22','03/29','03/24','03/12','12/05','12/22','01/25','0223','0247','0274')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410639','TX','BEE','BEEVILLE 5 NE',2.845750000000000e+001,-9.770611100000001e+001,'03/17','12/27','04/02','03/17','03/01','12/10','12/27','00/00','0228','0257','0291')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410690','TX','DUVAL','BENAVIDES 2',2.759694444000000e+001,-9.841611100000000e+001,'03/29','12/23','04/05','03/29','03/11','12/11','12/23','00/00','0224','0246','0275')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410691','TX','TARRANT','BENBROOK DAM',3.264750000000000e+001,-9.744388900000000e+001,'04/06','12/06','04/12','04/06','03/24','11/22','12/06','12/22','0209','0218','0244')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410779','TX','REAGAN','BIG LAKE 2',3.120000000000000e+001,-1.014625000000000e+002,'04/15','11/24','04/24','04/15','04/07','11/19','11/24','12/06','0171','0194','0215')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410786','TX','HOWARD','BIG SPRING',3.224416666000000e+001,-1.014536110000000e+002,'04/14','11/27','04/20','04/14','04/04','11/21','11/27','12/09','0192','0212','0226')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410832','TX','BLANCO','BLANCO',3.010611111000000e+001,-9.842861100000000e+001,'04/13','11/30','04/19','04/13','03/26','11/18','11/30','12/16','0189','0206','0231')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410902','TX','KENDALL','BOERNE',2.979861111000000e+001,-9.873527799999999e+001,'04/11','11/30','04/22','04/11','03/28','11/20','11/30','12/14','0183','0207','0233')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410923','TX','FANNIN','BONHAM 3NNE',3.364027777000000e+001,-9.616611100000000e+001,'04/12','11/24','04/17','04/12','03/31','11/13','11/24','12/08','0183','0202','0222')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410958','TX','HUTCHINSON','BORGER',3.563638888000000e+001,-1.014541670000000e+002,'04/29','11/10','05/09','04/29','04/14','10/29','11/10','11/18','0149','0175','0199')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('410984','TX','MONTAGUE','BOWIE',3.355111111000000e+001,-9.784722200000000e+001,'04/06','11/27','04/15','04/06','03/31','11/17','11/27','12/16','0199','0214','0228')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411000','TX','OLDHAM','BOYS RANCH',3.553027777000000e+001,-1.022563890000000e+002,'04/28','10/31','05/12','04/28','04/21','10/17','10/31','11/10','0143','0167','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411007','TX','KINNEY','BRACKETTVILLE',2.931666666000000e+001,-1.004144440000000e+002,'04/01','12/08','04/14','04/01','03/11','12/01','12/08','01/24','0196','0218','0258')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411017','TX','MCCULLOCH','BRADY',3.114444444000000e+001,-9.934916699999999e+001,'04/10','11/27','04/16','04/10','04/01','11/18','11/27','12/08','0198','0211','0228')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411033','TX','HARTLEY','BRAVO',3.562000000000000e+001,-1.030072220000000e+002,'05/09','10/26','05/18','05/09','04/25','10/17','10/26','11/09','0134','0152','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411042','TX','STEPHENS','BRECKENRIDGE',3.275000000000000e+001,-9.890166700000000e+001,'04/14','11/24','04/24','04/14','04/03','11/15','11/24','12/06','0184','0205','0225')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411048','TX','WASHINGTON','BRENHAM',3.015916666000000e+001,-9.639722200000000e+001,'03/18','12/27','03/31','03/18','03/06','12/09','12/27','01/10','0228','0256','0282')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411063','TX','WISE','BRIDGEPORT',3.320638888000000e+001,-9.777611100000000e+001,'04/18','11/25','04/21','04/18','04/08','11/12','11/25','12/05','0176','0197','0219')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411128','TX','TERRY','BROWNFIELD #2',3.319083333000000e+001,-1.022680560000000e+002,'04/17','11/20','04/28','04/17','04/08','11/07','11/20','11/30','0173','0193','0215')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411136','TX','CAMERON','BROWNSVILLE INTL AP',2.591416666000000e+001,-9.742305600000000e+001,'02/13','00/00','03/08','02/13','01/17','00/00','00/00','00/00','0287','0313','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411138','TX','BROWN','BROWNWOOD 2ENE',3.173833333000000e+001,-9.894555600000000e+001,'04/10','11/28','04/22','04/10','03/29','11/21','11/28','12/08','0183','0209','0226')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411250','TX','BURNET','BURNET',3.075861111000000e+001,-9.823388900000001e+001,'04/13','11/30','04/16','04/13','03/30','11/20','11/30','12/17','0192','0210','0236')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411398','TX','REAL','CAMP WOOD',2.967027777000000e+001,-1.000097220000000e+002,'04/13','11/27','04/20','04/13','03/31','11/19','11/27','12/14','0188','0209','0232')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411429','TX','COMAL','CANYON DAM',2.987055555000000e+001,-9.819666700000001e+001,'03/21','12/21','04/02','03/21','03/10','12/08','12/21','01/10','0221','0249','0268')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411430','TX','RANDALL','CANYON',3.498055555000000e+001,-1.019263890000000e+002,'04/27','11/08','05/09','04/27','04/15','10/30','11/08','11/19','0150','0171','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411486','TX','DIMMIT','CARRIZO SPRINGS 3W',2.848972222000000e+001,-9.987388900000001e+001,'03/21','12/29','03/31','03/21','02/25','12/07','12/29','00/00','0228','0247','0291')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411492','TX','EDWARDS','CARTA VALLEY',2.979083333000000e+001,-1.006741670000000e+002,'04/08','12/16','04/17','04/08','04/04','11/21','12/16','12/18','0193','0198','0221')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411500','TX','PANOLA','CARTHAGE',3.216138888000000e+001,-9.433972200000000e+001,'04/05','12/02','04/17','04/05','03/21','11/18','12/02','12/17','0188','0216','0242')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411524','TX','BREWSTER','CASTOLON',2.913444444000000e+001,-1.035150000000000e+002,'03/30','12/17','04/05','03/30','03/09','12/04','12/17','12/27','0218','0232','0263')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411578','TX','SHELBY','CENTER',3.180750000000000e+001,-9.416416700000001e+001,'04/07','11/28','04/18','04/07','03/26','11/16','11/28','12/15','0183','0207','0232')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411596','TX','LEON','CENTERVILLE',3.125805555000000e+001,-9.597444400000001e+001,'04/07','12/01','04/19','04/07','03/25','11/20','12/01','12/16','0188','0212','0237')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411663','TX','ATASCOSA','CHARLOTTE 5 NNW',2.892750000000000e+001,-9.874944400000000e+001,'03/29','12/13','04/12','03/29','03/15','12/04','12/13','01/05','0210','0233','0270')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411698','TX','CHILDRESS','CHILDRESS MUNI AP',3.442722222000000e+001,-1.002830560000000e+002,'04/13','11/22','04/21','04/13','04/06','11/12','11/22','12/01','0178','0199','0219')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411715','TX','BREWSTER','CHISOS BASIN',2.927027777000000e+001,-1.033002780000000e+002,'04/10','12/10','04/18','04/10','04/04','11/25','12/10','12/26','0190','0215','0231')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411761','TX','DONLEY','CLARENDON',3.493250000000000e+001,-1.008902780000000e+002,'04/23','11/10','05/10','04/23','04/13','10/27','11/10','11/21','0147','0178','0204')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411800','TX','JOHNSON','CLEBURNE',3.231388888000000e+001,-9.740611100000000e+001,'04/09','11/29','04/16','04/09','03/27','11/20','11/29','12/17','0196','0215','0234')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411810','TX','LIBERTY','CLEVELAND',3.036361111000000e+001,-9.508388900000000e+001,'03/29','12/12','04/09','03/29','03/19','11/29','12/12','01/06','0211','0230','0258')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411875','TX','COLEMAN','COLEMAN',3.182111111000000e+001,-9.942000000000000e+001,'04/08','11/28','04/13','04/08','04/02','11/23','11/28','12/12','0196','0215','0227')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411889','TX','BRAZOS','CLG STN EASTERWD AP',3.058916666000000e+001,-9.636472200000000e+001,'03/25','12/17','04/09','03/25','03/13','12/01','12/17','01/06','0214','0246','0263')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411911','TX','COLORADO','COLUMBUS',2.969888888000000e+001,-9.657305599999999e+001,'04/03','12/08','04/15','04/03','03/22','11/30','12/08','12/29','0199','0222','0248')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411956','TX','MONTGOMERY','CONROE',3.033027777000000e+001,-9.548305600000001e+001,'03/20','12/17','04/06','03/20','03/17','12/03','12/17','01/10','0217','0240','0260')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('411974','TX','REAGAN','COPE RCH',3.153333333000000e+001,-1.012841670000000e+002,'04/18','11/19','05/02','04/18','04/11','11/06','11/19','11/27','0159','0184','0205')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('412015','TX','NUECES','CORPUS CHRISTI AP',2.777416666000000e+001,-9.751222199999999e+001,'03/13','01/23','03/22','03/13','02/21','12/28','01/23','00/00','0249','0286','0311')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('412019','TX','NAVARRO','CORSICANA',3.212250000000000e+001,-9.648666700000000e+001,'04/02','12/12','04/10','04/02','03/14','11/23','12/12','12/27','0209','0232','0259')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('412082','TX','CRANE','CRANE',3.140722222000000e+001,-1.023577780000000e+002,'04/13','11/29','04/20','04/13','04/02','11/20','11/29','12/07','0189','0204','0227')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('412114','TX','HOUSTON','CROCKETT',3.130722222000000e+001,-9.545083300000000e+001,'04/01','12/10','04/15','04/01','03/22','11/25','12/10','12/28','0202','0225','0251')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('412121','TX','CROSBY','CROSBYTON',3.365166666000000e+001,-1.012450000000000e+002,'04/15','11/21','04/30','04/15','04/11','11/07','11/21','11/27','0172','0187','0210')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('412173','TX','DEWITT','CUERO',2.908916666000000e+001,-9.734333300000000e+001,'03/24','12/17','04/12','03/24','03/15','12/05','12/17','01/04','0208','0240','0264')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('412225','TX','MORRIS','DAINGERFIELD 9 S',3.292027777000000e+001,-9.472250000000000e+001,'03/26','12/12','04/12','03/26','03/14','11/25','12/12','12/23','0205','0233','0259')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('412240','TX','DALLAM','DALHART FAA AP',3.601666666000000e+001,-1.025500000000000e+002,'05/08','10/31','05/14','05/08','04/26','10/22','10/31','11/11','0142','0157','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('412244','TX','DALLAS','DALLAS FAA AP',3.285194444000000e+001,-9.685555600000001e+001,'03/28','12/17','04/09','03/28','03/12','11/28','12/17','01/03','0217','0239','0266')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('412266','TX','WHARTON','DANEVANG 1 W',2.905666666000000e+001,-9.623194400000000e+001,'03/21','01/14','03/30','03/21','03/09','12/13','01/14','00/00','0226','0257','0288')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('412360','TX','VAL VERDE','DEL RIO AP',2.937833333000000e+001,-1.009269440000000e+002,'03/15','12/28','03/28','03/15','02/27','12/04','12/28','01/28','0230','0247','0294')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('412404','TX','DENTON','DENTON 2 SE',3.319916666000000e+001,-9.710500000000000e+001,'04/06','12/04','04/11','04/06','03/25','11/20','12/04','12/22','0204','0220','0243')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('412464','TX','CASTRO','DIMMITT 2 N',3.458583333000000e+001,-1.023119440000000e+002,'05/11','10/29','05/16','05/11','04/22','10/20','10/29','11/17','0137','0153','0183')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('412598','TX','ERATH','DUBLIN 2SE',3.206277777000000e+001,-9.830472200000000e+001,'04/05','12/02','04/14','04/05','04/01','11/22','12/02','12/20','0199','0218','0235')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('412617','TX','MOORE','DUMAS',3.587305555000000e+001,-1.019725000000000e+002,'05/03','11/07','05/12','05/03','04/18','10/30','11/07','11/17','0149','0167','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('412679','TX','MAVERICK','EAGLE PASS 3N',2.875694444000000e+001,-1.004791670000000e+002,'03/10','12/29','03/26','03/10','02/19','12/12','12/29','00/00','0236','0265','0308')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('412797','TX','EL PASO','EL PASO AP',3.181111111000000e+001,-1.063758330000000e+002,'04/12','11/22','04/27','04/12','04/03','11/12','11/22','12/08','0182','0204','0219')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('412820','TX','BASTROP','ELGIN',3.034944444000000e+001,-9.736833300000001e+001,'03/20','12/19','04/09','03/20','03/13','12/06','12/19','01/04','0215','0247','0270')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('412902','TX','RAINS','EMORY',3.287111111000000e+001,-9.577972200000001e+001,'04/09','11/29','04/19','04/09','03/25','11/14','11/29','12/14','0187','0210','0232')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413060','TX','STARR','FALCON DAM',2.655805555000000e+001,-9.913722199999999e+001,'03/05','00/00','03/14','03/05','02/06','01/09','00/00','00/00','0256','0300','0337')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413063','TX','BROOKS','FALFURRIAS',2.713944444000000e+001,-9.812000000000001e+001,'03/18','01/10','03/27','03/18','02/20','12/18','01/10','00/00','0239','0269','0314')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413133','TX','ELLIS','FERRIS',3.253388888000000e+001,-9.666083300000000e+001,'04/02','12/03','04/10','04/02','03/19','11/25','12/03','12/17','0207','0220','0250')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413183','TX','FAYETTE','FLATONIA 4SE',2.963388888000000e+001,-9.706444400000000e+001,'03/24','12/29','04/04','03/24','03/13','12/09','12/29','01/26','0224','0244','0270')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413201','TX','WILSON','FLORESVILLE',2.913222222000000e+001,-9.815972200000000e+001,'04/05','12/11','04/16','04/05','03/16','11/28','12/11','12/28','0203','0224','0264')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413214','TX','FLOYD','FLOYDADA',3.398500000000000e+001,-1.013338890000000e+002,'04/20','11/17','05/04','04/20','04/11','11/04','11/17','11/24','0157','0184','0207')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413225','TX','LIPSCOMB','FOLLETT',3.643277777000000e+001,-1.001369440000000e+002,'04/30','11/08','05/11','04/30','04/19','10/27','11/08','11/18','0143','0163','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413262','TX','JEFF DAVIS','FT DAVIS',3.059972222000000e+001,-1.038869440000000e+002,'04/23','11/21','05/03','04/23','04/13','11/10','11/21','12/08','0159','0178','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413266','TX','HUDSPETH','FT HANCOCK 8SSE',3.118527777000000e+001,-1.057413890000000e+002,'04/24','11/13','05/07','04/24','04/11','11/06','11/13','11/23','0159','0182','0207')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413280','TX','PECOS','FT STOCKTON',3.090722222000000e+001,-1.029152780000000e+002,'04/16','12/03','04/21','04/16','04/10','11/23','12/03','12/08','0186','0204','0216')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413299','TX','LA SALLE','FOWLERTON',2.850333333000000e+001,-9.883916700000000e+001,'03/25','12/13','04/07','03/25','03/08','12/08','12/13','01/07','0219','0239','0275')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413321','TX','ROBERTSON','FRANKLIN',3.103277777000000e+001,-9.648888900000000e+001,'04/04','12/10','04/12','04/04','03/17','11/27','12/10','12/23','0206','0221','0254')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413329','TX','GILLESPIE','FREDERICKSBURG',3.023916666000000e+001,-9.890888900000000e+001,'04/11','11/28','04/20','04/11','03/26','11/20','11/28','12/13','0189','0209','0234')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413340','TX','BRAZORIA','FREEPORT 2 NW',2.898444444000000e+001,-9.538083300000000e+001,'03/03','00/00','03/24','03/03','02/17','12/31','00/00','00/00','0247','0286','0307')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413341','TX','DUVAL','FREER',2.787222222000000e+001,-9.861750000000001e+001,'03/15','01/04','04/08','03/15','02/23','12/14','01/04','00/00','0227','0250','0294')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413368','TX','PARMER','FRIONA',3.464000000000000e+001,-1.027230560000000e+002,'05/03','11/06','05/14','05/03','04/18','10/26','11/06','11/16','0146','0162','0190')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413411','TX','BORDEN','GAIL',3.277444444000000e+001,-1.014538890000000e+002,'04/14','11/22','04/18','04/14','04/05','11/16','11/22','12/08','0183','0204','0220')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413445','TX','GLASSCOCK','GARDEN CITY',3.186666666000000e+001,-1.014813890000000e+002,'04/18','11/23','05/01','04/18','04/07','11/11','11/23','11/28','0169','0191','0210')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413485','TX','CORYELL','GATESVILLE',3.141444444000000e+001,-9.770194400000000e+001,'04/14','11/29','04/19','04/14','04/01','11/19','11/29','12/05','0190','0207','0226')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413546','TX','UPSHUR','GILMER 4 WNW',3.274638888000000e+001,-9.504972200000000e+001,'04/14','11/23','04/18','04/14','04/04','11/09','11/23','12/09','0181','0196','0218')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413614','TX','MILLS','GOLDTHWAITE 1 WSW',3.144027777000000e+001,-9.859027800000000e+001,'04/09','12/05','04/17','04/09','03/26','11/24','12/05','12/21','0196','0215','0240')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413618','TX','GOLIAD','GOLIAD',2.866166666000000e+001,-9.738500000000001e+001,'03/31','12/21','04/10','03/31','03/14','12/02','12/21','01/19','0209','0231','0265')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413622','TX','GONZALES','GONZALES 1N',2.953388888000000e+001,-9.745000000000000e+001,'03/21','12/24','04/06','03/21','03/06','12/03','12/24','01/09','0218','0244','0279')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413668','TX','YOUNG','GRAHAM',3.312027777000000e+001,-9.856694400000001e+001,'04/20','11/23','04/26','04/20','04/09','11/11','11/23','12/04','0171','0192','0216')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413680','TX','WARD','GRANDFALLS 3SSE',3.130277777000000e+001,-1.028222220000000e+002,'04/18','11/22','04/26','04/18','04/09','11/13','11/22','11/30','0173','0193','0210')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413691','TX','TARRANT','GRAPEVINE DAM',3.295055555000000e+001,-9.705527800000000e+001,'04/09','12/01','04/16','04/09','03/22','11/21','12/01','12/17','0194','0214','0243')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413734','TX','HUNT','GREENVILLE KGVL RADIO',3.316777777000000e+001,-9.609833300000000e+001,'04/08','11/30','04/22','04/08','03/31','11/18','11/30','12/13','0182','0211','0225')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413787','TX','HANSFORD','GRUVER',3.626305555000000e+001,-1.014050000000000e+002,'05/04','11/01','05/13','05/04','04/21','10/20','11/01','11/12','0141','0163','0181')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413828','TX','KING','GUTHRIE',3.362666666000000e+001,-1.003369440000000e+002,'04/18','11/15','04/26','04/18','04/11','11/04','11/15','11/23','0166','0193','0208')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413873','TX','LAVACA','HALLETTSVILLE 2 N',2.947055555000000e+001,-9.693972200000000e+001,'03/30','12/24','04/06','03/30','03/14','12/03','12/24','01/11','0219','0236','0267')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413884','TX','HAMILTON','HAMILTON 2E',3.170444444000000e+001,-9.808527800000000e+001,'04/06','12/05','04/15','04/06','03/29','11/21','12/05','12/17','0205','0214','0241')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413943','TX','CAMERON','HARLINGEN',2.620277777000000e+001,-9.767277799999999e+001,'02/19','00/00','03/10','02/19','01/23','00/00','00/00','00/00','0270','0312','0355')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('413992','TX','HASKELL','HASKELL',3.315777777000000e+001,-9.974555599999999e+001,'04/10','11/27','04/16','04/10','04/05','11/22','11/27','12/06','0194','0210','0230')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('414058','TX','JIM HOGG','HEBBRONVILLE',2.731944444000000e+001,-9.867750000000000e+001,'03/12','01/06','03/28','03/12','02/24','12/15','01/06','00/00','0239','0265','0302')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('414081','TX','RUSK','HENDERSON',3.218083333000000e+001,-9.479638900000001e+001,'04/08','12/01','04/17','04/08','03/23','11/19','12/01','12/21','0193','0213','0239')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('414098','TX','DEAF SMITH','HEREFORD',3.481722222000000e+001,-1.024002780000000e+002,'05/04','11/04','05/13','05/04','04/14','10/24','11/04','11/19','0143','0167','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('414182','TX','HILL','HILLSBORO',3.201611111000000e+001,-9.710944400000000e+001,'04/06','12/02','04/17','04/06','03/25','11/22','12/02','12/21','0196','0215','0245')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('414278','TX','COLEMAN','HORDS CREEK DAM',3.184555555000000e+001,-9.956055600000001e+001,'04/17','11/24','04/27','04/17','04/12','11/17','11/24','11/30','0168','0195','0209')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('414300','TX','HARRIS','HOUSTON BUSH INTL AP',2.998000000000000e+001,-9.536000000000000e+001,'03/30','12/25','04/01','03/30','03/10','12/01','12/25','01/14','0217','0236','0282')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('414307','TX','HARRIS','HOUSTON HOBBY AP',2.963805555000000e+001,-9.528194400000000e+001,'03/18','01/22','03/26','03/18','03/04','12/25','01/22','00/00','0245','0265','0292')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('414382','TX','WALKER','HUNTSVILLE',3.070638888000000e+001,-9.554222200000000e+001,'03/21','12/19','04/01','03/21','03/09','12/06','12/19','01/17','0225','0247','0277')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('414517','TX','JACK','JACKSBORO',3.322055555000000e+001,-9.815611100000000e+001,'04/08','11/30','04/14','04/08','03/28','11/18','11/30','12/15','0198','0215','0231')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('414525','TX','CHEROKEE','JACKSONVILLE',3.196222222000000e+001,-9.527361100000000e+001,'04/05','12/08','04/15','04/05','03/19','11/27','12/08','12/26','0201','0215','0256')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('414570','TX','KENT','JAYTON',3.325444444000000e+001,-1.005725000000000e+002,'04/15','11/23','04/22','04/15','04/08','11/10','11/23','12/01','0174','0199','0214')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('414577','TX','MARION','JEFFERSON',3.276805555000000e+001,-9.435611100000000e+001,'04/12','11/23','04/17','04/12','03/24','11/07','11/23','12/17','0180','0198','0230')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('414605','TX','BLANCO','JOHNSON CITY',3.028361111000000e+001,-9.841722200000000e+001,'04/11','12/02','04/24','04/11','03/23','11/22','12/02','12/12','0187','0207','0231')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('414670','TX','KIMBLE','JUNCTION 4SSW',3.044527777000000e+001,-9.980444400000000e+001,'04/25','11/18','05/03','04/25','04/11','11/10','11/18','11/29','0163','0185','0208')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('414705','TX','KAUFMAN','KAUFMAN 3 SE',3.255888888000000e+001,-9.627249999999999e+001,'04/08','12/04','04/17','04/08','03/27','11/26','12/04','12/16','0194','0208','0232')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('414810','TX','KLEBERG','KINGSVILLE',2.753111111000000e+001,-9.784972200000000e+001,'03/17','01/04','03/28','03/17','03/06','12/19','01/04','00/00','0238','0266','0295')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('414903','TX','FAYETTE','LA GRANGE',2.991722222000000e+001,-9.687527799999999e+001,'03/21','12/16','04/07','03/21','03/15','12/05','12/16','01/05','0216','0239','0268')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('414931','TX','EL PASO','LA TUNA 1 S',3.198000000000000e+001,-1.065975000000000e+002,'04/08','11/24','04/26','04/08','03/29','11/15','11/24','12/05','0185','0210','0225')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('414982','TX','BAYLOR','LAKE KEMP',3.375416666000000e+001,-9.914416700000000e+001,'04/10','11/27','04/16','04/10','04/05','11/22','11/27','12/07','0189','0211','0223')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415013','TX','DAWSON','LAMESA 1 SSE',3.272277777000000e+001,-1.019455560000000e+002,'04/18','11/21','04/27','04/18','04/10','11/13','11/21','12/01','0172','0192','0211')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415018','TX','LAMPASAS','LAMPASAS',3.107166666000000e+001,-9.818472199999999e+001,'04/18','11/26','04/26','04/18','04/09','11/14','11/26','12/05','0174','0197','0214')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415048','TX','VAL VERDE','LANGTRY',2.980972222000000e+001,-1.015602780000000e+002,'03/31','12/10','04/08','03/31','03/13','11/28','12/10','12/29','0212','0229','0251')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415060','TX','WEBB','LAREDO 2',2.756833333000000e+001,-9.949833300000000e+001,'03/10','12/29','03/21','03/10','03/05','12/13','12/29','00/00','0239','0261','0290')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415094','TX','COLLIN','LAVON DAM',3.303527777000000e+001,-9.648611099999999e+001,'04/04','12/07','04/13','04/04','03/22','11/27','12/07','12/19','0199','0212','0241')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415183','TX','HOCKLEY','LEVELLAND',3.355000000000000e+001,-1.023758330000000e+002,'04/21','11/09','05/04','04/21','04/12','10/27','11/09','11/25','0159','0187','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415193','TX','LEE','LEXINGTON',3.040638888000000e+001,-9.701361100000000e+001,'03/26','12/12','04/08','03/26','03/14','12/05','12/12','12/31','0212','0239','0269')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415196','TX','LIBERTY','LIBERTY',3.005916666000000e+001,-9.479500000000000e+001,'03/23','12/22','04/01','03/23','03/06','12/03','12/22','00/00','0218','0242','0282')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415247','TX','LIPSCOMB','LIPSCOMB',3.623583333000000e+001,-1.002675000000000e+002,'05/06','10/26','05/16','05/06','04/20','10/17','10/26','11/07','0136','0154','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415265','TX','LAMB','LITTLEFIELD',3.391500000000000e+001,-1.023275000000000e+002,'04/22','11/13','05/07','04/22','04/12','10/29','11/13','11/22','0150','0176','0204')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415271','TX','POLK','LIVINGSTON 2 NNE',3.073944444000000e+001,-9.492555600000000e+001,'04/05','11/30','04/18','04/05','03/22','11/23','11/30','12/23','0187','0216','0243')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415272','TX','LLANO','LLANO',3.074250000000000e+001,-9.865416700000000e+001,'04/09','11/29','04/19','04/09','03/23','11/19','11/29','12/10','0192','0211','0239')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415341','TX','GREGG','LONGVIEW',3.247250000000000e+001,-9.471722200000001e+001,'04/08','12/03','04/18','04/08','03/26','11/20','12/03','12/17','0188','0213','0233')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415411','TX','LUBBOCK','LUBBOCK INTL AP',3.366555555000000e+001,-1.018230560000000e+002,'04/14','11/16','04/23','04/14','04/08','11/06','11/16','12/01','0175','0197','0212')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415424','TX','ANGELINA','LUFKIN ANGELINA CO AP',3.123611111000000e+001,-9.475444400000001e+001,'04/03','12/02','04/16','04/03','03/18','11/26','12/02','12/25','0194','0222','0250')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415429','TX','CALDWELL','LULING',2.967555555000000e+001,-9.765777799999999e+001,'03/30','12/11','04/16','03/30','03/13','11/28','12/11','12/28','0201','0226','0263')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415477','TX','MADISON','MADISONVILLE',3.093916666000000e+001,-9.592027800000000e+001,'03/30','12/08','04/14','03/30','03/15','11/27','12/08','12/24','0206','0228','0261')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415579','TX','BREWSTER','MARATHON',3.019250000000000e+001,-1.032716670000000e+002,'04/30','11/25','05/05','04/30','04/15','11/16','11/25','12/04','0160','0176','0197')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415611','TX','FALLS','MARLIN 3 NE',3.133361111000000e+001,-9.685805600000001e+001,'04/05','12/07','04/17','04/05','03/20','11/24','12/07','12/19','0197','0222','0245')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415618','TX','HARRISON','MARSHALL',3.254027777000000e+001,-9.435083299999999e+001,'04/10','11/29','04/15','04/10','03/23','11/19','11/29','12/20','0189','0210','0240')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415650','TX','MASON','MASON',3.074777777000000e+001,-9.923055600000001e+001,'04/14','11/26','04/22','04/14','03/31','11/15','11/26','12/04','0182','0201','0226')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415658','TX','MOTLEY','MATADOR',3.402500000000000e+001,-1.008172220000000e+002,'04/13','11/23','04/23','04/13','04/06','11/11','11/23','11/30','0185','0204','0218')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415659','TX','MATAGORDA','MATAGORDA NO 2',2.868361111000000e+001,-9.597333300000000e+001,'03/12','01/23','03/24','03/12','02/22','12/22','01/23','00/00','0243','0263','0305')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415661','TX','JIM WELLS','MATHIS 4 SSW',2.803722222000000e+001,-9.787250000000000e+001,'03/09','01/22','03/23','03/09','02/14','12/21','01/22','00/00','0249','0278','0314')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415701','TX','HIDALGO','MCALLEN',2.619166666000000e+001,-9.825111100000000e+001,'02/14','00/00','03/10','02/14','01/16','00/00','00/00','00/00','0277','0316','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415702','TX','HIDALGO','MCALLEN INTL AP',2.618388888000000e+001,-9.825388900000000e+001,'02/06','00/00','03/14','02/06','01/22','00/00','00/00','00/00','0283','0325','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415707','TX','UPTON','MCCAMEY',3.113305555000000e+001,-1.022216670000000e+002,'04/10','11/29','04/16','04/10','03/31','11/25','11/29','12/08','0196','0210','0234')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415721','TX','HIDALGO','MCCOOK',2.656500000000000e+001,-9.812361100000000e+001,'03/03','00/00','03/21','03/03','02/12','12/25','00/00','00/00','0250','0290','0313')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415742','TX','BANDERA','MEDINA 1NE',2.981000000000000e+001,-9.924972200000001e+001,'04/14','11/25','04/20','04/14','04/01','11/17','11/25','12/14','0183','0204','0227')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415757','TX','MCLENNAN','MCGREGOR',3.143500000000000e+001,-9.740111100000000e+001,'04/03','12/06','04/12','04/03','03/19','11/24','12/06','12/26','0208','0223','0254')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415766','TX','COLLIN','MCKINNEY  MUNICIPAL AIRPORT',3.319027777000000e+001,-9.659138900000001e+001,'04/08','11/26','04/14','04/08','04/01','11/16','11/26','12/18','0190','0213','0236')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415770','TX','GRAY','MC LEAN',3.523611111000000e+001,-1.005922220000000e+002,'04/21','11/13','05/05','04/21','04/10','11/02','11/13','11/24','0158','0183','0205')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415821','TX','HALL','MEMPHIS',3.472611111000000e+001,-1.005372220000000e+002,'04/13','11/17','04/24','04/13','04/06','11/10','11/17','11/27','0169','0202','0216')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415822','TX','MENARD','MENARD',3.091444444000000e+001,-9.979583300000000e+001,'04/25','11/13','05/07','04/25','04/11','11/05','11/13','11/26','0158','0181','0202')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415890','TX','MIDLAND','MIDLAND INTL  AP',3.194750000000000e+001,-1.022086110000000e+002,'04/15','11/28','04/18','04/15','04/08','11/17','11/28','12/07','0186','0204','0219')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415891','TX','MIDLAND','MIDLAND 4 ENE',3.201861111000000e+001,-1.020258330000000e+002,'04/17','11/26','04/24','04/17','04/10','11/15','11/26','12/05','0183','0199','0214')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('415958','TX','PALO PINTO','MINERAL WELLS AP',3.278166666000000e+001,-9.806027800000000e+001,'04/13','11/29','04/18','04/13','03/29','11/20','11/29','12/13','0198','0209','0230')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('416074','TX','COCHRAN','MORTON',3.371916666000000e+001,-1.027597220000000e+002,'04/27','11/09','05/10','04/27','04/15','10/31','11/09','11/25','0153','0175','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('416104','TX','JEFF DAVIS','MT LOCKE',3.070527777000000e+001,-1.040233330000000e+002,'05/03','11/18','05/15','05/03','04/22','11/05','11/18','11/27','0144','0163','0188')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('416108','TX','TITUS','MT PLEASANT',3.316888888000000e+001,-9.500555600000000e+001,'04/14','11/24','04/22','04/14','04/01','11/05','11/24','12/11','0169','0194','0221')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('416119','TX','FRANKLIN','MT VERNON',3.319527777000000e+001,-9.522333300000000e+001,'04/11','11/30','04/15','04/11','03/25','11/13','11/30','12/18','0192','0209','0239')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('416135','TX','BAILEY','MULESHOE #1',3.421916666000000e+001,-1.027327780000000e+002,'05/02','11/06','05/14','05/02','04/20','10/18','11/06','11/15','0139','0164','0181')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('416210','TX','NAVARRO','NAVARRO MILLS DAM',3.196111111000000e+001,-9.668805600000000e+001,'04/03','12/09','04/15','04/03','03/26','11/24','12/09','12/21','0200','0214','0238')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('416276','TX','COMAL','NEW BRAUNFELS',2.971916666000000e+001,-9.811888900000000e+001,'03/29','12/12','04/12','03/29','03/17','11/30','12/12','01/02','0211','0231','0260')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('416368','TX','GONZALES','NIXON',2.922833333000000e+001,-9.776750000000000e+001,'03/19','12/22','04/02','03/19','03/08','12/08','12/22','01/10','0222','0247','0271')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('416636','TX','YOUNG','OLNEY',3.337333333000000e+001,-9.876638900000000e+001,'04/10','11/27','04/17','04/10','04/02','11/16','11/27','12/06','0190','0208','0228')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('416644','TX','LAMB','OLTON',3.417972222000000e+001,-1.021355560000000e+002,'04/28','11/06','05/11','04/28','04/14','10/26','11/06','11/22','0147','0169','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('416734','TX','CROCKETT','OZONA',3.071694444000000e+001,-1.012061110000000e+002,'04/15','11/19','04/29','04/15','04/09','11/11','11/19','11/29','0173','0194','0210')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('416740','TX','COTTLE','PADUCAH',3.400666666000000e+001,-1.002988890000000e+002,'04/11','11/23','04/21','04/11','04/05','11/12','11/23','12/02','0179','0199','0219')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('416747','TX','CONCHO','PAINT ROCK',3.152055555000000e+001,-9.992638900000000e+001,'04/16','11/22','04/22','04/16','04/07','11/14','11/22','12/02','0179','0199','0217')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('416750','TX','MATAGORDA','PALACIOS MUNI AP',2.872472222000000e+001,-9.625361100000001e+001,'03/21','01/08','03/24','03/21','02/25','12/17','01/08','00/00','0240','0262','0305')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('416757','TX','ANDERSON','PALESTINE 2 NE',3.178305555000000e+001,-9.560388900000000e+001,'04/04','12/09','04/14','04/04','03/23','11/25','12/09','12/20','0201','0217','0240')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('416776','TX','GRAY','PAMPA 2',3.555444444000000e+001,-1.009736110000000e+002,'04/25','11/10','05/10','04/25','04/14','10/31','11/10','11/21','0153','0178','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('416785','TX','CARSON','PANHANDLE',3.541388888000000e+001,-1.013416670000000e+002,'05/02','11/09','05/14','05/02','04/17','10/23','11/09','11/17','0143','0166','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('416792','TX','BREWSTER','PANTHER JUNCTION',2.932722222000000e+001,-1.032061110000000e+002,'04/06','12/08','04/12','04/06','03/24','12/01','12/08','12/27','0197','0219','0244')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('416794','TX','LAMAR','PARIS',3.367444444000000e+001,-9.555861100000000e+001,'04/06','12/01','04/14','04/06','03/23','11/19','12/01','12/15','0198','0215','0238')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('416879','TX','FRIO','PEARSALL',2.888888888000000e+001,-9.908972200000000e+001,'03/18','12/14','04/10','03/18','03/13','11/29','12/14','01/08','0209','0240','0265')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('416932','TX','ECTOR','PENWELL',3.173555555000000e+001,-1.025897220000000e+002,'04/13','11/26','04/21','04/13','04/07','11/16','11/26','12/04','0182','0197','0214')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('416950','TX','OCHILTREE','PERRYTON',3.638972222000000e+001,-1.008238890000000e+002,'05/08','11/02','05/15','05/08','04/23','10/20','11/02','11/11','0139','0159','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('416959','TX','BREWSTER','PERSIMMON GAP',2.966027777000000e+001,-1.031736110000000e+002,'04/04','12/04','04/11','04/04','03/24','11/24','12/04','12/21','0195','0209','0238')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417020','TX','WHARTON','PIERCE 1 E',2.923527777000000e+001,-9.618166700000000e+001,'03/22','01/08','04/06','03/22','03/15','12/07','01/08','01/21','0221','0246','0273')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417074','TX','YOAKUM','PLAINS',3.318694444000000e+001,-1.028280560000000e+002,'04/26','11/14','05/06','04/26','04/17','10/31','11/14','11/25','0158','0181','0199')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417079','TX','HALE','PLAINVIEW',3.418916666000000e+001,-1.017022220000000e+002,'04/15','11/18','04/30','04/15','04/09','11/04','11/18','11/25','0169','0192','0212')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417140','TX','CALHOUN','POINT COMFORT',2.865750000000000e+001,-9.655527800000000e+001,'03/06','00/00','03/31','03/06','02/24','12/25','00/00','00/00','0244','0282','0302')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417174','TX','JEFFERSON','PORT ARTHUR AP',2.995055555000000e+001,-9.402055600000000e+001,'03/21','01/02','03/28','03/21','03/01','12/08','01/02','00/00','0227','0250','0287')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417179','TX','CAMERON','PORT ISABEL',2.609416666000000e+001,-9.730944400000000e+001,'02/05','00/00','03/03','02/05','01/22','00/00','00/00','00/00','0291','0330','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417184','TX','WILLACY','PORT MANSFIELD',2.655777777000000e+001,-9.742638900000000e+001,'02/21','00/00','03/13','02/21','01/30','01/13','00/00','00/00','0272','0308','0341')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417186','TX','CALHOUN','PORT O''CONNOR',2.843416666000000e+001,-9.642777800000000e+001,'03/04','00/00','03/18','03/04','02/14','00/00','00/00','00/00','0253','0290','0322')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417206','TX','GARZA','POST',3.319861111000000e+001,-1.013744440000000e+002,'04/13','11/24','04/22','04/13','04/06','11/13','11/24','12/01','0180','0202','0218')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417215','TX','ATASCOSA','POTEET',2.902833333000000e+001,-9.856861100000000e+001,'03/23','12/22','04/08','03/23','03/03','12/08','12/22','01/10','0214','0245','0281')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417232','TX','REAL','PRADE RCH',2.991666666000000e+001,-9.979083300000001e+001,'04/18','11/22','04/28','04/18','04/10','11/12','11/22','12/05','0170','0195','0214')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417262','TX','PRESIDIO','PRESIDIO',2.957111111000000e+001,-1.043713890000000e+002,'04/02','12/08','04/16','04/02','03/18','11/30','12/08','12/17','0198','0224','0252')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417300','TX','COMANCHE','PROCTOR RSVR',3.196333333000000e+001,-9.849416700000000e+001,'04/08','12/03','04/16','04/08','03/27','11/21','12/03','12/17','0198','0215','0232')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417327','TX','CALLAHAN','PUTNAM',3.236638888000000e+001,-9.919250000000000e+001,'04/07','11/30','04/17','04/07','04/02','11/21','11/30','12/12','0194','0216','0227')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417458','TX','WILLACY','RAYMONDVILLE',2.648194444000000e+001,-9.780972199999999e+001,'03/04','00/00','03/19','03/04','02/02','01/09','00/00','00/00','0256','0290','0334')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417622','TX','STARR','RIO GRANDE CITY',2.637694444000000e+001,-9.881166700000000e+001,'03/13','01/23','03/30','03/13','03/01','12/31','01/23','00/00','0231','0264','0298')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417677','TX','NUECES','ROBSTOWN',2.778944444000000e+001,-9.766194400000001e+001,'03/03','00/00','03/20','03/03','02/16','12/23','00/00','00/00','0253','0284','0318')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417704','TX','ARANSAS','ROCKPORT',2.802861111000000e+001,-9.705666700000000e+001,'03/02','00/00','03/14','03/02','02/15','12/25','00/00','00/00','0261','0281','0318')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417706','TX','EDWARDS','ROCKSPRINGS 1S',3.000388888000000e+001,-1.002063890000000e+002,'04/13','12/10','04/15','04/13','03/26','12/01','12/10','12/30','0194','0208','0230')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417743','TX','NOLAN','ROSCOE',3.244805555000000e+001,-1.005263890000000e+002,'04/15','11/26','04/25','04/15','04/09','11/19','11/26','12/02','0177','0201','0216')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417782','TX','FISHER','ROTAN',3.285555555000000e+001,-1.004611110000000e+002,'04/14','11/25','04/22','04/14','04/07','11/14','11/25','12/03','0182','0200','0220')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417841','TX','CHEROKEE','RUSK',3.180861111000000e+001,-9.514277800000001e+001,'04/01','12/07','04/15','04/01','03/20','11/28','12/07','12/27','0209','0229','0251')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417936','TX','JASPER','SAM RAYBURN DAM',3.106194444000000e+001,-9.410111100000000e+001,'04/11','12/03','04/20','04/11','03/26','11/21','12/03','12/18','0185','0209','0237')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417943','TX','TOM GREEN','SAN ANGELO MATHIS  FLD',3.135166666000000e+001,-1.004950000000000e+002,'04/14','11/29','04/17','04/14','04/03','11/15','11/29','12/05','0188','0208','0223')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417945','TX','BEXAR','SAN ANTONIO INT''L AP',2.954416666000000e+001,-9.848388900000001e+001,'03/21','12/13','04/07','03/21','03/13','12/02','12/13','01/05','0214','0242','0268')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('417983','TX','HAYS','SAN MARCOS',2.988333333000000e+001,-9.794944400000000e+001,'03/29','12/13','04/10','03/29','03/07','11/29','12/13','01/03','0211','0230','0266')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('418022','TX','TERRELL','SANDERSON',3.014138888000000e+001,-1.023916670000000e+002,'04/10','11/28','04/15','04/10','04/02','11/18','11/28','12/07','0192','0207','0225')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('418201','TX','GAINES','SEMINOLE',3.271305555000000e+001,-1.026466670000000e+002,'04/16','11/19','04/27','04/16','04/09','11/08','11/19','11/30','0174','0193','0214')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('418221','TX','BAYLOR','SEYMOUR 3NW',3.363250000000000e+001,-9.928972200000000e+001,'04/14','11/22','04/26','04/14','04/06','11/15','11/22','12/02','0173','0199','0220')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('418236','TX','WHEELER','SHAMROCK 2',3.521500000000000e+001,-1.002502780000000e+002,'04/19','11/16','04/29','04/19','04/09','11/05','11/16','11/24','0163','0180','0204')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('418252','TX','PECOS','SHEFFIELD',3.068861111000000e+001,-1.018272220000000e+002,'04/12','11/23','04/21','04/12','04/04','11/14','11/23','12/03','0182','0205','0216')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('418274','TX','GRAYSON','SHERMAN',3.370333333000000e+001,-9.664194400000000e+001,'04/09','12/03','04/14','04/09','03/27','11/21','12/03','12/18','0193','0212','0233')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('418323','TX','BRISCOE','SILVERTON',3.447222222000000e+001,-1.013005560000000e+002,'04/27','11/06','05/12','04/27','04/15','10/25','11/06','11/17','0150','0173','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('418354','TX','SAN PATRICIO','SINTON',2.803527777000000e+001,-9.749722199999999e+001,'03/11','01/07','03/26','03/11','02/26','12/19','01/07','00/00','0241','0270','0299')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('418415','TX','BASTROP','SMITHVILLE',3.000666666000000e+001,-9.716888899999999e+001,'03/27','12/11','04/14','03/27','03/20','11/27','12/11','12/23','0204','0228','0259')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('418433','TX','SCURRY','SNYDER',3.271000000000000e+001,-1.009111110000000e+002,'04/14','11/22','04/26','04/14','04/11','11/13','11/22','12/01','0176','0199','0216')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('418446','TX','BURLESON','SOMERVILLE DAM',3.033666666000000e+001,-9.654027800000000e+001,'03/26','12/13','04/11','03/26','03/13','11/29','12/13','12/30','0208','0233','0258')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('418449','TX','SUTTON','SONORA',3.058305555000000e+001,-1.006502780000000e+002,'04/20','11/22','04/26','04/20','04/11','11/10','11/22','12/01','0166','0187','0202')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('418566','TX','DICKENS','SPUR',3.347916666000000e+001,-1.008761110000000e+002,'04/15','11/18','04/25','04/15','04/11','11/09','11/18','11/28','0172','0195','0209')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('418583','TX','JONES','STAMFORD 1',3.294027777000000e+001,-9.980361100000000e+001,'04/12','11/26','04/18','04/12','04/07','11/18','11/26','12/05','0190','0206','0224')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('418623','TX','ERATH','STEPHENVILLE',3.223138888000000e+001,-9.823194400000000e+001,'04/09','11/29','04/20','04/09','04/01','11/19','11/29','12/08','0193','0213','0228')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('418630','TX','STERLING','STERLING CITY',3.183472222000000e+001,-1.009827780000000e+002,'04/20','11/23','04/26','04/20','04/12','11/04','11/23','12/02','0167','0187','0205')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('418646','TX','BELL','STILLHOUSE HOLLOW DAM',3.103722222000000e+001,-9.752833300000000e+001,'03/31','12/13','04/12','03/31','03/17','11/30','12/13','12/27','0204','0226','0255')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('418692','TX','SHERMAN','STRATFORD',3.633722222000000e+001,-1.020752780000000e+002,'05/12','10/29','05/17','05/12','04/25','10/21','10/29','11/12','0135','0153','0177')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('418728','TX','FORT BEND','SUGAR LAND',2.961833333000000e+001,-9.563583300000001e+001,'03/18','01/09','03/28','03/18','03/02','12/13','01/09','00/00','0230','0259','0286')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('418743','TX','HOPKINS','SULPHUR SPRINGS',3.314805555000000e+001,-9.562694400000000e+001,'04/12','12/01','04/16','04/12','03/30','11/12','12/01','12/11','0187','0204','0231')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('418818','TX','LYNN','TAHOKA',3.317138888000000e+001,-1.017980560000000e+002,'04/18','11/22','04/26','04/18','04/08','11/08','11/22','11/29','0174','0193','0211')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('418942','TX','BOWIE','TEXARKANA',3.343666666000000e+001,-9.407722200000001e+001,'04/10','12/03','04/14','04/10','03/25','11/20','12/03','12/21','0196','0208','0243')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('418996','TX','FORT BEND','THOMPSONS 3 WSW',2.948222222000000e+001,-9.563138900000000e+001,'03/17','01/04','03/28','03/17','03/04','12/09','01/04','00/00','0227','0253','0283')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('419101','TX','TYLER','TOWN BLUFF DAM',3.079305555000000e+001,-9.418194400000000e+001,'03/29','12/07','04/12','03/29','03/15','11/27','12/07','12/27','0204','0229','0251')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('419163','TX','KNOX','TRUSCOTT 3 W',3.375694444000000e+001,-9.986166700000000e+001,'04/11','11/24','04/16','04/11','04/04','11/15','11/24','12/05','0193','0205','0220')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('419175','TX','SWISHER','TULIA',3.452694444000000e+001,-1.018391670000000e+002,'04/28','11/08','05/11','04/28','04/18','10/27','11/08','11/21','0150','0176','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('419191','TX','HALL','TURKEY',3.439555555000000e+001,-1.008972220000000e+002,'04/13','11/19','04/25','04/13','04/08','11/06','11/19','12/02','0173','0202','0215')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('419295','TX','CULBERSON','VAN HORN',3.104166666000000e+001,-1.048372220000000e+002,'04/18','11/22','04/27','04/18','04/11','11/15','11/22','12/02','0179','0192','0207')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('419346','TX','WILBARGER','VERNON',3.415166666000000e+001,-9.932555600000001e+001,'04/12','11/26','04/23','04/12','04/06','11/15','11/26','12/05','0173','0203','0215')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('419364','TX','VICTORIA','VICTORIA ASOS',2.886138888000000e+001,-9.693027800000000e+001,'03/08','01/07','03/29','03/08','02/25','12/13','01/07','00/00','0231','0271','0300')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('419417','TX','MCLENNAN','WACO DAM',3.160027777000000e+001,-9.721694400000000e+001,'04/10','12/06','04/13','04/10','03/22','11/23','12/06','12/27','0206','0214','0247')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('419419','TX','MCLENNAN','WACO RGNL AP',3.161888888000000e+001,-9.722833300000001e+001,'04/06','12/07','04/14','04/06','03/21','11/27','12/07','12/27','0204','0221','0251')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('419491','TX','WASHINGTON','WASHINGTON SP',3.032361111000000e+001,-9.615944399999999e+001,'03/26','12/15','04/12','03/26','03/14','11/30','12/15','01/03','0209','0231','0265')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('419499','TX','TOM GREEN','WATER VALLEY',3.167250000000000e+001,-1.007283330000000e+002,'04/19','11/17','04/26','04/19','04/11','11/10','11/17','11/30','0169','0191','0212')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('419522','TX','ELLIS','WAXAHACHIE',3.242805555000000e+001,-9.684222200000001e+001,'04/04','12/05','04/09','04/04','03/19','11/24','12/05','12/20','0211','0223','0255')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('419532','TX','PARKER','WEATHERFORD',3.274833333000000e+001,-9.777000000000000e+001,'04/16','11/24','04/22','04/16','04/06','11/11','11/24','12/03','0175','0201','0218')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('419565','TX','COLLINGSWORTH','WELLINGTON',3.484222222000000e+001,-1.002102780000000e+002,'04/13','11/21','04/22','04/13','04/08','11/12','11/21','12/04','0179','0197','0213')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('419588','TX','HIDALGO','WESLACO',2.617805555000000e+001,-9.797083300000000e+001,'02/17','00/00','03/09','02/17','01/21','00/00','00/00','00/00','0279','0306','9999')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('419715','TX','BOSQUE','WHITNEY DAM',3.186111111000000e+001,-9.737500000000000e+001,'04/04','12/04','04/15','04/04','03/16','11/25','12/04','12/17','0201','0218','0249')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('419729','TX','WICHITA','WICHITA FALLS MUNI AP',3.397861111000000e+001,-9.849277800000000e+001,'04/12','11/27','04/19','04/12','04/02','11/15','11/27','12/10','0189','0204','0228')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('419800','TX','VAN ZANDT','WILLS POINT',3.270166666000000e+001,-9.601500000000000e+001,'04/05','12/07','04/14','04/05','03/21','11/21','12/07','12/23','0204','0220','0253')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('419830','TX','WINKLER','WINK FAA AP',3.178000000000000e+001,-1.032016670000000e+002,'04/17','11/21','04/25','04/17','04/04','11/11','11/21','11/28','0174','0194','0214')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('419952','TX','LAVACA','YOAKUM',2.927388888000000e+001,-9.715555600000000e+001,'03/25','12/26','04/03','03/25','03/07','12/08','12/26','01/10','0218','0246','0271')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('420061','UT','UTAH','ALPINE',4.046444444000000e+001,-1.117708330000000e+002,'06/07','10/15','06/20','06/07','05/19','10/10','10/15','11/04','0090','0112','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('420072','UT','SALT LAKE','ALTA',4.059055555000000e+001,-1.116369440000000e+002,'06/28','10/04','07/20','06/28','06/20','09/24','10/04','10/11','0039','0066','0087')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('420074','UT','DUCHESNE','ALTAMONT',4.035611111000000e+001,-1.102877780000000e+002,'06/20','10/09','06/28','06/20','06/07','09/29','10/09','10/21','0071','0085','0108')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('420086','UT','KANE','ALTON',3.744027777000000e+001,-1.124819440000000e+002,'06/21','10/11','07/03','06/21','06/09','09/28','10/11','10/22','0062','0088','0112')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('420730','UT','MILLARD','BLACK ROCK',3.870750000000000e+001,-1.129538890000000e+002,'06/20','10/04','07/04','06/20','05/29','09/25','10/04','10/13','0061','0091','0117')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('420738','UT','SAN JUAN','BLANDING',3.761305555000000e+001,-1.094847220000000e+002,'05/25','10/31','06/15','05/25','05/15','10/17','10/31','11/10','0101','0133','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('420788','UT','SAN JUAN','BLUFF',3.728250000000000e+001,-1.095575000000000e+002,'05/22','10/12','06/11','05/22','05/13','10/06','10/12','10/29','0104','0127','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('420849','UT','GARFIELD','BOULDER',3.790500000000000e+001,-1.114200000000000e+002,'06/02','10/21','06/19','06/02','05/23','10/14','10/21','11/05','0091','0116','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('421008','UT','GARFIELD','BRYCE CANYON NP HQRS',3.764111111000000e+001,-1.121688890000000e+002,'07/04','09/26','07/14','07/04','06/26','09/14','09/26','10/04','0033','0052','0081')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('421020','UT','KANE','BULLFROG BASIN',3.753000000000000e+001,-1.107202780000000e+002,'05/10','11/18','05/22','05/10','04/26','11/11','11/18','12/01','0147','0169','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('421144','UT','JUAB','CALLAO',3.989972222000000e+001,-1.137127780000000e+002,'06/04','10/13','06/18','06/04','05/09','10/02','10/13','10/28','0084','0110','0143')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('421163','UT','SAN JUAN','CANYONLANDS-THE NECK',3.846000000000000e+001,-1.098213890000000e+002,'05/22','11/06','06/02','05/22','05/14','10/28','11/06','11/18','0118','0143','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('421168','UT','SAN JUAN','CANYONLANDS-THE NEEDLE',3.815055555000000e+001,-1.097822220000000e+002,'05/27','10/26','06/09','05/27','05/13','10/09','10/26','11/05','0109','0125','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('421171','UT','WAYNE','CAPITOL REEF NP',3.829166666000000e+001,-1.112622220000000e+002,'05/16','11/08','06/02','05/16','04/25','10/30','11/08','11/19','0129','0156','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('421214','UT','EMERY','CASTLE DALE',3.920777777000000e+001,-1.110125000000000e+002,'06/09','10/08','06/29','06/09','05/24','09/30','10/08','10/17','0068','0101','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('421267','UT','IRON','CEDAR CITY AP',3.770861111000000e+001,-1.130944440000000e+002,'06/07','10/18','06/21','06/07','05/15','10/08','10/18','11/03','0088','0106','0141')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('421308','UT','SAN JUAN','CEDAR POINT',3.771583333000000e+001,-1.090827780000000e+002,'07/02','10/22','07/06','07/02','06/29','10/09','10/22','11/02','0080','0094','0106')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('421588','UT','SUMMIT','COALVILLE',4.091388888000000e+001,-1.113983330000000e+002,'07/04','09/22','07/20','07/04','06/06','09/08','09/22','10/03','0022','0054','0099')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('421759','UT','SALT LAKE','COTTONWOOD WEIR',4.062416666000000e+001,-1.117869440000000e+002,'05/20','11/07','05/31','05/20','05/07','10/27','11/07','11/18','0121','0143','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('422057','UT','WASATCH','DEER CREEK DAM',4.040472222000000e+001,-1.115286110000000e+002,'06/23','09/28','07/09','06/23','06/03','09/20','09/28','10/09','0042','0076','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('422090','UT','MILLARD','DELTA',3.933750000000000e+001,-1.125858330000000e+002,'06/07','10/11','06/19','06/07','05/22','09/30','10/11','10/21','0087','0108','0131')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('422101','UT','MILLARD','DESERET',3.928722222000000e+001,-1.126519440000000e+002,'06/14','10/04','06/25','06/14','05/26','09/29','10/04','10/14','0071','0096','0119')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('422173','UT','UINTAH','DINOSAUR QUARRY AREA',4.043777777000000e+001,-1.093044440000000e+002,'06/03','10/09','06/17','06/03','05/12','10/01','10/09','10/23','0086','0108','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('422253','UT','DUCHESNE','DUCHESNE',4.016777777000000e+001,-1.103950000000000e+002,'06/04','10/08','06/19','06/04','05/18','10/02','10/08','10/26','0084','0113','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('422257','UT','TOOELE','DUGWAY',4.018388888000000e+001,-1.129216670000000e+002,'05/28','10/11','06/14','05/28','05/10','10/01','10/11','10/31','0098','0118','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('422385','UT','SUMMIT','ECHO DAM',4.096555555000000e+001,-1.114350000000000e+002,'06/23','09/29','07/11','06/23','05/30','09/19','09/29','10/09','0038','0078','0111')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('422578','UT','SANPETE','EPHRAIM',3.935833333000000e+001,-1.115991670000000e+002,'06/12','10/09','06/28','06/12','05/24','09/30','10/09','10/20','0078','0101','0123')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('422592','UT','GARFIELD','ESCALANTE',3.776861111000000e+001,-1.115977780000000e+002,'06/02','10/19','06/18','06/02','05/14','10/05','10/19','11/04','0087','0118','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('422607','UT','MILLARD','ESKDALE',3.910777777000000e+001,-1.139533330000000e+002,'06/10','10/08','06/18','06/10','05/24','09/29','10/08','10/24','0084','0102','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('422696','UT','UTAH','FAIRFIELD',4.027027777000000e+001,-1.120944440000000e+002,'06/26','09/29','07/09','06/26','06/08','09/23','09/29','10/06','0044','0070','0106')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('422726','UT','DAVIS','FARMINGTON 3 NW',4.102222222000000e+001,-1.119352780000000e+002,'05/24','10/31','06/03','05/24','05/06','10/17','10/31','11/09','0111','0132','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('422798','UT','EMERY','FERRON',3.908750000000000e+001,-1.111325000000000e+002,'06/07','10/13','06/19','06/07','05/22','10/09','10/13','10/27','0092','0107','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('422828','UT','MILLARD','FILLMORE',3.896638888000000e+001,-1.123277780000000e+002,'06/06','10/22','06/16','06/06','05/26','10/11','10/22','11/07','0092','0108','0131')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('422852','UT','JUAB','FISH SPRINGS NWR',3.984000000000000e+001,-1.133977780000000e+002,'05/19','10/28','05/28','05/19','05/07','10/13','10/28','11/06','0120','0136','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('422864','UT','DAGGETT','FLAMING GORGE',4.093166666000000e+001,-1.094116670000000e+002,'06/26','09/26','07/10','06/26','06/03','09/17','09/26','10/03','0047','0074','0108')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('422996','UT','UINTAH','FT DUCHESNE',4.028416666000000e+001,-1.098611110000000e+002,'06/11','10/10','06/23','06/11','05/31','10/01','10/10','10/23','0087','0103','0126')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('423097','UT','SALT LAKE','GARFIELD',4.072361111000000e+001,-1.121980560000000e+002,'05/20','11/15','06/06','05/20','05/02','11/03','11/15','11/26','0116','0144','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('423486','UT','BOX ELDER','GROUSE CREEK',4.171388888000000e+001,-1.138694440000000e+002,'07/05','09/28','07/12','07/05','06/16','09/19','09/28','10/07','0036','0060','0093')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('423611','UT','WAYNE','HANKSVILLE',3.837055555000000e+001,-1.107152780000000e+002,'06/02','10/16','06/11','06/02','05/07','10/08','10/16','10/27','0097','0120','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('423809','UT','WASATCH','HEBER',4.049166666000000e+001,-1.114261110000000e+002,'06/20','10/01','07/07','06/20','06/06','09/23','10/01','10/08','0045','0078','0109')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('424100','UT','SAN JUAN','HOVENWEEP NM',3.738583333000000e+001,-1.090750000000000e+002,'05/29','10/20','06/17','05/29','05/22','10/08','10/20','10/28','0092','0120','0138')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('424174','UT','TOOELE','IBAPAH',4.003777777000000e+001,-1.139886110000000e+002,'07/08','09/16','07/23','07/08','06/22','09/04','09/16','09/30','0017','0046','0077')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('424342','UT','UINTAH','JENSEN',4.036416666000000e+001,-1.093450000000000e+002,'06/08','10/04','06/18','06/08','05/20','10/01','10/04','10/18','0082','0096','0123')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('424467','UT','SUMMIT','KAMAS',4.064916666000000e+001,-1.112847220000000e+002,'06/30','09/26','07/21','06/30','06/14','09/16','09/26','10/06','0026','0064','0098')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('424508','UT','KANE','KANAB',3.702861111000000e+001,-1.125366670000000e+002,'05/24','11/06','05/30','05/24','05/11','10/27','11/06','11/12','0122','0145','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('424527','UT','MILLARD','KANOSH',3.880666666000000e+001,-1.124366670000000e+002,'06/03','10/30','06/15','06/03','05/17','10/13','10/30','11/11','0098','0120','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('424856','UT','RICH','LAKETOWN',4.182500000000000e+001,-1.113208330000000e+002,'06/25','10/02','07/12','06/25','06/02','09/18','10/02','10/15','0038','0069','0113')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('424968','UT','WASHINGTON','LA VERKIN',3.720083333000000e+001,-1.132686110000000e+002,'04/30','11/13','05/24','04/30','04/16','11/05','11/13','11/23','0144','0178','0200')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('425065','UT','JUAB','LEVAN',3.956083333000000e+001,-1.118652780000000e+002,'06/09','10/11','06/22','06/09','05/18','10/06','10/11','10/28','0085','0106','0139')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('425182','UT','CACHE','LOGAN RADIO KVNU',4.173527777000000e+001,-1.118561110000000e+002,'05/31','10/10','06/19','05/31','05/10','10/03','10/10','10/26','0081','0117','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('425186','UT','CACHE','LOGAN UTAH ST UNIV',4.174555555000000e+001,-1.118033330000000e+002,'05/20','10/29','06/06','05/20','05/04','10/18','10/29','11/13','0110','0135','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('425194','UT','CACHE','LOGAN 5 SW EXP FARM',4.166611111000000e+001,-1.118913890000000e+002,'06/12','10/01','06/28','06/12','05/25','09/21','10/01','10/15','0063','0097','0123')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('425377','UT','DAGGETT','MANILA',4.099000000000000e+001,-1.097258330000000e+002,'06/12','10/07','06/23','06/12','05/21','09/27','10/07','10/27','0074','0092','0126')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('425402','UT','SANPETE','MANTI',3.925833333000000e+001,-1.116305560000000e+002,'06/10','10/12','06/20','06/10','05/18','10/04','10/12','10/29','0087','0109','0135')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('425477','UT','PIUTE','MARYSVALE',3.844861111000000e+001,-1.122275000000000e+002,'06/17','10/01','06/30','06/17','06/05','09/25','10/01','10/13','0063','0090','0116')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('425582','UT','SAN JUAN','MEXICAN HAT',3.714972222000000e+001,-1.098675000000000e+002,'05/06','11/06','05/20','05/06','04/26','10/25','11/06','11/14','0134','0159','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('425654','UT','BEAVER','MILFORD',3.840166666000000e+001,-1.130161110000000e+002,'06/17','10/09','06/27','06/17','05/29','09/30','10/09','10/20','0079','0094','0122')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('425733','UT','GRAND','MOAB',3.857444444000000e+001,-1.095458330000000e+002,'05/01','11/05','05/16','05/01','04/18','10/25','11/05','11/14','0133','0157','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('425826','UT','MORGAN','MORGAN POWER & LIGHT',4.104277777000000e+001,-1.116722220000000e+002,'06/17','10/02','07/03','06/17','05/24','09/21','10/02','10/10','0050','0085','0116')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('425837','UT','SANPETE','MORONI',3.952666666000000e+001,-1.115872220000000e+002,'06/21','10/06','07/04','06/21','06/09','09/27','10/06','10/15','0052','0079','0108')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('425892','UT','SALT LAKE','MTN DELL DAM',4.074972222000000e+001,-1.117222220000000e+002,'06/10','10/13','06/28','06/10','05/28','10/03','10/13','10/27','0067','0102','0121')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('425969','UT','DUCHESNE','MYTON',4.019416666000000e+001,-1.100616670000000e+002,'06/07','10/08','06/22','06/07','05/23','10/02','10/08','10/24','0085','0108','0134')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('426053','UT','SAN JUAN','NATURAL BRIDGES NM',3.760944444000000e+001,-1.099772220000000e+002,'06/01','10/28','06/13','06/01','05/14','10/18','10/28','11/09','0099','0122','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('426123','UT','DUCHESNE','NEOLA',4.041777777000000e+001,-1.100511110000000e+002,'06/11','10/11','06/22','06/11','05/24','10/03','10/11','10/27','0084','0099','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('426135','UT','JUAB','NEPHI',3.971222222000000e+001,-1.118319440000000e+002,'06/02','10/12','06/18','06/02','05/21','10/04','10/12','10/31','0094','0115','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('426181','UT','WASHINGTON','NEW HARMONY',3.746361111000000e+001,-1.132897220000000e+002,'05/24','10/25','06/13','05/24','05/16','10/18','10/25','11/08','0102','0128','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('426357','UT','MILLARD','OAK CITY',3.937583333000000e+001,-1.123341670000000e+002,'06/04','10/28','06/11','06/04','05/15','10/12','10/28','11/07','0104','0121','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('426404','UT','WEBER','OGDEN PIONEER PH',4.124388888000000e+001,-1.119466670000000e+002,'05/20','11/08','05/31','05/20','05/03','10/24','11/08','11/16','0118','0144','0183')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('426414','UT','WEBER','OGDEN SUGAR FACTORY',4.123194444000000e+001,-1.120283330000000e+002,'05/20','10/28','05/31','05/20','05/06','10/07','10/28','11/06','0115','0131','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('426534','UT','KANE','ORDERVILLE',3.727222222000000e+001,-1.126388890000000e+002,'05/30','10/18','06/14','05/30','05/21','10/06','10/18','11/03','0098','0125','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('426568','UT','UINTAH','OURAY 4 NE',4.013416666000000e+001,-1.096422220000000e+002,'05/28','10/08','06/09','05/28','05/08','10/03','10/08','10/25','0101','0122','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('426601','UT','GARFIELD','PANGUITCH',3.781555555000000e+001,-1.124386110000000e+002,'07/09','09/28','07/20','07/09','06/22','09/12','09/28','10/02','0028','0051','0081')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('426708','UT','JUAB','PARTOUN',3.963083333000000e+001,-1.138858330000000e+002,'06/12','10/07','06/20','06/12','05/27','09/29','10/07','10/19','0081','0097','0125')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('426869','UT','WEBER','PINE VIEW DAM',4.125777777000000e+001,-1.118377780000000e+002,'06/13','10/04','06/27','06/13','05/24','09/26','10/04','10/18','0068','0099','0124')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('426919','UT','UTAH','PLEASANT GROVE',4.036750000000000e+001,-1.117338890000000e+002,'05/25','11/05','06/10','05/25','05/08','10/13','11/05','11/11','0108','0132','0166')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('427260','UT','SEVIER','RICHFIELD RADIO KSVC',3.876194444000000e+001,-1.120775000000000e+002,'06/17','10/03','07/02','06/17','05/29','09/26','10/03','10/17','0068','0093','0121')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('427271','UT','CACHE','RICHMOND',4.190638888000000e+001,-1.118100000000000e+002,'06/10','10/09','06/24','06/10','05/16','10/02','10/09','10/26','0075','0108','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('427395','UT','UINTAH','ROOSEVELT RADIO',4.028777777000000e+001,-1.099586110000000e+002,'05/31','10/09','06/17','05/31','05/16','09/30','10/09','10/23','0088','0114','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('427516','UT','WASHINGTON','ST GEORGE',3.710694444000000e+001,-1.135611110000000e+002,'04/11','11/20','05/02','04/11','03/25','11/11','11/20','12/05','0170','0200','0228')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('427598','UT','SALT LAKE','SALT LAKE CITY INTL AP',4.077805555000000e+001,-1.119694440000000e+002,'05/08','11/08','05/24','05/08','04/21','10/23','11/08','11/15','0130','0163','0190')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('427686','UT','UTAH','SANTAQUIN CHLORINATOR',3.995777777000000e+001,-1.117794440000000e+002,'06/07','10/22','06/15','06/07','05/09','10/07','10/22','11/08','0096','0111','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('427714','UT','MILLARD','SCIPIO',3.924527777000000e+001,-1.121066670000000e+002,'06/18','10/04','07/02','06/18','06/09','09/25','10/04','10/09','0060','0086','0105')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('427846','UT','SALT LAKE','SILVER LAKE BRIGHTON',4.060083333000000e+001,-1.115841670000000e+002,'07/20','09/20','07/30','07/20','06/28','09/10','09/20','09/30','0008','0029','0063')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('427909','UT','WASATCH','SNAKE CREEK POWERHOUSE',4.054527777000000e+001,-1.115041670000000e+002,'06/28','10/01','07/12','06/28','06/08','09/17','10/01','10/09','0036','0060','0104')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('427959','UT','WASATCH','SOLDIER SUMMIT',3.992861111000000e+001,-1.110763890000000e+002,'07/12','09/27','08/02','07/12','06/24','09/04','09/27','10/01','0010','0039','0070')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('428119','UT','UTAH','SPANISH FORK PWR HOUSE',4.007972222000000e+001,-1.116044440000000e+002,'05/22','11/03','06/06','05/22','05/03','10/14','11/03','11/10','0111','0135','0169')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('428733','UT','UTAH','TIMPANOGOS CAVE',4.044472222000000e+001,-1.117075000000000e+002,'05/28','11/01','06/20','05/28','05/14','10/12','11/01','11/10','0089','0120','0152')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('428771','UT','TOOELE','TOOELE',4.052777777000000e+001,-1.122975000000000e+002,'05/27','11/02','06/12','05/27','05/10','10/12','11/02','11/13','0106','0135','0166')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('428828','UT','CACHE','TRENTON',4.191527777000000e+001,-1.119127780000000e+002,'06/20','10/05','07/04','06/20','06/08','09/27','10/05','10/13','0054','0082','0109')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('429111','UT','UINTAH','VERNAL 2 SW',4.042694444000000e+001,-1.095530560000000e+002,'06/14','10/05','06/19','06/14','05/25','10/01','10/05','10/17','0078','0100','0124')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('429133','UT','TOOELE','VERNON',4.010527777000000e+001,-1.124350000000000e+002,'06/15','10/03','07/02','06/15','06/02','09/25','10/03','10/13','0064','0094','0117')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('429136','UT','WASHINGTON','VEYO PWR HOUSE',3.735222222000000e+001,-1.136663890000000e+002,'05/25','11/12','06/05','05/25','04/26','11/05','11/12','11/22','0130','0146','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('429165','UT','SUMMIT','WANSHIP DAM',4.079083333000000e+001,-1.114077780000000e+002,'07/09','09/23','07/24','07/09','06/29','09/04','09/23','10/01','0015','0040','0073')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('429382','UT','TOOELE','WENDOVER AP AWOS',4.072055555000000e+001,-1.140358330000000e+002,'05/03','11/06','05/20','05/03','04/22','10/29','11/06','11/13','0136','0166','0182')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('429595','UT','RICH','WOODRUFF',4.152500000000000e+001,-1.111494440000000e+002,'07/16','09/12','07/30','07/16','06/22','08/27','09/12','09/24','0007','0028','0067')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('430277','VT','WINDHAM','BALL MTN LAKE',4.310027777000000e+001,-7.278361099999999e+001,'06/11','10/01','06/26','06/11','05/18','09/25','10/01','10/13','0059','0092','0130')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('431081','VT','CHITTENDEN','BURLINGTON WSO AP',4.446833333000000e+001,-7.315000000000001e+001,'05/20','10/13','06/02','05/20','05/04','10/08','10/13','11/01','0111','0131','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('431243','VT','WINDSOR','CAVENDISH',4.338472222000000e+001,-7.259888900000000e+001,'06/12','10/01','06/19','06/12','05/19','09/22','10/01','10/14','0073','0093','0132')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('431580','VT','ADDISON','CORNWALL',4.395722222000000e+001,-7.321055600000000e+001,'05/26','10/17','06/13','05/26','05/11','10/05','10/17','10/25','0092','0119','0144')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('432769','VT','FRANKLIN','ENOSBURG FALLS',4.490944444000000e+001,-7.280833300000001e+001,'06/04','10/03','06/24','06/04','05/22','09/22','10/03','10/15','0071','0106','0132')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('432843','VT','CHITTENDEN','ESSEX JUNCTION 1 N',4.450777777000000e+001,-7.311527800000000e+001,'06/02','10/10','06/17','06/02','05/18','09/26','10/10','10/21','0081','0111','0136')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('435278','VT','WASHINGTON','MONTPELIER AP',4.420333333000000e+001,-7.257944400000000e+001,'05/26','10/20','06/17','05/26','05/14','10/02','10/20','10/31','0081','0116','0142')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('435416','VT','LAMOILLE','MT MANSFIELD',4.452472222000000e+001,-7.281527800000001e+001,'06/28','09/27','07/14','06/28','06/11','09/20','09/27','10/11','0044','0069','0097')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('435542','VT','ORLEANS','NEWPORT',4.494888888000000e+001,-7.219111100000001e+001,'05/28','10/11','06/15','05/28','05/17','09/26','10/11','10/17','0086','0120','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('436893','VT','WINDSOR','ROCHESTER',4.385777777000000e+001,-7.280444400000000e+001,'06/03','10/07','06/20','06/03','05/16','09/26','10/07','10/21','0076','0113','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('436995','VT','RUTLAND','RUTLAND',4.362527777000000e+001,-7.297805600000000e+001,'05/26','10/12','06/11','05/26','05/15','09/29','10/12','10/23','0092','0121','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('437054','VT','CALEDONIA','SAINT JOHNSBURY',4.442000000000000e+001,-7.201944399999999e+001,'05/30','10/08','06/17','05/30','05/14','09/26','10/08','10/19','0082','0119','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('437098','VT','ADDISON','SALISBURY 2 N',4.392555555000000e+001,-7.309916699999999e+001,'05/28','10/25','06/13','05/28','05/16','09/30','10/25','11/16','0092','0122','0139')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('437607','VT','GRAND ISLE','SOUTH HERO',4.462638888000000e+001,-7.330305600000000e+001,'05/09','10/27','05/26','05/09','04/26','10/13','10/27','11/13','0126','0149','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('439984','VT','WINDSOR','WOODSTOCK',4.363027777000000e+001,-7.250722200000000e+001,'06/14','10/04','06/21','06/14','05/22','09/26','10/04','10/13','0068','0091','0128')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('440021','VA','WASHINGTON','ABINGDON 3S',3.666722222000000e+001,-8.196527800000000e+001,'05/17','10/21','06/02','05/17','05/02','10/16','10/21','11/06','0120','0141','0165')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('440187','VA','AMELIA','AMELIA COURTHOUSE 1',3.734500000000000e+001,-7.797805600000000e+001,'05/03','11/09','05/13','05/03','04/21','10/25','11/09','11/17','0142','0156','0182')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('440243','VA','APPOMATTOX','APPOMATTOX',3.735583333000000e+001,-7.883138900000000e+001,'05/01','11/09','05/13','05/01','04/18','10/24','11/09','11/19','0143','0171','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('440327','VA','HANOVER','ASHLAND',3.775000000000000e+001,-7.748333300000000e+001,'04/28','11/07','05/13','04/28','04/16','10/23','11/07','11/17','0144','0169','0188')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('440766','VA','MONTGOMERY','BLACKSBURG NWSO',3.720166666000000e+001,-8.041333299999999e+001,'05/21','10/20','06/01','05/21','05/09','10/12','10/20','11/03','0111','0133','0154')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('440993','VA','FLUVANNA','BREMO BLUFF',3.770916666000000e+001,-7.828861100000000e+001,'05/03','10/30','05/17','05/03','04/24','10/20','10/30','11/16','0140','0160','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('441082','VA','CAMPBELL','BROOKNEAL',3.706750000000000e+001,-7.895166700000000e+001,'04/30','11/03','05/16','04/30','04/17','10/21','11/03','11/17','0134','0169','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('441121','VA','BOTETOURT','BUCHANAN',3.752722222000000e+001,-7.967777800000000e+001,'05/10','11/04','05/19','05/10','04/22','10/19','11/04','11/15','0138','0158','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('441159','VA','ROCKBRIDGE','BUENA VISTA',3.772694444000000e+001,-7.936277800000001e+001,'06/04','11/03','06/06','06/04','05/28','10/22','11/03','11/18','0112','0130','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('441209','VA','TAZEWELL','BURKES GARDEN',3.709250000000000e+001,-8.133583299999999e+001,'06/04','10/12','06/23','06/04','05/15','10/01','10/12','10/19','0078','0108','0139')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('441593','VA','ALBEMARLE','CHARLOTTESVILLE 2W',3.803277777000000e+001,-7.852249999999999e+001,'04/16','11/18','04/28','04/16','04/09','11/07','11/18','11/28','0168','0185','0203')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('441606','VA','MECKLENBURG','CHASE CITY',3.677750000000000e+001,-7.847555600000000e+001,'05/01','11/11','05/17','05/01','04/17','11/03','11/11','11/25','0148','0167','0188')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('441614','VA','PITTSYLVANIA','CHATHAM',3.682250000000000e+001,-7.941055600000000e+001,'05/13','10/22','05/26','05/13','05/02','10/16','10/22','11/04','0124','0139','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('442009','VA','CAROLINE','CORBIN',3.820222222000000e+001,-7.737472200000001e+001,'05/05','11/03','05/21','05/05','04/18','10/21','11/03','11/20','0137','0159','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('442044','VA','ALLEGHANY','COVINGTON FLTR PLT',3.781055555000000e+001,-7.998833300000000e+001,'05/15','10/23','06/01','05/15','04/27','10/14','10/23','11/05','0118','0143','0171')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('442208','VA','ROCKINGHAM','DALE ENTERPRISE',3.845527777000000e+001,-7.893527800000000e+001,'05/12','10/26','05/26','05/12','04/24','10/13','10/26','11/10','0122','0146','0173')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('442245','VA','PITTSYLVANIA','DANVILLE',3.658694444000000e+001,-7.938861100000000e+001,'04/24','11/09','05/04','04/24','04/06','11/02','11/09','11/25','0161','0181','0209')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('442941','VA','CUMBERLAND','FARMVILLE 2 N',3.732638888000000e+001,-7.838638899999999e+001,'04/29','11/04','05/13','04/29','04/19','10/18','11/04','11/13','0145','0167','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('443267','VA','CARROLL','GALAX RADIO WBRF',3.666333333000000e+001,-8.091388900000000e+001,'05/21','10/17','06/02','05/21','05/08','10/10','10/17','11/02','0113','0133','0158')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('443640','VA','BUCHANAN','GRUNDY',3.728222222000000e+001,-8.208944400000000e+001,'05/10','11/05','05/19','05/10','04/24','10/22','11/05','11/18','0141','0156','0182')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('444044','VA','SUFFOLK','HOLLAND 1 E',3.668305555000000e+001,-7.676833300000000e+001,'04/25','11/09','05/04','04/25','04/07','10/27','11/09','11/25','0155','0177','0207')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('444101','VA','PRINCE GEORGE','HOPEWELL',3.729916666000000e+001,-7.727750000000000e+001,'04/19','11/12','05/05','04/19','04/10','10/31','11/12','11/22','0160','0181','0204')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('444128','VA','BATH','HOT SPRINGS',3.799694444000000e+001,-7.983166700000000e+001,'05/18','10/30','06/02','05/18','05/02','10/13','10/30','11/18','0115','0139','0165')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('444414','VA','MECKLENBURG','JOHN H KERR DAM',3.660027777000000e+001,-7.830111100000001e+001,'04/24','11/08','05/11','04/24','04/12','10/31','11/08','11/25','0151','0179','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('444876','VA','ROCKBRIDGE','LEXINGTON',3.779500000000000e+001,-7.941361100000000e+001,'05/12','10/27','05/22','05/12','04/23','10/15','10/27','11/12','0129','0149','0181')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('444909','VA','LOUDOUN','LINCOLN',3.908777777000000e+001,-7.769277800000000e+001,'05/01','11/04','05/16','05/01','04/18','10/22','11/04','11/15','0138','0163','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('445050','VA','LOUISA','LOUISA',3.804222222000000e+001,-7.800611100000000e+001,'05/07','10/28','05/24','05/07','04/28','10/14','10/28','11/13','0127','0152','0171')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('445096','VA','PAGE','LURAY 5 E',3.866611111000000e+001,-7.837277800000000e+001,'05/18','10/19','06/01','05/18','05/01','10/10','10/19','11/05','0118','0137','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('445120','VA','CAMPBELL','LYNCHBURG INTL AP',3.732083333000000e+001,-7.920666700000000e+001,'04/29','11/04','05/12','04/29','04/15','10/22','11/04','11/20','0146','0171','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('445300','VA','HENRY','MARTINSVILLE FLTR PLT',3.670555555000000e+001,-7.986500000000000e+001,'05/13','10/30','05/26','05/13','04/27','10/19','10/30','11/13','0128','0149','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('445851','VA','LOUDOUN','MT WEATHER',3.906416666000000e+001,-7.788833300000000e+001,'05/07','11/08','05/17','05/07','04/24','10/28','11/08','11/22','0143','0161','0184')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('446139','VA','NORFOLK (CITY)','NORFOLK INTL AP',3.690333333000000e+001,-7.619222200000000e+001,'04/07','12/11','04/19','04/07','03/22','11/27','12/11','12/27','0191','0223','0251')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('446475','VA','ACCOMACK','PAINTER 2W',3.758305555000000e+001,-7.582166700000001e+001,'04/20','11/20','05/07','04/20','04/09','11/09','11/20','12/07','0159','0187','0210')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('446712','VA','ORANGE','PIEDMONT RSCH STN',3.823222222000000e+001,-7.812027800000000e+001,'04/29','11/09','05/11','04/29','04/17','10/27','11/09','11/23','0148','0173','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('446955','VA','PULASKI','PULASKI 2 E',3.705555555000000e+001,-8.078416700000000e+001,'05/22','10/18','06/06','05/22','05/02','10/11','10/18','11/05','0112','0129','0166')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('447201','VA','HENRICO','RICHMOND INTL AP',3.750500000000000e+001,-7.732027800000000e+001,'04/21','11/14','05/07','04/21','04/11','11/02','11/14','11/26','0160','0183','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('447285','VA','ROANOKE','ROANOKE INTL AP',3.731694444000000e+001,-7.997416699999999e+001,'04/27','11/07','05/14','04/27','04/14','10/19','11/07','11/21','0140','0170','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('447338','VA','FRANKLIN','ROCKY MT',3.697694444000000e+001,-7.989611100000001e+001,'05/06','11/04','05/17','05/06','04/19','10/22','11/04','11/23','0139','0156','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('447506','VA','SMYTH','SALTVILLE 1N',3.688944444000000e+001,-8.177111100000001e+001,'05/25','10/25','06/10','05/25','05/19','10/16','10/25','10/29','0101','0124','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('448022','VA','GILES','STAFFORDSVILLE 3 ENE',3.727138888000000e+001,-8.071305600000000e+001,'05/16','10/18','06/02','05/16','05/09','10/14','10/18','11/01','0116','0140','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('448062','VA','AUGUSTA','STAUNTON WATER TRMTMT PLT',3.816916666000000e+001,-7.908444400000001e+001,'05/18','10/26','05/31','05/18','05/04','10/10','10/26','11/05','0119','0134','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('448129','VA','SUSSEX','STONY CREEK 2 N',3.697416666000000e+001,-7.740416700000000e+001,'05/01','11/06','05/12','05/01','04/16','10/27','11/06','11/17','0145','0165','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('448170','VA','PATRICK','STUART',3.663638888000000e+001,-8.025138900000000e+001,'05/06','11/11','05/14','05/06','04/18','10/31','11/11','11/27','0146','0168','0194')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('448192','VA','SUFFOLK','SUFFOLK LAKE KILBY',3.672972222000000e+001,-7.660138900000000e+001,'04/16','11/26','04/24','04/16','04/01','11/13','11/26','12/19','0173','0194','0235')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('448600','VA','NELSON','TYE RIVER 1 SE',3.764583333000000e+001,-7.896500000000000e+001,'04/28','11/01','05/14','04/28','04/16','10/22','11/01','11/20','0144','0163','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('448737','VA','FAIRFAX','VIENNA',3.890000000000000e+001,-7.726638900000000e+001,'04/22','11/15','05/12','04/22','04/14','11/14','11/15','11/28','0168','0196','0207')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('448829','VA','KING AND QUEEN','WALKERTON 2 NW',3.774333333000000e+001,-7.704000000000001e+001,'04/27','11/04','05/13','04/27','04/18','10/24','11/04','11/16','0144','0170','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('448888','VA','FAUQUIER','WARRENTON 3 SE',3.868111111000000e+001,-7.776777800000001e+001,'04/28','11/12','05/17','04/28','04/16','10/28','11/12','11/23','0141','0173','0194')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('448894','VA','RICHMOND','WARSAW 2 NW',3.798805555000000e+001,-7.677694400000000e+001,'04/25','11/10','05/07','04/25','04/16','10/28','11/10','11/25','0154','0176','0194')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('448903','VA','LOUDOUN','WASHGTN DULLES INTL AP',3.894083333000000e+001,-7.746361100000000e+001,'05/09','10/26','05/21','05/09','04/20','10/17','10/26','11/10','0129','0150','0182')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('448906','VA','ARLINGTON','WASHINGTON REAGAN AP',3.884833333000000e+001,-7.703416700000000e+001,'04/10','12/03','04/20','04/10','03/30','11/19','12/03','12/19','0185','0204','0231')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('449025','VA','KING WILLIAM','WEST POINT 2 NW',3.756583333000000e+001,-7.680000000000000e+001,'04/22','11/08','05/08','04/22','04/15','10/30','11/08','11/21','0149','0178','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('449151','VA','YORK','WILLIAMSBURG 2 N',3.730166666000000e+001,-7.670388900000000e+001,'04/25','11/12','05/07','04/25','04/14','11/04','11/12','11/27','0158','0179','0210')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('449186','VA','FREDERICK','WINCHESTER 7 SE',3.918333333000000e+001,-7.811666700000001e+001,'05/13','10/29','05/27','05/13','04/23','10/15','10/29','11/07','0118','0140','0176')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('449215','VA','WISE','WISE 3E',3.699861111000000e+001,-8.253888900000000e+001,'05/16','11/02','05/26','05/16','04/25','10/14','11/02','11/13','0128','0148','0176')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('449263','VA','SHENANDOAH','WOODSTOCK 2 NE',3.889694444000000e+001,-7.846777800000000e+001,'05/13','10/28','05/19','05/13','04/25','10/16','10/28','11/08','0126','0143','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('449301','VA','WYTHE','WYTHEVILLE 1 S',3.693166666000000e+001,-8.109416700000000e+001,'05/24','10/17','06/08','05/24','05/15','10/08','10/17','10/28','0105','0122','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('450008','WA','GRAYS HARBOR','ABERDEEN',4.696583333000000e+001,-1.238291670000000e+002,'04/25','12/10','05/18','04/25','03/16','11/10','12/10','01/20','0149','0195','0256')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('450176','WA','SKAGIT','ANACORTES',4.851194444000000e+001,-1.226136110000000e+002,'04/07','12/08','05/01','04/07','03/12','11/13','12/08','01/03','0163','0208','0251')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('450456','WA','KING','BARING',4.777222222000000e+001,-1.214819440000000e+002,'05/15','11/08','06/03','05/15','04/14','10/25','11/08','12/10','0114','0148','0211')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('450482','WA','CLARK','BATTLE GROUND',4.577166666000000e+001,-1.225286110000000e+002,'05/12','10/29','06/07','05/12','04/16','10/18','10/29','12/01','0105','0148','0203')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('450668','WA','KLICKITAT','BICKLETON',4.599805555000000e+001,-1.203005560000000e+002,'06/17','10/28','07/16','06/17','05/23','10/10','10/28','11/07','0064','0108','0145')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('450729','WA','WHATCOM','BLAINE',4.897750000000000e+001,-1.227927780000000e+002,'05/04','11/02','05/25','05/04','04/12','10/16','11/02','11/29','0127','0156','0198')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('450844','WA','PEND OREILLE','BOUNDARY DAM',4.899472222000000e+001,-1.173544440000000e+002,'05/24','10/18','06/18','05/24','05/02','10/02','10/18','10/31','0082','0114','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('450872','WA','KITSAP','BREMERTON',4.756888888000000e+001,-1.226827780000000e+002,'04/23','12/03','05/11','04/23','03/17','11/12','12/03','12/31','0158','0199','0255')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('450945','WA','PIERCE','BUCKLEY 1 NE',4.716944444000000e+001,-1.220036110000000e+002,'05/09','11/03','06/03','05/09','04/12','10/20','11/03','12/14','0114','0158','0205')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('451233','WA','KING','CEDAR LAKE',4.741444444000000e+001,-1.217561110000000e+002,'05/17','11/10','06/07','05/17','04/20','10/21','11/10','12/08','0113','0151','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('451276','WA','LEWIS','CENTRALIA',4.672000000000000e+001,-1.229527780000000e+002,'05/08','11/24','05/26','05/08','04/12','10/26','11/24','12/21','0130','0158','0209')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('451350','WA','CHELAN','CHELAN',4.783611111000000e+001,-1.200380560000000e+002,'04/25','11/08','05/21','04/25','04/04','10/25','11/08','11/30','0135','0170','0203')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('451395','WA','STEVENS','CHEWELAH',4.827333333000000e+001,-1.177408330000000e+002,'06/03','10/02','07/10','06/03','05/17','09/20','10/02','10/15','0051','0096','0125')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('451400','WA','DOUGLAS','CHIEF JOSEPH DAM',4.799666666000000e+001,-1.196483330000000e+002,'05/10','10/26','06/01','05/10','04/26','10/13','10/26','11/14','0107','0144','0177')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('451484','WA','WHATCOM','CLEARBROOK',4.896722222000000e+001,-1.223291670000000e+002,'05/10','11/03','06/04','05/10','04/14','10/14','11/03','12/10','0109','0146','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('451496','WA','JEFFERSON','CLEARWATER',4.757111111000000e+001,-1.242922220000000e+002,'05/26','11/02','06/19','05/26','04/14','10/18','11/02','12/06','0089','0126','0196')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('451504','WA','KITTITAS','CLE ELUM',4.718888888000000e+001,-1.209130560000000e+002,'06/09','10/02','06/29','06/09','05/14','09/22','10/02','10/15','0064','0094','0129')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('451666','WA','OKANOGAN','CONCONULLY',4.855583333000000e+001,-1.197491670000000e+002,'05/24','10/23','06/15','05/24','05/02','10/08','10/23','11/03','0099','0132','0163')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('451679','WA','SKAGIT','CONCRETE PPL FISH STN',4.853972222000000e+001,-1.217422220000000e+002,'04/29','12/06','05/16','04/29','03/20','11/02','12/06','12/28','0151','0177','0243')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('451760','WA','SKAMANIA','COUGAR 6 E',4.606250000000000e+001,-1.222041670000000e+002,'05/08','12/11','06/07','05/08','03/28','11/21','12/11','01/14','0126','0183','0249')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('451767','WA','GRANT','COULEE DAM 1 SW',4.795444444000000e+001,-1.189997220000000e+002,'05/10','10/31','05/22','05/10','04/22','10/21','10/31','11/19','0126','0152','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('451783','WA','ISLAND','COUPEVILLE 1 S',4.820722222000000e+001,-1.226913890000000e+002,'04/24','11/20','05/22','04/24','03/31','10/26','11/20','12/26','0133','0173','0223')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('451968','WA','KLICKITAT','DALLESPORT AP',4.561944444000000e+001,-1.211661110000000e+002,'05/02','11/06','05/16','05/02','04/15','10/23','11/06','11/27','0137','0160','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('451992','WA','SNOHOMISH','DARRINGTON RS',4.826000000000000e+001,-1.216036110000000e+002,'05/15','10/27','06/08','05/15','04/21','10/16','10/27','12/03','0108','0147','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('452007','WA','LINCOLN','DAVENPORT',4.765416666000000e+001,-1.181408330000000e+002,'06/21','10/08','07/15','06/21','05/24','09/19','10/08','10/18','0042','0086','0116')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('452030','WA','COLUMBIA','DAYTON 1 WSW',4.631527777000000e+001,-1.180022220000000e+002,'05/19','10/24','06/04','05/19','04/26','10/13','10/24','11/13','0111','0136','0171')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('452157','WA','WHATCOM','DIABLO DAM',4.871416666000000e+001,-1.211430560000000e+002,'05/06','11/15','05/26','05/06','04/04','10/29','11/15','12/16','0131','0166','0220')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('452505','WA','KITTITAS','ELLENSBURG',4.696916666000000e+001,-1.205400000000000e+002,'05/27','10/08','06/17','05/27','05/07','09/28','10/08','10/24','0085','0117','0145')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('452531','WA','GRAYS HARBOR','ELMA',4.700916666000000e+001,-1.234008330000000e+002,'05/26','10/30','06/15','05/26','05/04','10/16','10/30','12/01','0099','0130','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('452548','WA','CLALLAM','ELWHA RS',4.801638888000000e+001,-1.235905560000000e+002,'05/12','11/23','05/28','05/12','03/29','11/02','11/23','01/02','0126','0163','0228')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('452614','WA','GRANT','EPHRATA AP',4.730777777000000e+001,-1.195152780000000e+002,'05/08','11/01','05/28','05/08','04/19','10/16','11/01','11/16','0122','0155','0181')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('452675','WA','SNOHOMISH','EVERETT',4.797527777000000e+001,-1.221950000000000e+002,'04/25','11/14','05/14','04/25','03/21','10/30','11/14','12/20','0141','0171','0232')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('452914','WA','CLALLAM','FORKS 1 E',4.795583333000000e+001,-1.243538890000000e+002,'05/19','11/10','06/06','05/19','04/14','10/21','11/10','12/21','0103','0146','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('453320','WA','GRAYS HARBOR','GRAYLAND',4.680083333000000e+001,-1.240863890000000e+002,'05/15','11/23','06/09','05/15','03/26','10/31','11/23','01/01','0107','0159','0243')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('453333','WA','PACIFIC','GRAYS RIVER HATCHERY',4.638722222000000e+001,-1.235602780000000e+002,'05/29','10/31','06/25','05/29','04/21','10/18','10/31','12/14','0080','0130','0200')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('453515','WA','LINCOLN','HARRINGTON 1 NW',4.749333333000000e+001,-1.182500000000000e+002,'07/09','10/04','07/26','07/09','06/11','09/14','10/04','10/13','0032','0055','0099')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('453546','WA','FRANKLIN','HATTON 9 SE',4.672250000000000e+001,-1.186525000000000e+002,'06/02','10/22','06/21','06/02','05/06','10/12','10/22','11/06','0082','0117','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('453730','WA','CHELAN','HOLDEN VILLAGE',4.819888888000000e+001,-1.207736110000000e+002,'07/09','09/23','08/03','07/09','06/11','09/03','09/23','10/14','0010','0054','0100')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('453807','WA','GRAYS HARBOR','HOQUIAM BOWERMAN AP',4.697277777000000e+001,-1.239302780000000e+002,'04/25','12/16','05/18','04/25','03/07','11/19','12/16','01/27','0148','0191','0272')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('453883','WA','WALLA WALLA','ICE HARBOR DAM',4.624472222000000e+001,-1.188786110000000e+002,'04/22','11/02','05/11','04/22','04/11','10/22','11/02','11/27','0142','0170','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('454154','WA','BENTON','KENNEWICK',4.621111111000000e+001,-1.191011110000000e+002,'04/29','11/06','05/15','04/29','04/09','10/27','11/06','12/06','0139','0165','0195')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('454169','WA','KING','KENT',4.741722222000000e+001,-1.222433330000000e+002,'05/06','11/17','05/28','05/06','04/13','10/31','11/17','12/13','0111','0154','0199')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('454338','WA','WHITMAN','LACROSSE',4.681666666000000e+001,-1.178830560000000e+002,'06/16','10/09','07/12','06/16','05/25','09/25','10/09','10/19','0050','0089','0121')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('454486','WA','KING','LANDSBURG',4.737666666000000e+001,-1.219613890000000e+002,'05/16','11/04','06/11','05/16','05/03','10/22','11/04','12/04','0099','0141','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('454572','WA','CHELAN','LEAVENWORTH 3 S',4.755861111000000e+001,-1.206750000000000e+002,'05/28','10/12','06/23','05/28','05/06','10/01','10/12','10/28','0081','0118','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('454679','WA','ADAMS','LIND 3 NE',4.700222222000000e+001,-1.185658330000000e+002,'06/12','10/11','06/26','06/12','05/18','10/03','10/11','10/25','0072','0098','0137')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('454748','WA','PACIFIC','LONG BEACH EXP STN',4.636750000000000e+001,-1.240377780000000e+002,'05/03','11/23','06/02','05/03','03/22','10/30','11/23','12/21','0109','0161','0238')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('454769','WA','COWLITZ','LONGVIEW',4.615055555000000e+001,-1.229163890000000e+002,'05/09','11/29','05/27','05/09','03/24','11/04','11/29','12/26','0137','0172','0237')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('455133','WA','OKANOGAN','MAZAMA',4.859333333000000e+001,-1.204052780000000e+002,'06/22','10/05','07/04','06/22','06/05','09/23','10/05','10/14','0059','0081','0106')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('455224','WA','PIERCE','MC MILLIN RSVR',4.713583333000000e+001,-1.222558330000000e+002,'05/13','11/05','06/01','05/13','04/18','10/19','11/05','12/07','0123','0148','0193')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('455326','WA','OKANOGAN','METHOW 2 S',4.810750000000000e+001,-1.200077780000000e+002,'05/25','10/13','06/21','05/25','05/12','10/06','10/13','10/27','0085','0125','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('455525','WA','SNOHOMISH','MONROE',4.784527777000000e+001,-1.219944440000000e+002,'04/30','11/15','05/24','04/30','04/06','10/24','11/15','12/18','0124','0169','0206')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('455659','WA','KLICKITAT','MT ADAMS RS',4.599972222000000e+001,-1.215402780000000e+002,'06/30','10/04','07/19','06/30','06/02','09/24','10/04','10/24','0037','0070','0115')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('455688','WA','YAKIMA','MOXEE CITY 10 E',4.650527777000000e+001,-1.201677780000000e+002,'05/30','10/21','06/21','05/30','05/11','10/08','10/21','11/04','0094','0123','0152')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('455704','WA','KING','MUD MTN DAM',4.714138888000000e+001,-1.219355560000000e+002,'05/13','11/06','06/07','05/13','04/18','10/23','11/06','12/12','0114','0150','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('455840','WA','WHATCOM','NEWHALEM',4.867583333000000e+001,-1.212419440000000e+002,'05/04','11/29','05/18','05/04','03/22','11/07','11/29','01/05','0147','0182','0244')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('455844','WA','PEND OREILLE','NEWPORT',4.818416666000000e+001,-1.170475000000000e+002,'06/26','10/01','07/20','06/26','05/23','09/21','10/01','10/19','0036','0071','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('455946','WA','STEVENS','NORTHPORT',4.887416666000000e+001,-1.178666670000000e+002,'06/08','10/15','06/20','06/08','05/12','10/05','10/15','10/29','0080','0107','0143')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('456039','WA','LINCOLN','ODESSA',4.733277777000000e+001,-1.186944440000000e+002,'06/12','10/07','07/08','06/12','05/23','09/26','10/07','10/18','0050','0095','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('456096','WA','SAN JUAN','OLGA 2 SE',4.861166666000000e+001,-1.228063890000000e+002,'04/14','12/12','05/10','04/14','03/04','11/19','12/12','01/17','0164','0207','0269')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('456114','WA','THURSTON','OLYMPIA AP',4.697333333000000e+001,-1.229033330000000e+002,'05/23','10/24','06/15','05/23','05/05','10/10','10/24','11/15','0089','0128','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('456123','WA','OKANOGAN','OMAK 4 N',4.846083333000000e+001,-1.195166670000000e+002,'05/30','10/11','06/17','05/30','05/08','10/03','10/11','10/19','0086','0111','0145')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('456262','WA','LEWIS','PACKWOOD',4.660916666000000e+001,-1.216744440000000e+002,'06/07','10/17','06/27','06/07','05/12','10/03','10/17','11/06','0071','0100','0143')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('456295','WA','KING','PALMER 3 ESE',4.730583333000000e+001,-1.218513890000000e+002,'05/02','11/27','05/28','05/02','03/18','10/30','11/27','12/26','0134','0175','0242')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('456534','WA','CHELAN','PLAIN',4.778500000000000e+001,-1.206455560000000e+002,'06/18','09/29','07/11','06/18','05/26','09/15','09/29','10/09','0050','0082','0119')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('456610','WA','GARFIELD','POMEROY',4.646722222000000e+001,-1.175883330000000e+002,'05/27','10/19','06/13','05/27','05/07','10/08','10/19','11/01','0092','0119','0156')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('456747','WA','GRANT','PRIEST RAPIDS DAM',4.664638888000000e+001,-1.199063890000000e+002,'04/29','11/08','05/12','04/29','04/05','10/23','11/08','11/24','0146','0163','0192')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('456768','WA','BENTON','PROSSER',4.620138888000000e+001,-1.197580560000000e+002,'05/16','10/25','06/02','05/16','05/01','10/11','10/25','11/13','0109','0136','0171')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('456789','WA','WHITMAN','PULLMAN 2 NW',4.676027777000000e+001,-1.171861110000000e+002,'05/31','10/14','07/04','05/31','05/13','09/26','10/14','10/26','0060','0107','0140')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('456846','WA','JEFFERSON','QUILCENE 2 SW',4.780916666000000e+001,-1.229136110000000e+002,'05/06','10/31','06/08','05/06','04/12','10/17','10/31','12/09','0109','0156','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('456858','WA','CLALLAM','QUILLAYUTE AP',4.793750000000000e+001,-1.245550000000000e+002,'05/19','11/03','06/16','05/19','04/27','10/14','11/03','12/13','0086','0138','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('456880','WA','GRANT','QUINCY 1 S',4.721555555000000e+001,-1.198477780000000e+002,'05/14','10/24','05/28','05/14','04/29','10/12','10/24','11/06','0115','0136','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('456898','WA','PIERCE','RAINIER PARADISE RS',4.678583333000000e+001,-1.217425000000000e+002,'07/25','09/16','08/03','07/25','07/11','08/28','09/16','10/11','0002','0020','0061')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('456974','WA','FERRY','REPUBLIC',4.864694444000000e+001,-1.187313890000000e+002,'06/25','09/29','07/10','06/25','05/27','09/10','09/29','10/08','0044','0074','0115')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('457015','WA','BENTON','RICHLAND',4.631194444000000e+001,-1.192633330000000e+002,'04/21','11/02','05/06','04/21','04/11','10/18','11/02','11/20','0146','0170','0202')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('457059','WA','ADAMS','RITZVILLE 1 SSE',4.711777777000000e+001,-1.183722220000000e+002,'06/03','10/17','06/29','06/03','05/16','10/07','10/17','10/31','0074','0113','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('457180','WA','WHITMAN','ROSALIA',4.723250000000000e+001,-1.173625000000000e+002,'06/11','10/09','07/06','06/11','05/21','09/26','10/09','10/23','0059','0095','0131')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('457185','WA','WHATCOM','ROSS DAM',4.872722222000000e+001,-1.210722220000000e+002,'05/01','11/23','05/23','05/01','03/28','11/05','11/23','12/18','0143','0180','0232')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('457267','WA','WHITMAN','ST. JOHN',4.709333333000000e+001,-1.175877780000000e+002,'06/27','10/05','07/17','06/27','06/06','09/21','10/05','10/18','0039','0073','0106')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('457342','WA','KLICKITAT','SATUS PASS 2 SSW',4.594805555000000e+001,-1.206669440000000e+002,'07/21','10/06','07/30','07/21','07/03','09/21','10/06','10/18','0006','0029','0069')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('457473','WA','KING','SEATTLE TACOMA AP',4.744444444000000e+001,-1.223138890000000e+002,'04/04','12/07','04/27','04/04','03/11','11/15','12/07','01/02','0179','0222','0271')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('457507','WA','SKAGIT','SEDRO WOOLLEY',4.849583333000000e+001,-1.222355560000000e+002,'04/22','11/19','05/18','04/22','03/20','11/01','11/19','12/20','0140','0181','0235')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('457696','WA','SKAMANIA','SKAMANIA FISH HATCHRY',4.562277777000000e+001,-1.222175000000000e+002,'06/15','10/24','07/12','06/15','05/17','09/30','10/24','11/24','0042','0095','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('457773','WA','KING','SNOQUALMIE FALLS',4.754138888000000e+001,-1.218361110000000e+002,'05/11','11/08','05/28','05/11','04/12','10/24','11/08','12/11','0118','0152','0209')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('457938','WA','SPOKANE','SPOKANE INTERNATIONAL AIRPORT',4.762166666000000e+001,-1.175280560000000e+002,'05/18','10/17','06/09','05/18','05/06','10/05','10/17','11/01','0103','0130','0152')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('458009','WA','KITTITAS','STAMPEDE PASS',4.727666666000000e+001,-1.213372220000000e+002,'07/12','10/22','07/20','07/12','06/29','10/09','10/22','11/13','0054','0086','0114')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('458034','WA','SNOHOMISH','STARTUP 1 E',4.786638888000000e+001,-1.217175000000000e+002,'05/17','11/06','06/02','05/17','04/12','10/23','11/06','12/10','0115','0143','0204')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('458059','WA','CHELAN','STEHEKIN 4 NW',4.835083333000000e+001,-1.207263890000000e+002,'05/16','10/27','05/28','05/16','04/22','10/14','10/27','11/13','0123','0139','0182')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('458207','WA','YAKIMA','SUNNYSIDE',4.632361111000000e+001,-1.200102780000000e+002,'05/09','10/26','05/27','05/09','04/23','10/11','10/26','11/08','0122','0149','0180')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('458715','WA','WHATCOM','UPPER BAKER DAM',4.865250000000000e+001,-1.216930560000000e+002,'05/06','11/16','05/30','05/06','04/15','10/28','11/16','12/17','0126','0163','0205')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('458773','WA','CLARK','VANCOUVER 4 NNE',4.567777777000000e+001,-1.226511110000000e+002,'05/10','11/03','06/06','05/10','04/24','10/15','11/03','12/01','0105','0151','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('458959','WA','YAKIMA','WAPATO',4.643527777000000e+001,-1.204202780000000e+002,'05/15','10/26','05/25','05/15','04/24','10/16','10/26','11/01','0121','0143','0177')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('459012','WA','DOUGLAS','WATERVILLE',4.764972222000000e+001,-1.200800000000000e+002,'06/01','10/14','06/22','06/01','05/15','10/01','10/14','10/26','0082','0115','0142')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('459074','WA','CHELAN','WENATCHEE',4.742888888000000e+001,-1.203100000000000e+002,'04/24','11/08','05/13','04/24','03/31','10/24','11/08','11/26','0141','0170','0207')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('459082','WA','DOUGLAS','WENATCHEE PANGBORN MEMORIAL AP',4.739777777000000e+001,-1.202013890000000e+002,'04/25','11/02','05/15','04/25','04/09','10/22','11/02','11/16','0139','0169','0204')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('459200','WA','WALLA WALLA','WHITMAN MISSION',4.604361111000000e+001,-1.184627780000000e+002,'05/26','10/06','06/23','05/26','05/01','09/28','10/06','10/21','0076','0113','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('459238','WA','LINCOLN','WILBUR',4.775666666000000e+001,-1.186775000000000e+002,'07/03','10/07','07/12','07/03','05/28','09/23','10/07','10/23','0041','0073','0126')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('459376','WA','OKANOGAN','WINTHROP 1 WSW',4.847416666000000e+001,-1.201886110000000e+002,'06/14','10/02','07/04','06/14','05/21','09/19','10/02','10/14','0059','0092','0126')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('459465','WA','YAKIMA','YAKIMA AP',4.656833333000000e+001,-1.205427780000000e+002,'06/01','10/12','06/29','06/01','05/09','09/30','10/12','10/29','0077','0119','0150')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('460509','WV','POCAHONTAS','BARTOW 1S',3.853111111000000e+001,-7.977138900000000e+001,'06/05','10/12','06/19','06/05','05/28','09/30','10/12','10/19','0079','0105','0124')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('460527','WV','GRANT','BAYARD',3.927277777000000e+001,-7.936833300000001e+001,'06/06','10/09','06/19','06/06','05/19','09/27','10/09','10/23','0083','0112','0139')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('460580','WV','RALEIGH','BECKLEY VA HOSPITAL',3.776472222000000e+001,-8.119388900000000e+001,'05/31','10/14','06/10','05/31','05/13','10/08','10/14','10/25','0102','0121','0145')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('460582','WV','RALEIGH','BECKLEY RALEIGH COUNTY AP',3.778361111000000e+001,-8.112305600000001e+001,'05/21','10/21','05/31','05/21','04/28','10/14','10/21','11/11','0117','0137','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('460921','WV','MERCER','BLUEFIELD MERCER CO AP',3.729583333000000e+001,-8.120777800000001e+001,'05/03','11/06','05/22','05/03','04/22','10/23','11/06','11/19','0136','0159','0181')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('460939','WV','SUMMERS','BLUESTONE LAKE',3.764111111000000e+001,-8.088305600000000e+001,'05/13','11/05','05/16','05/13','04/22','10/24','11/05','11/21','0146','0157','0185')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('461215','WV','POCAHONTAS','BUCKEYE',3.818722222000000e+001,-8.013361100000000e+001,'05/29','10/17','06/11','05/29','05/17','10/10','10/17','10/30','0104','0125','0149')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('461220','WV','UPSHUR','BUCKHANNON',3.898027777000000e+001,-8.022000000000000e+001,'05/27','10/20','06/06','05/27','05/13','10/09','10/20','10/29','0111','0127','0153')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('461570','WV','KANAWHA','CHARLESTON YEAGER AP',3.837944444000000e+001,-8.159000000000000e+001,'05/08','11/07','05/19','05/08','04/17','10/23','11/07','11/17','0141','0160','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('461677','WV','HARRISON','CLARKSBURG 1',3.926833333000000e+001,-8.035222200000000e+001,'05/14','10/29','05/28','05/14','04/24','10/15','10/29','11/15','0127','0151','0179')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('462522','WV','WAYNE','DUNLOW 1 SW',3.794972222000000e+001,-8.240472200000001e+001,'05/10','11/03','05/23','05/10','04/29','10/24','11/03','11/14','0123','0147','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('462718','WV','RANDOLPH','ELKINS RANDOLPH COUNTY AP',3.888527777000000e+001,-7.985277800000000e+001,'06/04','10/14','06/17','06/04','05/17','10/07','10/14','10/26','0096','0120','0147')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('462920','WV','MARION','FAIRMONT',3.946666666000000e+001,-8.013333299999999e+001,'05/14','10/26','05/31','05/14','05/01','10/17','10/26','11/10','0120','0145','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('463361','WV','BRAXTON','GASSAWAY',3.866500000000000e+001,-8.076722200000000e+001,'05/15','10/30','05/29','05/15','05/05','10/21','10/30','11/13','0127','0151','0171')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('463544','WV','GILMER','GLENVILLE',3.893388888000000e+001,-8.083250000000000e+001,'05/23','10/27','05/31','05/23','05/05','10/17','10/27','11/11','0122','0139','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('463846','WV','LINCOLN','HAMLIN',3.827944444000000e+001,-8.211138900000000e+001,'05/14','10/23','05/26','05/14','05/02','10/13','10/23','11/09','0127','0145','0166')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('464200','WV','MASON','HOGSETT R.C. BYRD DAM',3.868444444000000e+001,-8.218361100000000e+001,'05/13','11/06','05/24','05/13','04/27','10/22','11/06','11/21','0131','0151','0174')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('464393','WV','WAYNE','HUNTINGTON TRI ST AP',3.836500000000000e+001,-8.255500000000001e+001,'05/03','11/06','05/16','05/03','04/19','10/21','11/06','11/18','0142','0161','0187')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('464397','WV','WAYNE','HUNTINGTON SEWAGE PLT',3.840138888000000e+001,-8.252666700000000e+001,'05/03','11/09','05/16','05/03','04/21','10/25','11/09','11/21','0142','0164','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('465224','WV','GREENBRIER','LEWISBURG 3 N',3.785638888000000e+001,-8.040416700000000e+001,'05/23','10/13','06/06','05/23','05/08','10/08','10/13','11/02','0110','0130','0148')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('465353','WV','LOGAN','LOGAN',3.787166666000000e+001,-8.199472200000000e+001,'05/06','11/13','05/14','05/06','04/19','11/03','11/13','11/26','0149','0169','0191')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('465365','WV','KANAWHA','LONDON LOCKS',3.819472222000000e+001,-8.137055599999999e+001,'05/01','11/18','05/14','05/01','04/15','11/05','11/18','11/26','0156','0173','0201')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('465563','WV','BOONE','MADISON 3NNW',3.810250000000000e+001,-8.184638900000000e+001,'05/11','11/02','05/30','05/11','04/29','10/25','11/02','11/16','0126','0151','0170')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('465672','WV','POCAHONTAS','MARLINTON',3.821750000000000e+001,-8.009138900000001e+001,'05/31','10/15','06/18','05/31','05/17','10/11','10/15','10/25','0092','0118','0139')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('465707','WV','BERKELEY','MARTINSBURG E WV RGNL AP',3.940194444000000e+001,-7.798444400000000e+001,'05/04','11/03','05/18','05/04','04/16','10/18','11/03','11/10','0133','0157','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('465963','WV','TYLER','MIDDLEBOURNE 3 ESE',3.949527777000000e+001,-8.090472200000001e+001,'05/20','10/21','05/31','05/20','05/11','10/13','10/21','11/05','0122','0138','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('466163','WV','HARDY','MOOREFIELD 1 SSE',3.904611111000000e+001,-7.896638900000001e+001,'05/14','10/24','05/28','05/14','05/01','10/12','10/24','11/01','0123','0143','0166')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('466202','WV','MONONGALIA','MORGANTOWN HART FLD',3.964277777000000e+001,-7.991638900000000e+001,'05/18','11/03','05/25','05/18','04/28','10/17','11/03','11/12','0127','0143','0175')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('466212','WV','MONONGALIA','MORGANTOWN L&D',3.961666666000000e+001,-7.996666700000000e+001,'05/19','11/02','05/27','05/19','05/10','10/20','11/02','11/15','0121','0139','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('466248','WV','MARSHALL','MOUNDSVILLE',3.990555555000000e+001,-8.075500000000000e+001,'05/13','11/01','05/22','05/13','04/29','10/17','11/01','11/14','0134','0152','0178')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('466442','WV','HANCOCK','NEW CUMBERLAND L/D',4.052611111000000e+001,-8.062750000000000e+001,'05/14','11/02','05/29','05/14','05/04','10/19','11/02','11/14','0122','0151','0176')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('466591','WV','FAYETTE','OAK HILL',3.797138888000000e+001,-8.115083300000001e+001,'05/18','10/25','06/01','05/18','04/30','10/15','10/25','11/11','0120','0140','0172')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('466849','WV','WOOD','PARKERSBURG FAA AP',3.934500000000000e+001,-8.143916700000000e+001,'05/07','11/06','05/20','05/07','04/20','10/22','11/06','11/22','0139','0154','0186')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('466859','WV','WOOD','PARKERSBURG',3.928111111000000e+001,-8.155722200000000e+001,'05/07','11/05','05/21','05/07','04/19','10/22','11/05','11/20','0135','0163','0189')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('466867','WV','TUCKER','PARSONS 1 NE',3.910305555000000e+001,-7.966583300000001e+001,'05/23','10/23','06/06','05/23','05/10','10/12','10/23','11/06','0116','0137','0161')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('467029','WV','WYOMING','PINEVILLE',3.757416666000000e+001,-8.153555600000000e+001,'05/16','11/03','05/21','05/16','04/29','10/24','11/03','11/14','0139','0152','0176')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('467552','WV','JACKSON','RIPLEY',3.881722222000000e+001,-8.171194400000000e+001,'05/16','10/27','05/27','05/16','05/02','10/14','10/27','11/09','0122','0143','0164')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('467730','WV','HAMPSHIRE','ROMNEY 1 SW',3.933888888000000e+001,-7.877277800000000e+001,'05/19','10/25','05/30','05/19','04/30','10/14','10/25','11/07','0122','0141','0172')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('467785','WV','PRESTON','ROWLESBURG 1',3.934194444000000e+001,-7.967000000000000e+001,'05/20','10/29','05/29','05/20','05/03','10/15','10/29','11/12','0125','0143','0171')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('468384','WV','ROANE','SPENCER',3.880083333000000e+001,-8.135833300000000e+001,'05/24','10/22','06/05','05/24','05/11','10/13','10/22','11/03','0111','0133','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('468614','WV','NICHOLAS','SUMMERSVILLE LAKE',3.822000000000000e+001,-8.089388900000000e+001,'05/14','10/27','05/31','05/14','05/03','10/16','10/27','11/13','0122','0147','0165')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('468662','WV','BRAXTON','SUTTON LAKE',3.866111111000000e+001,-8.069694400000000e+001,'05/21','10/24','05/28','05/21','05/01','10/15','10/24','11/11','0125','0136','0162')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('468777','WV','PRESTON','TERRA ALTA #1',3.944666666000000e+001,-7.954694400000000e+001,'05/15','10/24','06/08','05/15','05/07','10/11','10/24','11/08','0108','0138','0155')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('469011','WV','MONROE','UNION 3 SSE',3.754361111000000e+001,-8.053361099999999e+001,'05/27','10/12','06/13','05/27','05/15','10/08','10/12','10/23','0101','0123','0146')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('469281','WV','HARDY','WARDENSVILLE RM FARM',3.911388888000000e+001,-7.858111100000001e+001,'05/15','10/20','06/01','05/15','05/07','10/11','10/20','10/30','0112','0136','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('469323','WV','WAYNE','WAYNE 2',3.822611111000000e+001,-8.244305600000000e+001,'05/14','10/28','05/25','05/14','04/25','10/18','10/28','11/12','0129','0147','0176')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('469436','WV','LEWIS','WESTON',3.904388888000000e+001,-8.047250000000000e+001,'05/16','10/28','05/31','05/16','05/02','10/16','10/28','11/14','0120','0143','0166')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('469458','WV','DODDRIDGE','WEST UNION 2',3.929111111000000e+001,-8.076944399999999e+001,'05/20','10/31','06/01','05/20','05/10','10/14','10/31','11/10','0120','0134','0159')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('469522','WV','GREENBRIER','WHITE SULPHUR SPRINGS',3.778888888000000e+001,-8.030833300000001e+001,'05/28','10/18','06/05','05/28','05/09','10/11','10/18','10/27','0108','0127','0153')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('470124','WI','BUFFALO','ALMA DAM 4',4.432722222000000e+001,-9.191944400000000e+001,'05/08','10/24','05/26','05/08','05/01','10/10','10/24','11/05','0122','0143','0160')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('470175','WI','POLK','AMERY',4.530111111000000e+001,-9.236305600000000e+001,'05/26','10/09','06/13','05/26','05/10','09/30','10/09','10/19','0088','0119','0139')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('470239','WI','LANGLADE','ANTIGO',4.516027777000000e+001,-8.911277800000001e+001,'06/08','10/03','06/20','06/08','05/20','09/24','10/03','10/11','0070','0097','0130')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('470265','WI','OUTAGAMIE','APPLETON',4.427694444000000e+001,-8.843777799999999e+001,'05/18','10/22','05/26','05/18','05/06','10/11','10/22','11/08','0120','0132','0153')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('470273','WI','DANE','ARBORETUM UNIV WIS',4.304111111000000e+001,-8.942861100000000e+001,'06/08','10/11','06/18','06/08','05/18','10/01','10/11','10/17','0082','0100','0133')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('470308','WI','COLUMBIA','ARLINGTON UNIV FARM',4.330083333000000e+001,-8.932694400000000e+001,'05/20','10/16','06/08','05/20','05/05','10/07','10/16','11/03','0102','0130','0151')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('470349','WI','BAYFIELD','ASHLAND EXP FARM',4.658305555000000e+001,-9.096777800000000e+001,'06/17','10/04','06/23','06/17','06/01','09/27','10/04','10/15','0074','0094','0117')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('470516','WI','SAUK','BARABOO',4.345833333000000e+001,-8.972694400000000e+001,'06/03','10/03','06/16','06/03','05/23','09/27','10/03','10/15','0088','0108','0127')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('470645','WI','DODGE','BEAVER DAM',4.344472222000000e+001,-8.884777800000001e+001,'05/18','10/16','06/01','05/18','05/04','10/05','10/16','11/04','0117','0136','0157')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('470696','WI','ROCK','BELOIT',4.250388888000000e+001,-8.903111100000000e+001,'05/08','10/23','05/20','05/08','04/29','10/13','10/23','11/10','0132','0146','0168')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('470904','WI','CHIPPEWA','BLOOMER',4.509555555000000e+001,-9.148861100000001e+001,'05/27','10/09','06/08','05/27','05/10','09/29','10/09','10/19','0089','0120','0143')");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900063','AB',NULL,'Athabasca',5.470000000000000e+001,1.132666700000000e+002,'6/1','8/29',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900064','AB',NULL,'Calgary',5.103333300000000e+001,1.140500000000000e+002,'5/23','9/15',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900065','AB',NULL,'Edmonton',5.353333300000000e+001,1.134833330000000e+002,'5/7','9/23',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900066','AB',NULL,'Grande Prairie',5.516666700000000e+001,1.187833330000000e+002,'5/18','9/13',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900067','AB',NULL,'Lethbridge',4.968333300000000e+001,1.128333330000000e+002,'5/17','9/18',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900068','AB',NULL,'Medicine Hat',5.003333300000000e+001,1.106666670000000e+002,'5/16','9/22',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900069','AB',NULL,'Peace River',5.621666700000000e+001,1.172833330000000e+002,'5/26','9/3',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900070','AB',NULL,'Red Deer',5.226666700000000e+001,1.138000000000000e+002,'5/25','9/9',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900071','AB',NULL,'Abbotsford',5.105000000000000e+001,1.139166670000000e+002,'4/24','10/18',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900072','AB',NULL,'Chilliwack',4.915000000000000e+001,1.219500000000000e+002,'4/6','11/9',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900073','BC',NULL,'Dawson Creek',5.575000000000000e+001,1.202333330000000e+002,'6/5','8/29',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900074','BC',NULL,'Kamloops',5.066666700000000e+001,1.203166670000000e+002,'6/1','10/5',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900075','BC',NULL,'Kelowna',4.988333300000000e+001,1.194833330000000e+002,'5/19','9/20',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900076','BC',NULL,'Nanaimo',4.915000000000000e+001,1.239333330000000e+002,'4/28','10/17',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    tx.executeSql("INSERT INTO [CityState] ([COOP],[ST],[COUNTY],[CITY],[lat_dec],[long_dec],[avg_last_spring],[avg_first_fall],[spring10_36],[spring10_32],[spring10_28],[fall90_36],[fall90_32],[fall90_28],[free90_36],[free90_32],[free90_28]) VALUES ('900077','BC',NULL,'Nelson',4.948333300000000e+001,1.172833330000000e+002,'5/4','10/13',NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL,NULL)");
    
}